# Parser grammar

This is a user guide describing how to generate a secure binary rev. 2.1 based on a configuration file (a so called BD file or command file) and additional inputs like certificates, keys, binary files etc.

## Supported Syntax

The syntax is written in EBNF (Extended Backus Naur Form), however, the application uses (namely SLY - python implementation of Lex/Yacc) only BNF. From this perspective the graphs visualize the EBNF form with the grammar and the conversion into BNF as well as remarks what is supported.

**command_file:**

![command_file](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAY8AAAA5CAYAAADOfqc7AAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAEfxJREFUeNrtnQdYVEfXx%2F9LUVGaIFYi9o4KRETFBkqMvWHXF1vUIHaNGs1nEv0Syxt7iYXYojG2GGtsUWPE3mIliqCoKDaaoJR95wzuCrhLL8tyfs8Dl2UuM3fu%2FZ8558wMuwDDMAzDZBCFPnTCqSaU%2FCgZTVy4qR8aZztgXeoaRvryMM7%2F5cuKZJLxcdNBBa7PbAesy9zCgB8lo%2B%2FROEfkDOuSnQfDMAzDzoNhGIZh58EwDMOw82AYhmEYdh4MwzAMOw%2BGYRiGnQfDMAzDzoPRF15Hv0Ho83Ct5Y9DXuJtbFyW2njw8Bni4xP4ZjMZgnRJ%2BtTEm7exCHnyMkv1R71OXfvsPJh8wb6DF5IJ2f%2FOI3QfMAdxcTk76B44fAne43%2FUWt6133e48s%2B9TNefkKCEi%2FskPH8ZwQ85nw7gpM2krFp7EAuX787xtn0mrvygbRUXrwRI%2B8gKew6cw9jJa%2Fghs%2FPI38ycuxUBgSHq19bWZujZpQkMDBR8c5g8gzRJ2kyKY73KaNigOt8cPcaooHV4he8BNG5YAzt%2B98OdgBC0aeWAfj1bJEYql%2B%2FisUhzq1UphyPHr6C8rQ3aejjh7r0QrNlwWB4d6laE95C2MDMzSbOtiIhorFx3ELf%2FfQhL82Jo2rgWOnzaQJYF3n%2BKNesP4%2Fadh6hvXxGfD%2F4UlpbFZBlF4KvXHcL9B6GwKWGOrh0b4cnTVwiLiMKW7Sfxt99NuAjDrFnNFiHi9yrnER3zFqtEe2fP%2F4uypa0weEArVK9aTpYdPXEVRoaGuB8cioNHL6NsGStMGt0VVsVN033v9ooIj%2B6bqWkRjBnRARXtSmk8b9e%2BM9i9%2FxwMFAp079wEHm711WX3gp5g3eY%2FERoaJu9vr%2B6u%2BKiczQfTDavWHoJ7c3vUrP4RW2kOcOVaIDZvO4EXLyNhW9YafTyboUqlMurnvGvvGcTGxqFtayd4igBFxZkL%2Fti5%2B7TUdp1adujdrSm27vxbavOHJbvkOYP7t0LMm7fiOcYly5LXrD%2BEh49fwNmpKoZ6ecCkSCFZtujHPfBo6YAtO0%2Filn8w2rg74D993NLdl8jIGMxb%2FBsuiUyD6ib7NDI2%2FOC88PDXWC7s%2F7LIkqtULIPPBnoI7ZVIltkf%2BvOyyOTj4eJcHZ6dm3xQx7Wb93H85DV5%2FYWMjQq0hgpc5rF89QGMmrQK5cpYo1WLepizYCe2iwFROo%2BrAZg%2BaxNGTvgRT8Tg9uJVpIyqenjNRb06FTB%2BZCe8FMY2dPTSdLX1%2BfgVePjoOQb2dUN94XT2H7oof38%2F%2BBm69Z8tBkZbTPDpjKjXMRjkvVjtcDp4zkREZLQ0Wmsrc%2Fy08QiKW5rCyMAQpWwspeDNzYviZVgkFgvDUzF8zHJcux6E4YM%2BQY3q5dBtwGwEPXgqy44cv4ohPktwN%2FAJOrRpIB3n9Jk%2Fp%2Fu%2B0aBx4NAFtG5ZD8ZGhug1aJ7GdQ7fjYcxf%2Bnv6NHFFZ3bu%2BArcT9V95fuZYdes2Bd3AzdOjVCXHw8tu%2FyS%2Fb3VOeQkUuk46whnCOT%2FZAmew%2F%2BL5xEdtBLDP4WQksnTl1PnG4SQcuyVfvQXwRUXn3c5WC7edtfsuyPI5cwbNQyGey0Fxq6efsB%2FM7dFgGOhdQm6ZK%2BDIU%2BTooAhwIWIkgELN36f49qIpAhbV67EYTPRD0qFq%2FYi%2BFjl0knRo7ju%2FnbcUwM0OmFpscMDQzkNe3adxZzFu384ByaGqU%2Bhz4Lw6hh7WRQ1lFokZwnsWTlPnwv2qUxwV187f3jvNRgUq7fuo%2F%2FDF8Ie%2BE0C7rjKJCZB7H0v8NQu0Z5%2BTNFSBRNdxPRPVG5Ymn84jsBhoaJfnXyjPUY0KsFenZ1TUzH61ZCVccRMjugQTA1rt96gBmTm6CRcw35RdGdHGA3HJL1qV471a%2BMWs4j8UhEZQeOXJRZwcxpfWVZC9c6UviUXRQrVgQtmtVBQ6dq6sFYxb93H8Pv7C1c9VuIIoULwbVRLWHcwVi%2F%2BRimT%2BohzxnYzx1TxnWXP5cUTmjyjHXpvmfU5uK5n8mfKSL7uPl4%2BJ25jeautZM75zUH8MOsQTLLSjTaBCxYvkfe35VrD6Ljp87wEcZLuDWrK%2FumIi42HsNGLxP9t8b3M%2FpDoeDpuJyAAofChYzwiRioKQhxa2avHmAXrtiNvb9Og91HJeXvxkZ0xMZfj6N396ZYsGw3pk7wFIFBYkT%2BaWtH%2BTdWVqYiUzmbLENJysZfjons00FmJMTHjlVQr%2FEYmZGrMuM1S3yk7RHnLt6RWQRpPz18Ka6pe%2BfG8udSJS0wYdpaTB3fPdk5p87clGszu7%2FxkrZE9kjtbN91SgR37jII27J2onSMROd2DWXfLly%2BK1%2FTtQ78fDEWfDdYrW12HjqCQ23UM1CiK5SgUbyq%2BLJDLnzeSKUKpbH1t7%2FVr62tzNSOQw7KIt3e98cFdfSVKFBLkSpHp%2Bk8xvt0wvgvf8KchTvh5FAZg%2Fq1khnMbVEnRV87fn8fdVNmQTs7yLDtxTnJ0sN0rGmQI%2FnI1kY6DhU0%2FUYO5X097%2FtF0WasSM8zA90fmrIKefryg%2BkmcoCqAUF1DQH3Ep3cHeHgVEaetG8qBzJmyhq5c4sGkux2HOl4B1MqD6JHLlTnl6DAjkvXcUUf7aBRw%2BqoW7sC6ruORe1a5dFMDIbDB7XBa6E%2Fyqx7es1Ldn7VymXfBSiPxN%2FZZVibNFXp7FhV%2FZo0SlOWASILVmklaT00JZwhbSa5BHJAT0PDkgUlidfwFFUrlUnWTvWqZUUmHoLHQsdke5RRaOrbo5AX6DVwHrz6umW748gvutRJ5yECgGpxCixVJKCOuEubxa1aZJiAGxX8EbQViM%2BmB6CVFyKDKG6p3QlQtD%2FGu4Mc%2BDNKX8%2Fm6NqhEf65HoT9hy8Ko5yLSyfnw0zU6T20rTTYlJiKsmeZ2BpoZmoip7qSEhHxWtaXE1BblhbFkv3O2MhIpvPhot2SNhbqaTi6Ntk3cQwLf621zqYiW6J55xnfbcY3X%2FbJ1utN68N3PIVPDKwGu3gD0OjgJgbwA441cc1ICW%2Fhf%2F31yQ7oGa1bMVquo1FkTVNT9PP%2FTe4lnfbebdM1Bkb0HF9peH4KurVKZao2FJ5Sm5GkC83azErgEBEZI51PSqem%2BRpiYC7ONS1aRFy%2BUq6JFNewBkgOdcLozpg1b5tcL22QxBHquy5TI0%2FXPBxqwT1egdPi7h0Pi0WFizcx7uIt7Dnnj4D0GkxmCH9nADSwrdv0J9p5OGk9t00rR%2FhuOKLeL04iowGOpljSYsfu09JQaRFvxOA2cm0jJvotPNwdsPbno3LuWQUtYtMUmnuLutLR0II6QXvYDx9LDDQsLYqKzOSx5ntZr5I89%2BiJf9TG%2BdveM3BrXjdb7tmbN7Gy7wRlM8GPn6OxGPFSRmotm9lj45Zj6t9t%2BPWYuIbEaRF3cS20SPvqVZR8%2FexFOE6deZ8Z9ezmio2rx8o%2B0LpJbkJ6I92R%2FkiHpEfSJemTdKpPdvCPyHpv%2BT%2BUGTRtCPnEzUHO%2FZNzaOJSE3Pm71Bv%2FyYb%2BfOvRE2RNmkLrkr7NFVK6x7mZkXllBCdqwn3ZnXltJYquKH1jIioaDjWr5wt%2FYmJeauedqP1QVo3SYmr6Net28G4ej1Qvn76LAx%2FCDujKTtyGHQty9bsV59%2F%2Bry%2FPIeoXbO8DATnfuuFgd6LcUP0uSDoUmczD4q04pXYKsajAXRjcrPtcVN9ZaD08lWknNtMbWcHzfXSDqUW7abBytIUYZGv5ZSNR8v6abazbtNRTJv5M6qJtP%2BeSNG%2FmtRTCrV7p8YIehAK945fyTrDhSHZiTS%2BWZNacm1h7IgOaOv5LSyFUb4SUTwtuNNC3qD%2BrTD16w1ygZHmnTu3b6hui3auLJs3DKO%2FWA1b2xIIEml6x3bO6NTWOVvuGaX3zm4TZXbxKjwKS%2BZ%2BpnHH2azp%2FeA1YiFatp%2BGWDHIlLA2h%2B9Sn8RMrEdz3PQPRiOPL1DcvJi8l19P7p3s7yni3ew7Hp16%2F7%2FMbGidJi%2B4cwf0n2czHWvgsoiwtgq9uuREpJcXdkBBxrBR8%2BV6B%2BmGpmxWL%2FaWZYtmD4HPpFWo22S01N9L8ayHeX2Clk3tMX1iD4ycuBL1mo6BhWlRxLyNhe8SH9SzrwCXBtXg0noSjA0NseuXqcnaox2GtL7QpPVk2NmVRHDwM6HV4ShqUjhb%2BrNwxR4sW7Vf9qN8eRusWz76g3MoE5470wv9hsxHpYql8W%2FAIwzp31qufRCL5wyV623bdp2S07vFihbGtvVfJKuDgkwaM%2FoO%2FgG%2FbZ6iXhfSR11mcLYwdxEp9kFxOCHStpnZMW%2BY3o%2FfpIW6Tb7jULaUlYyULVJMvWiDdgFRam8lBjcSVnqhlDdSZBy0uyPpegQR%2BzYOIaGv5HpHyuklVXulbSxhXOi9j4%2BMipERXpnSxTW2R1EhzeGaFTNRb%2F3NLsg4aZpPU19SQmsftDZC0a22emh3TU4uiif9uM%2BsfGa00Nc0cWgm6vDQFzsggh8%2BlzZAGzRSQtkhZQeanhFpmvSZ8tnSWkORwsbSKWkiLCxKTh2l1HR2QFkCaV9TX5JlKSK7D30WLgMT1XRqynpIt2mtZ%2Bq7LnU286BFQSTA3iwaHfPKeRXPwP83qOaJk%2B4Jp73iKf8xKim0JZGyBWpHW1tkQEnrTK09FeRkUlvHoP3t2urUBA0SQ0Zp33pMO2pUu2TIaabXcaZmxBmpRxcQOp0XYQJv0m12LlbmtR3YlrPWWkaBh7bgQ5ueVetc2qBALb3BGrFzz2n8%2FOsJreWzvx6g3qFVsoRFuuqkoCc1%2B0hvPfqsS512HgYJ6Cb87aZjgYjJ7ba%2FndYH5UpbZ7ke2tK3bf0k5HdogNCHfuQkpFOnWtgkdYvsM9K8tIP8QJf2LvKLyV1dplu%2FedFpJdBIfDuaF213bOuc7dM5TAFA6FXqVk%2FsgGFd5kvnoYBcJLzOT57JL5BeSbdsB4y%2B61KnnYfAxiQST%2FjRM%2FmFd3q1YTtgCoAuddp5FPEL5nleJv%2FwTq9F2A6YAqBLnXYetD1NyY%2BeyUcokf1b29kOGF3UpU47D4ZhGCYfw86DYRiGYefBMAzDsPNgGIZhdBC9%2BTCopO8XwzAFFbYDhjOPDEBvLpaVNxhjGLYDhimAzoNhGIbJXfTqM8w56mIYtgOGMw%2BGYRiGnQfDMAzDzoNhGIZh58EwDMMwuu48%2BM3gmPxGTryJIdsBo4u61Gnn8aZFhbx5G2GGyQyNbKVeY9gOmAKgS512Hs%2BjTPPmA0wYJjNEm6KUOISyHTAFQJc67TwC4hLy5qMTGSYzGCpQWwn4sx0wBUCXuus8RGfPKxLgyo%2BeyTco4KYA%2FNgOGH3XZYacR8M6MvXRSlrlGTYaBfYqFOgB8H%2FCMrqPXJdQok%2BCAbazHTD5XZdZHc9Vf29I30pZI7ysDeqUL40TD58iKuXJaZVnlJBQBJUtiZHlbBDyKBQ3WAaMLmNdBpPFweTiDczLznrZDpi80GVmx3PnmuhSuiQOJSRgyuNnmGWUmPnIDMQzPh5dnGpip5EhfM5cw5P3mVHq5ZkgQdQ5TqnET%2FVr4PzlWwhkKTC6iGMNtBeHcYZKuORA9WwHTK7rMqPjOTmNeAUWxSthm3RTsMw8hBea8e41VVpbiHlMGRvYqzxTWuWZ6byItO6UKYlCBkosE8fzj0NxnyXB6ApVqqBwxVKYolBgjhjhPS%2FcxPmcaIftgMltXaZ3PFdlGsJfDBUvzZPWITKPr%2BVcq%2FA%2BSi0eKk4U7CQvlVp5VjIRpxroIypaIBcPldiSYIhzFlEIOBaYN3uXmYKJELhhYDXYxRug1rtFyN5Ck9eMlPA%2Beyvnd7OwHTC5pcu0xnsjBfbHAd%2BAMg0t0Ds3p%2Bo8SMjCNVUXR7NUy5UwEi2b8KNmGIbJn8jABcJJASbimKB8NzOlzXkYafFAp8QfPhTHVgnAanEcm1q5sRFmZ3ENhGEYhskFUiYLScdzcfyxiDF8Y2IxSCQGQ5QKhGnLQIw0VaJMrOSMsSFqklMQjY1NrZwfB8MwTP4ijfF8XMM6mB0bjy%2B0OZGkzmNrGk5hKzsNhmEYvSDN8fzd77Q6EZXziBaVBKfiFNIqZxiGYfIHGRrPUzoRkbEM51vIMAzDZIr%2FAYhM3fV%2BbCVtAAAAAElFTkSuQmCC)

```
command_file
         ::= pre_section_block* section_block*
```

Comments:

The options block, constants block, sources block and keyblob block must be defined prior to the section block. There may be multiple blocks in any order, but all must precede the section blocks.

```
# options, sources, keyblob & constants must precede section block, but there may be
# multiple definitions in any order
options {

}

sources {

}

keyblob (0) {

}

constants {

}

options {

}

# Section blocks must be the very last blocks defined
section (1) {

}

section (2) {

}
```

**pre_section_block:**

![pre_section_block](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAN0AAACpCAYAAACvdzjNAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAIABJREFUeNrtnQdYFFfXx%2F%2FLLr2riGIjEVDQqIgIqKiANYrGghFL7IkdW9QvMTHmjSbmTdPYxagYJVETNbF31Nh7AQSDDURUpHcWvnsv7AoIsvgiC%2Bz5PY%2FuMHfmzr0z53%2FPOXdmdwCCICoUSXXohJM9culSVi0uhVQP23sdZNWlIxdP%2FkKWXEVo4z5ao%2FuvRSZAqCs60dQIhURHECQ6giDREQRBoiMIEh1BECQ6giDREQRBoqvapKRm4GlsYonl0Y%2FjkJmV%2FT8d42HUM%2BTk0AM%2F5S46l%2BawfNVGpZVrioH%2F8deZQuv4358v3KK2Nu09cBF%2Bc9aWWN7HdyFuBT947fqzMrPh6jUb8QkppJRy0IFifyG6LDkeOdlja0mVllauCTx7noiP520otM6hSX14dHyHrFFDeF0dtLVHPycHPMyW4y7%2FWzx7KckTn49czgrtsUMmxZRzNxGj2Km08qpEcko61qw%2FgItX76BRg9r4cGQ3vNUo7xzuP3wZxkb6uHbzHk6fC4VD0wbwm%2BANQwNdbNvxD%2BQ5cvywbJfYdlC%2FDshgniApKU1Zd2RULNZuPIjbd6Lg%2BM7bGD%2B6O0xNDUXZ%2Bl%2BPoG0bW%2BzefxFXb9xFexd7TBzbE1paEuTm5mIrqz%2Fo1C1oa0thz8Q8Yogn9PV0VOrT3%2FsuYMfuszAxMcD0id6iX8Xx599nsYd5R6lUi7W%2FPbp0bqksi7j3GAGBx%2FD0WSIaNrCA78COqFvbrND%2B6RmZWLvhELp6tEJTu3oaJ7qy6oCLTS7BUnku6hd84K1QTpebJ0JeaWRxii6tvCowcsJS3L0fg8njesG6YW30HbwIj2PiRNk%2BJrpxfiuQkJiCPu%2B2xenzoZg7f6Moq13LlJ11CRrUqyX%2B6epp4zoT566950V5fHwK%2Bg5ZBHMzI%2FiN743Y50l4f9R3kMtzRPkvTHSjJv4MUyaM3j3aYP3mI0xop5RlG7cchU%2B%2Fdujm2QohtyPxKPq5Sv05ff42Dh27Kvbjj%2B0PZsfkYWFR1m44iGVr9mDwgA7o28sFn3z5K2v7OVEW%2Fm80vAcvhAXrY%2F8%2Bbshk%2B%2B%2F4u3AonZGZhdGTfsajx8%2FRxNZKoz1eaTpQeDY5G%2BfABVcEWSmVCkWXVl5VPN%2FV63dxOzwSv62bCRnzKO1cmgqvE7j9JKZP6iO2mTimJyZ%2F%2BK5YbtHMGj0GLsD3i0ajk3tzSCVaTBjti637D2akTW3rYRrzNBxX5yZo13UOTp0JQacOzcS6H1k97V3txfLdezG4fDWCicAdwaEPmedgoap7Xqjaq3sblfvUrm0TLP12nFge2Lc9WrtPx%2FnL4crjKFixbh9WfP8R3No2zQuVsrKx0n8%2F%2Br7rgjUbDmCAtxsmjcvrt1enFmLyRM7iIcW246b4s0HKEgs%2FG8rGHgmIYnQgwT423H1Z1LOpJDoFbIy%2Bylxhj9xSyrOzcZcdVL%2Byn6QI5uHetq4jBKegiU09%2FHs3%2BkUIUcCeGltbCq8RG5tUat3ce9raWBWoRwLbxlYibFOIjoeSCkyMDfA8LlksjxrmhbGTl6G521S0aWWD93q74D3mjcqKTKYFa%2BvaiM733AUngZ48TYCdbb0C%2Fc5rm8LTDRvUqfAMG2urPH95yuy1bP94bFzlV%2B6Cqw7fNOA6YGelV3YuBrLPUud6ZSXErqfZjlHsswur0J99Tn9VubYMixWezgeQ3rNDI7kWHNiGnmwbX7btTVkuJrFoLexNdFrVC2dkqIek5LRC6%2FjfRkbFjxfP45NF%2FmNqaoBnTHg893pV3c%2BKTN%2BLutn6khIEBc3tG%2BLM4cUICYvEuQth%2BL8Fm1CDhakd2zcre86anC5C3ILo6miLgYbnnzXNjcW6xAL9NjbSQ3xiyTOUnTs0x87d5%2FDlt1sxf8775XrtKsuXWVkAYJctwXLWmObsKgcyizoqzUGwdRjub0Pe%2BFPUzgrqgH2uZhnHL%2BksCmeOaGyuBAnFhZYv5XS8EvaxjVVgz%2F5FsrDR%2FnIIZpRWXjC05A1kdhNxORS7eVlCFqzZfkEsoTzr6AAvdZ5Y1zZ2Ilc6dylP%2B3HM0%2Bw%2BcAGeBWYgE5NS80YvNl4tX7tXGJyBvi5MjfWRxcKtB5HPiq3bs2MLHDxyVXgUzs2QB7gZ%2FADu7RxKbdeBI1eEIByaNBATKI3qWwjBq0J6WpZy%2BeTpYMQwj%2BTC%2BlnUA3Zq1wybfjueFxaxwWPz70EijFS0fcu2E0jIvzXA7%2F2dYSOkAh4Cb143AwcOX8HS1burXZjI7ZLbJ7dTbq%2Fcbrn9cjtWCE4VnZy%2Bjpv8UyqFLTvF29h2SWzjyFd5Ol4JV%2Bw5PoFWTI5WWnmx3LmDDPbxVeumIhTdxkYU1zfl8UqDz%2B4tWTwWH05ZgUaNLERexQ2Kz8YVnOHbvuuMmDjgs5r%2BSyeJ9XwWkk9CdOs3H4YGeljO8qNCI6WTLcaO6AoP73mwfdtKhKyLvxyBOpbmpbaLz5b6zfFH47fqCNE4sRCzV1cnlfoUHvEIzh6zoC2TISEpBcv%2B%2B2Gx3vXr%2BcPFJJKn92fIyMiCpYUZflk%2BRZR94OuB0PAouLIc1NzEEIkpafjykyGF9reoaYLA9TPx3uBFMDc1wvDBnauF4LiHYznYNiaSD7jQVNilVB3kr5vh0hyLs%2BSYU9TzSfLdZiqrZBWrZHFxlZRWXoYwcB776MhCim7lHV6W5eca%2BFMaMU%2FimfcyEEJU4DfXH3YsDxs9vAsSE1NhWWTKnMPv12lJtFDD3KjYunlIyW8mW9QygZ6ujsptSkvPFOGpsaE%2BzMwMy3wbJI55RlWOyT09D5mL6xvP%2FZ7HJaG%2BVc03OllS8Oca1B1eMts5yD5OsHZ8pcK2r6UDPrvJxcc6Op4dx0B4OuYe33pVJaWVq4pxGr5L0sckx2ZoeeUWrqnrROuwJJRP%2B5cEvz9W0j2yWjVMXt1HlicZG5V9Tokfr2CbYpnxf%2BS3ssTte3dvg5FDPZX5ZIm5YxGs6tYosYzfj%2BT%2FNAVuh8jBO8wu%2B6g0UfWaOijo%2BZThZWkVldftgOP3kO7kgC1aORjAo6rKdhGG%2BnSCiXHlmITlEx7bA2aDeHMIO5RgC7fLMojntVHsX%2FG%2FBpaLo8xFT6uU8T3LywjNgdmhmyQXP1W42Cv6gCxpvcViWzu65IS64XbI7bHai04%2FWbhYC7rkRCXAIt8eq7fozkSK%2BFmPrjdRCdDLt8fqLbq8UBr08B5RSSLMin8Mjb45ThAkOoIg0REEQaIjiKpLtXlVlqa%2FfokgT1eh8IdmNfklgwSJjiAITQgvFR6PLilBno4gCBIdQZDoCIJERxAEiY4gSHQEQZDoCIJERxBEUarFzfHq8Hv4hGpUhwcgqs0TKWX5sVmialJdHmqn8JKoclFNVY9sSHQEQaIjCBIdQRDVRHT0NRwCmmh%2FahOdW336wVlCfajT%2FtQmujQjWNKlJzTR%2FtQmOqkEzejSE5pof%2BrL6STwpEuvHvgbV%2FkbZUuCv601KzP7tevn7zR%2FGPVMvLe9Emd0nponulwM6WxdvfO6myEPcPnqv%2BVW3%2Fadp5GalvE%2F17NrzznM%2BL%2BSn%2BDp5fMfhN6Jev3QLT0Trl6zkZKSXimvi7A7Zn%2BaJzrgRpI%2BZlVn0e07dAnbdp0ut%2FpmfrYez58nk6v%2BH8m3uxvqOr7anr2U5mKyXIKzrZvi6uVQ7K6o4%2FKwKeD348IDGRnpw6tTC3TzbCXKArefxMGjV6Cvp4vBAzqgY%2Fu8sP9W6AOEhkXBzNQQv%2F1xEjKZFNMmeKOJbT1Rfvd%2BDNb%2FegSPn8TD0sIM%2Fb1dUbOmCc5dCBOj%2Fg%2FLdsGU7TtmeBfs3n8BR0%2FcQHxCCixrm7HjuKNlc2tRz%2BHj16Cnq42IezFiuZ5VTcye2g%2Fm5kb4468zyGXhmn%2FAQZgYG6Ara3Nz%2B4asPadw4vQt8R71Zk0b4IMhHqwOHZXOxU7m8f7aex6mJgaYPqkvGtavVaKH3Xf4MrS1pRjUrz08O7ZQlt2JiEZA4DHEPk%2BCdaPa8B3QETVqGBXan3tn%2F42H0KNLa9jZWKlVcMzeerOPGcz%2BXJn93dYoT3c%2BFGE5EvhIJAhwssc8GxtUyBvmx05djmPM6Af0bSeMdIX%2FPrGeC2PjlqMYPtiDGYcj%2FOb640jQ9TzRhTzEzHnr8ceuM%2Bjm0UoIY8zkZcpQqu%2FgRWjYwALDBnViQqmBw0FMPHraMDbWh6GhHhrUq4W6luZi%2B%2BiYeDi2eBtjP%2Bgq1g0a8a0yvzp07Jqo9%2F7Dp%2FDu4Yyw8Ch88c1vosyCiZhTt04NUZ8Rq3fNhoPYvC0I7%2FfvIAaOG8H3EfM0QaXzcOJMMI6dvIHuXo4i9%2FId%2FR2ys3Ne2o6fn1XrD8B3oDt6d2%2BD2Z9vxJ6Dl0QZH4j6Dlkk2tS%2FjxsTV6YQckHSMzIxcsJSPH2WqFbBcfvidsbtjdsdtz%2BN83ScK8E40rYpXLMlWG6qjUmt7RHI30kuzUGwdRjubwPk5Xm867fu4fzlcFw%2B8QPzZnneYNj7nSGX5wgD3r5pjvAenITEVKxct194Qo5rGzus%2BOEjsdyVCa%2BZ6xTExSUjPjEFiSlpeLerE6zq1lB6R44DE%2FVzto0P8w4Kxo3oKoTKPYRzaxvhbUNCI%2BHezkGUj2FinO3XTyzXrGmMzxcGimVer0RLgl7d2qB%2BvZpiXXDoQzjYNUDnDs3zcjEmClXp6OaAJd%2BMFcsDvN3Q0n0aLl27Axcnu0ITIqvYOVi3fDJra9772NPTs9h52cfa4cTEuB%2Fv9%2BuACWN6iDJ%2BrriAudA4GVlZmDBjFZqyiODLTys2hfJhwdQ9OzSSa8GBT5pIAN9clmbLmIe7FKI%2BwalddAqPx%2B3YsRlaauWiP1uemiOFbYQ9GjmV81MD4f9Gw7ZxXaXghKtnhvyYeZ%2Bk5LRCIzEPHXnYqAyHtV4EBSYsHBOhqlyOtxpZwod5zfbd5op93FyaYsLoHqhtYVpsG75dsgObfw9CCxZS1mKi4gYqz3nhYaTSAsdhYWR2dsnjzqhhXvjQbwVauPnBybExC2vd4N3TuexGwMLGRvUt2HmIK7Q%2BkQ08sXFJaGJTT7nOztZKhL955%2FMRG0S6FQ6dtF5csokzVouw89e108vdbkr7pkFE3sse77PWhDMrOsO8W48rt3CtMuSUleb7dPkn5NqbuAAKeEiWkJD60noeAkpY3MGFV9PcOC%2FZZst8e1X4739G4tOZPrh49Q4LUY9h8sdrsHXDx0pvoSDk9kOsCziEUwe%2FUYaLXfvOf%2B1z1uqdt3DuyLcICYvE2Qu38fFnG4SQ3Vj4UObJheR0mJkUzsX0DXRZ%2FqqFxKQ05UCTxJaNjfLOizHz0gksNy0J7vm27vgHi77fjk9mDixXe6nKX2bVqAeeeYjIR%2FNDx66Kv3koxCc2uPHwUO%2FX346L9Tzc3Lw1CJ6dWpRa5%2F3Ipzh3KQxmZobo0rklfN5rJ0JKjpmJIf69%2B1i5bWaWXISIOjKp%2BPvqjbuIeRKvcvvNjA1x52608u%2F9hy8jmYnFoUkDjBzixcLOWspjl0Z6RpZymed28QnJcHayKbQNn5xp72qPX7ceV56vX%2Fl5yZ9I8WKfm5jX5kLkPGH55NmLLyK3IQM7Yov%2FDPy977wI1YlK5ukqAj6DuOqnCZjxyS%2FQ1w0UuZgj8xa9ezjjh0WjMWL8Evy9%2FyJS2Pq3rC0xc3LfUuvkM4p%2Bs%2F2Zq81FrRomePIsQZkr8Xr9Nx2CU6eZrMwY%2B%2F%2BcDw%2F3d%2BDiNVtMsrxtXQd6%2Bjoqt%2F%2FDUd3w4dTlYjbTb7w37j14gmlz16Hx23VEiMwHle6ejirVFXo7Es4es6AtkyExORUrvvsIBvovz2UtXjACIycsEQNVWlqWyFu%2FmT88P7ztgjAWYrb1%2BhjmbIBJYudt4WfDgGaNlPvzGdot62biPd%2Bvxewvn5DRdNTionk4WJ7hAa%2BvrD%2FXEBkVy0RoILxc0fU6ujLUrmVapvq4B81i%2BVd9q5oiVFXAvUNUdKzI8XR1tJXbarHcrazHEBM8LJzLyMpW7ssnZZ7FJsKE9YMPKmUhOSUdcfHJhdpWElGPYqHNPF9xuaqiHj6r%2BiYp%2BHMN5WE%2F5W2H5OlKQTEDqOr60qiTf0vgpfidhZNFjbGkbVX11oXyLj2dQvXzEG%2FizNUl7t%2F33bYYPrizMsdVNW%2Fl9wxflSurWg%2BhwaKrrnBPtD1gNp0ImkghCIJERxAkOoIg0REEQaIjCBIdQRAkOoIg0REEQaIjCPVRbZ5IqS6vUSLI01UJ%2BEOr1eFlgQSJjiAICi9L93h0SQnydARBkOgIgkRHECQ6giBIdARBoiMIgkRHECQ6giCKUi1ujqv6s%2BpE5UMTH2ioNk%2BklPXHZgn1o6kPqVN4Sag9StG0SIVERxAkOoIg0REEUU1ER1%2FDIaCJ9qc20bnVB73mhYAm2p%2FaRJdmBEu69IQm2p%2FaRCeVoBldekIT7U99OZ0EnnTpy4eU1Aw8jU0ssTz6cRyyMrNfu%2F7c3Fw8jHom3ipbjTI6T80TXS6GdLamvK482L3%2FAqbPXVdiee%2F3v8Kt2w9fu%2F7MrGy4es1GYmJqtThfwu6Y%2FWme6IAbSfqYRZIhKpp8u7uhruOr7dlLaS4myyU427oprl4Oxe6KOu61m%2FcQuP0Ensclo75VTQzx6Qibt%2BuKssDtJ3Hw6BXo6%2Bli8IAO6Ng%2BL%2By%2Fev2uCK%2B8ezorR%2F5lq%2Fdgyoe9oK0jw5ZtJ9DWyRYPIp%2BKbd%2Fr7YK3retg%2F%2BHLrL6ryGLbuzg3gc977aCro43rt%2B5h02%2FHERUdi7at7TB%2BTHfo6eqIMO73P08h6J9b0NGWwaFpA4wY4iHKVOGvveexc885mJoYYNqkPmhU36LY7f746wz2HrwEmUyKQf3aw6tTC2XZv3cfIyDwGJ6xcLVRw9rwHeguXqlcaBIiPRNrNx5Ed09HNLGtV6UEx%2BytN%2FuYwezPldnfbY3ydOdDEZYjgY9EggAne8yzsYHumz5m1KNY%2BI75Hk4tGzNRuQvjPHH6lij7YdkubNxyFMMHe6BHF0f4zfXHkaDrouzK9Qj8ve%2B8sp6MjCx8z7bPzJaLv7cwEQ8b9yPb%2FxiSUtKRzspXrz%2BAr%2F67DZ4d30EXj5bYf%2Bgy7t6LwZVrERgzeRk6uNlj2oQ%2BCA59gDmfB4h6%2FAMOCzFyIXTzbIVbIQ9EPqYKp86FiPZ293IUDzL6jvwO2Vnyl7bj7Vrhv1cMKn3YIPJ%2FCzaxvl0QZWF3HqGP70JY1jZD%2Fz5uSGfi2rH7bKH9MzKzMGriUjyOiYedjVWVERu3L25n3N643XH70zhPJ4w5GEfaNoVrtgTLTbUxqbU9ApnFHJXmINg6DPe3AfLyPN6diMfM08iEYZowwXFBcOTyHKzZcBDbN81Bc%2FuGYl0Cy19WrttfyAu8iolje%2BIDXw9lfQOGL8am1dPQxtFGrOv7rouYiBg3dTlmTOor%2Fua8ZW2Jtp1n4fuFo4UAm9rVh4d7Xrt6dW%2Bjct86uNhjyeKxYnlAn3ZwdJ%2BGC1fC4cZOcEFW%2Bu%2FDqiUT4drGLl9E2ayf%2B4QX54L06dtO9IXD%2B87bnJWdNwmTyT6nTF4rIoOv5g2t1CLzYcHUPTs0kmvBgU%2BaSNg4xAajmzLm4S6FqE9wahedwuOxj66OzdBSKxf92fLUHClsI%2BzRyKmcnxpwc2mCFs2s0arDdDRzaIiO7RwwfnQPpDDvlJScVmjk5mHT3fsxKtddMAR78jRBTDq0aG5dOKzQYvFMeBQuX%2F0XS1b%2BrVzPPUt6RiZGDfMSonzHbSqcWtmgn7eLUpxluqgyLREaRjNvVCiXYX3ks5xNGhfspxUi7uX1MzziEUb4er7UZgWTZ60RYWfAar9yt4Py%2FqZBBER991nrw5kVnWHerceVW7hWGQaESvN9uvwTcu1NXjCeJ21c5YeYJ%2FG4xAx%2F5S%2F7xfL8uYMhYXEHN8qa5sZKAzUyfDG5mpWtutM1NNAV9cUnpKB2rcL5kLGRPuZO74%2FePZxf2o8PCGcPf4uQsEicuxCGOfMDRHs6uDmU%2BZwks%2FabmRoWWqfH8kmZthSJKWkwNzcS6xKTWD%2BN8vppbKjPPHxKiXVyD%2Fwnywd52PzZ7EHlev016cusGvXA843g%2BwgNixKe5d1uTmIigE%2BocCE4t7bBryyfUoSHm7cGwTM%2FtOReLPj2Q6SmZYhwa%2Bfuc688Dg9deX08PFV69EvhLA%2BKE6HtChbixcfnGXd2dg72HLwklg8cucLEkg6HJnwCxRMN61mI9qkCz78UBJ26hWfPk%2BCSH0Iq4JM%2BHZmAFf3kEzebfw%2BCV8e8fvL%2B8n4rbg1wr3jmwou5Bl%2BWB29eNwP7WHuXrdlL06BV3dNVBFw0H039UYhCX09H3FT2%2F3lS3kTKotEYMX4J%2Ft5%2FkYWbaSLXmjm5b15u07kFlq%2FdC6dOM6EtlaInE2xp%2FMTyq%2FF%2BK%2BHIQlnuXfgM5NYNH2PyuHfx%2BEkcXLvMRg0zI8Qxz9KGhZK9WJ185tNvjj8av1WHbRMvZkR7dmmtUt9u34mCs8csaMtkSEhKwfLvPhIetyhfz%2F8AIycuFZMufEKoDhuA1i2bIspGMqGHsfDXhbXN3MRQeMSiuRv33IHrZ6Lv4EUwMzPEsEGdSEVlRC0unYeD5RlO8PrK8nMNkVGxIlexqluj2DIdXdlLYSH3CpGPYmHCvKJpkbDtVXBvwSJN1KphUmg9n3bn%2BZFFLZNCtwQU63mox426TCEly03j4pNfqrM4HkU%2Fh1SqJbx%2BSfU0qFfrjdpBwZ9rUEd4Wd52SJ7uFdSvV7PMZTxHex0jtKhpUux67mmLq6%2Foei7aCdNXlVi%2Fd482IhTl8By0YB76KoobcBSUpR6CRFft4KLdHjCbTgRNpBAEQaIjCBIdQRAkOoIg0REEiY4gCBIdQZDoCIIg0RFE1aHaPJGiqa9dIsjTqQX%2B0KomvlyQINERBKFJ4aXC49ElJcjTEQRBoiMIEh1BkOgIgiDREQSJjiAIEh1BkOgIgihKtbg5Xt6%2Fg09UHJr4QEO1eSKlLD82S1QONPUhdQovCbVHKZoWqZDoCIJERxAkOoIgqoHoeAxPX8Mh1Ikk3w41RnTpbvVBr4Uh1Ea%2B%2FaVrkuiephnBki49oS7y7e%2BpxoiO%2BfQwqQTN6NIT6oLbH7dDjREdC6bPsP881XFs%2Ft7vzKzscq2Tvz88ISGl2DL%2BjvKHUc%2FEm1xLg7%2FrO07Fd4wXhb899dnzxBLL%2BZtXszJfv9%2B8%2Far2o4pkdJ7CDjVFdDla%2BIO5uyGdrSs%2Br%2Bs%2F9Bvxbu%2Fy5KeVf2HZ2uJffM%2FF6Oo1G1nZ8lLrWb3hAL5duuO12rBz91l8PG9DieU9%2Bi9A%2BN3o1%2B4jFzXvR2paZpXXm7A7Zn%2FCDjVFdFdu4Rr7uJGkj1kU6BAVTb7d3ci3wwpHbc9eSnMxWS7B2dZNcfVyKHarJbdkodL6zUdgb1cfbm2bilBw89YgHDt5AzKZFL4D3eHh%2Fg7uRz7Fnv0XMXFsT%2BW%2B9x48weHj1zD2g67ib%2B7J%2FAMOIejUTTR%2Bqw6mT%2BwDU1PDl46ZncW223QI%2F5wNRa2axhg51Astm1u%2FiALkOdj023EcOnYVDRtYYNpEb9SqYaJyn3Ywj%2FfX3vMwNzPC9El9SnxP%2BrYd%2F2Df4cvQ0ZHh%2Ff4dRD8VhP8bzdpwDLHPk2DdqDaGDOwIExODQvunpmXAf%2BMh9OzqBNvGdauM4Ji99WYfM5j9uaqrDWq7OX4%2BFGE5EvhIJAhwssc8GxvoVrTg5n6xCUeDbqB1q8Zi3SdfbsKRoOv4cFR39OvtipmfrsfZi2GoU9sMK9ftw7lLL%2FLulev2izxJQeC2E4h8FIs%2BPdsiJCwKU2avLfa4Mz9bj5OngzFuRFc4t7bFkLHfI%2Fj2Q2X5H3%2BdQWh4JLx7OOPBw6f4aOoKlft0%2FORNBP1zCz26tEY2GwSGjPkBcibiovy8eg%2FWbDiIoYM6oXf3NpjFwtJ9hy6LshDWlveGLoJV3Rro5%2B2KlNQM7GIiLkh6RiY%2B%2BGiJEGVVERy3L25n3N643XH7U1db1PotgyvBOMIcjGu2BMtNtTGptT0CWax9VJqDYOsw3N8GyN%2FUsT9fGMhEE4tfVkyBjrYMT54mYOeec7h66kfo6eqIbW6HR2EXW%2Bfaxo55vY4I2HIMLk52SEpKE%2BsP7lygrO8DXw98OstHLHOv6dpl9kuTIspjnPgR5uZGYt3d%2BzFYF3AY3y8cJf726dceCz8bJpa9OrdEqw7TEBkVi%2Fr1apaeq7g3x09fj8nLXdmg0YLte%2BV6BNo42hQabHjuGLDSTznYcGGt%2BmU%2F81qtxWDCPdv40T1EWRfWBh4BpKTm3dLKyMjC5I9Xo7lDQ3wxd3ClFRm7EtJ7dmgk14JD%2FqSJby5wU8Y83KUQ9QlO7aJTeDz20dWxGVpq5aI%2FW56aI4VthD0aOb2hp1a%2B%2B3knrt%2B6hwtHvxOC49yJiEZaeiY6vzuv0LZdPFqKz%2BGDO4uyp7GJInxzdW6ChvWLD924QHR1tBHzNB6WFmaFQlIeKioEx2liUw%2BbtwUVW08Ntp25qRGiY56rJLqCaLOwsSELLaMfxxVaHxefIgYDWxurF22wrYeIe4%2BV54ELrVA4pPXiMoyfvlLsv8V%2FZrlek%2FL%2BpkFE3tMm91nLw5kVnWHerYe6crhKJ7oikyvXKuKC2TGDM9DXxdQ5a%2BH%2F82RIpVowMtKDsZE%2BzhxeDInkZa3z3Mi9nYMII7fvOo2v5g0tsf6MzCyW42XD1KRwTsePkZKSLryN4hiJyakwMtQvth7uYXjuZGZq9NozjmZF8koDAx3R3%2BTkdNFfMbHAPLeRYd5EsiH7TExKLbHOrkyQv%2F15Eot%2F%2FBNzpvcvt%2BuvSV9m1cgHnnneteqn8UhISMWMT38RInBo0hDGzOBW%2BO97EQ4%2BS8CZC7eVf48c6omlq3aLkZ8LsCDcSyrYsPkomts3RN065oW24V7N1NQAO3afU%2BZG23dKxyltAAACPklEQVSehlenFsXWE%2FjHCVGHzdt1VOpXwX15bsrF5OxkU2gbHjrz8HfT78eVwv51axA889vAvVxA4HEkJaeJv2OexIu8VsEQlgduXjsDf%2B4%2Bg9XrD9BUaFX2dBUNN74NK6ei%2F%2FDF%2BOLr37DgE1%2BsXzGV5StrsWb9QRga6CKBeaEFc30B57x9OrVvJmbxRg31eskb7j14CQeOXBHrpUyUAaunvzxjyzzMiu%2FG46PpK1ged0hMxHTs0EyErgqCTt6Es8csVocWsuVy1ka%2FYj1vcQSHPBT7astkwoOu%2BmG8Mj8tyLf%2FGYFRE5aK9qalZYrQ9b9fjhBlY4Z3RdidR2jr%2BTHMmadOSknD1%2FOHc1%2Bv3L%2BOpTkC181EvyHfCE%2FKZz8J1akWLp2Hl%2BX5cw08b%2BNT%2B0U91b93H6P3%2B1%2Fh4vHvhSiLwnOd5NR0WNWpIQRWEnxG8dHj56wOPZG3FYXfUE9knqauZQ3IZGULRriHimf717YwFXnlq4h6FAttltPybYsLTePik0u85VAeFPy5Bk0KL2U07ryMRc3i74vxafZB77UvVnAcPkFibl56%2FsUF%2BSpj5vf3Ct7j44%2BucQ9cEv28XTDUp5NY5nmaIlcrjXpWJU%2FO8BxPkecRJDq10cHVHm2dbCv8uDyc2x4wmy4AiU7z8O7pTCeB%2BJ%2Bhn2sgCBIdQZDoCIIg0REEiY4gCBIdQZDoCIIg0RFExVNtbo5r6muXiKqHtDp0IvoZFvB%2FVhb4gi5p1b2GFF4SBEEQRHXg%2FwExG%2BbPNkzHHgAAAABJRU5ErkJggg%3D%3D)

```
pre_section_block
         ::= options_block
           | constants_block
           | sources_block
           | keyblob_block
```

referenced by:

* command_file

**options_block:**

![options_block](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXsAAABHCAYAAADm8edpAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAFM1JREFUeNrtnQl8Tccex393yc2ekAVNaBCJJNZIROxLra2lsZSqUnm2olVL0VevRZWiKEpVPdtrldhqrS5aKpYQERIJEUmQ2LLv6733zZzIlRCy3SXJ%2FX99jnPPmXNmJjPz%2F89%2F%2FmfOHIAgCIKo9YioCAh9x8MVSioFzXI5nHSNrpFSERAEEHhmKxWChvDs6kuFUA0QUxEQBKGN0RONoEjZEwRBEKTsCYIgCFL2BEEQBCl7giAIgpQ9QRAEKXuCIAiClD1BEARByp4giOpIRmYOEpPTy319eno27sUlCHuClD1BEC8hMysX%2Bw%2BfL3GOH3%2F25S6t52XfL%2Bcw%2F%2FOd5bqW57F9rznwnboe%2F9tziiqyBkPLJRCEFkhISsPHC7Zj2OCOqnNuzRvCqq5Ztc73NxuPYPM3U9GtcwuqRFL2BKE%2FcBfI5m2%2FITA4Eg6N6mHSe33RxKG%2BEHbizyCYmxnjamgMzgXcgJtLI8x4fxBMTQyx9%2BBZyBVyrP72kHDtWz5dkJtXUMI1EhuXiB92%2FI6bkXFwb9UUU3z7wdLSVAjb9uNJeHk64eiJQASHRKNzB1dMnTAAYnH51hc78uslHDhyXogvn6VbnPjENOFvCgm7g2ZNX8GU8f3R0N4ah44HIO5%2BIk6evobAK5GYNL4fzEyNqBHUUMiNQxAV4L331yH6ziNMn%2FgGGr9aD0NGLcXDR8lC2K9M2U%2BcsRGpaZkY%2FLoXzl28gfmf7xDC6tlYAiIRGtnbCJuhkQGusU7h0PGLQnhKSiaGjF6KunXMMGPKQCQmpWPk%2BK8hlyuE8K1M2Y%2Bfuh6WFiYY2N8T2346Cb%2BD%2FuXK8497TuGLlX7svvbo3b11CX8972z438DTnTVtCOrZWmL42OVCh2BjZcGyLIItyzvPs0RC6oIse4LQA4KvRePmrVjs%2Fu9sSA0k6NTBRbCyf953BjOnDRaumfqvAZg%2B6XXhd%2BsWjdF%2F%2BCKsWuqL7l1bQiISY4RP51Lj3s%2Bsbhcne3w0dZBw7N2%2BOTr1mQf%2F8%2BHo3qXQhbKGxdPZ21X4HR3zCEHBURg1rGuZ%2BV73%2FTGsWDwOPbq0FI4TEtNxNiBc%2BL330Fm4t24ijBI4Xh5OOHQsQBi58LQM2N%2FZv7e7YPETpOwJQue4t0AbsRJDoQR3ijuxzQFq%2Fl5DFLPomzZuICj6Ipo3s8ft6AeqY1GxFB0b1xcs5MTEsme%2B8NGCUzO7YvGI4ORoh6iYhyplX9xlY2FugqTkjDLjTc%2FIFlwxvOMpjYjI%2B%2FjrTAi8X5tb4nxObr5G6qkcK1%2Fy8Dtsu8Vq77xChANXruMqtXBS9oSe4%2BUC5wIRNogUaMm0xM9MVayTKBDWOAJ39gJyNSkgAe6v5srzWWVqZmZc6vVJKRmC68PS0kSwppVK5UvjTkhMez7uF%2FnIy9mNyWRSoZNIz8wu9WEwj3%2FI6174auFYrdRXWR8xGQFIYpzhIBfDjR32Yh34iXauCJUqMe3iDURQi6885IQjaq4174bX5CJcYNrjdGo%2BGgeFY1bQDRy9FIGo8ir6iuDt6Yz7D5IQcLlQ5yQzy%2Frob5fQq1sr1TVp6VnCXqFQYsMPxwXXiYmxISzNjZFfIMfd2IRS4%2B7VrTV%2BPxmMx%2FGpwnFo%2BF2Eht1F105uVcqzocwArVs2ht%2BBQv9%2BWloWzj1x4XD6veYuPDe4fuOu6tyloFt48DBZJ3XK643XH69HXp%2B8Xnn98nrm9U2tnix7Qg8terkSe5mxPJYrBm2kaWFhgrXLJ2DSBxvh4GAr%2BM25z7xPz7aqaw4cuYB9h84jNy9fmKWzZd004TyfBTNqWBf09fkcpiZG2LBqcsm%2Fx8MJE8b1Qc9BC%2BDU1E5wDS1fPA4N6tetcr6%2FXDAGYyavwa69%2F0BeoECbVk1gZGQghLVv54RP54zAW%2B%2BthKWZCbKyc4W%2Fc9eW2dWiniMjkct2S9q5IJhZpntZvXuThV856LuQRI3EwxW%2Fs90%2Fl8OxRA1xKSvyWcK8%2FAI8epzCrHUTQTEWMWP%2BFjg72sH33d6CBV2%2FXp3n7uXz7cUi8Qvn13PXTUpqJmxtLGBkKFNbefHOh48a%2BGwbbu0%2FCx%2BJxD1IhIWZsWq6p7oo%2FlnCqnyLltXTArbrxuLoSxJAlj2hD%2B6bFmgDBVqZZ2OwLtKXGUiFqYgvwthIJmylwaczvgw%2BT9%2F8Bc8ASuO0%2F3Ws33zsheHzPvIRrHeu4F%2BWZ%2B7Xf1l4dYDV99fpxpjG658e2pKyJ%2FQAsQLDmH2461QMcqpTvt4Z0R0W5sZaTZPP1CmarVPb4fXt4YZdQv2DlD0pe6LWowQ6ipT4prrli%2FvdCY1X%2Fl%2Bs%2Fj%2BigqiEkURFQNQ0RBAezl6nktA%2FeL3z%2BqeSIGVP6Ae2xhl4RMWgfzypd1sqCVL2hH5gdD62evnrCe3wpN5pNTZS9oSewKfvKakY9BIlaMo4KXuCIAiClD1BEAQpe4IgCIKUPUEQBFGDoZeqCAIl128hCLLsCaIWwhfnqsoCXQRBlv0LKO%2FHIoiSCkmT8SsDJxnsO39hRlhE8tibt1OdklLzDOOTcspM07quYYGpsUGKjZXh6ci72cv%2BDsi6TLVF1HRqozzozI1TkSVlycWgWRfDH9s93v9o7S8rI6LTTAf2aoQ3p7yKBvVMUM%2B67HdXHifmSB8%2BzrLxD3w87E7c3SGDe5gExiVkjbkcitvUoRI1kdoqDxJdJGpni4WTfIdQqyonm7cdEsqMbw8SsEht1otyodjNKtFv%2Ffbwj%2Fv1aChbMrsdvN1tUd%2FWGKYm5bMD%2BHX8%2BvZtbDByYBOxQomGIeHJk%2BrZiILuP1ZGaqr9qLMciJqFpuq%2FpspDeSGfvR7jt27%2Fnq17bg1ftaA9xvo4QmZQtebA7%2BfxbFjsbWQiEx3xdAM99SRIHqqJPJCy1%2BOh6pbdEcNX%2FtsTrZrXVWvcPL5vF3lLpFLxFndS%2BATJQ7WQB1L2egh%2F%2BHT05L2VY5jVoe6GXbyBjx7SVCSF6Htm0QygUidIHnQrD6Ts9RA%2ByyDyTrrpqIFNNJrO5LebQyYTSxVK7PFoCUd1yifVot6i9kXwaoE8kLInSifsVvK4%2Ft3tq%2ByTLAsev1cbWy6dUsjxtRqjzu3RmJa51Uc6NhTqPYfkgZQ9UQ5uRqU5dvGsr5W0%2Bnaz4zv%2BYdYuwofC1UNiphl9wEIfyTYDb7jxJA%2Bk7InyaMqkXCP7BiZaScutWZ2iwffjJx%2BKVgdRBQr6NJ0%2BIhGhhRKIIHkgZU%2BUg6S0XJG1pWGl7r3%2FOAf3HmQhK0derusb1lcJkRnb%2Bqgj%2F0zYA0UKdKGa1ENE6CUCzutKHh4mFLb%2FjKyCSqWlCXkoL8KbAh1aon5A6Iu%2F6VlWuKb5658Q%2FLDjd0THPIKJiSH69mqL6ZPegJmpkSp845Zfhd9GhgZo5eYA37G9ERXzECvX%2FvLCeFd%2BMQ4f%2F2eH6njOh2%2FC27PQYAwKvo0NLM7r4Xchk0nRtZMbZrw%2FCPVsLIXwUHZ%2B4bLdaN3CAZ%2FNG%2Fk0znUH4d66KXr3KByh%2FX0mBJu3F%2BbdyMgALs4N8ZZPF%2FTq1kpn8qKQKyGWVOxl0YiYDLw7%2ByKi7mYKx5uWtMOwfvZlWxNP0lEqYSVS0xvbShGOMStlHfu5GPSwVm%2Fgz2nSlRitEKO%2FruRh5IcBCLuVBim73ndEE3w5u0XFrOtKyENV9W%2FR%2FYJlny%2FHfQ9X%2BPGTpV1cVrgm2ffLOUydvQlvvtEBe3fOxeqlvrh2PQYj31uJvPzC3jU%2BIRVJyemYPX0wxo3uiYjb9zF45BLYN7AWzvHtzYEdBAVedMw3u1essGaZLy5duYVpEwegTcvGQnxnL4Rj5Piv0cHDCXu2z8HmtVORmprF4vwSKSmFyi4tLQsxdx9h9wF%2FhITdUeX35q04PIpPEX6f9r%2BO92dtwtCB3vDbMRcbVk2GK1P2h44H1DhBW70lQlD0owY2wi%2BbOqF7e5sKGmSCJaOW9nMlDH%2BzCMWebtodBhO6Jd0Yc9gu5Mp1XNVVHtYuaIMfV3vB0sIAm3dHITwyrZIDlPLLQ2X1r5crfDzccK9AjmiVZS8qdOeMkMtZoCsOSiX4oHhPUla4psjPK8CSlX5Y%2Btm7GDrIWzjXyN4G2zZ%2BiO4DPsX%2BQ%2Bfx9vCuhWMiMyN09HIRfvfs2hotO36A29EP0b1LYc9rYmIEiUSsuqYIHh%2BnQb06MDaSCb8XL9%2BDDya%2FgUnj%2B6muW79yIt4cvQyb2Qhj7gwf4ZylhQnGvt0Ty1bvw64ts5%2FL%2Fx%2BngtGHWfgjfDqrzrVweRUFBYoaJ2iPk3KF%2FaRRTdCquWVlo1HX8hwK1iZnMetoW1sXBAbfQAypwtpNOxcMZLtZEiW8dZmPtm6FPvdu7W1x8Hdm2CXmwrUZNCoPFdW%2FXMnLRVjHBiwNi497S%2FjslYXKn0caW1pPUla4url%2B4x5S0rMwqJ9nifOGMgO83tcDp8%2BGlt5JFBSwjkIOQyODCqeZkJQmuGh8BpVsUyKRSBhdnPYvmeaEsX0QfjMW5y%2FeeC4uFyd7%2FHM2DH%2BeuoqMzKezxaTSmveopMhHaWFmUC3yExiGX5WsQTNpOdPODV1JHdZOmjWDIdM1C5j47WQ9%2FAgmZhHVIV%2FmZtIScqENytK%2FRZa8HDgAruifQVpGpEJPUla4piz9xwmpsKpjBgPZ89nklvjVkOinyigjR1C4mVm52LHrL7g426O9e8W73ISEwmFZA9s6z6dZvy7iE0sO20yMDTFjyiAsXb0fR3Z%2FWiJs1LBuuHMvHjPmbxHcP45NGjzn%2B6%2FOyJlpEB2biX8uJeDajVR0ameNV%2B1Mqk3%2BgsKw1MMFMSIl9rdzRSDb71FIcMkyE1GnYtQ7F5vQDiOYtRvjDAe5GG5PHsa%2BzfRNqJRZ9JfDq4ei5%2FDnVT8fvocNO2%2FDpq4hnBubMV0l07bSL9S%2FIvzKupzFz1ry5VL2qrEyEMxs0P7KMsKZIR3NEjVW9x%2FFH8BmMotYycbr3LIu4b9j501Nn75Xc%2F9BElZ9exgymQQdPJzxL2Zxc7dNReHuHk5aZjasZeYl08zIVj0ULs6Yt7pj87bfcOLPoJKFyyz4T%2BeMELaIyPvCiGHbTyfx7sQ1%2BO3gwkqViTa%2FBcCHqB2H%2F104bPWywU%2BrvSCq4iLAmso%2Fy9YA9t8AsULw7fJ0iBpI1NP6LF63DeQi3KxOdcoNn5%2FXemH0zIsYNPEsRgxoiI2L3bUqD1z%2FsrJ5o0CJ4WyvKCsi6QsE5xy7MY7te7MIt7D9zJeFG0ixvCKWfXn%2FwJauryIvrwBBwVHwcC%2F5dvGZc2Ho2bWl6tjZyQ77ds6tciU2srcWrG4eP3fbFMf%2FfBjatWn6fCEaSDBnhg9WrD0Ih0alv%2Bvj3MxO2JwcX0H%2FoYuEh8syg4pPTlHHmuvlLX8bZqn8d5kHzl5OxNZ9MZi3IhRr%2F1O190BozXiiulEZhctnp036NAj1rY0wfawjOrSx0pg8PJu%2F4vqX7b83MsDWnHz4MtN2glKE1NJcOBzxs5Gw3V4WgSvbYqUSuAaFY1ZZ4Zp6WGthYYJ3R%2FXA3M%2B3IzYusbA3Y%2F3Xuk1HERn9AKOZRa12C5GZrlMnDMAXK%2FwQfvOe6vzeg2dx7LfLmDiub6n38Y5BLBazDiFcdY7Hcfj4RdWsIf7A%2BcCRC8Ksn8ooem0jk4kxuLcdls9rBVdHc%2Bw6fFeYZ08Q%2Bs42ZvwkpeTh31Nd4Du8MVo4WWg8zRfp33PXEMr3EgmclErsZdels4tjX2bZ80h4TxHADFXXUhR4WeEa4bO5I7Hkaz%2F0HLgA1lbmSM%2FMFqZU7t46B7bWVSvgh4%2BShRk28gIF3pm4Bqu%2BHM9GC60w8b2%2ByMnNh887X8HS0gQ52fnCbJ%2Ft332I5k6lzy0Xi0WYP3Moxk1ZW8Ka%2F2rNAcz8ZCtsbSyQkpYpvAPw%2FdqpNa5x21gZArfTkZKaB7t6tCwNod8kM0XPsdaSn748%2BvfJuVkdWmJ5vhzznrX0i5R9Nu8pXqLEywrXGNxFsvCTtzFv5jAkJKbB0NDguYebI4d2EbaXwa3pW1e%2BK3GOP3C9cHJFqdfzqZdTxvfDw%2FgUSJjFzufkF6dTBxecPPxFiXP8Raq4G1ufy1dicjqysnJhbmqMOnVMa2TjNjctbConzjxC86bmkEjIG0PoJw%2FicxAYmlzofTDTygi9Qvr3WaXPJHWKStmz4UCTl0VSVrg24HPgi%2BbEaws%2BC0gdaVrXNRe2mszEkU1w6kI8ln13Q9jK%2BwYtQdQmuo8%2BLbxBy%2BGTFtzd6mje4K2k%2Fi2u9FXKvqyIdK3oCfXCX9mu6JIJXTxtcOVob4RHpgvHzZuYleu%2BjMx8KnCi1sgDf4M2M1sOU2OJ6gWrilAZeaiq%2Fi26X0pVrX%2FUMZcVJKbmSm2tKuZ7t7KUobOHdYXuuRWTRgVO1Bp5aFtFS16X8kCrXuoh5qYGKXEPs7SS1sWrCcJepAQfEsip9AmSB93IAyl7PcS6ruFp%2F0DteOb%2B8L8v7JUiPGY7cgcSJA86kgdS9npI5N3sZcf%2Bii3Iy9fsgmzRsemIic0oamn85ci7VPoEyYNu5IGUvR7yd0DWZZmBOHD30WiNpjN%2F%2BeWnB0rwtaH%2FoNInSB50Iw%2Bk7PWUuISsMVt2R%2BSE3EzWSPwrNofi9p30ooYdxTYPhRj7qeQJkgfdyAMpez3lMmt7efnKYdM%2FvyBXdwPnDduvuJUkgr8IuKTLj04QhL7LAyl7PSYgRH48I7tg4uRPzinX7wxHVX2W3Cc58oNTJRu2Ej%2Bx%2F%2FspJZhLJU6QPOhOHmievZ4TFIZtnq4K8f%2F23960%2B3C01LutDfp3bwhnRws42L38xamsnALcjErDxeB4%2FOl%2FnzXujJIX8IbN1yQXYXwgs5yotAmSB93Jg04WONHmmuy1bripoSWC27VAfyiEFfP4p9Kq9m0C7pNkQ1W2788smHFB13GCao6oSdRGeZDoItEHCVjENztbLKRmVfGy00i88Yi0awA%2F1iAd2WbLrI8o1tBzWSPlo7%2BylvbLYNfGiZW4qBQhhPXkDmIR4tmdo1jDvkS1RtQ4OauF8kBuHOLpqKFwaOnj3gJtxAoMY7%2F7MutGxP6VtVSnmVKJFNaw%2BbvkF5n1siiQHsYSJA8kDwRBEIR2%2BT%2FMdrJkSWUBvAAAAABJRU5ErkJggg%3D%3D)

```
options_block
         ::= OPTIONS '{' option_def* '}'
```

Comments:

```
Example:

options {
    opt1 = "some_string";
    opt2 = 1234;
    opt3 = 1 > 3;
    ...
}
```

referenced by:

* pre_section_block

**option_def:**

![option_def](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAUEAAAAlCAYAAADcHFvJAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAADlhJREFUeNrtXQdYVMcaPQtLr9JFrKgIahRRIc%2BCXWJDFCOxhxiVF4yFaDSmaOw1Ro2xYMP4xBaNJbbYIjYESywIqIgCIqB0UGHZNzMrKyqwQLaw6xy%2F6907c%2B%2FM3Ttnz%2F%2F%2FM3MHgIODg%2BM9hkAVlbo5Q%2Fy%2BPODIKMU%2BY3HEGJ3dFy5OuB2TPiL6XmajZ5kv9VKfPa9wnZY19AqNDHQyrCz0ztx9mD%2F%2F1KW8SN7%2BnH%2Fy5p8qeFZRCFVVccTZjRpPwNYd%2FBVa%2FvHNbgETf963OCYuy6hPl9roP64O7GwMYWOpX%2BEyUp4%2BFyan5FmFRaQMjE986N2vk2FEYlresMibuMfbn%2FNPXvxTFc8qAm1VVGpvjZlj%2FL01noTrNv3BvivdHqdhltysr3imlovF050rN0dN6dnJQXdOUCt4uFrD1toARoaVs2v0fHpdmxZWGNynvlaRGA43otLH2FgJriSliO%2Fy9uf8kwf%2FVMGzikKLU0X9sHPFnh0bd8T6Lv22DUb4OEJXRz7NSMuh5f3yo4e%2Boa7gQGsX%2BPOnzSFv%2FlU3nnERVDPQECQ4NMZ38Tet0dyphkLqoOWumuWhLRRqBbtyIeRQEP%2BqC8%2B4CKoRaCf0wROPFg8jVlRRAliSoEO8GwiEEKwllvoj%2FvQ5FMG%2F6sAzLoJqBDoKdzc%2B28ivT32l1Df2Eyfo6moJi8TY4dYMjrwFOP8UwT9V84yLoBrhdmz6SC%2FPWnLrA5QFWk%2FbFtZ0joUQIizhLcD5pwj%2BqZpnXATVCNH3sxzbt7ZVap09OtrTnQHZ2rs2RQveCpx%2FmsYzLoJqhKfPXujXsjNUap0uDc0lHwRI0SrCQN4KnH%2BaxjMugmqEZ1kvBJZmekqt08FWSnpjsnXnrcD5p2k8YzMb3ZvB9tJNPCnrJFn5ikJc%2FBNM%2BW6L9HjWN35o2qQOZsz%2BDdGxSSzNooYxGje0x4C%2BHmhQz0567rZdZ7D3wKV3ypz3%2FTB2%2FvAxyyEqEmHt8v%2FCxNiA5Z0Ou4nzl%2B7Af1hXBE5ZX%2BZ9Fd%2BHslEkEkNLW7lvOhbXJxbDQqDCN4yUgZtRD%2FHyRQFateRjQMrmX1V49m91qfh6VlmBCEluztgj1Mb40gqVla8wL6SmJeZ8OxRd%2B32Hgzu%2BRcMGNVn6jdvxcHdrjC4dmxMXPRsnzvyDnj6zsGTuKHj3cmfnPHyUCj1dIQLH9HqjzJp2kqH9y1diUcveAms3HcVX4%2FuztLS0LERFJ8Dc3AhBgf1YWmFhEfz8l2DVkjGws5G47LXtrd67H4BAYqENNPk7Hj4eiWfpOVwE1YRnVdWlts7wEQmwolAES3IoecdFIAmLB4lE8CGF7n27UFn5ioIOETEqVMXipaerI82jgvhh2ybscx%2BvNuj7UVuM%2BfIXtHFtBPuakmusrc2k55SGKV%2F6YOL0DRg1tAusLEyl6fp6utLrCl4Wsn2rFg1Qt7aN2pApPjEPCcn5pbv%2FxOq6t7SoSrFKf82SPv%2BQHadx5do9GBOPvavnB%2BjRpSXL2777LI6dvAoDfT34DWyPju2asvRbdx7iTkwizM2MELrnLISEsBMD%2BsKpUS1phLHptxNITsmArbU5iyIsLU1x6XIM8p%2B%2FxLJVf8CMXPvZ8G4y7%2B8JKWP9lmPEMD%2BEE4kwxvl7Mf7RiOJ29COMHvE6sgsOOY62bo3wQdN6WB18GO0%2FJL%2FgPy7g%2FoNkeHVvhaGDPNl5kVfvITk1A40Ix6mBr1%2FXBl7dWqmVmAXvjMP1qEx4dbRD7852CuFZZXWpWPyIQ%2BtQcgmPN9xOseS4zEJl5asS1Ct0blIbh45G4PNRPVhaamomLoTfeeO8Zi51peFvk8YO6NnFFSvXHCIh7icaZVG3%2FB6PlSGlv5JpTGxf3Bn1mP88mhg2kagI%2FkSQEhLTmHhQEaRCdezkNUydOAA5OfmYMC0YS%2BZ8ykTyVtQjTP1hC3p1c0OPzi1xnnDgs8BVCDs6n4mct988fBnQB906tWBC9deZ6xg5pAtMTAxIWKaF2rWsYGQkexGKjIxceH8yj4llj0BXnLsYhY9HLcbpQ3PRzLkOvpqxCQKBgOVTAdx%2FOBwj%2FTqza1dvOIxd%2B85hiG9H1KtjgwXL9sDIUB%2F9e7sj8tpdrCERio0VMeLuTWBqqn4O%2BLmIpzh46jFq2RpURQQrBVm6VJb4lSqCZRVa2UpVhXq1rZGQ9FR6fPvOIyxdtf%2BdPkGThq9JFURC4e7e3%2BPzkT00SgS9u9mjcX3j0j1BoXqMh%2F1z6wHCr8Tiyt%2FLiLeny9KGDe7ERHHd5mPYvfVrJjYUmVl5%2BHXDESaCFB6tG2P1srHsc3cihE09xiOdhLoZWbnIys1Hr%2B5uzGMr9h4pXIgRpeHwIJ92Fbq%2FHXvDSMTgJDW61Mv7%2FcBFXL8RBzdXR6xb%2BQV8RyyEro6QeYv7t89g0U0xfl02jhliirz8F8wrpCJIQfutt62fDG1t9Ry7dGpggvSsl6hjrzwBf0eXBDhM4rgfyxK%2FckVQ2hEKXCNN4CWWkV9YiDhSqcrNVUZmLhzr15Qee3ZohuXzPyv3mjoOVoz0S1ftQzt3Z4Xdm7LX0KtbyxAW5jqlhxECgVp8j9h7j9HIsaZUACm0tARIfpKBbOL9UaGQ%2FuhIqEvDXGk8pfVaPExNDV%2F1IYlIaGmLQd7%2FQbse09g11NMKICGsjbVZpe8v5m4SjhJv1KPr1DfSn794KYk6iEAHfeGNaTNDsHXdJNi%2B6lMuDXRQb9%2FB1wN5ljVM5CqAyubftHFOKrtfqkuE4b0LxfAl%2ByJZBQnLiLXPkwsTyb4bKTCY7CeVl08M3cLKeIKKaJCkx89I6BuN6UG%2Blb52QkBfdPCaDitLU4WRQh6LW1bmua3Yclch4bAyv4cxCUkzM%2FPeSaehKhVyKoRULCjoZ2Ojiq2juHj2KMwIGoQIEnZu%2Bd8pBE5Zh52bp0i8CXHFqUnr8%2B33IX6cMaTM%2Fsz9Ry6juUtdhGw%2Fhc7EKJdlgJ5lZMPCwkRj%2BJeU8hxxj3JhYiTEB03MFHK%2Fb99PSV0i%2B7X6Otj4vAD%2BxJSMFguQCeoRyhLB4kLEkkIu6WjDmYobqWxSefmq9P6ys%2FNx4XI0Zi0IxTC%2FTnBxql3pMqyJ%2BPkP64b1JMTyaOMETYCnuxXxoErvX9bREajFd6AhbfKTdBw%2FdY2FtEXEpv95LIINhLVp1RC%2FhZ5mBoyGx9t2nkGXV6FweYhPSGVl0tkFtE8wL%2B8FVqw9xPLMTY0QHhlb4fvz6ubK%2BiyHDPIkYa1k0OViRAwaEG%2BTepbfz9%2FOPi%2BaPRK9fGdj1bo%2FMX5sb%2Bn1mdkSgc8iofyWbadIqO%2BpMd0xSzfEIOT3eEwPaFIlEawMZOjSZPdmWFggwtdliWFJEdwlQ9x2KVv8omMTMXzscva5r99crP0pQDp9YfI3G9lmaKAHJ0JASi6%2FgR3evOG959hWEgdCZ5Q6BYKGRCGhpzSGhJ5trdmmzqAjtGuWB7B2NtDbzvryXJvXZyK4bJ4%2FRo77GQeORCCXpNevZ4ugQNkLtYqJkE6YGkx%2BB2I2IyAlLRM%2FLxjN8mi5wVuPw80ziOSZ4OjemeWWRWcQTBnvgwHDF8DcxBC5RFAtLIyxfUMQdu87zwZKDu%2F5gc1qWEO423fwHDbLoJ2HpNtl0tcbSKwmRnpGDgYQj5L2d2oKzl5OYxGHv289RVclU5depZUphsUimE8KSShH3GTlKwS0zyb85OJ30mkHsyxMn%2BzLtrJwJ%2BKXN47pyODNCyve9Zp0hUi8w5eCVxU6d2iOq2d%2FQkLiUyKKhtKRfdq39%2FfheSxdV0%2FIRlKL8bFPO7aV7Ecs2YYXTyxi3mBBoQgO9pbSEJVOw7pwfBESHz%2BtcB8hnV41nEQgScnPYEaEsLj%2F0bf%2Ff9hWDNq3%2BTbnNq4ez6bo0Pujgl%2BMMZ%2F2VOs2o1OzaCj8xXBH4l3rKLKqSunS22JIWn2cVASF2qhfXiGy8jk4FA2HWpaVSpcFO9vS18OjgkSnyFDQaTV01Lk0uDg5SPsCtV9Nq6kKatQw1ri2CotIo0tjIWBoA4XWU1VdKimGUhGUVRAXwOoB%2BmqRsl%2Bdy8kteG%2Bf94ZVgQore%2B53Q1HTtoZG8u8jTzt08rCGbSX%2B4FdVePZvdan4er6AghrB3ES38GnmC6XWGfsgiz94BYC%2B3lkyBNYk%2FpmZ6MDOSl9teMZFUI1gYqSTkZicp9Q6w6%2Bnsb1AjGyyE%2FFW4PzTNJ5xEVQjWNbQOxMWodyeieNhktV6xAKkkB3vFuH80ziecRFUI9x9mD%2F%2F0MmEwpcFRUqpLy4hGw8ScoqZcp%2F8%2F5C3AuefvPmnap5xEVQjnLqUF6mroxURejBOKfVNWxj5%2BkCMXGqweStw%2Fsmbf6rmGRdBNUNiWt6w4NCY5zei0xVaz6J1N3EvPruYmPfJ5lakhT28BTj%2F5Mm%2F6sAzLoJqhkjCmZcF4oGBP1wUKUoIKTF3lrT2AoQJgMtXb%2BE6bwHOP3nxr7rwjIugGuLSDdGfOfmFn4%2Bdfl68MiQK8uqjoX0zg8effpOYYmwj%2F%2FcUa2Mqf%2FIc8uBfdeOZkDepeuLKbWxq7VyktXXPvTWh%2B%2BOEHi2t4OXpgMaOpqhrX7G3EPKeF9I%2Fo4jwa6n4KyyJkDPnzRMoMQXoIhDg0wjiAfCnzlEV%2FlV3nqlkORFlr21WLcKIKMU861ZN4YUi7BJIliSXz5qOtG%2BGhCZk70Us88grt3CEtz%2Fnn9z5p2CeVRTaqqj0cRpm0c3eGjPfFxLS76uQclNx194OOwmRHMlmTazpfULIF4Rc1MvXrWAxOeSaRC0xwsUC3CAKVVdLgFRSgh8h5mXe%2Fpx%2FcuKfUnnGw%2BH3ycpLQggf16Zo8eoPV%2Fcg1llA%2FlX0vSxjsRgZhJh06eNwYpVnRfBBEA7584%2FzjIODg6O64f8rmKvsck0WfAAAAABJRU5ErkJggg%3D%3D)

```
option_def
         ::= IDENT '=' const_expr ';'
```

referenced by:

* options_block

**constants_block:**

![constants_block](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAZsAAABHCAYAAADRE%2BoYAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAF49JREFUeNrtnQdcVMf2x3%2B7LL1KsSBWUAELzYIm1liITyUEiSVG%2F5LEaKIxkUSTpy%2FPRBONvueLGk1ibNHYW6K%2BxKeJ2GJBQGyAiIgKFhDpTbb8ZwZZQdHdhV2Knq%2Bf6907M3fuZe6cOXPOzJ0LEARBEISBkVAREIR%2B8POAikqhbhIVR21dbSOjIiAI%2FRF5dDUVQh2jc89QKoQ6gJSKgCCI58HqJMuTlA1BEARByoYgCIIgSNkQBEEQpGwIgiAIUjYEQRAEQcqGIAiCIGVDEARBEKRsCIKoS%2BTmFSIjM1fr9Dk5BbiRehe5uYVUeKRsCIKoq1yIu47omCt6y2%2F7L8dRUFhc5fM37ziGWXM2aJV2y85j6PrSxwh9dyk2bT9CD7MeQ8vVEMQzzu8HonAvMw%2B%2B3q56yS%2FsH2vg36UdLJqaGvzev1m%2BG2uWTUH3ru70IEnZEAShKyX35Vi35ZCwOKyszPFS704Y2M9bxG3afhT7D56BuZkpRga%2FiF4vtBfhF%2BOvIz4hFXa2lsw6OAqZzAgfTBqKdm2aivir1%2B5gzc9%2F4nZaFho52eHVof5wcLDBqdMJKCy6j0Xf%2Fgpbdu6bb%2FTH3n2ncfDIeWRl56NRQzt2nZ7w6tBS5PPHobMwMzVGUvId8bupswOmvx%2BEBg2ssGP3CaiUKqxctx821hYYwO65o2cLjX%2Fvrr0nsfu3CHHv%2FF4kkofrYqalZ2PF2v%2FhfOx1tHNzxsTQADg3sRfn3LyTif3hZ3Ei4hImvhkAC3NTqjz1FHKjEUQt8Nb7yxDOGvvgwB5o794My1f%2BLsK5Qvhp40G8MbIvAvr7YOonK%2FHn4XOlyibuBsJmrcGOX09gYF9voRDenPytiOMNeODIr9C8mRPGvNabKQh7%2FHGYKQ0zY1hbm8PS0gzNmjqiSaMGIv2tO1nw6dQab40dIMJeG7cAd%2B%2FliLgDrHHn%2BV67kY6hAV2QcDkVs%2BdvFnFOTHlxmjS2F%2FlZsXw1wRXggm92YtjgrujXqxMy7j0cr8lmyi5w1Jdo6GiLsMmBsG9gjRB2L%2FISBRztbYRS4nH8WkZG1FyRZUMQhNacu5iMiOjLiD6yiFkvJiJszIg%2BUCiUrIe%2FH9vXz0AHj%2BaljXFOAb5btU9YPhz%2Fzm2xfNE74vcApnDa%2B09BZmYesnLykZNfiMED%2FIRVUGYNcTyZMuNutJCgF9Rhb48bIBRUYtItdPF1E9ZVXHwKevbwFPFvMiU0fWqQ%2BO3gYI3PvtwkfvN8JVIJ%2FjawM1yaOmj8W1UqFZb8sBffLpyAF%2Fw9RBi3vKLPlo4hiTEZ9jdNGD9IHHf1a4Ode07gzPkkcS9GEikGD%2FRFi2YNqeKQsiGIZwef9vCSqvAqVOjODtuwjfuI9PotlMtXbqGNaxO1ohEuBtaA32bWBp%2Bp1dbNWR3OXWTcPVaGkfRh797GxkLsSxQKtGrRCCHMSnph4CfinO7d3DEpNAANnWwrvYcFi3dhw5bD6NShJRyZMikqvg%2BFUvnwOuWsCO4uk8sVVfpbs7LyhZusU%2FuWlcYnXLmJ%2FQdj4P%2FS9ArhxcUlBnm%2BWqz8zOOv8cfEnvoJpQQ7z1zEWZIMUjYEoRe6uqOtXIJlEiU6sNZmE2tylhgpEdsyAde2AVq1tNouYc9dT9nZBY%2BFc1cXdxtxhePQwFqE8d%2FauKo4C%2Bf8H2aGhSAyJhE%2FbQzH5I9XYOvaj9UWRhlxl25g1boDOLZ%2FvtotNiDwnwYpVxNTY%2FXfxN15lZXF8GE9MGfW6Bp5zpo%2BohbC9GxyW7RQSMFNvH6s47HP1wMXZCq8FxGPBJKUqkNOUIKsGU%2B8pJDgJGuFDmeXoGV0HKZFx2Pv6QQkaatodIG7wm7fycSB8BhxrFSqxIC9tZW5cGn9vPmQCOdutQ1bD6PfAxfa07iWko5TUQmws7NE%2Fz5eCHmlh3CdcexsLHHl6m112vslCuEKM5EZieOY81dxJy1L6%2Fu3s7ZE4tVbWqW1tDAVY1Jbd%2F0ljvkYzQnWapcxqL8vduw5gfiEFHUY%2Fzt0uR99wp83f%2B78%2BfN6wOsDrxe8fvB6QtJClg1BVNmiUaiwjXX8x%2FIGpiauyWeEff%2FNJEz7%2B2qYm24SYy0%2BHVthSEAXLPoqFOMmLsaefZHIZ%2BGtWjYSA%2Bea4DPEpk5fyUwrlRhYT7ubjcXz3xJxPN%2BV6w%2FAr3cYi7PGvp3%2FRN%2BeHdHtpenC2mjdsjHMzE20vv8J4wdiwvvLxOy0qROHYnRIr6em%2F%2FKzMRg3aTHWbQ6HQq5Ex%2FYtYMosHk73Lu0wY2oQgsd%2BDVsrC%2BQXFLN8LbFp1Ud1on4kJoK%2FUDTX1x0xrGe%2BjdUXf7JwqgZ9l5t4rvHzwH62OxIVh7l6yEul62ehU1IzmPKxEFbNo%2BEmpjIxE0sXuMVUIlfAxdmhwvRibj2l3soQYzimJsbqtFIjqc7XKLNQikvkWp%2FLx4TS7%2BaIadYmxo%2F3cbkVd%2FP2PdhaW6jHovRF%2Bc9Ca3KjaXi%2Bs9iuF8tjIEkOWTYEoTV8MgBYR9u6EMNq6x6eNKNLm5leldH4wdTmR%2BETEPj0YW3SamudcQ4eOYflK%2Fc9Md3MsOHw8WoNM1OTx65fHj4h4WnxdQFWT%2F6Va473eL2hSQOkbAhCa6RKBLN%2B7sZDySii0qga%2FL0Zvj0P8Hri54mNot6AlI3O8kZFQDyvqIDu7L%2BDVBKEDpXmoKg3BCkbgtAWCcTkgItUEoS28PrC6w2VBCkbgtAFJ%2FM83KFiILTlQX1xopIgZUMQumB2IoXGawjteVBfzKgkSNkQhC7wabAqKgZCB1SgV0ZI2RAEQRCkbAiCIAhSNgRBEARByoYgCIKop9AKAgShR8qvw0UQBFk2BKF3%2BCKP1VnokSDIstEz2n5kijBMg2jI%2FFWRE4y3nzg5NTYhc%2BylK9lt7mXfN02%2FV6Txmg4NTOWW5sZZjvamhxOvF84LP1UQRU%2BLeF55FuWo1txoui7FTlQfQ7t4Dqz1m%2FTB4l8WJlzNsRzSrxlemdgcjRtaoKGD5nfg0jKKZLfTChyPRaYFX0u9Hjisj0Vk6t2CMVEXcIUUOvE88azKkVFtXNTZCbMnhAZSraphVqz5VZQ9327dxed664WpZks97TO2Ll0b9%2FGgPi4mc8N84e%2FjhEZO5rC00K4%2Fw9Px9F28HDFiSCupUgWX83GZExo6SqJvpqkSDVUP9VkOxPOBoepNfZUjbaExG6LabF2yY8vqLZeH%2F3tWF4wNcoWJcfWqFT%2Bf57PsC38zCxPJns6eoFF3guSonssRKRui2ib%2Fys0Jwxf%2BvTM6tmug17x5ft9%2B7m8kk0lX%2BpDCIUiO6rUckbIhqm72R04w3vvnjYVjWO9J3wJSXlBGB7aWyCD5gfXMXqZSJ0iO6qcckbIhqgyfLZN4Lddy5JBWBr3OO6PawcREKlOqsMWvA1z1Kef0FAkd0fvirc%2BAHJGyIQxL7OXMcQG9m1bbt6wJnn9XLycu5TIo8C89Zl3cpyUtF09oT3cXUV%2BKSI5I2RA1yKWkHNcXOzeqkWsN7OXMd%2BZse9GnPbz0lG1GvhV9CIvQnkIr8AqfTnJEyoaoQTLuFZs1bWxRI9fydLMrc2KkSZUI1lO2SXIlfeKX0B4jCdqrgASSI1I2RA1yL6dY4mBrWqVzb6YV4catAhQUKbRK79JILYxWbBugj%2FtnjUakRIkX6UkSWiNBPwlworbk6PbdUrnJK5BX6VqGkCNtEW8KdeuARqcuPPlb7JriDU3MuatYsXY%2FYs5fhaWFKdq4OmP4K93Rr1cnEX%2Frdia%2B%2BW4Pjp%2BKR0mJHJ06tMSUd%2F6Gjp4t1HkMH7sAFuYm%2BHHpezA1MRZhv%2B2PQkLiTXzw7lBxfOXqbfxn2W6cOZcEpVIJt9bO6NurA0LH9EfIuAVQPWFYcGLoIPTvU2qRHgiPwQ9r9uOd8QMxoK%2F3Q1P5cipmztkAz3Yu%2BGLmaHX4N8v3oK2bM6RSCVau%2B6PS%2FI2NjbBpVRju3svBv5f%2BihMR8SgqKkEzF0d079IO7779MsxMTWr8uSgVKkiNdHtZPiE5D2%2BERSDper44%2Fn6uL4IHNdXcK3pwHfYM7CV6WvlCJcF%2FWW9rCfv5BWiyAKEBPr6Xq8JopRQBtSVHI94%2FhdjLOZCx9KEhrfBlWHvdrIsqyFF12%2F%2By88XFShS46eeBHTIjTKksU03xhuR%2Ff57B%2B9N%2FxMdTgzD9gyCmTBQ4eOQc5izYKpRNekYOhoyYi749O2AlVySmxti7LxKvvj4fm1aHobOPGytYlWig3ds2xU8bDmLC%2BEGlvYS0TFy%2BclP85g35sFFfYtyofpg6aSgk7ElERF3Ghq2HhbKZNjkQZdpm0off453QAHh3bCmOXVs1Ud%2FvTxvDkZWdL%2FbllU1uXiGuJN1iSicFgYO7wc%2BndDIIv76NjTkGD%2FBD2ORhIuz0mUSs2xSOpQveLu1MSaVQKJQIYQqTK9DliybC0tKMKeEkrN90CMGv9EALl%2Fox9LBoZYJQNCOHNBNbu1ZWOnYsRY%2FMXB%2F3ciYW4X6ekHb2RHBkLLZTc0o8jVxzfMR2589cxNnauofFs7xwJ6MYU%2BfEYMXmJIwJbAYPN5sqGGjay1FV2%2F%2BuHghSSLBEroADOyxdA0FS6k4LUSgQxDLd9WimmuINhVyuZNbAz%2FjHjBEY81pvdXgb1yYY%2BWqp92PZj7%2BJ43%2FNHa%2BOnzxhMPLyCzF34Tb8svFTdfiMD4IRNnM1RrO8rCwrTkI6FXlZWAfTmVIrw611E7wWVHodbkGUYWpmDA9moXTv6l4hj7T0bJZPAvZunYVBwZ%2BL44ZOtup4C2aVjRvVF%2FMWbcf29TMqnNu4UQOxcfLyi8S9lM%2BfW13cCvtlw6ewtbUUYVzBcMXFy6m%2BkHavWOwnjGyFju1sq5qNvpZZUrK6PY31IdZ4uyMyJh7J1KQSleHrjiFsN81IBf%2FavA9vz9Ixl15dnLBrf6pQPB5uMKgc6dr%2BlykZZrC5lPcXVBizUZWaVTzTFJbpVm7%2B6BKvby7GXxeWy%2FDA7o%2FFlTW4R%2F66iKAhjz9%2FHhYVkyga7jK4NeHn7YbvV%2B97LH1bV2ek383GqvV%2FCCtH7WeUaT%2Bs9cvek%2BjDLKx2bZqim19bcfwo417vh2sp6Qg%2Fel6nsnBuYg9ra3P857s9uJ5yt6IvVFZ%2Fht7KfM02VsZ14n6YRfO7igkGk7qjvp7oSc0qUR43N5iytm6WRIJ1rGcSEhGv38kBVcXaSlZBnmoCTe0%2FVzJ%2BnrihAHaCK5pHkGnIVGgyTfGGsnTS0rNgb2f11PGINKYgGjW0eyy8MQtTKlXIYIrD0uKhi%2BmTD4PxyutfYfyYlyqk59bRoq9CsWjpr%2Fjsy41wcrBB927umBgaAK8OLbW63%2B2%2FnlCP%2F7w61B%2Br1v2hdtmprSITY0x7LxDzF%2B1Anxc7aF0W5mYmWLNsCmbP24wf1%2B6HjY0F%2FLxcEfpGf%2FTr1bFOC6yCdXGupuTjyOm7OBefjR6%2BDmjubFFn7i86Fl%2F5uSNZosIOXw9Esv0WpRFO2%2BYj6VCyft%2BpIOo2Iay3n9wWLRRSeD6YDDCKtXcXZMyiiYqrG4qGw8c5N%2B2%2BgWXrrsCxgSnatrRibWXNjNs%2B1v5L8DtTeV88aslopWzUPgYghvWZA1Qa4uVyXGUXNdf3H8VdXXl5RUJp8AH0StNY8DSFj4Xn5pW2EZaPuMv4uM2gfj5Y8t1etGhecZxjeGAPsd1Jy8K5i8nY%2FVsEgsfMx%2FEDX1dwh1VGfEIq4i%2Bn4F5mLrbt%2BktYVNwy4%2BH8muV5LegFYV3t%2Bf20TuXB3Wr%2F2zUbWVn5OB97DYeOXcC4id9gx%2FpP0NWvjU551eQ3hbip3314eKn539URGxZ1FWNi1cFQ989u62X238tSpfDR8%2BsQzxFJD%2BtB%2BTrRWCHBpbpUF3iHbdPirhj9YQSGvv0XQl52wfIvfGpUjnj7z8rmb3IVhrO9UlNGsicI3HF2Yirb92cZrmT7D58WbyzD17pYNtr%2BgR08W0AuV%2BCvk3Ho2cOz0jQ%2BXq1x9HgshgR0qRB%2B9EQsWjRrCEd7GzFBoDxhU17BgMDP8Hq5caDycEtpQENvMcPMo%2BtkxF66oVHZ7Nh9HO5tXBAV8%2FCzEdydxsNnfhRSIa2RkVSMDc1j1o2nezOdH7KdnaUoD75FnkkUs%2Bd0VTb6%2BOaKts%2FRkfW4Vs3zw19RGVi9PRkzFlzA4n9U730y%2BmYM8axQlQafz%2BqcMDMajRzMMHmsK7p52RtMjh69v%2FLtP9v%2FYGaM1UUlCGWGx1sqCbIrc6FxpI9mwnbbWAYebEuRGcEjOg7TNMUbarKAtZU53hzbH9M%2FWysa%2FPJWxOSPVojf3M217Zfjwgopg%2Ff6uZuKTxSojOYujghh1sX6zYfUYdwa4ZMNMjPz1GG%2FHYiGQq5Ee4%2FmT9fwTKfv2nsSsz8dif%2FMe1O9zfjgVRGurETnDx7oB1sbC4Qf0W7s5nT0ZeHeS72ZoQ47eyFZTKnu7O1Wp4XJxESKYf2d8fWMjvBwtcbG3dfFezYEQVSNNazTdi%2FrPv7%2BrjtCh7dE%2BzY2Br%2Fmk9r%2F4%2Bdwge%2BNjNCG9eu3sXS5LHHK0ywbngnXVKeMWSaVKBBN8Qbh02nDxXRmPpXZyspMTAFWscZ7VEgvEc%2FHU1YseRez5mwQjbEJS8unGU97dxhGP0hTGXx689adx9THrq0aY8O2I8LacHF2QFHRfeGCW71sihi%2FeRrc8uLGk3%2B5GWucfj07oqDwvog3N6%2FoT5VIJGL8aGSodksUNWlkj6TkO%2Bgx6BNxP%2Fz8%2B8VyoeDKplHXBxztTYErucjKvg%2FnhrQsGUFUhUymaDgOdjX2fp3G9v9B2LRuHfB1iQIzHrV0ypRNIddUT1EimuINBnc5ffx%2BkBhUv3n7HoykUjEzqzzc3cU33utXsla%2FScMGkBkbVWjYU%2BMrfoaaN9gJ0d%2Bpj329XcU0aT7WkpmVBxNjWaUTD0Sh%2FrmwwjF3Z0Ud%2Fvdj6YxNZIg9tfShUto%2F%2F7HzHr0vDn8%2Fp%2Fw7OhyXpg74%2BccPcb9ELsaUOM2aOtY7IbG2LK1y%2B47eQbvW1uz5kjeMIHThVnoRIi9kit82VrKauKRO7f%2BjSodJ%2BES1smHmUKunZaIpvqaUjqbGtamzQ7WvwyclPPoOTp1ySTElWB%2BVTBlvj2iFQyfTMe%2B7eLFpu4IAQRBA79GHxQoCHD7ZxsfTzuDXrGr7X17pqJWNpoxqW9EQdRO%2B9IWuS9a82NkRZ%2Fb2R1xirjjWdgWBvPwSKnDiuZcjvoJAfqECluZG6hc8daEqclTd9r%2FsfBk9aqKq2FmbyDOyi2VO9rpZgva2JnjBTzcr9HJyDhU48dzLkXc1LZnalCNa9ZmoMtaWxlmptwtq5FoRZ0tXTZCowE0iBZU%2BQXJUv%2BSIlA1RZRwamB4%2BFlkzHtYDx0oXTFVJkMZ25NYlSI7qmRyRsiGqTOL1wnn%2FPZgiv19i2IVAr6bkIjklr6zG8pe8r1PpEyRH9UuOSNkQVSb8VEGUibE0cvPeqwa9zidfRz08UIF%2FCOcAlT5BclS%2F5IiUDVEtUu8WjFm5OaHo%2FKVMg%2BS%2FYMUFXLmWWyYgSWzzU0qxg0qeIDmqX3JEyoaoFlGsDt8vUQVP%2FudJhb4FhQvI1vK9PQmOSfi35Wrx41UEQXJEyoaoJU6dV%2FyWVyh%2F%2B51Pj6uWrotDdX3P3Lc8YsqhigKiwgb2%2FyCVEaZTiRMkR%2FVPjug9G0IvRMdiTWcPpXT9jivfb959Vebv7YiA3i5o62qDFs5Pf3GzoEiOS0k5iIhJxx%2FHbjIhyauYgAsI%2F7aIBOMjWQ%2BQSpsgOap%2FclQrC1PV5LdUiCeY7QZaot%2B3PQKgFCu%2F8sXpqveNI%2B5bZiY%2F2wewnti46IvYR0%2BOeB54FuXIqDYueusuPuebsxNmU7WqHXj5GyTfdCQ6N8ZWVrFd2ebEelFJTGCKWWXnVrSmJWrzWNpUqQoRKgnOsx5JC6kE6ezMkUxATtNTI54b%2BXwG5YjcaIT%2BraZSEz3Ipz28pEoEs98DWS9Nwv5ZajjVSqVCFhMQviZHBOuFfR5JkwEIkiOSI4IgCILQhv8HHEvHZ5c1t1EAAAAASUVORK5CYII%3D)

```
constants_block
         ::= CONSTANTS '{' constant_def* '}'
```

referenced by:

* pre_section_block

Comments:
Only numbers can be assigned to identifiers in the constants block.

**constant_def:**

![constant_def](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAATsAAAAlCAYAAAA9d06YAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAADaNJREFUeNrtXQdYFEcbfu84ehEpgoAFUBA1KqCCvwWiiFgJ0TxixBj5FTSxRI2xG0nUxJbY%2F9iVJIrdKJpmYjREBEFjNCKCIgqoVCnS4f6ZPe8EBY5D7s7FeXmWLbP7ze7Me%2B9838wWgIGBgeE1gEAdmbo6Qfy6FHBsnHLLWBwTpHk48uKMG7dy3ou%2Fnds%2BO7dUOyO7uN55mjbXLtfX1XxsZqJ9LvFe0RdnowpjWf0znjWUZ%2BrgU30hUlfGMX%2FuavIE7N43UKn2f93jOuWj9cdX30rK0x%2FWvxXemtwali300MJUp9420rOKRQ%2FTC80iYtJHJqfe8x3hqReTmlkYEHsdt1n9M54pyjN18ak%2B0FBHplbmWBoU6NvkSbht9w%2FctdLpQSZCGq2VFS8VdjTJOrhxT9ycQZ42Wstmu8Dd2RwW5rrQ11Os%2FaL70%2BN6dDXD6GG2wkoxbK7F5QS1MBNcTksXJ7L6ZzxThGfq4FN9IWRU4R8ObjhyYNeBhFFrF%2FXAe3720NJsnGqkdqi9zZ%2B56%2BhpCU5274hAVtqMZw3l2avGJyZ2PAMNKXaE3Rq1ekF3vOHYXCl5ULubQtw1RCLhDmcmeIxnL8mzV4VPTOx4BNpJHP7b%2FdUBpLVUltBVJei7vnYCEQRbSYs8mJU%2B4xnf%2BcTEjkego2GJyfn6%2FsNsVZJf8BhHaGkJRZViHHDtDHtWA4xnfOYTEzse4UZCzngfD%2BtG66OTB5pPz67m9J4GESqwhtUA4xmf%2BcTEjkeIv5Nn36e7hUrz9O5nRWe6ZOrj3AldWS0wnvGVT0zseISs7BIda0s9lebZsZ2xZEGAdGElRrJaYDzjK5%2BY2PEI2XklAtNm2irN08ZCRnoDMg1U9TWnPchGWWl5o9t9%2BCgHpWXljFQq5pk6%2BcTdGejWGRZR1%2FGotp3kpSsLScmPMGfxXtl6yAJ%2FdOrQGgs%2F%2Fw7xCWncNpPmBnBoZ4W3h7vDrq2lbN%2FvD53DsZNRL9hcsSSA239c0DpUVFZg67oPYGigy6X9EXEdF6JuIjBgAKbO2V7reUnPQ9WorBBDqKHaJ%2Fyk%2BYnFMBGo4YmbwSM%2Fw75dsxq9vEeOW4m1KwLh3t2BqZsKedYQPr2s%2FkiP5zIrq0CaqxOOiDQwrSaj8tKV5lW0NMWyRWMxYMRihB9YhHZ2Lbnt124kw83VAf37vUFc7nz8du4fDPILwZrl78N3iBu3z737GdDWEmFq0JBqNltaSobSL11OgLWVCbbu%2FhkfT3uL25aZmYe4%2BBQYG%2Btj9tQR3Lby8kr4B67BpjVBsGwhccFbWZm9dj8AgaQl1mVSwKBqPjVUf3o6wa9CgA3lFTAlq5JnPgSScPadigr4EaPHnjcqL11Z0CRiRQVJKlLaWpqyNCp8vXp24JaH%2BfTA8ME9ETR9M3o4t4dVS8kx5ubNZPvUhDnT%2FfDR%2FJ14f2x%2FmJkYybbraGvJjpOGUC5d7dCmVQvekCk5tRApD4tqdudJ6%2BrWzaQhZtXyeOGDhzk4cCSC8%2FR9Brpg7DsesrSIyBvYf%2FhPFBaVwOvNrnh3VD8IBBLv4V5KJrbv%2BQWJSQ%2Fg3MUOUwJ9YGiouF4Xl5RiZ%2BgZXLx0i4skJowdgG5dbHH3XjqJHi5i4viBsujg9C%2BxEAoF8PFywfFTUbC0aI6oS%2FGIjk2AM%2BHQtOChHI%2FpNYX%2FHIO3R7jjh1OSCCQwwIt3orXjYBKuxuXCp58lhr5pqRQ%2BKao%2FUpEjDqpN1VdOVHMjxZL1Wo3KS1cnqJfn1KEVThECTXrfm9uWkZGLyOib1fbr3LGNjJgdHGwwqL8zNn5zioSmY5pUy7n3aDI2htb8KKIBaeOSzvHnPuHPVx0kAtcP9raWWPnVUejpasNvmDt%2BP38NsxfswtIF%2FqRO9bBmwzGuj482Ylk5%2BfAdsxwTAgZgiLcLDh2%2FgDET1%2BLE%2FoWcGCmCwA83kijDjBOqeykZCAj%2BGqcOLSaNnzmuXr%2BLT5bsxf%2B%2BmoyYK4lYvHwfToYt5I47Hh6FK1fvYNwYT9IY98AOIpiPc59w0Qo9z9XrjxKhPo%2F%2FuHWAkaEeL3n2V0wWws8%2BgLWFbkPETiHI05%2FaRK5GsavNqKKZqgttCflS0rJk6zdu3sfaTSde6LMzbPesdZ9NQtiBvkswabx3kxI7Xy8rONga1OzZifg1LrXlq2BZn11%2BQTEOE%2BGiYrdtz8%2BYMWW4rOuipYUxEbgVmDllBLdPl05tMT14mKTfprsjevb%2FmHhn8Zy41BexV24jJTUL32%2BfxXmMPV3bI%2BJiHH769TKCJwzChpUT4fN2CDZuPYX9h85z3R3SyIKLHma8hYDRntyybVsLTPhgIyd20gjih30LGuRtvipwtDNETl4pWlup7hpe0B8BfiTx12e1iVydYifrqAT%2BJj8LH7Gc9PJyJJFM1V5jtNW0t20pW%2Ffo2xnrvvhvnce0tjHDO369iSgeR283J6Wdm6rf4dbGWg8mxpo1hwUCAW%2Bu43lQ7%2B5YeCS3fOfuIzi2t5KlObSzxpPCEjzKePw0zVqWRr259vZWZPtDhcTu1u00pKZlo5fX3Oo%2F8nYS20ZGeti8NhjDRi%2FjhLdXD8fnC1u2SAfQcglHachNoaun1ehCp%2Br6mTfZUW3nS%2FWHlO7QcjFGkXmlPEOiWmLkC%2BTAVDL3IgZ3kPnMutI1RVipiGenjAqhYUFkdDzmzx6l8LGUpH195sPM1EhppGiMlysqUm4b9iYqJYxV9XU8j4KCIhgb6XPLhgY6yMt%2F1i%2BZT5apkBvo63BTXn5htWPpuoGBYuJC7VBBPX14Sa37HD5xAW90bIPjJy9iMvH2qADWhOzsfC4E19XRajI8S0svRtL9JzDUF6FLh2ZKOd%2Fnz6eq%2FpD5Vh1N7CouQyBxvCaKBcgF9fDkiZ3UiFhiJEpTA05UxEhmM%2BtKV2dLTwkeSUKTkC%2FDEODviY6OrRS2YU5EjnYO085s9x6OaArwcDMjP6qa%2B381NQW8upbiojLJvKQU%2Bw6fx2AvF269f78u3OCEl2dXaGgIEXrgLFy62aFZM30M8OiCD2dv5bopaP3%2BfS0JCYlp6O2umPdO95%2BzeA%2FCf7rEDYRR0IEJKpw0TD5yIpILjWkf3txPQzF97g7s3jJN5j3n5UkEl47qb9n5I4Z4u76UZ%2F2qYe3OWwg9moz5Uzo0SOwUgRz9meXWGSvLKjC3NtGrKnaH5IjYIVWLXHxCKsYFr%2BOWh%2Fsvx9avpxAyS54fnrVgFzfRltLRwZrrPPYf2bf6CR%2F7i5uqgnYeS21UBR2pCw0722RI6NHTnJuaAqbN2caFgzm5BfDs01k2avnRByMQPGMLenvP4wadikvKsPeb6VwaDVVp4%2Bc5dCHa25HwNekh1iybwAmfIqCjrzs3TcXHi3ZjyYr90CJhTElpGTasnIS4%2BPsI%2BSIMR76bx%2FW%2FrVgyDoNHhmDTttMcHylC95%2FFzm%2FPoKi4FJ2dWnMcbkr481ImFykEjmqr7Kzk6s%2FTbbWKnlTsioiRlDpETF66cjo%2F21sj%2BvfVL2ynI2ryMH%2FWKG6qDTdjNldbp30n1yM3vOgFaYmQepO9QlxduHpB0tilpmVxddHC7Jn3oK%2Bnje%2B2z0R6Zi5KS8phY21a7djZU30RNN4bj%2FOeoIV5s2q3Lv31y5cKeXeRZ1Zxt4uIyI%2BgqmD%2BE7m%2B2vmc%2F3FFtWOnEtGjgylPCournbursz2iflvN67qhtzbREPbDcfYwNtJUZlYK6c%2Fzokc8wskysRNpwLYuI%2FLSGRiUDWsr01rTqorI86CNWF2DAKvWH%2BPugasJdFDj4J45snXpDemKgoognZoaImIy6SubMGWsnVLzaaj%2BVBU9mdjJM8SE7tUAfdRG1Y%2BMFTwpa9Jl%2BskMP6XZnvieV7XbUJoazwZ7WMLT3RwWCnzgqSF8eln9kR4vYhLCHxgbapVn5ZaIzE10VJZnwt08VvANRJ9eHZs0z5oZanITX%2FjE3nrCIxjqaz5OfVio0jyjr2Zyc4EY%2BWRWwWqB8YyvfGJixyOYNtc%2BFxGj2h6FXyMkb5cRC5BOZqw7g%2FGMt3xiYscj0C%2Bsn%2Fo9pby0rFIl%2BSWl5ONuSoGUKXfI%2F3usFhjP%2BMonJnY8wtmowlgtTWFMWHiSSvKbtzL22YoYT2jDzGqB8YyvfGJixzOkZhYG7Ai7VXwtPkep%2Bazadh23k%2FOlxLxDJtdKIY6wGmA84yufmNjxDLGEM6Vl4pFTP71YoSzBo8Q8WLVVFyBCAFy68i%2BushpgPOMrn5jY8RBR1ypOFxSVTwqef0G8MTQOjdW3QvtURk%2F7ozoxxfie%2FB8k1sAnrOQZz%2FjMJ3afHU9x%2BQZ2d3eqFH575PY3YSeSRO7dzODjYQMHeyO0sTKol43C4nL62TxE%2F52BMxFphJwF1XegxBSgv0CACTGkpWelznhWF89edT6p5fUL6n4nmlrCgjjllLVLJ%2FigEocEkldcN87L0WifCgk1yNyHtMDjL%2F%2BLn1j9M541mGdK5lN9oZ5vCmQihE5W5lj6upCQXq9S7GYg0coSBwmR7MlkTlrNO4SQJYRc1Guv74vTCsgxqUIxosUCXCNK1EYoQAax4E%2BIeYnVP%2BOZgjxTKZ9YGPs6teaSkMCPfmH96YeHvUkrLCB%2F%2BvU0YSAW4zEhJv18WjRpfUNi2GAEQ8N5xvjEwMDAoC78H%2F7hb365CQltAAAAAElFTkSuQmCC)

```
constant_def
         ::= IDENT '=' bool_expr ';'
```

referenced by:

* constants_block

**sources_block:**

![sources_block](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAYEAAABHCAYAAADhn%2Fs5AAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAFaBJREFUeNrtnQl8TNcex38zmWyyyoYkCEIkQSQhwlMULVq1FM%2BufVqq1tL19XldladKa1%2BaUmpfijaWoho7kcQWCUESkQRZZN9neeecME1sM1km2%2Fy%2Fn8%2FNndx759w755z%2Feu65FyAIgiD0FglVAUGUxtcdKqqFqiE0knRQdSOjKiCIJwk5sZYqQcd0eGE8VUINQEpVQBBEdUZdFHmRESAIgiDICBAEQRBkBAiCIAgyAgRBEAQZAYIgCIKMAEEQBEFGgCAIgiAjQBBE5ZOdk4%2FUtCytj8%2FMzMWdhBRkZeVR5dViaMYwQRCC7btP4uz5KKxZPFnjsTv3nMbsbzahsaMdhgzsjEnj%2B1IFkhEgCEJf%2BH7FbwhYMgVdO3tQZZARIAj95VJ4LLbsPI4HadlwdrTFqGHd4Nq8kdi3ZecJHDp6AaYmxhgxpCu6%2FcNTbL94OUakUV7r11H8X1gkx7LV%2BzBt4qswNJJh847j8PNtibj4ZHHsoP6d0NylIQ4eCWPlXUQRO75TRzcMG9QFxkaGuHw1Fr9sDULC3VT4%2BbTCpLf6wMTYSKvr37v%2FHPYEnoO1lRkKCuSl9iWlZODHnw%2Bx8m%2BjZYtGeJd5%2B07sN%2B7Zdw6Jdx%2FgSNAlBIfewDtsu1k9Y%2BoMtRQaEyCIcpKQmIqRby2Er1cLpuRfgJVlPRw%2FfVXsW7RsL9ZvPoqxI15E397emPFJAP48dlnsu3A5Gr8fCFaXU1BQhIXs%2BEK5Qvy%2FmRmVMRO%2BZ9%2F%2FC1k5%2Bchn%2B1ev%2BwNzFuxAz25t0ftFLxw8HIaY2Pu4cCkab01dxjxyd7z37gBEXIvDx59t0Or6N2z5C3MX7mTGyA%2B9urcrNR7A8%2F2DRsyFrY0F3p86EA52Vhg27lsUFcphx7ZJJBLYs22NnexgYEAPAqVIgCD0kJvR95gnLkOfXt6wZAaAK2iOQqHEGuZB7%2FzlY7RxbyK2ZTCluvKng0LZasPkt%2Fth3MgX1eUNGTsfv6x%2BDx28XcW2ga90glKpwoTpyzFrykDxP6eZSwP49fgAC78ZD5ns%2BT7ektWBWMSOexShcM%2Bfjwlwtu85BV%2FvFupcP49MdgeeRSgzYDwFxMvu95KPiFAIMgIEUePw9oSXVIXXoUJn9m9LtjRFJb8%2Fo3MnN7TzdEH7rjPh6dEE3bp4CKWZw7z3rOw8tHJ1VB%2Fr1tIJMbfva122g73V32mZ5Azhmbdr41I6jJdKcP1GAsIu3sLilb%2BrtzdwsGbRQyHMZSbPLJ%2BXd%2Fdemrj%2Bp3HjZiKOsMjFv9dHpbYX5BfppL20eJIo33%2BbXxprxTNKCX69cBWXqKeTESCIUvi1Riu5BMslSrRhWmMLUx1LDJSIcInC7R3Mqa4khSQwMpRh%2FaoZuJ%2BUjlCmiFeuPSg%2Bf%2F7JCJEu4YbAtr6FOJZ%2FNjf7WykXyRVa%2Fyaeb%2BflpWfkiLRMSSzMTfHJzNfRv2%2FHMtWTkbGs%2BBpz8mBtbfbkOdm1Du7vj7mfjamSdtP0cplhgEFsKzRVSMFHonsyA3%2FQxx3hMhWmBF9DFPX88kNjAkTd8f490EshwVmmTY5lFMElLBKzwq4h8HwUorU1AGXhSsRtXItKEJ73Ky%2F7ok9PbzFAzBVzRx9XbNwapE7nbNp%2BDD0fpoK4lx9x%2FQ5y8wpESocPzD4Pnmri5fF00iP4gOy9%2B2kiFbUi4ADS03PEdrlciX2HQjVeOx84bufZFNt3n1JHBqfPXVPv79vbRwwAR7LrfPyc1QFvP96OvD15u%2FL25e3M25u3O%2FV%2BigQIigBaKVTYoVJhHFcUVXFOrsTfmf69UNKmJkbIyS1AwNIpYt%2BiuePxxqTF%2BP1gCHKYt81z9XyAldOrRzss%2F3E%2FfLu%2FD0MDA%2FRjBkQTP8x%2FG5NmrIR315mQGRoIJb795w8xdcIruJeUBv%2FeH8HG2hxpmTno0N4Vr2pR5pzZozF20g%2FYuC0ICmY8vNq6wNS0%2BC4fPgbw75lDMPSNb2FlXk%2F8VisrM2wOmFUj2vvmTRTwn%2BDTGheZJ7uDtb8%2FRQTlg4b1iTqBrzsOsdXx0EjMqYSyVGV5vWR8QqrIzzs2snnqPp56eTyNo2LWKj4xFZYsauDKVVuSUzMhYVJrZ2NZantefiFS2D57O0utbw%2Fl8LGD5JRMEc3w9Nbj8EiF33pa1uvUhpKvl6zIu4ZZe81mq26sjJdJEigSIPQxDeQJLyjR1iIPA6rj%2FM5OtmXex%2FPx%2FPbKsmJva%2FnU7TwSKVle0MlwLFuz%2F5nlcC%2Bf3%2F3DDcbzroMbt%2FJcZ1XC2v27LFNM4f2ABovJCBB6iFSJIcyP3BwUi3yqjWJ6dG0jFn2At7uvBzaLfgAyAmWWH6oCorajAjqzP0epJvS6ExwV%2FYAgI0DoHxKIQeGrVBP6C29%2F3g%2BoJsgIEPqJvWk27lM16C8P29%2BeaoKMAKGfmJyJp%2FEAfeZh%2B5tQTZARIPQTfnuhiqpBr1GBbnknI0AQBEGQESAIgiDICBAEQRBkBAiCIIhnQjOGCeIplHyuDUFQJEAQegR%2FmFlFHmhGEBQJaEDbl3YQz1dUuixfFTLRcOeZszMiotLGXb%2BV0fJBRqFx8oN8jee0rW8sNzM1TLezMT52My5v3l%2FnckOptYi6Ql2Ui2pLB5XlUb1EaXSdqjj8s%2B%2B77y3esyAqJtOsf8%2FGGDSpCRo61IODrea5OEmp%2BbJ7Sbl2J0OShtxOiBs4oEe9kISU3DGh4bhFhpaozdRVuTCojpM62uOLieMHUq8qJ2vW7RV1yJe7Kfiy0rwc1RdSD5vU7Ut%2FjvywTw9noznv%2B8Df2x4N7E1hVk87f4Efx4%2Fv6GWH4f2bSZUqOF%2BJTJvoYCcJS0xS3dRVf6rMeiBqJ7rqB7VVLrSFxgQINduX7Nq2dtuNoQtnd8S4wS1gZFix7sG%2Fz8tZ%2FpW%2FST0jye8dPECjrQTJRQ2TCzIChDrUDdgaNXTBpx3Q1q1%2BpZbNy1v2pb%2BBTCYN8CZDQJBc1Ci5ICNAiMGuwD%2FvLBjDvJPK7uglO%2Fyogc0lMkhWM8%2BnH9U6QXJRM%2BSCjAABfrfDzdtZZiP6N9Pped4Z6QYjI6lMqcI23zZoUZnySq2o91T6QwTrgFyQESC0I%2BJG2ht9uztVONepCV6%2Bn5c9l1YZFPiuEosu6OFCjxHWZzo7i%2FbPJ7kgI0CUg%2BvRmS26dmhQJed6uZsjX5mypat4QXzlkJpjTi8U0WfyzME7cDLJBRkBojwa9EGBiVPDelVyLg9X60fBe9LDF4NXBtFyJb1aUJ8xkMBTBUSRXJARIMrBg8wCia2Vcbm%2Bm5iUjzt3c5Gbr9DqeOcGaqEyZ8tLlXH9TPhDJEp0pZbUYyToKQHOVJdc3EsploPsXHm5zqULudAWMdOhUxs0OBf%2B7He0atqvUwWVlo1Fy%2Ffi1NlI5OUVwtnRFv5%2Bbnj3rX4wq1fcQJHX72Dp6v0Iu3QLBgZSdOnUGjMmvQZnJ1ux%2F3zYDfyyNQhLvp1QquzZczahZ7e2bGmHI0GXsGrtH8WVIpPCzdUJb47uiWZNS4eDgQfPY%2Buuk7gZfRe2thZo494Ub456Ee5ujfHd0j04e%2F5JZ2TdimmwMDdFBLvOJasCcflKLOu0ErRs0Qh9enlj1LBu1So%2FSoUKUoOyTY6Nis3G2PeDER2XI%2F5fNccHQ%2Fo4afY6Hp5HpYKNpJJmrKsk2Me8mSXs41egQWK9g48HZakwSilF3%2BqSi%2BHTzyHiRiZk7Pjxw5rhm%2Fc9y%2BaNl0MuKqqXH31fnKxIgURfd%2BySGWDa0wrVtF9XqFiNDH9zAVOWjli6YCIsLerh0pUYbNx%2BDANfeSCU6OWrsRg6dj4mv%2F0KPpg%2BEHK5Eus2%2FYlXh32Ng79%2BjkYN6yMtPQcXLsc8UX54RBw8WzcRn%2B8npyM9Iwdf%2F2ckcpmxOXA4FP2Hz8GJA%2FNgU99cHDP%2Fh1%2BxY88pfPHJCHi1bcbKzcbuwHNYzBT7qu%2FfRdSNBLg0sceQAZ1LncfUxBh3ElLw%2Buj%2FYfKEfvhw%2BmAolSqcPheJXXtPV7sRKA%2BLAqKEARjRv7FY3JqZl9FxEx6PaWVcy4UI%2FOXrAWkHDwwJicBOUov6RZYpPmCrKxeu4lJ1XcPi2V64n1qAGV9fxJqt0RgzsDHcXS3LEdBoLxfl1ct%2B7hiskGCJXAHuJRfPeZYUp4WGKRQYzArd%2FXihmvbrivjEVOE9b%2FppFhzsrMS2Js52eK1fR6HsOXMX7sSof3bHe5NfU39v3udjkXj3AVPOv%2BN%2FX4zT%2BnyWzFvv7NdafO7VvR0C%2FwjBxSvRIlKIjUvCioD9OLDrc3gwr5%2FT2MkO7TxdkJGRoy6jibO9uoyS8EimYQNrTH%2Bnv3obN2Kj%2F9mjVgpe0oMCsZ44ohnaulmVt5jKemyJkvXRWcxnWNe%2BNUIuXkMsqUb9wKc1uEDNMlDBvzqvo71HcU6%2FW0d77D6UIAyCuyt0Khdl1cuPlD8LcJxLxsulxgRUxWEILzSeFbqdhwtl2V%2FZNHCwRn3mhfMUyu07SaXzWDIpCovkOHP%2BOgb3f7L9Xx%2Fgj%2BMnr1YoDVWQX8QUffFNJ0ePX0Ybj6ZqA1ASKysz9ee4%2BGScCb5WauEGq3VLZ8Tcvi%2BimDRWdsnfURt5lPu0NDesEdfDIoADKtbBmfSc8PHAC6Qe6zaurjBmOmi2RIINzAMYxsQsqiZcl4W5rJR8VEnGRINe5sqfRcp3FMCv4AbgMWQaChUWRtN%2BXUUGRoYyrF02DZ%2FP3YJ1G%2F%2BEhYUpfLya41%2Bje%2BGlF9sLZSpnMVFDB%2BunGJD6SErJKNP5Eu6lYtGyvcJI7j8UirffeEl46yJdlJQOp4Y2GsvgHn9sXOk71fiYQPt2zTBn9hhh0D7%2BbD2LCuqji58bpkx4Fa1bOdUKwVMwFyImPgfHz6fg8rUMdPGxRRPHejXm%2BsIiMNe3NWIlKuzycUcIW29TGuC8VQ6ig2Ir9x5yomoZxrzj2FZoqpDC4%2BEg8Egmp%2BEyFgGERtYMA8Dh42JbfruD5Rtuwa6%2BMVq5mMPG2qiqjUGxXpbgADNFXz3u%2BWtlBNQxNnCR%2Bal9VRr2y%2BWIYSc11cUP8%2FNtiQO7PkN6eg7CI2%2FjxJkIvDV1GTYHzBJ5eQlzBbKy80TUUMpTZdvMzYrnD7FDxPjCE5XGtkmlTw788HEHXu4H0wept5mxstIzczVe78ih3TB9Uv%2Bn7hs7oodYEhJT2W%2BJw869pzFo9FwE%2F7kAlpblU6ZV%2BW4GHuJ2HvpXcdjrZ4dNi%2FxE3VYEXV0%2Fu6x%2B7E8%2FqVLkjPl5iFpM9N%2FtWrKNGyokuF6T2pY7RlsW%2B2HUzGC8NuEUhvVzxoqvvKtULrheZnXzqlyFoWyt1FSQ7BkCdJp9MYGte7MCA9h65vP2M4d9flkigfL8QGtrM3Tt7CGWsEvRCLscLT5zT%2F346atwbd6o1PEnTkfA17s4KWdjbYG0jGwxGFtS6SenZKoHfTlODW0xa%2BpAFBXKMWL8d5j%2BUQBWfT9JGISOrKwlKwNFmqjkd8qDk6OtWHp190Jzr4niTiOf9uWbLV4Zz7zXtj3smEfz0zxfnApNxdqdsfj423As%2Fm%2FF5rXQM%2FuJmkp59BS%2Fa27if8LQwNYEU8e1QCcvG53JxePXV1Ivs%2FVqE0OszS%2FCeOaov62SIONpqSCO9PFC2GoHK8CdLfEyA7iHRWKWpv26GiS%2ByDzyT7%2FaKO6secTVa3FsuSOUMmfKhFewcNlehF74%2B90MB4%2BEYeO2Y3j3reI7xtp4NoFMasC2BamP2fdHCFJSM%2BDn0%2FKJ8xoayfDj0qm4Eh6LeYt2iW3%2BHd3EIPCkmSuRnJqpPvbYyauYs2C7xt%2ByfvNR%2FLj%2BMLKy8tTbdu49JSKMlq6OtUIojIykGNDbEfM%2Fbgv3FhbY%2FFucmCdAEEQx65hz9CC9EJ9Obo3xQ13g2dJS5%2Bd8ll4%2BfRnhfG1ggJYqFXaw47LYwfHPiwR4IdyCnDNkhTxFsWvaX%2BnwXH88MwAv9PsUtvUtxByAvLwCfDpriPoOnKEDuyA7Ox9vTF4ME2NDKORKyNgFLvtuIjo8NBTGRoZYvWQypn6wGt%2Bv%2BE2UU1SowIpFk0oN6paEe%2FvrV7%2BHASO%2FgUsTB3Eb59rl08Tcgk4vfggHeytk5eSJ65o5ZYD6e%2Fw2Ur6UJPzMEhGp8DuZvv52Gxwb2iA3twA2NubYsGqGmENQ27CzMQZuZSE9oxCODvTYHoLgpDEDwLGtonEAbfTyw22zOrXB%2FCIFPn48MnhkBPK4BXmOcte0XzdGoEF9bGCKmKdn7iWni238tszH4ZO6eK498d4DZugk6kliJfHv0AohQQvVUYVTI9tSqaHRw7qLpSQ81RQZvKxUSoobl7z8QhZFZMLU1Igpw78t%2FZolU575W%2F7h7459O%2F4rIoH0zBwYM4P16LbX2oiFWXHXOXjiPtyacwNNWR1Cv7mbnI%2BQ8DTx2dK8St7cWya9%2FLgxYBI7SW0EWPjQ7HmFaNqva3h65mnKvyTcu9d0zLOMSFkxNTEqdzn8Die%2B1HYmDG%2BGoLPJmLfymli0nTFMEHWR7qOOiRnDHH7ThLeHtc7PWV69XNIYqI2ApoKq0wAQuodPWS%2FroyO6drDDhcDeiLyZJf7XdsZwdk4RVThR5%2BSCzxjOyVPAzNRAPXGsLJRHLiqqlx99X0ZNTVhbGMlTMwpk9jZly%2B3bWBnhH762ZfrOjdhMqnCizslF%2Bwp6%2FtUpF%2FQUUQIWZobpCfdyq%2BRcwZeKx2QkKvAQQkG1T5BcVK9ckBEgYFvf%2BNjJkKrJ%2BB0%2BmSjWKgn4c0AozUiQXFSzXJARIHAzLm%2FevqPx8sIipU7PExOfhdj47Ec9j08CjaPaJ0guqlcuyAgQ%2BOtcbqiRoTRka2CMTs%2FzyfzQv%2F9RgT969TDVPkFyUb1yQUaAECSk5I4J2BqVf%2BV6mk7K%2F3ZNOG7dznrU0aPZ4quUYhfVPEFyUb1yQUaAEISyvlhYpBoy9fOzisru8Lyjby%2FpTUlwUgKcr86XgBAEyQUZAeIxzl1R7M%2FOk09459%2BnVUs3RKKiuVCe6xw%2BLah0R1dhE%2FvbR2WAj6jGCZKL6pcLmidAlCIsAus6uCulv%2By6tWrrbzEy%2F%2FZ26NvdGa1aWKKp4%2FMnhOXmy3E9OhPBF5Nx5GQi6%2BzZpQ%2FgHZ0%2FC16Cf4UwD4tqmyC5qH65qJYHvlTlM%2FDrfLiqo0cx%2B3iiL5TiyYP8VXcVe84Fz3WyUJet%2BzJP542wqzhILUfURuqiXBhUx0nvpuBLvjja4wvqVhWvS52Um4ybjg2xnXXQFmyxZ15KNOv4BazT8uhR0yMSs9mxCVIVglUSXGEWv6lUgmT2zRGso5%2BnViNqrbzVQbmgdBDx7CijODQd7O0JL6kSQ9jnl5kXxB%2FUaqbhq%2BYqFdJZR%2Bdz6YOZl%2FNlCA0CEyQXJBcEQRBEzeL%2FryE%2BHB%2BO3SUAAAAASUVORK5CYII%3D)

```
sources_block
         ::= SOURCES '{' source_def* '}'
```

referenced by:

* pre_section_block

**source_def:**

![source_def](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAmUAAABlCAYAAAAMEJQOAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAIABJREFUeNrtnQd4FcX6xt9z0huBVEiCBBIgCZ2EEJGOQFCKiFxRseUqoCBgQdDLVbnX8veKXhWwgdiuiiA2sAuKorSEIiUkgYRAQknv%2FZz9z2yKQRNSOCUn5%2F09z8luzu6Z2Z3v2%2F3enZmdAQghhBBCiNnRmCPT8FAo1lLAcfHGLWMldo7dx7t2LzqWmHtbwsn8njn5FQ6ZOWXNztOzk0OVi5NdnpeHw44Tp0uf%2BXFPSRztT4ztt4QQYq54aI6411xszZVx7C%2Fr272DRIyIMWr6378dfs%2Filz57LjGlwGXy2K64bt4V6OzjDB9Px2ankZFdZns%2Bo8RrZ2zGjNT009OmjnaOTc8qmR13BCdpf%2BvE2H5LCCHmjIfminvNwcYcmfp544k5MdPavZO88dbn6rnKz7ksrDDY04DyhDbMI3vjqrfjl0wcHWD%2F5IODETXIG77eTnBxbpnOlvvL3w0Z4IUbJ3fX6hUEHI7PnePjpdl%2FNkM5QftbH8byW0IIMTStiYfmiHvNRUuTWh4bX9780fqPkm54fvkQ3DY9CPZ2hjGjTEemt%2BZfUY7O9potEWFglQkhhJB2Gw%2FbWtyjKLMwZBXtug2JNzz3aAT69e5klDxkuqtXRNnY2mrXDaIwI4QQ0s7jYVuJexRlFoTsxLh125nnZgtVbyxBVt9Bb57WQ2MLzeviyWESS58QQkh7jodtIe5RlFkQ8q2SE6mFLrMmdzdJfnNv6g17e62tXsFH4X0RRAsQQghpz%2FHQ3HGPosyCOJaUe3v0KH%2BD9SFrCplP5ABvOTaCLXRYSQsQQghpz%2FHQ3HGPosyCSEguCBoe4WvSPCeM9JMLJ%2FEZPqgPBtAKhBBC2nM8NGfcoyizILJzyh39OzubNM%2Bw4I7VKxpkaPWYQSsQQghpz%2FHQnHGPosyCyCko13i6O5g0zwDfOqd3FZ%2FxtILxKS2rQEZmPguCEELMEA%2FNGffUkdWG9oXvniO40NhOTW03FimpF7Dkn%2B%2FU%2Fb%2Fi0VnoE3IF%2FvHv%2FyEh6az6nUcnV%2FQK9sP1U6LQI7Bz3b7vb9qBT7fs%2BUuaTz82W93%2F1jkvQqfX4fUX74Wbq5O67aedR%2FDbnuOImT0OC5asbfS4ao%2FD1Oh1CrQ2pp39pjY%2FRYGHxowzQFgTO4Qfrl77FbZ%2BtJyFQQghJo6HrYl7l6uTan%2BvZlapw9nwUGy2tcF9DSXa1HZjEdDFE08uvwXjpv5TDVDBPbqo3x8%2Bloqh4b0wdmQ%2FZOcUYtuO3zFx%2BgqsfOoOTLtmqLrP6TOZcLC3xYI511yUZpfO1a%2FO7tufBH8%2FD7z%2B1rd46L7r1O%2BysgoQn5CGjh1d8OCCqep3VVV6zIpZidUr56CzT3WVZlc%2FL6u7ADTVTwxOvBUQQghh3DOMTooMxXSdBi9X6eAp%2Fq2eg0BT3Yw5U6fDdJHop39OtKntxsJOiCopnGrFlIO9Xd02KdCujAxR1ydHD8GUSZGYs3ANhgzqCb8u1b%2Fx9nav26chliycjsWPvIk7bhkLL48Odd87OtjX%2Fa6yokpdDh7QA926%2BliMM6WmlyDtfGmD22zFU8DQgR6tSdbk03IdOnIKH378M3JyixDg54mbZ46sE%2BcffvwLvtt%2BAE6ODpg1YzhGXtVH%2Ff7g7yk4k54lfGKI%2Bn9FZRVWv%2F4l7ptzrepTH2z6GZHhPXE6LVPd97rJQ9Va1m9%2B2C%2FSO4hKsf%2FQIb0x87phqs%2F9fvQU3tvwE9LPZSNycC%2FM%2B%2FtE1UcuRVp6Nj77cs9FDwXyuy%2B%2Fi8XcOyeqDxby%2BDMy8%2BDi4ohxI%2Ftj6jWRf0lHNmW%2Buu5rLL53KrTa6qe3T7fuVsugX1g39f8Dh5Lxv407cP5CLoZGyOOLhr0dKzUJIUSybmMKDsXnI3pkZ1w7prNR4l5LdVKtGNMpCIBSLz7X30mp%2Fr%2FRRJvabk5krVloSFd8%2BW0s7r5jgvpdZmY%2Bdu09ftF%2BfUUgq22uDOkVgIljB2HVa19ixaM3tSsnfOeTVKx6t%2BEpvFyFFk%2FZ0fbHg00%2Fm42b%2Fv48ViybBU%2FPDjgsxNHPvx1VBckLqz9XBdTDi69HUVEpFi1bh5VP3olxo%2FrjwO%2FJqt1rRVl5eSWeF%2FvPjYmuFmVC5L382lb07umPHt07o0xslzWmUngtu%2F966PR6bPr0N0QMDEJpaQXmLH4Fy5fMRBdfD6x75zssfexdvPTsXZc8dl%2FxQLD27e8wJDxYrdWVvLvhR%2BTnF1f7ZlYBuvp74erR%2FZGbV4zHn%2F4QdkJITRo%2F%2BKJ0SkrL1WNfOHeyEGXV94ZPvtiNayaEq6JsT1wi7luyFo89%2FDf4eHfEq29%2BjUdXvKeWBSGEEODX2Gxs%2FfEc%2FH2dWiPKWkRTOqkxMdagKGss0ZZmai4Cu3ojTQTyWo4dPyMC2hcX7SP7lLkF%2F1Eb%2BeB912H8tMdw9%2B0T2pUTTrvaD726uzZcU2ZrGe93nEg%2BrzZBTxw3CB06OKvCW6LT6fGGEDwfv7cUfUOr%2B%2FblF5QIQfKNKsqaw713TcJtN42pS2%2FGrc%2FivdcXI2JQcHX5XTMUer2CuxeuwQPzp9U1i3cP9EXk6Ifw%2FFMxlyxHKf7%2Bdv1Vam2YFGWyGXzTZ7%2FiXZFH7UPEmBF91XN0crTHoAE9sP%2FQyb%2BIsqaQNYBLhTCVtcUS%2Fy4eGH3tcooyQgipoXcPN%2BQWVOAKP9P1wPmLTtLg6yrgX42JsUuKslr0wEERdqKVJrZXVSFFZGr2%2FkZ5%2BcUI6t6l7v9RIui9%2BMzfL%2FmbKwK8MHP6VUK8fYarhoYa7dhE%2BSimLItu%2Fs7w6GjX4DaNRmMR53Hl0N7o3ycQA4ffjz5hV2DksDDMi4lGcXEZCotK1Rc26i66nv7qiyHNxcfbvW5dvulYIERd%2F76BF%2B0jmwsTktKx%2F%2BBJvPTqlrrvfX06oqy8Aq62jpfM45a%2FjRKC%2F3H8%2B9GbsWtfAvw6e9Q1OX7%2F40Ese%2BI9tXk%2BKLAzUs9kIPCKljePJ548iyef24jnXvrj2cnTw01tsjVEE6ap%2FZYQQgzNsnm9zXYflDpJRNxrqxTcIJb6phJq8K4tfvib%2BGG6WF4tElwnlvdfaru49z%2FbkpoyY9zoz57Lwa69CXjkwRta%2FNtF90zBiOhH4OXZwWhOERePy35NpCXl9vI7J4zSfGnK85Ci4p3XFuFCRh7ihDB6df036vrjy2apwlIKM89Obuq%2Bct3V5Q%2BRVFmla%2FbxuDg7qOlJUe%2Fj5X7RNtnULZs0a2uiWoIUWYMHBql9y3785TBm3zi6btvD%2F3wHzzxxK6Kvrq4Z%2B%2Fd%2FNkJRlAauxerirhSPW7Z2f%2B3aIM956T9mYMLYgWbx25mAzale6KbTIkzsOVbsfJM4iyO2CubvPY5EhgNCyJ%2BJDEGvKg3WiPtFX3G%2F%2BFBEhO02ehwLTETqJqBZN%2B%2BWxMOzGWVIOVMMNxdb9A9xN0rc%2B%2FPx1NdJYvm6ox3Wl1UiRgvcpWiQD1lj1pQoq01EqU5kj4gBoVJsiczuv9R2cxq3sLBUrYVY8X8bMHvWaIT17triNLyFGIuZfbXaByhqSO924fSjhnrBybHh%2Fol2dhqLOAfZGd7O1hYhvfzVPlTJpy6oTXxSKA0ZHIz%2FbfhJFdSy%2BfH9jTswtqbpUtaCHUs4o%2FbHkh3yP9u655L5yKZRmZ5s%2Fnx86Y3qd3vjktRaVNl0%2Bsq6rzE8Kkx9K1c2Q367%2FQCuFcfTHG69cRT%2B89KnyM0rwprn59Z9X15ZBQeH6prMzOwCtbP%2BwP5%2FncOtgzhXeQ6x%2B09gxLAw9aWDpJNyOJjq%2FCeOG4zVa79EVEQv9TyqKnX47seDanmZAvUGmohksSo%2FW4OD8Yi7HZboNNg9KAwzDxzDNoYgQkgt4r4wTqdgk4hCL%2BRXYvKJEyiv3bbPSHk%2B%2F2Yi3v0kFY%2FcE9IqUdYSmtBJDwzti2fFbXppY%2BKsvijb1ITY2mRqMSabjm6d%2B6K6PmXWU3j9v%2FeoNQ%2FqmT26Xv04Ozmgtwja9829FrNmjLj4gD%2F9Vf3UZ8uGf9SlUZ97YqLVjtjthVGR3urHkpGiau7C%2F6piQ%2Fa7Ki4px7pV89VtLzwdg9vnvYQt38SiuLhU7ev14IJp6rZxo%2FtjzdqvED7qQdjZ2GBSMwTKi8%2FehXmLXsWg4ferNVJSCG18ewkW3H0NzmfkIurqh%2BHR0RW5BcWIGBjcbFEWLUTT8n%2B%2Fr75ZKc%2BhlmWLr8ddC9bA26uDKs68PNwa%2FL08loXzrsWt815UHx78u3jWvagiWXzvFPUNzsixS%2BqOb5h4DDWVKPszNTfYJweHqF0bNolDiWKNGSGktoZMCjJFwW37j2OrqfL9ZV%2BW2kIUc0Og0Z9Tm9JJNd81Ks40NdVuJSKR10QiDTZDNrW9pchqvthf1rd7B4wYEVO3bqhmv9gvppj%2BPKZuMfx5tMD%2BcigJ2b%2BrdqiTP2%2Bzd7D9S7OjbAqUL33ImiZ3d5dm5yVrrWSXu%2FpDpEjk0BRZYpsUUU0Nh9Fc8vKKUSgEpXwLsymycgpQWaGrG2evIQErx%2ByTtYT1h44xp98KO8vRb0eKNCaAEGL1iHvCd2Lxs7gnPGmqeCiHhho05QfMvzUITywMM1rca61OkoPGSnEmMpgn8qkep8zWBt0vlUhT2wkxJgH%2Bni3eJvuINUfs%2FBnvRvoVylqu%2BunJ2R9Wv%2FFVo%2Bk8cv8MhA8KumResjlUfprDn0Xin5E1xs7%2BDm3Kbm6lWFnohPlyQt8DR3GInkyI9aJO7K1HP3FfmGrKfHfGZsHeXot7bulh1Hxaq5Pq15yp6dT7sqkfETMjp34w9VRLRcWVLPgGGD28r%2FohjfPTKZSFh%2BGDmgl9KcoIseb4Je8DGnwg7wumjIeTRnXG6Chv%2BHo6GjXuXa5Oqv09JyS3IDq62Vdl55ebNM%2BkUwUseNJ6FGxXgCtZEIRY%2B61A3AfE%2FcDU8dDdzQ6dvRxblLY54x5FmQXh5mKXl36%2BxKR57j2UpS41CgrRzFeVCalFPMgeFc%2BxvVgShFg38j4g7weWEA%2FNGfcoyiwIz04OO3bGmrYl%2BfudZ6ufcjTIEAs2Y5MW4VSk%2Bow3S4IQq8e75n7Q5uOhOeMeRZkFceJ06TNfbk%2BrqqjUmyS%2FlLRCnEorqvUUOQ7VaVqBtIRdaWr%2FEUeWBCFWj2PN%2FaBNx0Nzxz2KMgvixz0lcfZ22tgNW1NMkt%2ByZ%2BP%2B%2BEeBnEn7e1qBtBA5yrWGxUCI1aOpuR%2B06Xho7rhHUWZhpGeVzF63IbHscEKuUfP5zxtHcDK1sNYxk8UnXK%2FFZlqAEEJIe4yHbSHuUZRZGHHCZyoqlRkLHt%2BtM5Ywk465sf7ThwY7xSPOPo41RQghpD3Gw7YS9yjKLJA9h3VfFZVW3T33kd%2BUVe%2FGw1Bt6rIt%2Fcb7frrYMRW8L%2F5OVGzwMEueEEJIe4qHbS3u2dKklsn%2BY3grIlSvfW%2Fzydc2fJFiGzXQC9GjAtArqAO6%2Bbk2K42SsiokJBdg78FM%2FLDzrHDOoot3kI6pwViNBnfGiicSljohhBBLjodtPe6ZTZTVn1%2BPtI7YeLw5uI%2BSrqvQbdqx94KN%2BDgZJGHZlq7BTrEWrWhxe9xRfEP7k7aMEjvH7uNduxcdS8y9LeFkfs%2Bc%2FAqHzJyyRl8w8OzkUOXiZJfn5eGwQ77FJTsNsxQJ%2Fd%2BK46EJ4l5zMOtbUXJCUWu5aAwxkXej5dgXQdBhpSjNEULdnxNfuSsaeIj%2FmzsTd5E4uEyNgkS9BiWKgkitBntk1W2cEZ8UrMn%2B1uy30s7G9P%2Fv3w6%2FZ%2Bu2M88lphS4TB7bFcMjfNDZxxk%2Bl5hWJSO7DOczSrAzNgOf%2F3C6ytHeJlZ2Go5jjTCxMCzF%2F419H2hFPDRL3GsKG3M6k583nrCWC%2BdcFlYYLe0M5Ir0P%2Brsi2%2BFg0mn9xEOaCfWOjQzCXv56q9wXDnh1y7hlMv3H8PLMl3a37oxhN9KOxvD%2FxXlCW2YR%2FbGVW%2FHL5k4OsD%2ByQcHI2qQN3y9neDifOlGALld7jdkgBdunNxdq1cQcDg%2Bd46Pl2b%2F2QzlBC1P2jqW5v%2FGug9cRjw0S9xrCo4fRAgx7pOrkZ6QP3qp36b1HyXd8NyjEejXu9Nlpyff3pJvcZWUVs2JPYb1tBxpy1ia%2F5uqpszS4duXhBCLQzbZrNuQaLCAJJHprF4RZWNrq103KAzs9Ejo%2F4SijBBCLoXs1Cz70MyeHmSwgFQ%2FMN08rYfGFprXI8IwiaVN6P%2BEoowQ0q7iCAzYVUK%2BZXYitdBl1uTuRjnYuTf1hr291lav4CO10zAhbQgL9X%2BDTrFEUUYIIa2n7MoAw01Kfiwp9%2FboUf6wtzPO7UumGznAW0YRW%2FUtLkLaEJbo%2FzXXfxmtR1FGCDE%2FmaWu8DVUYgnJBUHDI3yNesATRvrJhRznaPigPhhAE5K2giX6f831n0nrUZQRQsyMAiTaaNDHUOll55Q7%2Bnd2NuoxhwV3rF7RIEOrxwxakbQVLNH%2F5fUv7wO0HkUZIcTMaIBdctoSQ6WXU1Cu8XR3aNFvsnLKceZcCfIKKpu1f4BvXdCTc7SMpxVJW6G5%2Fq8IFSR9Xn4qKlo2H6TB%2FV9OWyTvA4SijBBiXvRabIaCm0cHGqZfmV6nQGvT%2FPcGklKLED5tG8bc8rMaoJp1Y6xJXwQ2D7G4glYkbeZ6aqb%2Fa8Qu%2F30rCYOnbsP9Tx1qmTAwoP%2Br1724%2FtX7AKEoI4SYlwNHISPC4UInPGSO%2FBf96xBKynRYuaw%2F%2BvV2b%2BEDvlpT4EsrEkvkuaX90T%2FEHRu%2FSsP3v15o8e8N4f811%2F3hmvsAoSgjhJgbGwULxOKBwSGYbMp8f96bhX2%2F5yBqoAeum%2BDX6sOnBYlFXnc2Gjz9YF91%2FYV1SSb3%2F5rr%2FYGa659QlBFC2gJ7j6uT%2Fs7UaPBueCiWBwfDwRT5fr3jvLq8eSpbIIl1MlQ8kPS4wgVxR3NxPss0o1LI61te5%2FJ6l9e9vP5pieZhyyIghJiCA8ewLTIEUVUarHG3w%2FzBofgQCrbb6HEsMBGpmwCdofP8PSFfXQ7p34kGIFbLkH6dkHy6GEcSCtDZy9Hg6c8EbE71QjedFmE1nfpvUoAjtgqi4uIpyCjKCCFtkpon5vFy7COtguvF%2BkK9DXomh6JbOAw%2FWXFuXoW69Ox0eRVzcjJlWo9YKl4e1f6fk19hFP9Prh6tP1VcwEniKt6l1yCafcgoygghFkLNDbtVN%2B2WCCRX1%2BpbXGmZDp062LX6eMXTvqaVNQXz2XRDaokMQS9ZUyz8o6%2Fwj1bVFLfmAaGkpDppFydbo%2Fg%2FoSgjhJAmCfR3EQIwD0cS8%2BHn42i0fNSAmigrDNTP1uBgPOJuhyU6DXYPCsNM2XRLa1g3wg%2FG6RRsEurmhfxKTD5xAuW12%2FYZOW%2Fp%2F5IeXZ1piDYOO%2FoTQtotY6%2F0Vpebv043ab4y4MbF40lFwW1aEYhlDQmtYb1I%2B0s%2FkP4g%2FaK%2BIDM2qekliD2Sqz6UhAR1oDEoygghxDxMn%2BCvdmzesv0c4k8UmDz%2F%2FcexVSxe0GmwmtawXmrs%2F0KNP5iU59YmqKP7z7s5SB1QllCUEUKIWXCw1%2BLph%2FqiskqPex8%2FgMLiKpMfg1spVopFP05sbp3U2L1fjR%2BYlE%2B%2FS1cHjg3r2QExMwNpDAuAfcoIIZb1JGmjadFUS1PGdcG7K4cgv7ASaedKEBrcdBNOUXGlwY73p1MoCw%2FDBzUTO%2FONNGvzV2l3DT6QfmBK%2F5e1Y3rxefmxgRg22FN9QGkuhvR%2FQlFGCGnHdHSzr8rOL7f19mh%2Bx%2F1Jozq3KI%2BkUwZu6lSwXcTHxbSe9SHsfqVGwYum9n%2FZVDljon%2Br8jC4%2F5Pmi24WASHEknBzsctLP19i1Dz2HsqqDmwKCmGAQW11Co6KGMnO%2FlaItLu0vzX7P6EoI4S0Uzw7OezYGXvBqHl8v%2FOsulQ0yBCLy87MqUhNw5vWs0q8a%2Bxvtf5PKMoIIe2UE6dLn%2Flye1pVRaXeKOmnpBXiVFpR7R1Sjjt2%2BnLT3JWm9idypPWsEsca%2B1ut%2FxOKMkJIO%2BXHPSVx9nba2A1bU4yS%2FrJn4%2F74R0GxrDgwQLJyFHYOSGCdaGrsb83%2BTyjKCCHtlfSsktnrNiSWHU7INWi6%2F3njCE6mFtYGpGTxCddrsZklTuj%2FhKKMEEIaIE7EjopKZcaCx3frDBWYZEDaWL%2F2QYOdGmAfJ1Ym9H9iKmxYBIQQi6wtyFCSPDvpz3y9PW1qSblOMyjMEzY2LW8hlH1o5v1jF3buq9efWcH7IihNEHfIm85lwCBRz88bT5zLwgpazrowlt0tzf9J8%2BA4ZYQQi2X%2FMbwVEarXvrf55GsbvkixjRrohehRAegV1AHd%2FFwb%2FE1JWRUSkguw92Amfth5VgSloot3qA5IYzUa3Bl7BCdZyoT%2BTyjKCCGkGcTG483BfZR0XYVu0469F2zEx6lVCck%2BNBrsFGvRiha3xx3FN235vMNDDdd5nFxMXLzlvJRhrf5PUUYIIW21xkAEkPC%2BGAgdVorgMkI85Z8TX7srGniI%2F10a%2BVmRiLyZGgWJeg1KhMKJ1AKuii2G7beQGoLYX9bT%2BAYmYkQM%2FZ81ZBRlhBByOcRVB5LpcgLomnkmJ0Avnv01jQYlV0VBnghcHcX6XsUGK2LZqZngj1pIS6oxo%2F9TlBFCSJuj5m0x%2BXmMpUHo%2F8SS4JAYhBBCCCEUZYQQQgghhKKMEEJMB6dasj4MOsUSoSgjhBBiGMquDOCk5NZEjb3LWBKEoowQQtoWmaWu8GUxWA819s5kSRCKMkIIaUMoQKKNBn1YEtaDtLe0O0uCUJQRQkgbQgPsktPXsCSaR25uEQoLSy3d6GNVuxNCUUYIIW0HvRaboeDm0YGW06%2BsuKQcm7%2B4WFPI%2Fx976gOj5%2F3kyk146%2F1t6vq2Hb9j0dJ1Tf5m%2B8%2BHcSY9q02UnWpnYW%2FV7oRQlBFCSNuhZlDPw4VOeMhSjjkrpwBLlr990XdhvQMwZmQ%2Fkx5Hj0BfRF89uMn9Vr2%2BFYcOp7SJsqux8%2BEDHCWftACO6E8IISbCRsECnQa7B4fg4P7j2GqqfIuKy%2FDGW98i9uAJdOvqgzl3TED3btXvHHzzw364uTrh0JFT%2BG3PcYSFdMWie6bAxdkBmz79FTq9Di%2Bs%2Flzd92%2FTh6O8ouqiZsW09Gysfec7JJxIx6B%2BPTAvZiLc3atn9nnrf9sQGdETW7%2BJxUEhlq4aGop775oErbZlI4NUVemRl19c9%2F8vvx3D51%2FtUc9Lnsdts8YgJfUC0s%2FlYIvIK%2FHEWfTr0w3jxww0i52FfSeLxQPC3lH0etISWFNGCCEmYu9xdfLnmRoN3g0PxfLgYDiYIt877nlZFS0L7r4WgVf4YNqsp3H%2BQq667Wshyu5e9AryC4ox9ZpI%2FCYOctnj76jbfLzcAXGwXf291I%2BDox1%2BF%2BLt86%2F2qtvz8oox7ean0amjKxbNm4zsnELceOdK6HR6dft6IcruvHcV3Ds4Y3J0hNocufHTnS0%2B%2FqSTZ%2FHh5p%2FV9bgDJ7Hw4bUYM6IfZky9Ugg2HfYfOokOIg8Hezt4eripxyqPydRIe0q7SvtKO0t70%2BtJS2BNGSGEmJADx7AtMgRRVRqscbfD%2FMGh%2BBAKttvocSwwEambAJ0h8zv4ewoSktKw4c0HYWtng2FDQ9Raqw8%2F%2FgX3z5%2Bq7nPv3ydhwZxr1PX%2BfQIRfcMKPP90DEaN6AsbjRYzp1%2FVYNqbt%2BxCSE9%2FLL53ivp%2F1JDeGDZ%2BKXbuiseo4dUvmv5XpHNVVKi6nnLqAvYfTMasGSNafT7x4lx8vN1x9ZgBqgirXxvm5emGYZG9hQAcYhJbzgRsTvVCN50WYTWd%2Bm9SgCO2CqLi4inICEUZIYS0eWpqUMYP6oMBWgXXi%2FWFehv0TA5Ft3ADj%2FqfnHoBPQI7q4Kslt7B%2FjiZcq7uf029HIMCfVFZUYXs7MIm05a1bz2D%2Feqlo0HPID8knzpfJ8rqN1V2cHNGTm7RZZ3PtePD8dEnO9EvaiH69%2B2OsSP74e7bxsPO3vDhLDz00qPxJ1eP1p8qzjBJWG2XXoNo9iEjFGWEEGKB1ATwVgXxpgRDLa4ujigsunhoCfm%2Fq6tTg%2Fvn5BXBxkYLd3dnZAlhpijKJdPOyi74a9oujbxgagC52amTK7Zs%2BAdS0zKx%2F%2BBJvPjKFlRWVqn94CSKASc1iovntFjEtLBPGSGEtGOiInrh7Lkc7Imrbk2T439t%2FXafWsNUS0FhibrU6xWsWfsVRg%2FvC2cnB7i7OaGySofTaQ0PMzF2ZH98t%2B0gMjLz1f%2BPxJ%2FGkWOnMWJYmNHOZ9e%2BBHXYi24B3pg%2BOUptMq2tfZM1cSeSz9HoxGJhTRkhhLRjZAf4l569C3PuewXdunmr%2Fbpkn676fbE%2B2bIbH3%2B%2BC%2BUVlerbjOtenq9%2BL9%2BinDVjOCZMfxwuzo5Y8%2Fzci9KODO%2BJu24fjzFTlqNnDz%2B1SfTZf92Ozr6djHY%2B2dkFiJm%2FCv5dPKHT6eDoYI%2B3XrlP3XbHLWMxb%2FGravPm2FH98fRjs%2BkAxKJg1SwhhFggsvky9pf1zd6%2ForIKFzLy4O7mrAq1WhYtW4deQX6IufVqFBSUwNen419%2BK8cr02q08OjU8BuNsslSDlnh7dVBFUnGRr7defZ8jtrRX3b6r09pWYXaHy7A37NVaUeMiKlbZ%2FMlMTWsKSOEECvA3s5WHSqiMZwc7dVPQ3h5dLhk2nKcM7dG%2Bqg1xI6dR7HqjS8b3b508XQMGdyz0e2yz1tj5yLPobWCjBCKMkIIIWbjlpmj0MHNyaR5yjcza9%2FOJIRQlBFCCEF1vzBCSNuAb18SQgghhFCUEUIIIYQQijJCCCGEEIoyQgghhBBCUUYIIYQQQlFGCCGEEEIoygghhBBCKMoIIYQQQsif4eCxhBBiodSfp5EQYvnYsAgIIcTyOJeFFfLj540nWBrGK2OWAjElbL4khBBCCCGEEEIIIUTy%2Fyr0xHnKKM%2BPAAAAAElFTkSuQmCC)

```
source_def
         ::= IDENT '=' source_value ( '(' option_list? ')' )? ';'
```

referenced by:

* sources_block

Comments:

`option_list` in `source_def` is not supported and raises syntax error when used!
According to the grammar, identifiers defined in source block are referenced in the grammar
as `source_name`, however, the grammar can't be defined using this type of token, as there is
no rule to distinguish between an identifier token and a source name token. So the grammar uses
the `IDENT` token instead and documents this fact in description, that it's a `source_name` identifier.


**source_value:**

![source_value](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAYkAAABRCAYAAAAnx1pLAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAGh5JREFUeNrtnQdcFEcbh%2F8HRxcUAQv2LooFsPdoLFiI3WiMGnvsJbHFxBKjH5YYuzGWxN57iwaNFVFQEdRQBFGwoRTp5e6%2BmTnuAAU5lHbwPv7W5bbM7s6%2B87aZ3QUIgiAIIhMkheEiHGygoFtZtPB4WDhklyAKOtLCciHuV7bS3SwiNGo9nCqBIPIIHaoCQlujR4ogCYKMBEEQBEFGgiAIgiAjQRAEQZCRIAiCIMhIEARBEGQkCIIgCDISBEEQBEFGgiAIgtAU8cR1U1uUdvPGy8w2ymq9NhEWHo1f1x3DtRsPEReXiPLWFmjWpBa%2BHeGIhc778CjwRYb7dfqsAdq0tMXcRbvUy6pVKYP%2BPVvCwa6a%2BH3%2FvyeYt3ivev3yRcNQuWIpTJm9BcEhb7DaeSSsy5YU67weBOHPXRew4pdv1Nv7%2BIXg921%2F47bnI8hkClQsb4kWTWtjUN82MDcvluW1fTNuNWZO6Y3aNcunW75hy1m4XLon%2Fq5QzgI9uzXDmk2nMi1n75bp%2BOHnnXj0OP0tNzLUx45NU%2BD36DlmL9iRWg%2BVS6NvzxZobF%2FjvbL4tYeFRWHb%2BknQ1U31SX5de4xdn5XYjyCInOdT9bZqf2EkkmR45mCDQ1JdTMyo0KzWawsKhQIDhi1DjWrWWLNsNMxMjeHpFYid%2By%2Fhi65h%2BKp%2FG8TExCsV%2FOqjqMqMQO8ezcTv0qVK4A1Tdt5MuW9bPxGJiTLccPdBn6HOOLlvLmxtKqJ61bKYPbUPnAb%2BgosnF6FcGaVB4MfQ0ZFgBVOMKqPw9m0sPL0fq8%2Ft4hUvfDt1IyaO6Ybxo7pCT0%2BKu%2FcCsH3PRZgWM8KQgZ9leX237vjjbVTce8u%2F7N2KGccoYcRmsfPTYcp6%2BgSnFMP2lBnN49iyZrx6e12pDu7dD0K71rZo06JO6nJdXTGPjo4T17T998lIYsLh5uGLfqxej%2B2egwa2ldXb%2Bwc8x%2FmLd2FsZIArrg%2FQrpVtqkH0f8bqhAJZgsgtPlZvN7FBL5kEq5NlsGA%2FjYWRkCjTTv1kMvRihR55t9Cs1msLwc%2Fe4IHPU%2BzaMg2lLIuLZdxb7%2BHYGMnJckilqUqrZElTVGDrmjeprV7GjQRXoKplbVvVxTW3h7hy%2FYEwEgb6eihbxlysK8ciFD391FdjTRrbHTN%2F2s4ili7CmKQlmd3N7%2Bb%2Bibkz%2BmNw%2F7bq5fzcnLo2EdHPp8CjkOJmJiwSMBDGjmNlYaZer89uaNrrVMGNaUbLlQYjtR7atKwLVzcfXL52P52ROHTMFd07NULx4ibs7%2BvpjARBELlLdvW2yjjIFCif9oU36Vw5hTL9xAsNZoXu5%2BFGdtYXdLiC5Apz9caTCHr6Kn3eTZp9r5Yr99ehb1GxglWW23KjNHTQZ1j62%2BH31t3xCkBERAwG9GyZ4b4lNUg15QZ%2Bj57B9eZ%2F6ummh1%2FG9cAMbOgbXg%2BW6aK2wydd0fuL5iIaO%2FvPHcTEJlDLJYi8zqBkobe5cXCog6cy4DC4gXgHaRaFCguU1XptiSz09aTYunYi5i3eg207XWBqagT7BlXxzVcd0PGzhhqVER%2BXJPLpnBvuvrCpXQGd29tptO%2F4kV3RvNNM3PUKTLf85asIlLIyU0ceSYnJOHrKTb3ejp3ju9FHXnDmvAdu3fZX%2F1b1SXASElLr4eZtP1StXBrdOjZSb3vjlg%2FzZCRoYl8DEokElSqWwum%2F3dGvV0tqtQSRv8ZCqbclOJMMLHw3ctDISKiQA3eZf91FkcX65GQEsoMaaUNFNXGogTOHfhKeu%2FfDIJErHzFhLXZvnoZWzetoXM7TkNd46PMULid%2B1jgKMTMzxrgRjvjfykOYOLqbenmxYkYIj4wR3jdXqMlyOa4zz51z6dp9TB7bPV%2BMxKSxPdR9MpkR8jxMdMK7HFsIqZ6uevnBY64iXXfw6HXx27qMOQ4ed81xI0FvgiWI7MH1tgTolqxAXzaXZ9WAMjQSbMfrbMcQNv%2BcFbiZzad%2BaD1z0J1VkUQ%2FQPdxTVSS6aAO27A922Yg29ZbqsB4pvd8c%2BOiP0ZRlChhIowCn257BuD2vQCNjIShkR6mTfhC%2FD1tzlYMG7sKh3bOEl62Jgz%2F%2BnNs2fGPME7qSKFeFSTEJ4m%2BDZ7f52WtXDJCrBs4YkWBFDQDg9R6kOrqYCirh8O7ZsPE2ADxCYk4dc4dn7dtoDZ2vI%2FnyAlXPH8Rru63yQno40NEUaRJbdRMlmAdE35bpvz2MA14QVeOB5V9EXQAkGWkF9PqbTb%2F3VAPW5naGc5c3JEKCSIzSjVxdN4thM0OsAJs2BQs1YXN7YeYltX6tKkmfoK3fBFw%2Bz%2Bc5Osik1CZ7XdJJsENuzrokJ8Vy9M8cxbuFFGACj7ih4%2FwaWxXPdvlOc8fIkbujJ%2F%2BO%2BRyzewUNwBTxzlhy%2FZ%2F1Mt4x%2B6Y4Z0xlRkd9zup6R2ubKNTRlsVZH75cbC4hm%2BnboBMJsc5l7uoYG2JtctHC2PHp9%2FY1Ni%2BJo6cvEEtnCA%2BAa5HuT7lepXrV65nub7leldlIDTR69fvwZvPdXVRQ6HAAbZdFNs4%2BEORBC%2BEWxg3PVZIBn0MWa3PEH9%2F8N7KRfa1RWrqALOAzXIrosiKMqVKIJgZiNaOc2BhbipG6MTFJWDOtD6ZjuL5ELwP4Y%2FV49F9wCIsXLoPTl0aYwxTlJz2PeZix%2B9TUbO69Xv7DezTGhu3nk23bMbk3mIE0sgJa0XKiXvqEZEx7LxqiRSZpvT6akm6319%2F2U4Mod114DISE5IwaOQK7N48XaOyJn6%2FSUzqtJiJIXw81r8fjjKB%2BGPVOFYPv2Dekj148jQUPbs3fW87vmzbzn8wbqSj%2BL1s9RExqahauQyunF1MWoAgPhBByJhCZ0p9CDcMGuySpd5OWTatqS2ck2SY%2BW5kIUkJS2JZIRtZIc4ZFZLV%2BmykheayWRuPh%2BiU0%2Bmm7Hy%2BlHcMvwiNEH9XKGdZ4ATh2fMwyORylLIqLobVEulJ%2B%2FlSSjcRRQmm686x2WUm94s02Paj9DYf%2FcSNBWtYY9lxlM9JsPCjyocKyWq9ppjGYXmUEcbb1UWDO%2FfhmV8VzSOAgmgcVKieyk7LfOahez98mnG9FjMUTzQTBFGI00xMb0KOekyPOmmy%2Fcfq7bSRhSgnzcKsdvpk%2Fn2MeIc62K0jRx%2F205Nuu%2BbMnz2QKoEgijBCb0qwm%2BvRbCj7j0a1f96%2FF0GBCywEak63nCAIIjuqk%2BlNpj%2Fz3Djl9QFlCtyXADXplhMEQWgO15tcfxZ6I2EULUIYK7rlBEEQ2cIqRX8WbiPhGizyaYZ0vwmCILKFYYr%2BLNxGAiK1RsMWCYIgsokkRX8WeiNBEARBaAlkJAiCIAgyEgRBEAQZCYIgCCIHkRaWC0n7Ph%2BCIAiCIgk1%2FCVv9KI3giAIMhIEQRBEHiItTBdD0QRBEARFEgRBEAQZCYIgCIKMBEEQBEFGgiAIgiAjQRAEQZCRIAiCIMhIEARBEGQkCIIgCCIjCsXDdA42ef8hjoJObj9YqHAfrXfQ9cbkB77hQ3weRdYIi0w0CA2Lz%2FSYFuYGySZGehGWJQ0u%2BT%2BJW3LRLdaD5IIgeSYjkWe4X9lKLSmF3H7Z4fk%2FHb6dsuroMt%2FAtybd21dAz7EVUaaUMUpZZP5V2ldv4qUvXsVaXnV%2F1Sco5MkXTu2M3UNexw728MYjkguC5JmMBJFP0VVOemAKxXyd%2FasP7Vu60bvv4N7VsHR2Y%2BjraZax5A2OT%2FVtSmLklzWle08GNtu819e7UT1Fb3cv2Rm6YwTJc8GE%2BiQIjeENaus%2Bv74r5jbGkF7VNG5Q78L34%2FuvW9jM0FhfcqJRHdB73gmSZzIShDbDQ3LmKfVdNqcR6tUyz5EyeTlrFzTTlUp1NtuRoSBInslIENoJ79Q76fJ02WDmLeVUg0rbsAZ9UVUiheR35oE5Um0TJM9kJMR9YhO91ltL4KM%2B%2FIOiTL7sXiVXyh8zsBb09XWkcgX2OdiiGtU4QfL8HpIUvVlkjER88%2FIwJHHVDh74hQ%2Ft0rbcR%2Bdss4KX26SBFW8FUsiwnGqcIHlOT4q%2BjC9KRiI0rhhKk7hqBz4Bb6u1apS7t6tTG2s%2BM2JTK7u6aEC1TpA8p5KiL0OLjJFgMZOvrgR1SVy1gzdhCYblyhjn6jHqVC%2BhCqpf6cjRh2qdIHlOhetLrjeLjJFgYZgr%2B689iat2EPY2QWJR3CBb%2B7wOS8DT57GIeJuk0fblS6sbbTE2daRaJ%2FJbnhVMK3MZ5lNiojxbx8hxeWb6UujNfCBfHqaT6%2BAQs65n21XGD%2F8%2Bzts827Q5W%2FEk%2BHW6ZWamRti6biL%2Bt%2FIQTIsZYfyormmU3VtMmvEHxgzrgjWbTmVarvOCITj7z21cvOL93rr1v45BieImGDTiV%2FWysqVLoGunRnDsaJ9axsrDuHXHH3Om9YF9Q2V%2FV%2Bibt5gyczN2bZ6Wb41KLlNAR1fzcQZ%2BQdH4fPBl6Onp4MiG5ihhVjxrbyWlfNYwS0ryQS4HjliB2aze69etnOW2B45cQ4%2BujWFooF%2FgFOCr0Ejc9nyELp%2FbkzX4RHmWsE1WbvPDjiNP0L9reaxbYKe5952D8sz0pGGUAoOY3uxSZIzEnfvwdLCBV5QRvmM%2FF%2BXlsT29A9GNKefmTWqlVoJUV8wH9G6FLr0XoEWT2rBrUFUsmzVvO2pWL4dG9tUxfYKTWBYVHY9vxq3GlrUTUNxM6TGULlUC%2FgHPUdqqOAYPaJvumHwbmUwO15v%2FYcOvY2FlaQav%2B0GYOmcLYmLi0bdnC7Hdf37BCI%2BIwuIVB3Fwx0yxLCE%2BCW7uvlrVCCcv9ERsvAx%2F%2FNgQ9WoVz9a%2BEqXnZZTX59zHqTm7dyU08C4VmDJ7C9q2soWhVcEzEr7%2BIXD%2B7TAZiRxi2cz68HwYif2ng9GzkzU6tiyd5%2FKcoie9uN4sMkaCo6vABJkEN%2Bxr4%2B7t%2F3AyL49dq0Y5ZiRqv7e8SqXSmDm1t1De544uwIkztxDw%2BCXWrRgDA3099T7h4dFizg2HZUmzdGWUs7bIsOy4%2BEQxt29QDeXLKbd5%2FDSURR5eaiPB%2BXrAZ1i%2F5QwuXPZC%2Bzb1tK5RXb75GrfuhaFZw5KiUX2seOT1eb8Ji2Keo9L7%2B9vljogoffxCxH2oVNEK30%2FsieIsGjxw9LrYZuPWsyhmYoguLBKsU6tCluWfOX8b5y%2FeRVJSMpo2roV%2B7J5zmbru9h92H7iMaOYsfN6uPr7q31acR2RkDP7acxGd2tvhj7%2FOIfR1JL7%2Bsh06ftZQqTii4rCJLefnWMLMBG1a1kG3zo1w4Nh1vHkThV%2FXHhPbjRrWSVzLh0hITMLWHS7CieEOzbBBHeBgVw1BwaE4xK531FBWhqmyDB4ty%2BUKFgU74Pjpm7BiTtGt235wu%2BWLhvWrYOKYbiLCevkqAsdOuTHZbinmMrkcI4doXxZRl0UEi6fbovuoa%2Fh1s1%2B2jcSnyjPTj915AoTpy2b5VQf59jAdk0dfuQT9WHvYzqKKudWrwyCvjs0bFm8QqokLuYpvvuqAUsyjnD1%2FB3523oc1y0aJxqwpIc%2FepCubT7wRZsTzF2GoWN4q3TIDAz1MG%2B8E55WHhNeqbZy59ELMBzlV1Krz5kr%2FxatwtZEYPn4NnrH74%2BTYWER9Py%2FbL9bxKJBjXbYkKpSzhIlx1mK7YctZER1yo9%2BhXQOcOeeBx0GvcOX6A4ybtpEtq4%2Bhgz7D3sNXRcqTE%2FE2BktXHcGcBTtEVNvYvgZGTV4v5IszbvpGPHsexuS1vVDO3AiJ87Mwg1RPV5wbn1RR8ocYOWGdiIInjO6Gdq3rYdi4VQgMeolKTDYf%2BDzF9B%2BUL0m8ey8QcxbuVKfkjp%2B5idGT1iEhIQlOXZvg%2FAVPzF%2ByVynbL8PF%2Bfcb6gz%2FwOfCcGkrTZnDU7WiCTzuh%2BPF67zJjnN9yPUi149cT3J9mV%2FXn68v%2BLvzAC7MoW6WLMG64noYb2%2BDPVDggq4cDyr7IugAIMuN45782x3Xb%2Fqof%2FM%2BCd4IlXlICZbM%2BxptHOdgGGuAdWtnT9nxPoWXoZHplvE%2BCZU3t3n7OXY8YxGhBIe8wYpf3n96vx%2Fzvrhi4Y3QoUF1rWpQ93yU1964vjm0mbHDu2DKuB7ib%2B5Fc4XHadfKVsydHJswZyLrVFpyshyrNp7A7j%2BmqfuZenZrKrzxRczwjGeKuVd3pZNY3toSjn0WYDqLWjj6elIc2jlTHeEcPXUD95jB4tGq98MnWNirlYhI%2BTSoXxv1%2Bblcuod%2BvVpqdJ13vQLxKPAF%2Fto4GTo6EjRxqIEbt3xwmhky3je3cvEIOPZdiFUbTmDf4WtYs3SUiIRVTJ%2FQU7QTodiqlMWgkSuw%2BKevlQ6PoR6O7JwNMzNjaDuN65kj4EkMvH3eooxlzj%2Fi1Y9FG49ropJMB3VSOqkHMhfRW8oiCI%2BHyNd8c76%2FBTbFQnbkY4l1FOjN%2Fp4k10WNABtUcsilp7KnT%2FhChOaZ8dfuC8Jo8HB68tgeGikDFVwBzJneN9N0Eyc2LgGnmKE6uH0mSpoXyyDE1cGMKb2xePkB7N7yaR3Wef1NhfAI5XVamBto1Xm%2FF2Kn6djkKZikpI%2FzV16y6ISnht7tEOcK%2BVHgS5HKUVGjWlkkJiWLCFPlsKgMhNKZ4X1byvPghoQPwuDGy75hVQwf%2FDka2FbO9vn5%2BT8TqaEWHWemW66KcLmB3LByrOirmzC6K1o2s0m3XZrTQ9XKpUXajPezcXjaKacNRH7JhWVJpTyHRSbmynkHKJ%2BmDmLV6ce0niuLHrrkVx9EgTMS6qhCWSGe%2BS04l6%2Fdx1mXO3A5thBLWOj%2F3dxt2P77lBy7zpFDOglPrFxZC4ycuBYn9s1N55mp6NrRHuv%2FOI09B6980vFy4tXK2anfYsWkKUZRBnMzPa0579yC91twRR8RFfNe%2F5VpMUNERcepf3MFywc4mLB9VIo2Mwb3bys623kq7PR5DwwYtgx3rq4U67KTpuTHqlalDM4dnZ%2FpNoeOXUe9OpVw7NRNfDvcESVKmGTsIERGC8NgbJx7meP8kovYWKVxNjGS5tt555vDBEJNREQMpv2wFct%2FHiY8qB%2B%2B6wdf5ml9qqLOiG8Gd4BjJwcMGfub8DTfhSuWWVP7YMv2f7SqDiuXUyoQb9%2FIQikj%2FL5w75jn8DWBd3Y3sqvODH7qJwbcPHyF996%2BbX0hWzwlxdmx918RDbxrTDJU3MddRTqKp4fGjXBETGy8GAnHz%2B0FKzsmNkGj82vZtDaehITi6Ck39bKgp6%2Fg6f1Y%2FH3stBv%2BveqNw7tmiShi4oxNIlWmIjIqVsy5cVvHrrFzBzsRCRc2VPJctYIxihpF8qNDoyevT%2Febp3y8XFdj1oLtYvRIm5bKh8F5p%2BTyRcMwctI6tGpuIzoCs2Id8%2F75lJYbLkthafF%2Bw%2F%2F5h0EYPHolRk1eh52b3k8rtW5RR%2BSxPe74a03dtm9uhSPnQnDoTAg6tSqcb14ZM6wzhn27CuZMbr6f2Cvd6LSMWOU8AmMmb4Bdq6nQlerAyNAAB%2F76HpPGdmfL16Nl55kobmoiFP2fGyZrdA5%2F7bmAH3%2FZjZrVrBH4%2BCV%2BmjFAePjcSDSwrYKmHb6HrkQHZw%2FPQ9ky5h80YtvWT8L02Vux0HmfMDy8I3rl%2F0aIAR5zf97FznUmjI0MsOjHr9A1pX9i6njlcPBd%2By%2Fhr90XRTqVj%2FLatGpcobvfQSGxcPcOh3UpQ9SuZlbk9GWheBMrDx%2FpM5WppP3cY06F5%2B7He2i0bUKiHI2%2BcMGbiES47GgNm%2BqaN6pGTidy%2FrxzSS541JmYnIxSlpr3V716HSm8bAtz03TL%2BQOT8UzJauKEpEvvhEcjmhkWPuLq3Qf7eKTCFbtq6KomvHgZDh12fppeE0%2BXtm5eR3SS81RZdupCW%2BSZM2H%2BHew7FYyFU%2Bri26%2Bq5ps8UyRBFAoM9HWw%2BDtbDJ%2FljnHz7uD4ppYwNSl8YqbKy5%2B7cBeb%2FjyX6XY%2Fzeyv7rTOTIlaWXycd8ojGfMMBj5w%2BMOdnBVrj8E1zUi%2Bdzm4fYb67zKlP25EGjdGfCqM8KiYP0hXp4YZhverXCTbNBkJIkv4SJ%2FsvJqjR4ey2L68MSKjkhD8PFajaCI6Jkkr66ZT%2B4ZiKqjwkXy5BR9RlZ2Rf9omz7z%2Fn3e%2FrP6pIVrYWwgHSFO0VZ7JSBAf5zWb6ie%2FiUyQWpXUfHy4Y9sy2TqG3%2BO3VNFaRoumtQu1PPPhvX06l%2FuoYxQmeabRTUSWmJroRYS8iM3VY9z0VL50UaIAfzRXRrVOkDyTkSC0BAtzg0tX3V%2Fm6jHOX32mDPEleMVmL6nWCZJnMhKEluD%2FJG7JqQvByYlJ8lwpPzA4Co%2BDo1USGcD%2Bf0K1TpA8k5EgtISLbrEe%2Bno67ntPBuZK%2BbOcPVJ%2FKBDDHTGqdYLkmYwEoUWEvI4dvHmvb7yXT3iOlrt0kzceBUWpGlQAmxz4R6moxgmSZzIShBbhwWQ%2FMUnRZ8K8G7Kcali8Qe1P681JcFXCX6RbQF5sRpA8kzyTkSCygZuX7HR0XPKoMbOvK9Zsf4iPzenynO2Aif%2Bmb1AK7GL%2Fd1boYgbVNEHyXHCg5ySIbHH7AbY1spHr7Dj0aOPe44HSZg0t0aVtedSsZoZK1hk%2F%2FRsbnwyfgLe4eTcU%2F1x9xhpVdPoNeIPi79CX4Bt35uFRLRMkzwWHQvPuJhL3TMLqXHpnjH1ddIEcByTKTzN%2B3Dd8ec6WheRs3oV5XENv38dZkguC5LlgoVsYLuL5ayzgk7UV5lMzer9ucqXcUPhbl8F%2B1iCqscmKeU0BrIElsEbCo1P9THaLZtuE6ChwUyGBF9PglXQkCGV7fMka1C2SC4LkueBB6Sbi4706ZSjdS3xVUI4%2B7O9OzBuTsH8mmexSTKFABGtQ%2FO1zN5m3tcCdOqkJkmeCIAiC0E7%2BD6pQ%2BNrzVL%2BcAAAAAElFTkSuQmCC)

```
source_value
         ::= STRING_LITERAL
           | EXTERN '(' int_const_expr ')'
```

referenced by:

* source_def

Comments:

The EXTERN keyword references source files defined on the command line as the very last arguments indexed from 0. In the example below, extern(1) would reference the "./file2" file provided on command line.

Command file example:
```
sources {
    my_binary_file = extern(1); # my_binary_file = file2.bin
}
```

Command line usage:
```
elf2sb -c.. -o.. "some/path/to/file1.bin" "./file2.bin"
```
**option_list:**

![option_list](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAT0AAABRCAYAAACg2nEIAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAE%2BBJREFUeNrtnQlcFVX7x39zF3ZQdkUMDQVBzQVUfLUoU6Jyye0fmalZaf7TrEzLbLPNSvNfar1qmGmZuGW5pGZuf8kFL2qvCLIooGAIguz7vfOeMyyiIRfwLnDv8%2BUzzL2znLkz5zm%2FeZ5zzpwBCIIgzAjBVE9MVE1Tbj1%2BYnZswo1J8RfzuubklVtm5ZT%2B43ydHS0rba2VuS5OlkeSLpcsOnSyOJrMgiBI9FoV%2B78PmLHrwJXFCcn5tsOHdMTgQDe0c7OBm7PVP7bNzC5FRmYxIlWZ%2BPWPy5VWFnJV%2BvXiidExuEjmQRAkei3buxPfl21etm1T%2BMaEcRPHeCNseGdYKGWN3r%2B8QoOIXckIj0goLakQx6jOqfeQiRCEaSE3pZPxd8re%2FN2mxHFLFvRDyGAPyOVN03S%2BfS8%2FJwTe56LYfzQ9zNVRk3Y1C2fITAiCRK9FhrTL18XN5YLX09fxrtJyd7FGYE8X2e5DaSNdncUrGSR8BEGi16LCWtU05bKNUQceCfa04B6eLuDCV1KmFmLibjzu4QoV8%2FiSyFwIovUjM4WT4K20SakFtrwOT5dMf8oXFhYyhUbEpoAe8CZzIQgSvRZBbOKNyaHBHZrUaNEYeHr9e7ny1h4F1FhC5kIQJHotgvhL%2Bd6DA931knbIA1K4bM2mwX26oxeZDEGQ6Bmd7Jwyqw7tbPSStn%2BXtlUfBGTKNBhLJkMQJHpGJye%2FTHBuY6mXtD3da8XUjk3DyGQIonWjMIWT0KhFyOT66Wddk64owkkwketFECR6hFaEKk%2FPmq4EQVB4a07I6RIQBIkeQRAEiR5BEERLpMXU6fE%2BcDIRYyBiIPvalU1eaIGjwAT4sV9IEIQ2eDlJZVMiK8XHNQJ%2BPnMef5HoMfp3g0%2BlgK8FDXqwq7SRXaplcg1iOyUgdQug1rUQxV0sQE5uOTzbWcOrQ9P79kXHme7AqwShK8YD8hQfeKll8GdfhzCHZm9fP8QoRLwUdQEJZit6ffzxsFrEFqYiS%2FMqMDwpCWU1607p6ZhT31AhKbUQO78d1CzRIwhCO5LDkoBL7COfdnXpgvltlJirFnCClfvxZ2JxwFi%2FzWh1etzDY%2Bq%2FRRQxiXlPH9UVPH3xd1apJHj9ezkhqLcTWSZBGAhevnk55%2BWdl3te%2Fs1O9Jjir2CzpacvYJehjhmpui7NZ0%2FpQlZIEEagurwvrS7%2F5iN61Q%2Fu97QvMezIJUdPXYd%2FVwcMG%2BRO1kcQRqK63Pc01gAeRqnTkx7cF%2FDT4RSU6iQ9udCoR9HefskPSqUMQhOaIgqLKshKCUKH8HIf4I%2BfqgfwMHiLrlE8PREYyP4d1FV6be0tKrPztFcJujlbwtFB2aS0E1PyyUoJQvcicFDSAXMJb5mj5cMcs%2FM6c5dtlbnpGcV6%2Ba1Rf1XVAwoiCtDILjQEQTQML%2F9cB8xG9Biu1oW4pqvEnB0tj0Sqrunlh%2B6PvFp1YxKQyWbXyFwJ4u6pLv%2Bu5iR6VsfTdFOfx0m6XLJo98G0Sv7eWl2SnFaAlLTCmivF%2BxtdJnMliLunuvxbmZPoCYDuHuc6dLI42kIpU%2FEXdeuSNz%2BLrlsHUcQdPzJXgtAJIoz0mKnJDDiQfr14YnhEQum5%2BBs6Se%2Fz1TG4mFpQkz2X2BSgkWEb2SpBtG5MRvSimUaVV4hjZ753Qn23wscFb3Ndr1FAJLslnWopD0wTBEGiJ3HynPq3wpLKF6bPPyYuXx%2BHptbx8Tq8J2cdvlXwRGxg%2Fx8R5ZhH5kIQrR%2BTGy7%2BdCzWBvppZD9su7gyYkeyIqi3C0KDPeHj7QAvD7tbti0ureSvj0TU2Sz8EXmViV7h7bUOG5iXN0QQ8KyKeZJkLgRBotciUcVhTd%2FuYrq6XL3lSNQ1OZua9m4LXofHQlr2KVSUYXL0eewlUyEICm9btsfHhEqQozf7uI%2BJWLYAxLDpChOzono2L2TrkmUi2xbYLgKW0ouAFPjXaRI8giBPr7UQXRWSjpZGZa56zi8EGiZ7Amxv29ROFJErCuBv9o4S5ViookYLgiDRa61Ut7ry6V3KcoKg8JYgCIJEjyAIgkSPIAiCRI8gCIJEjyAIgkSPIAiCRI8gCIJEjyAIQj%2BYROfkAD%2FdDUja0omO0%2B%2FAi6JqmnLr8ROzYxNuTIq%2FmNc1J6%2FcMiuntNHHdHa0rLS1Vua6OFke4SNa8wFeKf%2FJ%2Fkj09IDq6Hcmb3CB90%2FVa%2Fr7vw%2BY8cpXvyxOSM63HT6kI5548R60c7OBm3PjR%2FXOzC5VZGQWu0SqMsempl8eNfJBGxUf4DVaz6PUmEP%2Bm7r9kegRDXo1urzjiuL7ss3Ltm36fGXMuIljvPH5%2FH6wUDav5oMLJJ%2Fu83PC82E%2BiohdyUHhEQkxgT3FMapz6j2Ug2R%2Fxobq9AhwwftuU%2BK4L97uh0mjvZsteLfD0%2BHpff1BkJWNhbAz0B9T6WoTJHqEUeEhLfPExi1%2BKxA9fR31cgye7oqFQXKFQhbeh4SPINEjjAVvtNh14Mriicwb05fg1RW%2BCaPuFRQQVjGP71G6%2BoS5iR61trUAeCttUmqBbdjwzgY53vSnfGFhIVNoRGwK6AFvygGzRjCWDhhL9Moe7GScF%2F0SN4lNvDE5NLiDzurwtMGP07%2BXK7d2BdRYQjlgvgz0lMp%2FqTmJXnaRHVwp641L%2FKV878GB7gY9ZsgDHnzG31kymI9oTblgnpTYgRteljmJ3qVKDXwo641Ldk6ZVYd2NgY9pn%2BXtjXBTWb1EP6EGSIX0J3FtglmI3rsZFWCBoMp641LTn6Z4NzG0qDH9HSvFVn%2BPs5hlAtmCn%2B1KnDcGIeWOicP6AH3kzG4dqeNtK1vsugJ2M3Udhn7%2BAEMWJmZnHoNc99ZV%2Ft94Vth6N7tHiz48EfEJ16Vljk52sGniwfGjAjCvZ3a1W67YcsRbN958h9pfvLuRGn7Z6Z9CbVGjVVf%2Fi%2Fs7areOHk4MgbHTl7A1IkPY%2Bbcb%2B%2F4u2p%2Bh6HRqEXI5IbtY1pzPFGEk2DineNj4i6jvKwCfXtTm01deH1%2BgYgJGhlCm7Lf3epQzf6S0VWocTXAD9sUcsyqL1Ft65vKmVgcCvCHLNAfY1Wx2GowL6O9Mz56%2B2k8PPId7Nr0Nrrc215afi42FQMCfDDkgZ4s5CvAgSP%2FwSOjF2LJx1Mw6rEB0jaXr2TB0kKBmdMeuyXN9u2qunqcOp2IDh5OWLV2H16f9YS07Pr1fMTFp6FtW1vMmTlSWlbJ4vqwqUuwYsk0tHOrCvU6eriY4Y1e8vSsTfkc9%2ByPRs6NQhK92yiwxuu82J1p4hsHm6tD%2Ff0wWi1gWaUazuyrjaLaAHmYO16txmiW6PbbE9W2vjlOBkvzNXa3X9u7G1RnLyDFEBdbyUSLC1ONWFlaKGvXcQEc2L%2Bb9Hl4aD%2BMeLQ%2Fpr38Nfr16QqP9lX7uLq2qd2mPua%2BPBqvzF%2BDKU8PgYuTQ%2B1yK0uL2v0qyiuled9e98Kro1urMdTU9GKkZZTUHy4w721Ab6dmVe0Y%2Bjz49V%2B%2F6TBOn70IO%2BaRPxx8H0KG9JbWbdx6FL8fPANrK0uEjR2MBwZ1l5afv3AZFxLS0baNLSK2HYWCFYBXZoyAb9cOtRHE2h8PICMzF%2B6ubaUowdnZASdPJaCktBxLV%2FyKNmzf554ZqvX3XWNpfLvud3YjvgxfFkG8ODVUsj8eMcTGX8Hzk27WCISv34%2F%2BAV1xX%2FdO%2BCZ8DwYPZIrw63FcSslA6LC%2BeHp8sLRd9JmLyMjKRVdm4%2FyG3tnLDaFD%2BxrFjvp2w3A2e00uIqgZN8om6VCN2LGAxrNuPKm4ra5N0VCi2tY3Bebh7enrj2Xs5I%2By%2BYTTsTjakgo59%2Fr8unXE7n0qvDAlRFqWlZWH41EXbtmuh79XbTjbzccTjwzpg%2BUrd7OQ9SmTujuv%2BzkVy9cn1bvOjt07k4%2B0jv7Gz7MbmVqtwVQmQGnp1yWx4KLHhen3g2cx75UxKCwswew3w7Hko2clUTwfdwXz3luHx4YGIOSh3jjGbOC5mSsQuW%2BRJGqjwj7ByzOGY%2BiDvSRh%2BuPIX5g8YQjs7a1ZOC9Dxw4usLXV3kMrN7cIo576RBLHkJl98OeJOPzPlMU4vPtj9PC7B68vWAtBEKT1XPB27InC5LCHpH2%2FWbMHW375ExPGPYBO97jh06XbYGtjhSceH4Dos0lYySIQNxd20x7QDQ4Ohnewu3SBZRsl5nLBYx7P%2BOi45jdiaNOhO4ldvaJ3p0SbetDGwoTuk4BuSBFEbOvrBxWbb9LIcapNES4dTjFOH566dOroirSr2bXfYy9cwRcrdvyjTs%2B%2By00jmsNC22Gj3sULk0NMSvRGDfWAT2e7%2Bj09Ret4sOc%2F51MQdToRp%2F9%2FKfPmLKRlE598UBLB1d%2F%2Fjq0%2FvCGJCycvvxj%2FXrNXEj1OUKAPvlk6Xfo8jAlf96BZuMFC19z8IuQXleCxYQGSR1bjHXL82U2Th7fjRw9q1O%2FbtD2SRQS%2BtTdZ7sX9vPME%2FjqXjIA%2B3li9%2FCWMm%2FQZLJQKyRvcsXGBFL3U8O%2BlL0o3Xk5xSZnk9XHR4%2FB65w3fvga53DB5NZ558Sk%2B8FLL4F%2FdaPEU040YBfPw7kbwGtQhAXtYHPXBncSuQdGrjUGBs%2BwShYpa1ldWIpkd9K5uH%2ByiPMr%2BPSrTSDE%2FH83B6OTmFcG7c%2Fva78H398CXi55rcJ97PF0kI%2F9ixS8YNEB%2FJ2HoMeS8OtjAqa2y%2FrwThFZxHokX%2F0ZX7%2Fa1gseRyQRkXMtFAfPuuDDUwENXHrbWxuGym2Lh4GBTXcekZqGiO8aP%2BhcGhbwp7cM9qRksJHVzbdPk35eQdBX7mLcZ9PC8W5aXlpVXRRVMkOe8NApvvr8eP6x%2BFe7VdcL1wRvhftl1s%2BHN2dFep4KnLd8u3SzXdct4O%2BaBxeu6bHMdYmk%2FXiliHJtrtBmU4g4CdIztmM7mQ1mC4Wz%2BakPr2Y3nM1227raEgnP17xwWysZj%2FpxxTd539owRuD90PlycHfR2zroY2qcp123ZuiS9hLeGPA87FmLm5RX%2FYzkPPblwc%2BHj4sDhn%2B1sG%2FfQ0OIPp2DBnPFQsTBy3U%2BHMHPuamz%2Bfm6VNyI23jT58caNHIgPFky4Y33kjr2n0NPfC%2Bs3HsJD7CZ8pxtOTm4BnJzsW7T93W0%2B19UhNl9lpcR3pRWYyqT9eVFAHrjHp030ahIRqxI5qZTDj4sZO9irDa03pTCuoKAEx0%2FFY%2BGnEZgY9iD8fTs2OQ1XJnZTJw7FtyxkCurnaxLXJXiAC%2FOQ6m93UCpbx9BqPETNuHYD%2Bw%2BdlUJUDfMJfvtdJTVc9evbBT9GHJZuWDzc3bD5CIZUh7YNkZqWJaXJW%2F95nV5xcRmWrdotrWvrYIuo6MRG%2F77QoX2kOscJ44NZmFrVSHJClYB7mTfJPcd3F22UPn%2F%2B4WQ8Nu5DrFj9G2ZNf7x2%2F7yCKkHPZ6H5ug2HWOgeDFNEiw69NqAHPqtQ4407iV9d0duiRcy2tHaxi09MxzPTv5Q%2Bjwj7GKv%2Bb0Ztd4LX3vpOmmysLeHLDI4bU9jY%2B2%2B9ANv%2FlKa67IxYUG%2BXBB7irI84ZDKGFtzfVZpaM7wFdeWXM6R8trbcKNXF9enZWRK9pZ9MxeQXv8LOvSoUseWdO7ljzsxR2uuVmHDOnhfOypUotdhnXs%2FDV58%2BL63j6Yb%2FsB8BwXPYOnvs2%2F5%2Bg2nxFv65s0ZjzDOfoq29DYqYgDo52WHjmjnY%2BssxqWFjz7b3pF4HK5ntjnjyI6kXwKCgqnjx1TfWsNhOxI3cQoxhHiOvrzRBtOpQ9bI7ip9Q7TYWs0RWskTqDVO1rTc23O01t%2BHidRUWqnaMMPx5jNyp%2B%2FNoYv6npWczEbSpbXmvu9zCUiG1dDYF7u1VVKrh6eF8S8jJvcn0v7MlT61uF6mG4J7m1YwctGHCV1N%2FqI0eA1%2FG1nXzpC4zvJ6SC3xLt79m5HOzdIh3Subix37wi%2Bx3V%2FXTU8jRuaFEtK0niNaGZwfnJi3XRjv3%2Bscj5ALEu6xweDcX3ipcH%2F6%2BnrV1efLqbi7NwdHRzmTzrLk6VNfzqw1vtSVEgmea8EfCDP0oWmFRhdle7zUrZuot7Y%2FfeRrt3R1N%2BvrdrQ7V7E8jJ5sxbe0tKrPzygx6zMSUfLrweoA%2FLqmPkNYkb%2FZ0CcwXe1tlbnpGsUGPGfXXdWkuiChgMzXlAkGiRxgMZ0fLI5Eqw9Zc7I%2BsGs1GFJDJZlRtQpDoEYYj6XLJot0H0yrLKzQGOV5yWgFS0gprLI932r9MuUCQ6BEG49DJ4mgLpUwVsSvZIMd787Pom19EFHHHj3KBINEjDEr69eKJ4REJpefib%2Bj1OJ%2BvjsHF1IIawbvEpgCNDNsoBwgSPcKgRDMtKq8Qx85874RaX8LHBW9zXW9SQKQAnGrqIJIEQaJH6IST59S%2FFZZUvjB9%2FjFx%2Bfo46KqOj9fhPTnr8K2CJ2ID%2B%2F%2BIKMc8uvKEMVDQJSA4p2OxNtBPI%2Fth28WVETuSFUG9XRAa7Akfbwd4eTSul39xaSV%2FrSSizmbhj8irTPQKb92ACx4fW03AsyrmYdJVJ4yBYAonYeix5VpEWKqnZx%2F7dkcoNNgiVA3lrpshdnkdHgtp2TyUeXiTT5%2FHXsp%2Fsj9jITeFDPj7OhbyycMV75uL0fHz1Uu6WUjyaIfNTEa82eTKvLJLzLrLmInzqMCikckUsn3SZSKiRAHnmCJ5yQRksRTCmOCdovwn%2B6PwlmhZd%2FGq0HN0n%2B7oVf1C7hDm%2FQnsr7HPOdmJInKZ4PGhfaOYd7dQRY0WBEEQBGF4%2FgurbXeo4uzwzAAAAABJRU5ErkJggg%3D%3D)

```
option_list
         ::= IDENT '=' const_expr ( ',' IDENT '=' const_expr )*
```

referenced by:

* keyblob_contents
* section_options
* source_def

**keyblob_block:**

![keyblob_block](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAmEAAAAlCAYAAAAKoz4YAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAGvFJREFUeNrtXQV8U9cbPUmVuiLF3aW0xYq7y3CHDhvD%2B8fZhm2s6BguQ4c7wwYbrqXF3Yq0SEu9lHr%2B97shIS0tSbsmbdp79stC8967776X79x7PrkvgICAgICAgICAgM4hyYqTupSHTNz69MH3vna%2FK5nPEKPdly6PvvcotN%2FDp%2BGlQ8LjTIJCYtI8p72tSYJ5HqMwBzuTM09efpxz6kq0r7AbAWHPuu234KOA4HX25IemMMyqE%2FucWycsVkO41vPQavsnNrh8N2bx%2FnmP%2FCLM2zYujI7DiiB%2FXjPktTdN85jA4BjDt4HRDud9Aju%2FCHjZoX1DM5%2BA99F9fO%2FgqbAbAWHPuum34KOA4HX25YcmMMiKkzo5YvoQjw7CajXE6vUH%2BD2j15v3mJFpXoVsurSCXfDOJRvuj2%2FRsJDxbM%2FqqOXsiHyOeWBu9nV9TttpP7eqDujetrg0SYZCt%2B%2BHDsnrILn2OlD2RNiNgLBn7fdb8FFA8Dp78kNTSIXp5F7s%2FH3PjnU7HndZMM0N%2FTqVhLFRxsyBjqPjl82sZWpmLPnLtQI8xN0VEPas234LPgoIXusfP4QIy6Wg0O7a7Y%2B6zJviisplbTOlTWpn6YxaBoaG0rXOYuAXEPacJf0WfBQQvNYffggRlgtBxY2H%2Fn01rw%2FzBrRh2L06lJAYQrKKeRitxN0WEPas%2B34LPgoIXusHP4QIy4Wg1SVPXkSa92hbXCvtD%2B1ZFsbGUsMkGXa4VEJJcccFhD3rvt%2BCjwKC19mfH0KE5ULcexzav2WDgv85t54WqN0aVR1prbIhEjFf3HEBYc%2B677fgo4DgdfbnhxBhuRAPn0WUrOuaT6vnaF7fid7ysFdd54qoKu66gLBn3fdb8FFA8Dp780OIsFyI4JBY04L5zbR6jgqlbOT%2FkCBQmoTO4q4LCHvWfb8FHwUEr7M3P4QIy4UIiYiV2FubpOuY9yGxePUmGmER8RrtXyifkjwW7NVM3HWBrLZnmQzchukVF5eUrnNow54zwkMFXgfG8OuIjknUCz6%2BfReKuPiETG0zLOwDwsM%2FpLotKUmGVwHv2Xeu%2FqH%2BERHRCA2NEkTS43nq7Xs5H6KiM2ZjWckP%2FqSzmpWQ78odvEtrJ3XbtYmJP21Cm%2BYuqO9eUfnZrLk7YWZmAs8RHbB9zznsPnDpi%2BNmTe2JVRuOo1mjavx4BZ49f4sff96GFYuGYf%2BhKzhwxFu5rXjRvPimXS3UrlGO%2F%2B3t%2Bxhbdp3B4l8Hpdq3uw9eYsmqw7hxyw%2BGhgaow44b%2FV1bFHSy59ufvwzE%2F6ZtUO5vY20G95rl0bd7QxgaGWSZcSclyiA10PzXJR6%2FiELTPmdhZCTFvhW1YWNlrV7df2qfjYF2kiz4ZYae3y7A5HGdUaViMbX77tp3Ae1au8HUxDjbDUSBQeG4dvMpWjatLkbl%2F2jPErbLovWPsXnfS3RrXQjLZjhr7q1qwZ7Ty0PCo%2BdR6OvpjWcv5eJj5ezq6NyiYLbn4ze9f8VvXoNQw6V0prX524qDbEwyxNT%2Fdf1iG4mzWk0mwO%2F2ahgbff1yV234GyFMhM35qW%2F24Pz7cPhef4pWzTKH8yfP3kLZUgWV81JO4zWh%2B6gruPc4AoZsf4%2BuxfGzZ8V0nSsj%2FPivukhxPI%2BExSfitUt57KQPU9tZ3XZt4vbd5wgKjlD%2BPXveTlz2eYihA1vwv1%2F6v2cCSMoEWftkr0JODmjFJq6pMzZzT0eBSdM3o4ZraVha5MGLV4HIY2qkPMbRwRo9POZz8cSVeGgkF1ip4cZtP3TqNQcVyhbGtnWeWLdsJB%2Fk23abjXeBYXyfqA8x8LnxRNl%2B6%2BauWLb2CJavO6pXZBg98yb3uOdPqoLKZa3TdaxE7lno3G46t6%2BNfI42GkRHZBgz%2BQ9mIx%2Bz5b1%2F9CQAXr%2FtFUorkzBvYhVUKWeNnUf8ceJC%2BsfPrLJnBRaufcQFWI%2B2hbF%2FZR00cHPQq%2F4LqMfTZ28wZ%2BHuTGtv0fK%2FcOvuixx9zxZPq4o%2FF9aAtZURVm9%2FhvtPIjLUTnr4kVFdVKM8OrlUwKuERPgpI2ESeVqya2Ii21ge%2BwwNMFJV4anbrissXX0Ep8%2Ffxe6NE2Bh%2Fvn3ohztrZTRK1W0aOLMI2Vei%2Ffi5x%2F6YO9fl%2FGeCbrhHp8fB5KXTdSKY%2Bl99fq%2F8ZaJqGJF8n61Lz%2FP34W%2BPRph1LC2ys%2B8ZvbH67ch%2BH3VIX4%2BrrDZ3VPt2yXvB3j9JkRvjPus93tcvRWCWtXs0LG5U0ab0XnYLzgkkoliuXfz97%2FXueh%2B%2BDiAeYW3UbSII8aP7Ahra3Ps2n9RHlFYd4zbVEvmfZKwVoejJ67hxKkbiI9PQE23sujasQ5MjI1w8coDbN11lgvwpg2roHe3Brwf5Jlv3HYKzRs7Y83G4whi3m7fHg15pJYQGfkRq9nn1EcbK3PUd6%2BANi1csevARQQHR2Lh0gN8v8EDmvNr%2BRpi4%2BKxbvO%2F3NasrcwwoFcTuDiXxAv%2FIOxh1zu4P2vDUt7GsX%2Bu8dRN6%2BYuOHjEG46O1rh67TGuXH2EalWKY%2BTQNjxCSI7FgcNX0KWjO39PTErCoH76l2U2YB7vL56V0HbwBSZoHqOZez69sGdllCQklr8P6VE83Q5Rdui%2FwvFZv%2BVflC9TiI%2BNZH9bdp7BqXO3eUahZ5d6aFSvMrfXw8d8MHzQ5%2FGaHOR%2FTt9U2l48m8nWbjqBM%2BfvoGTx%2FBg7vD3ndUoksBlz7eYTuHD5ARzsLTGgdxNUrVRMJeqShM3bT3NOFynsiDHD28HBzkqj67n38BXvP6VHqQ99ujdk84o1DxCs2XAcT%2FzewLlKCQwb2AJWVvK0F%2FW5Ts1ynHM37zxHvdoVMMyjJaRSCXbsu4DQsKjPnP%2FE13MX72HnvvMIC49Gg7oV4dGnKd%2F%2F1t3nePb8HczNTLBj73k%2BDo39vj1KlSiA85fu4Q2bkw4e9cZ91s%2BqlYujSYMqfBw8dOwqPsbEoUSxfOjfszHvs76iWgW5w13fzRH7jgfgXXAsypeCVvmRXl1E4itRgt8TZSgElSx5spowmVyUUaP%2BqSk8ddu1iT%2BZkZOBbV%2FvCRub5CSjSBlNOKovmtQIs6b2xm428ZABz%2FLaAa8Z%2FZKlAgODwpTH%2FLpoDxsUysLN%2BevfXkxsHLx9H6FTu1pfbOvUrjYbEO5%2BJje7a4r297PJ6%2FotPz4p6guOnnnL33u1L6JXpCRR9TYwVCnCPL5fwgVy%2B1ZuuM28wlnzdsoFvIN8oHUqYIfCBR34QKYOK%2F44hl8W7Ebj%2BpXRpGFVHD3ui%2BcvArmNDR%2B3kn1WBf17NcJ2Zq9kU4SwiA%2BYu3gfpszYDOeqJeBWvTQGj16OgNfBfPtwz5VcnA%2Fs3ZiLHxJ5CgeD7JX6Ri%2BapNRh0IhleMK86RFD2qAhm8wGDF8MvxfvULSQI58wPKfKf3SZorxTZv6pTNnSQD1k1DLExsajfesaOHHyJqbP2c63vXkXyvvftb8Xn1RIGOorajKHokQRc%2FjeDeW1JPoERc2LlYWRXt57EmCUjTh55jaqV5M%2FkmnKzM3498wtDGEipVPbWsw%2B1%2BOyzyPkz2vDuHYUV9hYq8o9VSd2G3N4%2FBmH2reqgfuPAjBywppUz%2Bv5w3rOz8H9m3Hu9Rq0gHNBgT0HL%2BHBY3%2B0a%2BmGl6%2BCMHTUco2u59qNp4wTc7n46ti2Jt4z5%2B%2FoCV8Eh0aiQ8%2BfmVNjhVHMkaGauJ7snCQ4CX8wEeYxfAlsbSzQtqUrF2t7%2F5KX1eR1sOY8V3DewFDKBdPUWX9yXg4f1BJH%2FvbFouUH%2Bf63773g0XwSdC2Yk0fHDmY8JpAgNTYy4oKS2iIHj%2Bai8T9s4A4g3e%2BPH%2BN4ZicnwNLCMBlPdGLTanSRIvKVCOwFCbAUMFTTKFd46rZrOzJ2%2BG8f7v38Pndwqt7Jg4f%2BWLD0YLLPZk%2FrhXKWhVCooD2PVvUZugg9OtXlBFTFnfsvlccGh0TwqAVNThQ5SAshIVFISEhCvrxfprto4KAohwKJzFNTtB8XH8%2FPQd5WuTIF9cKobz2UX4tbFVu9Jid5meTdcqIyr5IEBaFh3Ur8nQZxTTxB%2Bt4Xr%2FwLW9eMU04iHdvU5IMrpcq%2FZ8KHBjYCT4l3ngHPkR3531SbsufPicoI3f7Dl3magGo1yA5nMvukyAC9enWtr%2BwfTVBdO7lrdJ00mD71e4uNK0dzL5lqcC5ffYgjTCh%2BP7g1Fv3yLVp1mYnFK%2F5iTs0FLGGcIo4oJ6sRHTGACUFCqeIF%2BGT1y4%2FyWhkTUyPs%2B3Oy0pvXZ7hVtuVpvTsPI5DfwTRb9zWRuc5%2B%2Fh9w9up73HoQjjrV7VHEST%2B%2FA6rHff0mGOuWj%2BR8oJpHck5vnF%2BkrMmkaDBFW2u5lkHPLvWxaesp1HQpwx1r%2Bvz4%2Fs%2B%2FDd2vZyNlTRjxplbTCV8U2SvPcXYRbG0t%2BGfklPyx6R8s%2BHkg%2F5v4pchekGNVre4Y%2BAcEJ%2BNGali65giG9G%2FOo1IEEjY0FlC0m5ybUUPlmZKarmVRs8l4zkWKgBEWzx3Er4vw%2BMlrXLv5DF061EGjepV4hFqV85RS%2FHV6P%2BWxdM2jJ63lddGEerXKY8m8IfIxgzmH1dzHIDLqIypXKAp7e0t%2BnKLGjKJwBZ3s0LRBFRgZG6J542rIKaD6yG0HX2HZpqdwsDVBmWIWsLPRTa3vF7pIgqNMCs5MGfnSSIR9juLghhRoKVOzPSEBfuykebR1cRQtGD%2BqE%2FfaKVVUplTytFi9OhWUBpgahg5owSbdvejXq9EX2xrXr6IkImHj1pPcm7p44tc021OkQqOYkVOkQhVk%2BOYqqVIjQ0Ps3jRB%2BTd5cQ3bTEVdRhqKiKQX7D7LdGnUoWFx%2FN3e1uQ%2FtaPrfqeEaoEnpeji4xMz1M67wFA%2BGaQs%2BCfB89TvHU8dKFC6ZAG%2BIozSATx8zcSXQoDxaIalGZtg5f0goTZuyjouDqtXK8EHddV0iaagwZxSh3WaTUz2eZFCjkoBSotSWn4zAyOGtIY7s8NkIXaVOlhKU1Ba9cMHebSIJsnMFmBZZRcOdnJ7DgmPy%2Fb9ptRK7S6n%2BL%2Fr13DAloU1kn1P%2BnLf5y%2FZz1NnV0%2FOVxbLU8SWUmINW09Ltm%2FTRvJHNVHKnrZRtoMiPbXcyjJbTr0OjgQTpeLeBYUlqwelFCY57woBRqBCdVp0lRrs2H621hZ48y5ErQh7%2FPQNTz%2BmHAsoPag6T9FnNB7QwjCFkJKqfImWbCwI%2FFRLnBqePHuNURPXwNDAINn48bl9abLxjTuMaYxxFE3be%2FASKtUexdOTzZjoHMjGG6qt1ndek4OybXEN9BrrjXaDL6Brq0JYPtNZp%2F0nXcS%2B2TYJMnRh70nqGkpVhLEDL7IDA9h7U9bgWvY%2B9mvbGZ%2B80hMJS%2B8FUpiaCq0jIqPRd%2BgiHNw2NdUoVJoXSelHZvBSDUYuim689A9ik2PaS9hpIqLw89kLd1G8aPKM7LlL9%2BBaLe0oGqW98uezhR8bGDIiwnzvQ6JLglh8Cu9%2BjEmErVXGUyC67re2QAKchFRY5IcvorKWFqZchCtAAobsiES5QsikhT7dGnAbp1TpkRO%2B6D5gHq6fXyT3sGSaXzadi2zz%2BP7pae6z58BF7iEfOOyN7zxafZHeVwrw8CguvMzMTLR2P7PKLqKj5ROUeR7DbN9vB%2BbJ%2FzHHBRd8g7Fu93NMnHsHi3%2Boqnf3nUSJWR4TLibWLhkBAwMpG19MeY3jpX%2B8kjkoClAKjZxsSjvuZnY7e1rvNNunWsj4hAQmQsxTjGFy%2FhGPFOeIiIpmXE49bkCRrOiPsbCxtlB7TcT58IgPqY4TqmMBP2dkcgc9xZyaPKqS4s6amZli%2FfJRnLcZitKoNEjpziO7f%2BTi1Of6EyxcepApBZlysZs%2B85pWDw%2BZeg357E0xol9J1Kxqp7X%2Bp%2Byfqi5i76tMjbAuJh4eTNoOkkkQnloqkgvolI2wt12sgfLs5W9ogPLX7mOcuu26KtKf4tkFbs6l0XfIb3yCy3SPk3kiv688xKMDNEB8DVRvM495dtdvPlN%2BRimfbbvO8dRXaiCPj4q2KRpWMxOXamsTxQrKB7Q7j8KRE0GDMolq8sg1AdVYuDqXwvI1n1e4Us0K2U7jBlWwbfc5nrIkUKEvRbM0KfClmhSKDlD6cPi3rfAhOgaxjMHUN1oo8iE6VqP%2BuTMv%2B2VAEE%2B%2FKECrgKn4l3DgyBWcPn8He7dM4nY%2BcsJqZZ0KITxSvpKYxOMydo20uEUdF%2FQRCnsuUTj7p%2FWMjaVo39QJXhMro3xJS2w9%2BJI%2FJ0zfQCn%2Flb8NQ3h4NMZNXceFQYWyRWDJhMnytZ%2F5RI9ouHT1ofJvSo%2FTuEzRJBJkKcdUBTZsOYlK5YugQP7kpRMU9bK2NsO%2BQ3JOUE0v1QlTgXpq7Wzbc5a3UapEfrXXRKlLOi%2BJNgKlMKlOjNr%2B%2B5%2FrypX9xL9HjwO%2BiDyn5eRTrbKqiGvJeEiF%2BtR3heCkWleNxixLM17HqcCFy%2Ff5HESLzyj96eZSij8JICdgPXNSQsLiMGV4OXh0KYaKpa20fs60dNHFW7hD7wYGKM1MfRfbL5Lt7P%2B1SBg1QgruihFrJBVhpW67TibMRb94oM%2FQ3zBk9DJsWjGGf06rHumlin1bJmv0TBpaPUkvhfFTaPbXGf2U22lyLljOI9kx5EV06%2BTOhOBHXmtG3h2Ffim%2FvnzhUGWtkIIsiuMpIkdprM2rx%2BjNM1sa15avNtlzNADN6%2BbMle2Urh7w3WKerhg%2FshO6dKzz1f0Xe32LoaNXwLnuWF40m8fUBLs2jue1h0NHL4d7i4ls4DPnQmrDitEa9WHjtpP44eetKFPSCX7P3%2BHHCd15hIpssmql4ryexEAixbG9P30xyaQUieQxe05eh5leO7iwo0L7Rb9%2By2ttps3awvo6kdvs7B96o%2FWn%2BjBaTUWgVV4bt57ikxKl%2FlcvHp7jvu8XAdHwuRMKp7ymKFfSSq%2F6ztOoTyMRFh7H%2B69voMjqhhWj8E1fL77oY8aUntxeR4xfg9Xrj%2FOFMeFR0ZgxqSfgJj%2BmgXtFzoOBvZt8ES0jx5fECH1uwETaplVjvzgnORHL5w%2FD0LHLeUE8CZD6dSvyVKcCZ87dgVuj%2F7E2pEhITOS8lWiQOaGUPvHVpYEnbK3MubO0cI4HF2E8ldpmKkqXcMIzv7eYP3sgj0KpA%2FGOapJrN5sIQ9afQzt%2FwMwpveA5bT2quY%2BFnY0FQiM%2BoEPrGtxJUoeBfZrwBUNbd57lNWu08OfbkUtR2MmBz080Zkwb3y1HcFtZPmOjs2c%2BqtVFnz4bV7MSvJhMmJgyMib5FFaLZo2sZI2kmlZUtz0jYUafc%2BtyxJdOUQ%2BqHZCw%2F9TVD2QUrvU8Mj3M63OwnUb7xsYlwbXDvwhmxv3v5nooX0rzScu1%2FV%2BZ328t2Q0tL49LSNBokFT12GmAt7e1TPY5eb8xTMRQKiVdA0hoFKKYcKMVmykfHEuRNhJOikdLaAJakSVl%2FdP0mgaxgZmWynflDkZMuu6FvtgznzinX8eOw%2F6YOaYivutdImvtOR39JvQffxVHTr%2FF5O%2FKYXT%2FUvyRGzmFj8QbcmZTOhm00KRt99nwOb0g1dXLCt445bf7atSWoru0QtrczJTXfaUEPUYmIuojCuSzS3d9FNWJUrlMSueaPqeV0bToh%2BrV0gPifB7T5HWYivbS20eK1NGCMsUcpZi3TEyMMo3nWc3rN0ExvA6MnKxj6%2BvCpVL6FpOllx8Z1UW0epLEGDvBMHYeMx4JMzRA8a81om57bgYRIb2TrT7BxFiKX%2F5XCR6TfDD8p%2Bs4uNodluaGOe46FXVRx0%2FewOoNx9Pc78eJ3ZRF%2BWkNXikXa2gKisTZ2qZeh6KogVyw9AAueT9Msw3VRSBUe5gRkNijV04ERXXpQa0VSlvBo2sxvev%2F4O7FcfpyEOaseMBfmj4xXx%2BQFm%2BIj906uqf5%2BJiv8SZlROxrYzVFhFSfMUZODEXo0kKndjXRu2sD%2Fm9yjlJzkNL6XBOkVvec0fY4pwua5Nh5q0GvM%2FyJ%2BQRavOJcwUbr58yoLlKNjPF2VD5Ud5BADgGtFEzPT0K0a1IAm%2Ba7ITwyHv5vojWKhkV9iNfLe0PLtbPzkm3FknRtgFZk6uMDGzW1Z6pNpvK333%2BsxldRkYOhKbRhz%2BnlIaGuqwOuH2qK%2B0%2FkNTxli1tkWf91BVpJXiMLamjJiVF1agSy7zxFT8z%2F8DER5nkMlA9uTQ8ywo%2F%2FqosUxxuKrzr3wcbSOCE4PNbQ0U7zmpJWDfKn6xyPn0eIG61nUCydz6n2TCU%2BGY0aacOeM8JDgp21Mdxd7HMNH9u1chPkFPPUV1HtP0a%2BspIfUvFV5z5YmhuFBbyN1uo5vG%2B%2Bl098MpDLnijuuoCwZ933W%2FBRQPA6e%2FNDiLBcCHtbkzPnfbSbYT5x%2FjV%2Fl0lAv4Yu0tkCwp6zoN%2BCjwKC19mbH0KE5UI8eflxzuGT%2Fglx8Ulaad%2FPPxLP%2FaMUFkYPUnsp7rqAsGfd9lvwUUDwOvvzQ4iwXIhTV6J9jY2kPtsPaedHWyd5%2BX7%2BQwZ6nPQJcdcFhD3rtt%2BCjwKC19mfH0KE5VIEvI%2Fus3b7o5jbD0Mztd25q%2B%2Fg6YtIhUE%2FYy%2BXJCn2iDsuIOxZd%2F0WfBQQvNYPfggRlkvhy2wvLl7WecRPlxMzy8DJoHeqei0SnJcAV6%2FfxU1xxwWEPeum34KPAoLX%2BsMPIcJyMa7cTjwS9TFh8NDJF2VLNt1HRnPvlFPvPvJ0coOWYQv7fwuZAcSDdgSEPeug34KPAoLX%2BscP8ZywXI5r97DetXySdPOepyu3H%2FQzrFXNAS0bFEKZklYo6pT6gyCjYxLw8FkEvG8E4Z%2Fzr5lRRyXfgQxagsYSCQb6ME9G3GUBYc%2BZ32%2FBRwHBa%2F3nhyQrbij9JpQwq4whM36TKzVUr4iWSOK%2F9G7A%2FszY72xQTl2C8%2By9JfMo%2Bl%2B7i2PCbgSEPeu434KPAoLX2ZLfqcEgK0765j1m0MvJEdOFuab%2F3mml3SA8ccqPncwgS7KXI%2FMKnjFDj2VGStHStH6SPortEyCVwVsmwW02IheVShDEjujBDPqqsBsBYc866bfgo4DgdTbjh6YQ6UiBz96LPBTbybkiqkqT0Jn9uznzOiTsP%2FM0DrGQyRDGDJp%2BM8KbeRMzfETRr4CwZ133W%2FBRQPBa8ENAQEBAQEBAQEBT%2FB%2FcxbeNvJKpNgAAAABJRU5ErkJggg%3D%3D)

```
keyblob_block
         ::= KEYBLOB '(' int_const_expr ')' '{' keyblob_contents '}'
```

referenced by:

* pre_section_block

Comments:

The keyblob block grammar has been modified and it supports only single keyblob_contents
definition, which must not be empty!

Example
```
keyblob (1) {
    (
        start = 0x0800000,
        end = 0x08001000,
        key = "12345678901234567890123456789012",
        counter = "1122334455667788",
        byteSwap = False
    )
    # No further definitions allowed, if present, syntax error will be raised!
}
```

**keyblob_contents:**

![keyblob_contents](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAARUAAABHCAYAAAAp39OqAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAADvlJREFUeNrtnQl0FEUax%2F89R%2B6D3JgEEgiBJCQBkgABwxUhgnKYRRTR9UBFBJVDXXirz%2Bsh%2B1jwAmFXYEH3rcohsAqKouAC0QiEcIVgDnJADgi5L3LN9FZ1CAZNMpkwnZnMfL%2F3JjWTmqnuru%2Brf39V3V0FEARBGBCBqsB4RAZDpFqQh5MXyLeNhYqqwLgkHd1ClWBgosbMpUowIgqqAsJco0CKBElUCIIgUSEIgiBRIQiCRIUgCBIVgiBIVAiCIEhUCIIgUSEsg7KyalRVXaeKIFEhzIma2nrs%2Birxlv%2Fxz6%2B9%2FZns216xZie2fnpQen%2Fw8FksWrZZ528OHTmHy%2FnFZDgSFcJUKS6txMuvfnzL%2F0IG%2BWLC2LBu3Y%2F%2B%2Fl6YPDFC5%2FfWfbQPZ85lk%2BF6MPTsTw%2BhuqYOG7d%2Bh6TTmfDr44l5j8ehn5%2BXlPftD8lwdLDFmZQc%2FHzsV4QE9cGiZ6fB3s4aO%2Ff8BI1Wg3c%2F%2FFL67gPxMahvaLqlW5KXX4JNnxxAWmY%2BhoX1x%2Fy5d8PZ2V7K2%2FqfgxgRFYh93ybhNGvsd44MxoKnpkCh0O95vaYmLcoram5%2BPvpzKr785ph0XPw4Hp09Adm5V5FfWIq9bFvpmQUIG%2ByHSROGkvEpUiHk4PFn10qN7rmn74V%2FX0%2FMmL0SV66WSXn7mag8vWgDKiprMP2eEfj5%2BK9Y%2FvonUp6nuzMgCOjj4y69rG3UOMvE58tvjkv55eU1mDFnJVx6OWDR%2FKkoKa3Cg0%2BsgUajlfK3MFF5YsE6ODvZYerkKKk7s2NPgt77n3GxAJ%2FvOiK9P3nqIl74yyZMGBOGmdNHMcHRIPnMRTixbVhbqeHm6ijtK98ngiIVQgZOn81GWkYetv3rRajUSoweGSRFDZ9%2FcRRLFk6XvrPgySl4bt490vvwwf6YfP%2BbeGflXIwbEwqloMCs%2BDvbLHvX3kQEBfpg8YJp0ufo4YMwetIyJCRewLiYwdL%2F3mPl3BkdLL3PzrmK5NNZmD1zTJeP5wI7Fk8PZ0ycMEQSkdbRiLubI0aPGMQEbDgZnkTFMhk2GEMUIv4EEaPYx0D28oOB56nJYhFKf%2F%2FekqC0MGiADy5mF978LLTaYoC%2FFxpZF6ekpEpn2Tz6CRzg3aocAYEB3sjKuXJTVFp3dZwc7VBaVn1bx3PvpEhs352AsOgXEB7aD7Fjw%2FD0o5OgtjK8O3biSWWen8uDKWa1RK2A3afO4wx5NolKtzMiCAObBKwXtAhlXvk5c821Si1S%2FdORuxPQGMjhJRzsbVBVfeulWf7ZwcG2ze%2BXlldDqVTA2dkOxUxYRFHssOzikso%2Fls3%2B3yYGkEsXFwfs3fYKcvOusajnIt7fsBeNjU3SOJDUyg04YYGuyZpmAcqcgfDTKBDCPsayE8S3EcFIUYlYyHqR6eTpNKbSPdFJCO7SCPiFeevhikb4J1%2FA0uRfse9EOrI6Kyj6EB01EAWFpTh2stnH%2Bf0f%2B747IZ3hW6isqpVSrVbE%2Bk3fYHxMKOxsreHsaIvGJg0u5bV9mTZ2bDgOHDyNomsV0ueUC5eQknoJY0aHyFZ%2FiSfSpMvGfr4eiJ8aLXW5WqIfHgllZhV2my25vbjduP24Hbk9uV25fbmdydspUumWCEUjYic7mz7KHbE7tskHMD9Y9RTmPb8Bfn4e0rgGH9NoPRaxe%2B8v%2BOLLRNQ3NEpXUzavXSj9n1%2FFmT0zBnHxr8Pezgbr33nm1uOJDMRTj03ChGmvIrC%2Ft9SlWvXWY%2Bjt5SLb8ZSwyGjuwnXwucMNGo0GNtZW2LrheSnv8YdjMX%2FxP6TuUey4cKx87ZFutW9mJupZsiIiCKfZGXcns3c0RSz6QfN46t9HP8CSIyysXmGI%2Fr4%2B00k2sC7C1aJyFn3YSULTwqLlmzEwwBtz%2FzwRlZW18PLs9Yff8vtVFIICri5tX1HhXR5%2BydfD3Ulq5HLDry4VXCmVBmr5oG1rrtc1SONBvj5uXSq79XSStzNXLbPPqywZy8qII8%2BnSEWebs9gDIEWYY7XMd0Y27dSq6RLre1ha2MlvdrC3dWpw7L5fS6O7YzRtMXhhPNYt%2FHrdvOXLY7H8IjAdvP5mE97x8KPoauCYkiYnddU2WIhtzsN3pKoyIJCi5nsvPfZ%2F3JQZ0r79fCscXBytO3WbfIrQy1Xh8wVbufIEHwm2R0kKiQqMiACowQR75vcOE9kIBlHPqMfYnZfTBWhx8mXqqDzsM45H6Q9TzVhOXB7c7tTTZCoyIWHbTWuUjVYDjfs7UE1QaIiFzaJeaY1nkLIyw1721BNkKjI2AOiBaosDBF06wWJCkEQJCoEQZCoEARBkKgQBCEzdPObkWn9nApBUKRC3Bb8YbfbeeCNIChS6QAxaZ76i8RfFqWmlz2adrEisLSiwfpaaV27Dc7NxbrJ3lZd7u5qfTjz0vW%2F%2FXis9iSZk%2BipmJP%2Fm4SofP9x5LOLP%2Fjv6vTsSvupsX1w3%2Fy%2B6O1pB0%2B39u85KiqpU10pqnVPSCqamZt%2Facb08XZJ%2BcW1j5xMwcWeGLFQs7JczM3%2FlUZVZ%2FENRYhryY51H194%2Be7xvlYrXoxA9DAPeHnYwt6uY73j%2Bfx7w4e448Gp%2FRRaEb7nLpTN83QXkguKxEw59tfbA28UFuNNagaWhVx272n%2B3yNEhVfolu0Z9695ZTjiYryhVHbthM1%2FNyTYFVHh7qrvj%2BbP9nDR5hVcwykSFcKU7d7T%2FL%2BzGG2glod8m7el37%2F6r1EIG2SYqQt5OR%2B%2BGa1UqRSbh4WALqsQJt3lMVf%2FN4qo8EGpfQcvr34kPsBgFdq6YufM6C%2BoIHwUFYIp5L6EqWHu%2Fm8UUeGj3Jm5Vfazp%2FaTpfxnHhoEKyuFivUzt0eGIsCQ%2FkBNwuIw%2BEOkPdj%2FTVdUUjPKHps8zgdWank2z8sdMcSDe4MKGqwxYNH14%2F3pMXhLYpSvZO868n8TF5W0rMqAmCgvWbcRN1ZadY9P3BojTVhtGEpqHGjCHkviugO4o14j%2FzdxUSkprbfx6W0n6zZCBvRqCV6LbkxcbAiymrQ0taAloRQwmPV90sn%2FTVxUSivrBTdna71%2BU1xaj8uFtSivbOzU9329bhqNL3QzyRD7zZwrSdAihpqaBSEglnUjEo3h%2F3z5V%2B7z%2FNXQoNVrG3L4v16iMjIUHcZiuvL1RasRodDjmnxGbjUiZxzEhIePSBXcqQO7UT4zjCtL%2BhpEVAR8LQh4ADQTmEUgjZ%2BJmKNVYJcx%2FJ%2F5Gt7bmoGI6Qex5G39Vgjpiv%2Ffbjtv%2Bb0kKo0aFEQGY0d7herKl5tFb51BbZ0Ga5aHI2yQs54nGkmpDbLfp1LxIytQERXSveEkYRyqbPESS84ZcyGx1cvCER7kjB3f5OH7n%2FSfc10f%2F%2B9qOx8RjPjIEFxu0iD7pqgIzeksjQZ5bRWqK19OjhwvxomzpYge6or74ry73DU21EmG1cVSpv4fDg2CPzU78yUiCFNZslQp4jmjjumwiGPli6HS%2B3c3Z8jq%2F%2Fq28xYx0QC7WUTni%2BaB4VsfKBSbP%2FNC41mhe1RKPH8s5bclKXTly8H%2Bw1ekdM70vibhbEmp2B8RgrXM2Y6ydE5yKo5SEzQfBgyAtbMaL3NBYWeQWScvGH9x9pHshNq%2Frz1Oni%2FDleI69HaX964GXe2ci4lGwFoNF5I27uBRdaZQfTdqSM6mVUjp8HAXk3E8JiQrI4OQI4jYFRGMJJZu1ypxwrkGWaa2JCrRMbPYWTxnIPw0CoTcGJR9iPl3ikpEtCkISgvDw1yQdakGKWmVsotKu%2B1cwP4m4K32xKRDUbkZ6wOnWTw0WdSR39SEbLZRWRbzLStvkFI3F%2BvbKoftnyx3wzInnML%2BTFFopT443w7Rg8j6zY6tbdqbnYnTTMmW7q7N%2Fl9a0dDt%2Fs%2FbOauTe5tE3M9Sra6CVO00lJ%2FZD%2FNZOpEVuJmlSzrKV6uwSp9IRZ8DdHBo3sXrdRq4OKm7bBSas4QwFbrSwGtrNVJqb6uSzf9%2Fv1%2Bt2zlLP7JRY0tdI%2BayQOIpUUDFjXGUjkWlpRCxuZBjaiWCuViwjS3pKF9OA%2Fj72OPU%2BXKkpFfA25PukCcsE%2B7%2FnP597GTflo52vnRkKFY1arCsPXFpLSo7dYjFzu4UkxZiR3lgz4F87Nqfj7gYL%2FIuwuLIza9FUkqZdFINCnCSe3M62%2FmN%2F7UrLi2icp0VkteBWOjKl434OB%2B8vf5X7D1UiMWZlQge4EReRlgUqzelSXfXzp8TIN0QJyN6tfPfiwvbtfk3RUWlRL%2BOCtGVLyfWVgqsfCkUc5cnYcHrp%2FDVxjvhaE8rixCWAY%2FS%2BY1vIYFOmDvLX9ZtdbWdtxaXm6KiqyBDCwq%2FhVifW%2FWn3XUH%2Fr1mOCqqGpFXWNupaKW6ppE8kjBJOuv%2FPDrhl1rWvjYUoyPcpBNsZ%2BmK%2F99uO2%2F5vVFO%2Bb0crZpKKupVHq6dH3idMq63XtvIyKkk7yVMks76P%2B%2FqzLzbp0vbMKb%2FG%2BUpZUd7dXn%2BlVpZt3H8THGzYURUsURDrkyYCubu%2F0YRFTcX68MJSfIO0XyfUNAcQgooYslVcmXCVDB3%2FzeKqPAV1b4%2BlNfU0KiVpfzsvCrk5FW3HCG%2FafISuTJhKpi7%2FxtFVPgSjVZqRdK2fdmylL98VasVIEXUcOEmVyZMBXP3f6Ot%2B8OXaNy8Lb3uXFqZQcv9%2B8YUXMytaqnQLPaKNPQkOwRB%2Ft8%2BRluhsLAIZXe4C6cOHM2fHRXmrvBytzVIhe5orf4C9gpAcXIq1pIbE6aEOfu%2FUZc9zS8SM9xctJf3H8qbXluvEYaFuHVp6Ufeh5z%2FSiISTlxtHfZ9yio1jh3hQ9yA5MaEyUUrZur%2FJvHkblQwnhQE4Z9qtUIVPdQdk8f5YmCAE%2Fy8Hdr8fm1dE1%2FmAMdPX8MPCQWsUqtv%2FUJzhcYKAp7kkyqR%2BxKmjLn5v8lMBxAxGJOhxU6hOXrqWizI%2B5ACElg6WVTiseTz%2BJZclugJmJP%2FK02lUguvIdO7N3awCglgLw%2BmslmsgutZJfG7fq3a%2BVk1%2B06%2BQsRxUcA5EfBTCLjGfjGbVegJclWix4yxmJH%2Fm%2BTERXxFtRsLIMWxCvZhe%2BnbgTrnsfx89u4AH%2BU25sznBEH%2BTxAEYWD%2BD1%2BHl%2B8J2hbbAAAAAElFTkSuQmCC)

```
keyblob_contents
         ::= '(' option_list* ')'
```

referenced by:

* keyblob_block

Comments:

The keyblob contents must define:
```
start [integer] - start address 'maintained' by this keyblob
end [integer] - end address 'maintained' by this keyblob
key [string] - key used to encode data stored into address range defined by this keyblob
counter [string] - counter value
byteSwap [boolean, optional] - true for byte swap
```

Anything else defined under keyblob is ignored. If definition of keywords listed above, except 'byteSwap' is missing, a syntax error will be raised.

**section_block:**

![section_block](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAArEAAABFCAYAAABdRr4LAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAIABJREFUeNrtnQdYVMcWx%2F8Li%2FSqYBcVKxYELNgNdmNMjBpL7Bp7jxrjMyb68pLYYixRY8FoNPbeEo0aewMrNlQQBRULvbd9c2bZDSDIglRzft%2B37HLL3Lmzs2f%2Bc%2BbMXIBhGIZhGIZhihiKgrioa02ouOizh9ftvP2uVJ7DDLafOz%2F%2Blk9I%2F7sPwqoGh8UbvgiOzfSaxa0NE02NDUJL2BieuP8o5vvjF6K9uN4whaU%2BM8y7BNtnhu16xigL6mY9T3nwN64j9ZsPztP0j%2FzqOnLCot3zfPzCTTu7l8dHIyqglJ0J7IobZXrO81exymfPo0uc9nzezT%2Fw0YddWpl4Br6M7uvljQdcb5iCrM8M8y7B9plhu14IRSyTs15ubvZ0VKpv9LYu3rFl7grv7n0%2FdsDcLxugmIGeTueSAaVX3Zo2GNqrmnLzfj%2B31Zt9vOvXUX3seSPpEH9jTH7XZ4Z5l2D7zLBdzxo9LvZ%2FL2QgPbbc675gRgP07%2Bqgs4FMD51H5%2F88283IpJhiX31HsKuNYRiG7TPDsIhlch8aohI98%2B7zptdHnerWuZImpbN0lpu%2BUqm32pkNJcMwDNtnhmERy%2BQmNElg%2F9HH8%2FqK3nluGcjUhrLPh5UVSih%2BET3%2BjlzaDMMwbJ8ZhkUskyvQLNf7%2FhGmvTpXypP0h%2FeujmLF9JTJKmxxrQ0HLnGGYRi2zwzDIpZ5a27dCxnQoWXZHMdYZQWl29DJliK7lUjCfC5xhmEYts8MwyKWeWvu%2BoY7NKtfMk%2Bv0a5FGXozFq9mzrXgxKXOMAzD9plhWMQyb8Wr4DijsqVM8vQajlWs1B8UeK6XjG5c6gzDMGyfGYZFLPNWBIfHKYpbGmbrnJfBcXj8NBqh4Qk6HV%2BupNYIm4lXWy51hmGY3LPPKhWkTaZXfHxytq7B9pl5V5APO2hUGyUveCMos4Oy2p%2BnP%2BiQSPz48x6cOX8bMTHxKFemONwaVsfIIR1hamKIn1cdxPFT3q%2Bdt%2BzH4bArYSk%2FHzzshU3bT%2BLeg6coXtwctWtUQP8%2B72H1uiN4HPgqw%2Bt2bl8fEZExOHHmpvy%2Fkr0d5v13oPwcGxeP5av%2FwP4%2FPREVFYtyZUtgUN%2FWeL%2Bdq%2Fb8Gd9uxB2fQHw3sy%2BqVZFDN%2FDzD8Kcn3ZixcKRBfqlJyepoKev%2B1rE9%2Fwj0abvSRgY6GHX8sawsrDMuneUkr4wtDaKAnioRu8hC%2FDlpG6oW6tilsdu23UGH3RqACPDYoXuB%2Fr8RRguX3uADm1c2FoxzL8AXe2zQhyycO09%2FLbrET7pVA4%2Fz3LW%2BRoFbZ9zkxevwnHJ6x46pWp%2FV%2F16GNExcRg%2F8oMidz9XrvnCoJgStWtWeOu0qAwO%2FumF7h81KXT3%2Bba6UnO%2BrLwJSXjiWhM7lPoYm1GiWe3PK1TiF9Zz4DxUdSiDJfOGwcLcBNdu%2BGHD1hP4sFOw2F4a932foqStJfr2bJnmXEsLdU9zwdI9%2BH3bSXz9RU84O1VGaFgUdu%2B%2FgJ%2BW7cPozzoJYRwnj%2Fvfgu1S8HzQob78v3QpG3m94NBI3Bfid%2FLYj9QGJlmF%2FsMXISEhEXNnDYCdnSW8rj7AtK%2FX4emzYAztr%2B7Uet96JERwNOYu2onVS8bIbZFC8NKxRY3xs68hOjYJq76qhzrVLbN1rkLd0zfO7zx369JY1AsrnerYhC%2FXoGWz2jCyLXwi1ud%2BoOz4sIhlGCY9876oi2u3w7D1YAA%2BalcGbZtmL5a2oOxzbuL78Bm%2BnbctjYh1cXIQuiWpSN7P9r1npfbIDREbGhqFSf%2FxKJQiNqe6smFNdE1SYHFiEoqLf02UKRWZwgp6iO%2B8q0h0V%2FpEs9qfVwQ8eYVbdx9j45pJWq9qhXIl8EHHBkhM%2FGf4pGyZ4mjcsMZr5z8KeInFv%2BzH%2Fi0zUMfRXm4rX7aE%2FBwmxKylpan2WGvxuVIFu9fSsRSVycTEECXt1ILoj78u487dAJw58gPMzYy1aVqYG2PkxBXo1a05zEzVz7QePqgDZs%2FdIntWJKCLIicvvsSl68Fwq2cjjWQO0c%2FvfL8KjoBCofY2%2FHn0ivyu7t4LxLGTN2BfwRZTRKeEvv9tu8%2FKY1Z4%2FCG%2Ftw5tXeBYvXyW6R86chlHjl%2BVnZlGDaqjhzAShsUMcPbCHdlpog5Lm1Z18eknLWU%2BqL6t23Qc7dydsWrdYbx4GYZ%2BvVqh7Xv1ZHoRETFYKbZTHq0sTNGiqSPeb18f2%2FacxatXEfhRdMaIzwa209a7zIiLT4DHb0dx7uId2Zkb2Kc1XJ0d4B%2FwAjvE%2FX42QKRhbqytz9QxowZg78GLsBUdwkuX7%2BHCJR%2FUq1sJY4e%2FLz3UQc9DsefABWEMm8r3pORkbYeNYZiCQV9fge8%2Br43On53Bj6vvZVvEFpR9vub9UI6O0kgrja726dECVSqXlvsOHPaSNoZsa6e2rujRtan2vAtePti177y0l7VFO95btLc0khYWEaW1kUP6tZGjpXHxiamcAU%2BwZv0RBD4NRkPXqtKOGhupnRakEdq954wtu07jjk8AOrR2xoA%2B7jrfy26R1%2BOiXVHoKdBYtAXdujSBUqkn25qtIs34ePV9aIQkja7t2n8ebuJYjw1%2FibYhWtjSNmjW2FHm8%2BoNPxiJtoTup2RJK3zao6XUO2s3HsXpc7dgamIk2o6WWq2yXbQRle1L4oxoe85duiP1zcTRXaTd3rb7jHTUaMqG7HdpoWU8RFrkUKPRbFfnKuj7Sct8r7vZ1ZUa8ZqkQjn1w23VpImJVamHFSjRAJHoVnLXZmd%2FbkPC0draDItX7If%2F4%2Bdp9lEl0RAoxC412Klf1JD%2FfeoGalYtpxWwacRpKgGbHSi8oK17vdeExHvN60BpoA%2FPK%2Fe120jYjh7aCd8v3FFkjeShE8%2Fke58uFYpUvkmUPnseohWxg0cvwZNnwegiOkA3bvrjv%2FO2yn22JSzke5nSNrIzQj%2FqrFi%2B5g98t2A73FvUQetWTjgkjO5D%2F%2Bc4dfYWRk1aIbbVFUbwPWzeeRo%2FpHz3oeFRmLtoF6bP%2Bk12aBq4CEM6fpmsu8Soz1fgiTCwgz51l%2BKRRLLMX3ELWa8ob%2FRSKrNub4aO%2BVmOUIwZ9j5aiXo5cNQiGcpiX85Wdgo%2FFz1z4up1P0yfvUEbcrH30EUMG%2Fcz4uIS0KVTQxw5dg3ffL9Z7nsaFCLz32PAHNz3eyqFNcMwBU%2BjejaoXMEUXjdD8OxlbKHPL9k8CvdydXKQTh%2FqaJ88qw7bW7XuCJatOoh%2BPVvJzvdyYcc3bT%2BltePDxy1DvTqV0LlDA9wWtuzcpbvChltCqfePjdQXNvL0udtCRF6X51HnvVu%2FH1CtalmMGNwe3rf8hZ1bps3PkhUHMGLiMimmScBSe%2F33aW%2Bd7mXOwp1YuvKgHClr5lZTCuqXr8JkCOPUmb%2FKsERyZKxY%2B6cMfSSoXfrf%2FG2yDWnkWg21apbHwJGLESIEvYmxIcxMjWFubiLvRTOaOG7qKhlWRqPHHdu6YPj45bh555Hct2PvOXl%2BYmISPuzUCIePXZV5UrdvllpHG72MDA3wzZzN0tnSv1crKZz%2F%2FOsKkpKSC6w%2BZKUrSby6OuJxErATJGDTocwiUamQs9qfV57ZYgZKeCwdi6%2B%2F24S1G45K75GLEACDPm2t9WARl4RwDBK9m9RQTOyz56FSnOQm5EGrUa3c670KhQKlhOh%2BkS4fg%2Fq6Y7XoAZ4U4pcEeVHj%2Bl31%2FTSoa12kDf2IwR0wYZQ6PorqEQkyolWz2vK9S8eGsLPNOlSCesSLVuzD76smwaWeep3wj95vJL2Z3wphPFoIx66d3eT2cmVKoGO3Wfg8JRSF6vOODV9oPcS7D5zHdSGoaSTB%2B%2FYjzO7aTPau6UWeCU3%2Bjp64nsYb8SaoF%2F%2FA7xnWrRgPPT2F9DqcF4aejCoZwIXfDUHH7rOxaPk%2BbNl5BkvmfoZyZYtrz%2F98zEcY%2BKnaC1GlUmn0GboA383sJ%2F83NDLArg1fwsLCBAzDFB4a1LGG76MoeN8NR6kSRoU6r%2Fd9n8GwmBLthWAkW0LOAIJsKNnWA1tnwL68ndw2MaKLDB%2Fs3b25DAGcPrkHPkmxhSTm6BwbGzPsOXAxUxu5YfPfcgSMPLREfZcqcGoyQY56VRfCllgjdIZDpVJqPXH5vhw91bQNmREVHSedJUf2zNJ6kbt%2F2ETmicT3F%2BM%2FlmJbOs3EfQ4atRijhqofkmZjZYYtaydr09qy8zTu3AuQtr9K5VIynEBzP2TPyTF36fh86dAgLl%2F3xf5DnqhVQ%2B1c%2Bs%2BUHuj5cTP5meYOHT5%2BRdt%2BUHuTumxu3XksyryuFLAEhd4VBl7TlQocSgRmp%2Fe86iRiNQhtflUP6KDKYn9iIvzERfMkroYa4UM7ZsrYDu%2Fb%2Fjh17haGjFmK31dP0n4JJCKmf979tXNpeJiGcXMTSpOGMjIiXGw3NU1rQMilT6598sj9MKv%2FW19flLMqPytWSGi8fC9ubVik8p2e1BMlyKAkJOQsXipI9KLp%2B08%2FYYwE4wO%2FIDlUr4FituMTEmWstKajoxGwBBmqpJS4LRK6k6Z7SHHtUq8yBvdtA6faFbOdv3v3n8ih%2FyZtv0izvUI5W62AX75wBDp8PAtjhnVCU7ea6Tpj%2F3yuXLGkDIugyYuaupzbArag6wXDvAuUsFHb5%2BCw%2BEL%2FO2zcqLq0n%2FWaTUQtxwpo0cRROhmihSgkb2TPgWmfv0BzYqRte%2FBEnGf%2Fmt3NChqFauhSNU2bTPbQ92GQVsSmTodsZEJi1u3Do8fP5ciYRsCmzhNds1pK2kT1KmVl6ATpGGln0%2BX7TW0ShRjQXJ5mHb5Ms13jLCH09fTS5D91uGV6yJkx8cs1WL%2F5uIwd%2FrRHC7RoWqvQ2HXSlaJ03k9Uobt4T84qoQxFrDjxrDgxULy3EQmuFu8T37TfQIk52fHE5uQGraxMpWil12XRS6KeiEbEZnodZwfMX7xbzl6kYdncwLluZfy25W8ZZ5JakFBvicQD7U9Pr4%2Bb4xePP6U37G3xug1FflYwMzN1FYmJTYK1hUGRyXdeQZ0Y%2Bt5DI6JEw5G2TpmbGckVLTSQAKRhGurYaIRgZlBMEvWIKdTh4BEvOaHxyumF6h6qSvfbpmuRR%2BHw7m8yPWbHnrMyxIa8FyMHd5S%2FrQw7MGGR0uCbmBjmWXlmVS96CPv8sBrsk%2FTgKI50Fwf3FqXhrVRh9MU78GH5whQmGtZAtUQFfhb1tLaop5uExTqmn4xbFX3gvw3QqeecEzsXHa1O2tRYmSe%2Fw9zMN41I0UgRtZcUl0leS%2Fr89bRe0rYe2P4Vilubv3YehfCFhkdnoFcU6vXG3mATwyPTOp7ITpO9zlD%2FKHQrClNTYxm2SPG36Ve2MTMhZ1d0muvp6%2BvBxFRHW6pK2%2BaULmmNs3%2FN0enU1Pmnz%2BnbjzatnHDl5ELcvPtYhlwOGLEIJw59J%2Bcb5Zddz6i%2BpNaV4v0XIwN4xCZgsJDnQ1UKhGUUSiA7DekTEW%2FbRAI1xStAdDJqXr6NSVntz6tJXjQ0SjF7jwNfardRHMjNO4%2FRwLlKludTvAkN%2BY6csFwGU2ugof3Zc7bkKE80XBAmfkg0GzIxpef0%2FGWYnOHe9QM3lC71%2BrA7xe9OGfcR1qz%2Fq8gZ5Ypl1QLH2yfsnWx06EdO3kWKIdUFiqWuL%2BreslWHtNtosgEZYfeWdWX8lqYX%2FNvmv6U3Nb3YzVBY7j0njTuNPIwa0hFR0bGIE79gyhuFxdDQlS40bVQDjwJfyMkGGiienCZSEHsOXpDxXjs3TpNe2LFTV8rhLw1hKYaXxPfP4h5pyI%2BMb0FBDf8lH%2FhevoP9ZGvCElBR2KETSQqcd3ZEa5ZNTGGB6iPVS6qfVE%2BpvlK9pfqrq4DNKRr7XLl84Q%2F1uXHLXy4%2FSXNeaEJpe3dn6aUkkUo2ae7CnVobSqNex4XQImiuAS2dpWl3aclMioulES1yVGU2Qtq6RV3ZYdc4GMj%2BRUTFaMPBcgqJPvLCrlx7WLvtxOmbcvSX2oKN205qbSu1BXRvNPk3K%2Bh%2BHvj90x5R%2BAPZfwqr0EBxxann32SGZgIveYY10ATeZKEIqW0aPrg9TIWYDw2LLLg2OBNdefY6vOldXx9VhQ7fJo6LEAcHvKavUrcXKrUCvmAgEslAmGa1P9ehGNMAIWCbd5wue2bUmNKSWNMndUuzigAFTGuCpjWcPzpXBjJ7LB0j12x1az1VxjxS5bW2NNPGR76JWULobt5xSv5o%2Bg37Cb%2BtnCArxWaPyZg8Yy1qNxknZ5LTTHhy7c%2Be0TvTtGhFhWWrD%2BFVSNGaEOPe2Ba7Dgdix6FAtGtWEu8iwwe2x8CRi2TM8pSxXbNcjmTRnCEysN652UToiw6KsZEhtq2bgnEjOovty9C0%2FRewNDeVQvTX5eN1ysO6Tcfw1f9%2BRzWHMvB7GISZU3tKDymJWKfaldCo9RToK%2FTwx86vM%2BwopRbZa5eNw%2BdfesiOGgljmqi18IchMgZsxn83irx%2BIScQfPvVp%2BiUEh9LIS%2FERmEo1%2F1%2BHDGx8XKVhpWLRhWq7%2Br%2BfZCa%2F9alhgxl2ibMgBt7ZJmChjywSaKhFY1tfxKu%2BXlt%2F8BoeHqHoIydEWo4WBT6sqK1S4ePWyhtG60QQAJt9ZLRct%2FiOUNFx3oV6jYdDysh5kLCo6R9ponTX035BGOmrIRT8wmwNDNBLK3CsnQsnOpUhFuDanBrOxUGQvHs2Tz9tbaX4lybtp0Ge3s7BAS8xLL5I6QNfFuW%2FzgCIyYul0PzSUJ4U3zuzt%2BmYdqEjzF4zFI0a%2F8ljI3VwnXtMt3aAnKUde83Bw3em4yKFeyEvZ4q2pFx0lG2YPFuWWakY%2BbMGpBlWuTFpYllHbvNlh5pKl9aVWfqzHUylML%2F0XN079JYp%2FXU88pPkZWuTNk2qVFtzBFS7Iv0nllFils3WiSyQiSSYVhAVvuzC7mRPU956Hx8Qnwinr0IlZ9JmOYEcvm%2FeBkOI1EBciu04GVwuAyithEC2zQPh1zrNx%2Bs%2FZxbwz6ee3VbBDouPhn1PzyKV6HxOPpbc9SsonvZ1e%2ByL%2FfznY16kx0oVik%2BMVG7lJsukAeeOlbph77IKxArRGB26yrFg0UK4UsrJqQfniJPLxldTc9aF54FhUBP5E%2FXexo6dimaN3aUkwAoFCI7ZVEQ9VnUhxnirYVIox3LKKYgEXWR3HEnRV38Nj%2FtMzHmmyvYciAAsyfUwshPdV%2FKsaDtc0DgKxk%2FmtHka7LHJNRoxYD0w%2FtkJ2mugWbZS609fhEmZ99nFrdPHlIKKyhlayUfJpCbkH0mh0H6yduUJ1oqjCbvZgfyRD8NCkZpO2vtZC5NehQekP7es4KcZxR2YZOSP%2FJa04o51lZm2iVB89uu51RX0uoFJGbFBUaI66jXiVXqo9KbEslqf15DFS6n4lUDiYK3TSM9ugwTF3UMi%2Bnhu8m1MXiaJ0Z9fQV7VzaFuanynbtPTVwoLU%2By8tfDmR4384tPtL3WzEReTjtJZAAzW8FCY7To4R3nLt7NNI3t66dqP5cqmbMVJUgs54aXIq8xj8H8CGOMdq4Fpys3cY2lFFMQUP1DMuqI%2Btglv69No2T0oAPHqhYY3KNikSq31KuiZGSPM4vVz8xGZrW6DI1SZWdpTVrLdePWk5nunzOrv3ZFg8xEpS4r3mSouZR6GeqVnKaX3tFCzpDsOETygpzqytSeWZlOqo1ZncS8I9BM%2Few8evaD1qWxfn4DhEUkIOBptE7e2MiohCJZNu3c68lXYeXzMR%2FmWdq0IkJOjWRB8PdDxLo64ne9ZHQT%2F7KIZQrGnlL9U%2BB3qo%2F5aZ9pvg6FXC6eWQ9NXIpLh4OuFFX7nJ9QiGDqFQCY3OVtdaXmfCUX5b8PK%2FNiia%2FC4pS2NroPI3RsWSpb17j3MJwLuojRpFGNopdpFY6JdnwCf3tMwVVBNFao8FN%2B22caZe%2FWvmyOrsH2mXlnOpFcBP8%2BzE0NQgOfRefpNS5eU68oIYw7zWRL4lJn8oIkFW6KtrwalwRTUFD9o3rI9plhWMQy%2BUBxa8MTpz3zNkLkyOkn8l2lAD0vmMNRmDzBOFLWLVsuCaYAsU2ph2yfGYZFLJPX3H8U8%2F2BYwGJ8Ql587xkv4AIPAyI1NQwX%2FH3EZc6kxecC5BxiEZcEkwBYpRSD9k%2BMwyLWCavOX4h2quYgZ7n5v1%2BeZL%2BtDmpnkymAj1n7wiXOpNH0GriCi4GpgBRALn3NEG2zwzDIpbJgsCX0X1Xb%2FaJvXE3JFfTnbvSGw%2F8IzQG0le8XJP1sINLnGEYhu0zw7CIZd4aL2HL4hNU3cZ8fT4ptwwlGcitqb0HCpxWAJd4DU%2BGYRi2zwzDIpbJNS7cSDoYGZP42fAvz6qWrL%2BNnMZgUYxVz7F%2FpzWQKmwUf9ur9DGVS5phGIbtM8PkNrxO7L%2Bcy7ewtn7NZL3fdjxYsXmvn9KtXgl0aFkO1RwsYF8m4yejRMcm4q5vOC5efYG%2FTj8RRjIy7QFkIBVwVygwyNMbD7iUGYZh2D4zzDsjYlM%2FZ5cpWDxvY41LLVVgUnzSthMXg%2FTFK2fPo6MYKwVOi08dVHoY4HUTf3C9YYoa9Ax4LoV3G12e7c72me0zwyL2jQaEG4tC1OMXBs21NuohCfPFt9Jc9NKfis2WKgVsxP%2BZPXA6UnyRLxQq%2BCQrEC2%2BzIZ6gJlKiSaX86CHz%2FWGyTfhcMqDC%2BEdpSgKLbbPDFOIRCxTSL0TasPW1bkWnFKeR98OycIwKTI1kmYqFUKFIbUSny%2Bq9DHLkycJMAxTyNEIraLkkWX7zDCFTMQWJQPybyJltiq9ZhZKY871hmEYts9sn5l%2FPbw6AcMwDMMwDMMilmEYhmEYhmFYxDIMw7wZfvQsU1Dk6iNnGYZhEcswzL%2BL2MblYMTFwOQ3KfUulkuCYVjEMgzD5IQXMWYoycXA5Dcp9e4FlwTDsIhlGIbJNirAR1%2BBWlwSTH5D9Y7qH5cEw7CIZRiGyTYK4Bw9RpNLgimAyucu6x%2FDMCxiGYZhskuyHnZAhT6tKhbtuNgXr8Jx8LBXmm2rfj2MRcv3Fep879x3HhGRMdr%2FPa%2Fcx4ARi975eifrm6h3sv4xDMMilmEYJrukLP5%2BI8IYk4vyffg%2BfIZv521Ls83FyQGNGlQv1Pme9vU6vHgZpv2%2FTCkbdP3A7Z2vdyn17cYVfgoWwxQY%2FNhZhmGKPPoqjElS4LxLDVy9fAf78%2Bu617wfYtP2kwgOiUS5MsXRp0cLVKlcWu47cNgLew5cQEJCIjq1dUWPrk21513w8sEu8mBGxKC2oz16d2uObbvOICwiCj8u3SOPGdKvDWLj4hEXn6g9z%2Bf%2BE6xZfwSBT4PR0LUqPhvYDsZGxeS%2Bxb%2FsR7v3nLFl12nc8QlAh9bOGNBHtyiLpKRkrN90HH%2Bf9oaVpSk%2B%2FaSlTJ8gz2rQizBER8Xi4BEv2Ba3xIRRH6BMaRvsFvcXn5iEtRuOwdrKFO4t6sK2hAVeBUf8I%2FbEPS73%2BANXrvvCoVIpmWf7crZy3%2F4%2FLsHO1gpXxb6TZ2%2BJsiuFKeM%2FhqmJodx%2F7OQNeUxMbDwqVyyJAb3dxfGWBV7fRD3rLN4miXrnxr8%2Bhik42BPLMEyR5%2BId%2BCQr0EOhwHrXmphRpQoM8%2FqagU9eofeQBXB1ckAvIUItLUyEELsp961adwTLVh1Ev56tMLBPayniNm0%2FJff9efQKho9bhnp1KqFzhwa4ffcxzl26K8SfJZR6%2BihftoR86Sv1cfrcbSHkrsvz%2FANeoFu%2FH1CtalmMGNwe3rf8MUyko2HJigMYMXGZFNMkYL9fuEOKUl345vvNUiwO6tsazRs7YsiYJbh0%2BZ7c53X1AcZOXomL4n8S46Fhkeg%2FYhFUKhVK2JiLRkSBUiWtZJ7NzIykwF4j7p9ITlah99AFeBYUgnHD30dJIVg%2F6vUdXoWoRe7eQ5cwcNRihIRF4cNODXH%2Bkg%2Fm%2FrRT7jsnvtQpX%2F2Ktu%2FVQ9fOboiJicfVG34FWs%2BoXlH9onpG9Y3qHf%2F6GKbgYE8swzDvBFdu4WjDGnBLVOBnSwOMdqmJTVDhmH4yblX0gf82ICk3r3ff9xkMiynRXghGCyFg3VvU0Qq3RSv24cDWGbAvbye3TYzogg1bT6B39%2Bb4adk%2BTJ%2FcA5%2BkeGY7tnWR59jYmGHPgYtpPLap2bD5b7Rzd5YeWqK%2BSxU4NZmAu%2FcCUV0IW2LN0rHS20lcunwfV675olWz2m%2B8j8ioWKzfchxn%2FvgB5coWl9ueBAXLeNwGLmpvbKd2rpj334Hyc5f3G6J2o3G47ROAZkLwKpV68h4qV1Rf96LXPW3aFzzv4umzEOzd9B%2Fo6SnQWHxBJIrJ6zxicAd12Yzqgs8GtFV7VfT1sHbjUfn55p3HKFvGBm1a1oWBKOd27vXyvU71APQfVoN9kh4cUyZx9VYB3koV3Lxus4BlGBaxDMMwuUSKZ6ytcy046anwsfg8LlkfVX1rwt41l5%2Fq1bhRddStVRH1mk1ELccKaNHEUQqz6Og4hIREoufA%2BWmOr%2BpQRr7fe%2FBEnGefZh8JvKzw8w9CwxRRSRgZFkOFcrbwfRikFbGp0zE3N0ZCYta6PSDwJQwNlFoBS1SvUlYK6owwLGYgQwnIu%2BpYvfwb0%2FYVea7qUDpNvqpXLQNfvyDt%2F%2Fr6%2F%2ByzEHlOSkxWi%2BVODbFz7znUbjwOTnUqoW0rJwzq20aK5tzCteabn7blq34al7%2FI4T1Re84lK9CBY2AZhkUswzBMnpEiNHIkNrISNhqKCeG3bsV4BD0Pld5FChmgz19P6wWFQoED279CcWvz184zNzNGaHj0a9sVpLFVmV%2Fa1NQI4alWASBoVQBzs4wXZaA86AKlGxefgPiERHlPMt2IGJnPjKAwAhLpNlbmqbZlnLaZSJvSSpvnWBl2kFWe7UpY4uD2mXj46LmMy%2F1x6V4kiwsNH9Q%2B1%2BqJ121%2BXDHruBWuAAADNklEQVTDFGU4JpZhGCYH3Ljljzs%2BgShpZyWH29u7O8sJXiT%2BmrrVxNyFO5GY4lUkIXf81A35uXWrunKoPjFB7SW99%2BCpjIu1MDeRy2ylF30aWreoK72jmuWsKN41IioGLvUc3uo%2BKJaVQgE2bTsp%2F6d8bd5xCu4t66QRy6oUpbpRHGdqaignpBGWlqZ44Pcsw7SbNKopPc%2BaWFa6v0OHvbShF2%2FizPnbePI0GBUr2KH7h03QwLWKKN8IrngMw2hhTyzDMEwOiI6Jw%2FBxC2U8LK0QEBUdh9VLRst9i%2BcMxdipq1C36XhYCXEaEh6F4QPb473mdfDVlE8wZspKODWfAEszE8TGJ8Bj6Vg41akItwbV4NZ2Kgz09bFn8%2FQ01%2FugYwMZ59q07TTY29shIOAlls0fARPjt5%2FDtnT%2BMAwZvVSI19NCaIbBpW5lbcwqcd37Ieq3mozk5GRxr4ZYuXi0dlh%2F2IB2GDP5F9hYm8tzHGv8E2JgW9wCC%2F43GP2H%2FYRKFUvivt9TDO7bRsbSZsWz56EYMnYpypcpIT3FJJZniLJjGIbRwEMpDMMwqaBwAs9THjofHxD4SsZ8UpxoekJDo6S3lFYMSD%2B8T0PyNIRPntzUPH8RBiNDAymOMyIsLEqGFZSytZITnnIL8rQGPHkFY%2BNiKGFjod3%2By9o%2FceOmP376YSieBgVLz216wsOjERuXkOnyVyRC6b6sLExlrK6ukCebrmkoyoPCC3KD%2Bs0Haz9zOAHDFG3YE8swDPMWpJ4QlR4rK1P5yghra7MMt2e1Dip5JOmlK7v2n8fGrScz3T9nVn%2B5ogGJ7IwEqraxUOplup8Et8Ub8kCTwd6Udk6uyTAMwyKWYRjmHYbWWKVXTqElumh1AIZhGBaxDMMwTJFBs3wXwzBMYYNXJ2AYhmEYhmFYxDIMwzAMwzAMi1iGYRiGYRiGYRHLMAzDMAzDsIhlGIZhGIZhGBaxDMMwDMMwDMMilmEYhmEYhmERyzAMwzAMwzAFCz%2FsgGEYJh31mw%2FmQmAYhink6HMRMAzD%2FMPTl5hFrzK2%2BIZL493%2FrrkUGKbowuEEDMMwDMMwDMMwDMMwDMMwec3%2FAYz400B3cxffAAAAAElFTkSuQmCC)

```
section_block
         ::= SECTION '(' int_const_expr section_options? ')' section_contents
```

referenced by:

* command_file

Comments:

`section_options` is not supported and raises syntax error when used!

**section_options:**

![section_options](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAOUAAABFCAYAAAC11SH4AAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAADR5JREFUeNrtnQl0FEUax%2F9z5Q4hdzYJBkhCSEhASYCIgQgLGAXxIbDiBcoCcoq6q%2BDTp6vPZR%2B7yO6CsqsiqLvKEdGHRDxBkUg4JhwSEgk5OJIAue9zZnqrejLsAJnMTDJXmO%2F3Xqen093Vx1f%2F%2Fr6qrqoGCIJwKCSOciKCcpHi06zDK3Pza%2BaeLayLrq5rd62obr3p%2FPx9XVWe7oraAD%2FXAwUXW%2F7yw5HmbDIjQaK0MN99kLgkY9%2Blv%2BUX13tOmzgAKUlBCAnyQJC%2F203blle14kp5MzKV5dj9%2FUWVm4tMWVrZ%2FFh2DgrJnASJsrfeUfiTdOeGXTs2b8uf9diDkZgzbRBcFFKT92%2Fv0GB7RjE2b89vbekQHlSeVn9FJiX6OjJ7HjzOr2rnlh3nZq17aRSmpIRCJjPvGcG3HxHrh6ThAfLvDpbOCfTVlJRV4ASZlSBR9jBk3fhh3vNckAkxvr1KKzjAHUkJAdIvfyiZHugvXLpCwiRIlGaGrcpFig3bju67JzXchXtIS8CF2dKmluTk1UwNDYSSecwCMi%2FRF5Ha46C8lrXgQoMnL0NakqcejoGLi1SuEbAjMR6RZF6CRGkiuedq5qWlhplVqWMKPL3RIwJ57ZUcaqwj8xIkShM5W1QfmZIUbJW0p4wXw2F3NqXcMQwjyMQEidIEqqrb3MJCPKySdlxUf%2B0PCcqlGswkExMkShOorm%2BT%2BPu4WiXt8OBrYvdi02QyMdEnRTkmHt3GksbWm4tGLUAqs067BV26ggA%2FNruNTEzYit7qRLe%2FKMoONcoSY7HTUKLG1jsiEq2nDKasQtiKnupkdCxmJMbhkkqNYr4s78zAXJyz1Wq2Mhafy2VYcSQHV%2FUyeLfrrcnmncU4lVeHtPEhmDohxNzdZZRVCBs6ArN0wsWolmADCxzDIfz%2F%2F3L9jQTtssFEja23Bj8rq5Dxw2WEBbv3RJQEYXOM6cSQGLsUpaFEzT2oJYkZ7I2a%2BnbcFupO1ib6tjgl%2BEoFvG5IjN2K8lqFDHCS%2BeM0wch6lQrF7KBWUc3qxTG92p%2Bdl0DZg7AnXCcstJ2qEjCLzTXGMqTcQGx8iO1YyuaTWIKb2fzZ7tYr5Fhrjqc0Ryhl5a0ovtQEb085hg%2F1MfuGZOd13z1tNit3nh%2BCCLUUcWzLiWzjh9nJ5cgFLDv6K%2FIpSxFiyDkUQ1QSvM3yRzzLH9tYDt4v0yB3YD4upAPqrvK1vk7Y%2FB03Bba0dmA%2Bc2QLBAnqwD2mMVHqEhG0iRxRyBDLxcYO9mx36615M958Px8ffXYBLy4Z2iNRGkO8ofkoYj%2F5lBEVhRd9FHiexfyH74jD7BO52EdZ0rlh%2BeC3LORMZ%2Fl%2FfV0HphUUoE237lg3Ts2ATp4bE4%2B1HWqsMiROfVGmGxFbui3FqOPgsUp4ecgxf9ZAmxig84a%2FMXKoGJqnsydkMnlM5%2FaQXJCCgLnHf0WGKc95Yzrp%2FJ9BcepE2cISKelGbMbWW4WSKy1i6Lrs8Uj076ewqTG4AViEsJ55zLfY4hTKns5Jp%2F3XmyhIs3RyoziZh118TZRyGQZ1l4ix9dYiU1nJu2JhyaOD7WIQ7xasa3DHMt6w%2FcQZnKIs6mRhK%2B%2FQoEECywfTTdm%2BpzrRF%2Bc1URpLyNKC5E3hTGlqd29qCO5ODkRwFwNoGaKxqcNi5%2FnjebQmxuGTzobtJEonQ7S7BJ%2FwfGCGuHqMbn%2B7NEjv7%2B2iqqprM7qdj7cCIQFuZqV97ny9ZU9WwH4WktxJWdT5EO3O7G%2Fzh4FdwkJPRW3plWarpH30VKU4lwhoQGdVda%2FKFALOMH8%2BhLKo88Htzu3vFKL093U9kKm0ThH1u8wy7VNOgnI26%2FVB3BvFNAIpizolgZ32v%2FVFyUc2%2F3J%2FiYqP22pJiksacL6kUXdl%2FL3jxd6mmVUilifcKH86JW6d9r%2F1Rck%2FNeCikCr5QMqWZPXabP0CQRN3nJYpWjjO5x0IW0ewtm%2BmKbXX1fJPDfCRzU%2BfrbFIen99NweFFxp0MipiU6JGil2Ur4i%2Bht1Eyb%2F90d4hzFz%2B6mF1b4XJBblT3%2BtKkMkeccfo3SJBojSTI6fVextbVAufevGQsPGjPJhbxuRlyIdW%2FHi9IAV8zP7eI8jwApmX6IvI7X0Cx3OxNSlWI%2F3PrsJ%2Fb%2F%2BiWJ58ewDSUsMxJLIfIkK9rtu2uVXFh6fE0ZMV%2BD6zjImy8cbS38diTw8JnlTSV7gIEmXPUebh%2FZHDhFJ1uzr9wNGrMjaZ1zeTlyFZyAre91OKedln8LUj33Tq42nFYlFe36%2BUkzvKiRxnQkqMx%2B3iyOYCxjFvd5n920eQwI8te96weSO78xUSAfkaCZpZDh%2FN4nAvQY6xx%2FuIh1Qe3EIKsjBJ4%2BaTp7T4U04rqBm8IXBne9Mp0LAnn%2BQmUXoJAmqZYPnIy0dZ%2BfE1JVXqEHpRSF%2F2mHJHPKnOWlM%2BvULZjHA2pHQLCIJESRAEibLXUFM758MuTexIlKbTemc4NUp3Jjrt3UqidFwqWrzouyTORKe9K0iUjhu75sskGEZ3wnng9uZ2J1E6buEiizffozthGjU1jWhoaOnrRp8o2p1E6ZiIXcAEPHL3wL5TrmxqbsOuL67PU3z5lT9%2FYvVjv7EuHVs%2F1o5hve%2FAL1i5arPRffb%2FdBqXSisd4t6Jdmb2tlfXPxKlCXQ2Zjjd4I4%2F9pVzrqyux%2FMvf3Dd%2F%2BJiwjFhfIJNz2PwwGCkTRppdLuN72Tg1Olih7h3nXY%2Bba%2Buf3KSnIllDAHL%2BacM%2BMjpJg7MaxEam1rx7tZvoDxZgIgBQVj0xBQMitDWOX39%2FXF4e7njVM55HDryK%2BKGDsDKJffD08MV6Z%2F%2FDLVGjfVv7Ra3%2Fd2MFLS1q64LK0tKq%2FDeh9%2FibEEp7kgYjMXz74GPj7ZF49b%2F7sPopGhkfK3ESSaWu8bEYumCeyGVmvdmSKXSoLau6drywUO52L33iHhd%2FDrmzpmA4gtXUXq5GnvYsfILypAwLAKTJ9xuFzsz%2B05js%2BeYvZPtldfIU5oI%2F3SBRoLZEgk%2BSozFy1FRcLXFcZ9YskHMtMsXTsXA24LwwJw1uHJV2yn8KybKhSs3oa6%2BCdPvG41D7CRXv%2FqhuC4owIeViyQYEBYgTq5uCvzCxLt771FxfW1tEx54ZA18%2B3th5eJpqKpuwENProNare3TuoWJ8smlG%2BHTzwPT0pLEcHTn55lmn%2F%2B5wjJs2%2FWT%2BDv7RCGefuE9TBiXgJnT72SCVeP4qUL0Y8dwdVHA389bPFd%2BTraG25PblduX29men6ogT2lOGJuLffzbIvzrSz4KLBsZ2%2FXXlyzFyV%2BKcfZcCba%2F%2FwfIFTKMHTNU9FrbPj2IZ5dpB%2B1e%2Bvt7sXzRfeLv4cMGIm3Wa3hzzXykjouHTCLF7Bl3dZn2rj1ZGBodhmeW3i8uJ4%2BKwdjJq5CZlYfUFG1F899ZOnclx4q%2Fi89fxfGTRZgzc1yPryePXUtQoA8mTRghilDfGwb4e2Ps6Bj2ABhlE1t287W15Ow8%2B347hkTZA4%2FJZpPFniwCHmS%2Fn9bIEF0Ui4hEC7f6KWIecvDAEFGQOmKiwlBYfPnaskTviJGs%2FNbBQtSqqgajaXPvGx0VqpeOBNGRoSg6f%2BWaKPVD1X7eHqiuaezV9UydnIgdn2UiIflpDI8fhImsfLtw7mQoXCyfDY31WS3Stta5wK7wHLNaFvOOaY4yfAyJsneVP6eskWF0eHm6oaHx%2BlcLfNnLq%2Bs%2B4NW1jZDJpKxc6IFKJkxBELpNu7Kq%2Fua0PQ1UMFvgcePr64U921%2FChZIK5nUL8Y9Ne9DRoRLLwRzBgo3a%2BnLXLSpTOjDJSUNQdrkaR7K10RR%2F%2F5fxzTHRw%2Biob9CONK%2FRCHj7vb24OyUeHu6u8PF2Rwcrs10s6fo1w8Txw%2FHtvpMor6gTl3PyLiIn9yLGjY2z2vVkHTsrvvaICA%2FEjGnJYsis877cExcUXSajk6d0bHgFyD%2FXLsCiFZsQEREolut4mU6%2FLPbZnsP4dHcW2to7xNrMzRuWif%2FntahzZqZgyoxX4enhhrfffOq6tEcnRmPBvMmYcP%2FLiB4cKobEa1%2Bfh5BgX6tdTxXzzPOXbUTYb%2FyhVqvh5uqCrZtWaCu0Hp2Ixc%2F8SwxvJ6YOx5pXHnNau1PPBzvAw1dzhgNpZyHe1fJa5v08RKHqWLl6M4awcuD8xyehvr4ZwUH9b9qXv6%2BUSqTw8%2B26RpOHrPyVRWBAP1Ek1obX7pZdqRYreniljz4tre1ieTg8zL9HaesPB0IjDxBWxUUhF18VGMLdzUWcuiLAr1%2B3afP3nN5epo9TdiDzDDa%2B%2B6XB9auemYFRI6MNrudlXkPXwq%2Bhp4Kk8JVwCB6dncrKYu42PSavmdXVzhIkSuIGeLmQuPWg2leCIFESBEGiJAgSJUEQJEqCIFESBEGiJAgSJUEQtoYaD9iJW%2BWzbYTlkdEtsD2XK%2FEan0ID8Se6G9a7xxS%2BEgRBEMStyP8AXI8W%2BBK4i5IAAAAASUVORK5CYII%3D)

```
section_options
         ::= ';' option_list?
```

referenced by:

* section_block

Comments:

`<= IDENT` is not supported and raises syntax error when used!

The IDENT in `<= IDENT` must be an identifier defined in the sources block, otherwise an error is raised.

**section_contents:**

![section_contents](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAUEAAABzCAYAAAAGy7AjAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAHcdJREFUeNrtnQlcFVX7x393Yd9kEwNUDGUTFxYRzdTUFHPN5U19zcrcSrPFbHnrfdP%2BVq%2BatqhvWq755m71pqW55UK5AaIoCLIqIIKI7Ou98z9nLiCWyHbhDvc%2BXz7D3Htn5syZOc%2FzO885M3MGIAiCMGBkdAr0jwBvCHQWmofwGPIZfUNJp0A%2FCTu1kU6Clgl8fDqdBD1ETqeAIBoWZVOkTSJIEARBIkgQBEEiSBAEQSJIEARBIkgQBEEiSBAEQSJIEARBIkgQBEEiSLRizobH4WpcWr3XDz0djcTkDMkdR0JSBv44e5UKlCARJBrGdztP4LdTUfVe%2F5sth3H6fKzkjuP3MzHYsPUIFShRK%2FTssIFz8XIytu85iTs5BXB1tseUif1RUlqO6NhUZGXnobi4FB3aO2LCmL7YuuM4Ii4mIDevCC6P2OPFaUPg1qEtwi8ksCjwFg4fu4hbt%2B7Co7MzRob0QmFRKdZvOYSwC%2FFwsLfGjOeeRFevDuJ%2BN%2F33KHoFdMFPv5xDTOwNhDzpj7EjgplgHcbZ83Hw8WqPN%2BePhYmxkbj%2Brcy7TGgPISr6OjxZ%2BnOmh8D5ETtUVKjx5dp9GDU8CJu3HUXK9SyWTm9MGNtXPKYjxy8i5UYWVq7%2BH5RGCsyfPZIKnaBIkNCQlp6NyS%2BuQEAPd0wa%2FzhsrM1x8o8rsDA3ESf%2Bvb2LAxztbcT1M2%2FnonegB158dggUChnGP7sUFeUqWFqawszUGLZtLMT17e2soFYL%2BPuMlci%2Bk49XmPDw7Z554VNRzDgbmQjOmLcabWwsMGRgD3z4750Y9vQi5OcXYwwTsYNHLuDrTYfEde%2FeLcSYyR%2FDybENFswbI27zt%2BeXiwKoUquwggnc3AXrmDi6YODjvnj7g28RGZUEI6UCtraWYt54vrhwEwRFgkQ18YkZLNJSYthgP1gzwRvUv1v1so4s%2BvP2bI%2BJTz9W%2FRsXoPyCYiSw7bhwbdp2DGkZ2fDs4oJH2tki0L9z9fonQq%2BgpKQMH743RfwexKK%2BYycu4TCLzKb%2BbYD424qPXsBjwd7i51Ono9HDtxMTzBHidy6e4ZHx4ucd359CnyBPzHx%2BaHVa3%2B87g4tM6Hy7aiLLHZvehB0TPM5vJ6Nw4WIienbrJAp8QUHJfcdBECSCrQC%2FrughFzAOAvqwr124LkHL4z%2F26e2J7l3d0LPf6%2Bjq0wH9%2B%2FqIzUwrS7O%2FrKtSqVmEtQXHmMD08HUTozEOj8YeRFxCunhRInjwW%2Ff9XiV6YjNEfu9wLNk%2BZbJ7361YdFmVdlx8On49FvmXtEpKy%2B6lVXNbKzNUqNTNWj71GEmGL09h0zVWaqfVMnx%2F4QoukmWTCBJ1EOQFjwoZ1sjU8GVetJ250pcKNaLd4pCym2mRlhxUxNhIiS1rXxWbqOGRCfhq40Hx86dLXtB4sXAvmaMsiuMXGUJ%2F%2FQTmZibibwcOR9zv9TX2amlhip7dO2H3lrcadyJqiBpPa%2BKYvlj8j8l%2FWa20rPwBm8r%2BlC%2Ftj3xV1%2BCqEwFFsgc6quTwYV8HsQrtoL83LisFzD13FXFk6dKB%2BgSlFP35YLBKhjPMu07klsMtIgZvRFzF%2FvNxSKyvADaEqOgU8TYYp7Zt8NTQAAwb5CdeTODYWFuw5vLN6nXLmNgoFAoolYrq5m5xjUiM9x%2FyyK%2BKJx73ReSlJBY5Xqr%2B7VrCTfEiSEMJGeKPPT%2F9cd8tO2fC4pCZlVvntryZn3w9U4xkWxJeXrzcePnxcuTlycuVly8vZ7J2igSJB0SAKgG7WdAyjTtOS%2ByzqLgUs%2Bd%2FJgoFv3ggXs1dNVdcNmlCP%2FHiQ%2B%2FBC%2BHj2R7rvngZG7cehd%2Fjr4tXbPmFDqVcUZ3W1GcGYtqcz3HgULjYZ%2Fflsplsm5fw1r%2B2VEdmPCJb%2B9lLDc5n395eeHPeWIx79t9oY2Uu5tPOzhLbNyyoc9vB%2Fbvjy7X7EThgARRKOcKOr9BJ%2BcbHo5TNlvh7IZJFHrtZeQdTRCgN6H0JEoE1Yfml0JOsmbVEC2kJDRlePzUtW%2Byf47ec1KS8rAIZWXfh3M6ORYHy6nXNzU2qL0L8uWnKozN%2Bq03NJmn6zTswNlHCwc66ScfFo7n0jDuwYULIhbsh8Hxz4axqyjeGmsPrN%2BVdI6x83mez%2FiyNoWT51BwmoLkIwmbdrIrxqS727%2Bpi%2FxcB5BgZK8VbS6oEsGrdBwkgh0eIfP0%2F98nxtJsqgByeD55%2BQwWwKt9NEUBtUlnO3SrLnSARJORqjGdxxbbjySihs6H%2FiOXMylssd4JEkBDvpejD%2Fh2jM2FQhX5MLHeCRJAQO2b5RZErdCYMB17evNzpTJAIEhoczQpwi06D4VBZ3o50JkgECQ2mp1OpP9CQqCxvUzoTJIJEdYuYXuhtYAigW9RIBAmCIEgECYIgSAQJgiBIBAmCIFocGkBBT6n5nCtBEBQJGhT84f6mPOBPEBQJ6gFC2CyjPafPvBodlzMtNiG3y53cMpOsOyV1CoO9rUmFhZnRXQc7kxPx14s%2F%2Be1sUTiZCUF%2BoL9%2BoJcieHhzwEuvffHj8rikPIuRg9pj7JwOaNfWHG3t6743NTO7RJmRWeQQGpY5PiXt%2BpjRA83D0m4XTQ2%2FjITWGBGSDBgu5Af1Q6FXtZ6wSO5jl71r1eaYhcMGuhovWeCPYD9HODmawcK8fnrP1%2BPr9%2BrhgGdGdpKrBbhGxeTMausgi0jPFOKbI9%2FOjlh08zYWk9saFs1V7q3VD0gEtQAv%2BI07r0349L1eGNrPWXwtZJNODtu%2Bh7cdArs7KA%2BfSpvkaKtOTc%2FCBRJBQsrl3lr9QFfozYURHvqv3xE3Yfk%2FAtHN01arafP0Vi8OViiV8vV%2BPqDLrgT5gR75gV6IIO%2F83X%2F0xvKpT7trveBrGsCUMY%2FKlJCtC%2FTBcHI3gvxAP%2FxAL0SQX%2F2KT8m3mDSyU7PuZ%2FZkTxgby5VqATsDfOGuTfslFzY4tD5ohh74AYlgY4m%2BlvNcyAAXGBs17%2BHw9IN6OHLrVUKl1feBlA50o2GVDIk%2BrmJ5l5AfkAhqhdjEPPd%2BgU4tsq%2Bh%2FZ35zIxN%2FbT4opzsQksaYNOQKLYEN9gs8gMSQe0oyJ1SU5d25i2yL5%2FObaoaM5lafFFOYoWahlo3JBQydGVt4TjyAxJBrXAnr1Rmb9O41ymmZ5bgxs0iFJWo6rW%2Bq1O1kfH3Tj6pjfwzZwiTqdGPpMGAkGEQa06e1pUfZNzW2H1BUUWj9tUcfqArxDsne%2FvC6ezl2t9xUddyXaNWCZA38F6ouOQCPLvgHBKvF4rf1y7xx%2FhhLnXXGpX7EQTYybT0xI0gw8%2BsNvqSffwQdJFE7%2BH9v%2FkCpqjlCNGVHzwz%2Fyyir%2BVBydafPrETPlrQtWHRUzP4QUNpqi5VbS9GguUqpAd4Yxf%2F8UEr17W8NbJyfZwogJNGtsePa%2FtiQC%2BHBlbkYg2olfNxIRq%2FsQTlgT70HlpDIN8Mb7JZ1IUruKirPHzxfg%2F8d2UQbKyN8PWORMTE5zUyoNWeHzSUxupSkDeeDvDBjQoVkqojQZmmWTxRpWILvfGDUoFXaipsXctbI5l3SsX5rEmd0M3TptFdO9qqxNk5foPVqpt6eiEs8iqSSSr0E38vjGSzNxQCgnWZj54%2Bmj69%2Fr0c8cOhNNzKLoV3Z%2BjaDxoqwA3SJS5%2BKhm%2BZAGza8321n1hrKD5XmuidS1vTVT1hVhbGkkiP2HROODvgy%2BZc5xi8ykR0ThFkqE%2FdO4MExsjLOQCyGq8ieEx2r0o0lisLJX3%2BUNrpC5dqk38HiiCtSXa0J1KFRU7C0mphTh5%2FjYuXc1FX397dHA2l0z%2BmPB9HOCFZJmAvf7eCGPznWoFztsUIvF4Mr2SszUxkUVHyR7oqJLDp%2FIiyGTmN5eVLAKUigByeD%2F49p9uYM23CXCwNYGHmyXs2hjrhxjKcIBJ%2B4e1id9DRbC6jQZEsngzRKhjeUUFkthOzaR%2BknjI32fCb5pmQJADvlsZBFkTB5tix90sFzJYtoazf8PlarEPie%2BHaEUk3ivHmmXajkUksVIqSx4IbP8iCFNeP4dRM3%2FHxOGu%2BM%2BHfpLxg8bAdYmd6xEVAiawubqujClrccA%2F2IZpbD6EJbiezV9%2F2HIjJZZWRYIPqQHnnrvaPDVgfQvAgdVwGz4JwO%2Fh2di4JxlvL7uML%2F7ZtPs8acw%2BQio0Roj4XRKz3ouAk70p5k1zR%2B8edpLwgyAveFTIsIYl6ssOajs7smMKNaLd4pCymzXqHnS8NXWJzdeZGmFjSTmms0BthiBDLnhEWJcIViUiaBI5a6SANxc3trPXH7a8ZhpiBuPEipBP%2Bzt3xru8L4TVgGf8fDDxQjSO6spIjI3lGD3EWZxOX8jGtp%2Bu4%2B3ZnnBuS0%2BsEYbJJhYM3Llbho8W%2BGJCiIsk8sR0YjBrwu5merMytxwj4%2BNRWrXs%2FEOCtlp06Y3evlharsLbtYlhTRHc%2FTBxq8fyB1J5AEv8vcSm826m8MHNFRE2BAc7EyAhH3dzy0gECYMlhwkgx14i%2FYA8AuQCKAiYFnEV%2B%2BuxSZ26VPlbrWJYJYLFLJHUh4hbXcvrhB8QiyhXsohwNfs6VNcn28pCc%2BgHT92C56NWTR54kiBaGzezShB2OUf8bG0pjTdtVOrDynoKYIN06c9iyDx%2BTrUIKhXo9LBE6lpeb%2BEpxqf5ZpjLH7jW5Y2inJnPdMLxM1n45Kur4lTfJ0YIQh8YMOWE%2BMQIh18k9Ku8b1CnzWA%2BEIMa3ZhOjK7P%2Bo3VpZpiWC2CdSWkrdtf%2BG0eAT7YVvnAtdZEkD%2FC09BH5%2FoFOuDC%2FiGIic8Xv3t2sqzXdgWF5eRBhCRpiB%2FwJ0YKi1WwMFNU3zjdEJrDD0RdkGFbfW8Ha6ouVW3f8jGwgGMshH1Nm0m2sTKuyM4tVTraNaxvz87GGI8F2Ddom2vJeeRthCRpiB%2F0bGLk1xx%2BwHShj0zA5y1eebR4m1%2FAFVZPaXXYKCsLo7tpGUUtkv9zF2%2BLc1ZYPIRUkesRUqG1%2BwHXBa4Pei%2BCZgViCKrVAUTtbU1OhIa1zAMrh0PTNbWWDJlsdotcj5AKeuAHjpX6oN8ieDpVbO9r9Z6U%2BOvFn%2Fx8LLWirFzdrHlPSs1HcmpB1Znj90FeJ9cjpIIe%2BIFppT7otwhqmv7avbv8t7NF4cZG8rAd%2B5OaNePvLA2veRR8IMLD5HqEVNADP9D6y6ekKoLNQtrtoqnrd8SVRMXmNEv6y76%2BjISU%2FKqCT2RTgFqOveR6BPlB6%2FYDvRHBcFY2ZeXC%2BHkfnFFp2wB4we%2BqWbvKEMqqrPO6vteRIMgPmo5OBkN0dsSim7exWOu1YKZwzd5WfePAsdTRRaUqmZ%2BPfZOeBOF9H3PeO43Q87dqhv%2FfscIfys7c5JuZyCG3IyQXDbZSP2guXagLpb4ZQEQ0NgV6q%2BVb9yas3fFTkjK4pwNCBrjCw90aHZ0ffkN0UUkFf20hzkVm4UhoOiv8gvtX0BT8IJkML4SxGpfcjSA%2FaP1%2BoNRHAwiLwQb%2FrkKaqky1%2B8S5Wwo2NW2sQ973wUJ%2F8LEV5Xgu%2FAoOkpsR5Af64QdyfTWACFZAMgV6so%2B%2FssLLZo2By2y6wQqxsB6bF7B1k%2BQC2xb4QQBMxBfKKNE3ggSQID%2FQKz9Q6rMBhGtC9af5g9mVzysPhZoVvwwWdWxqKQi4K8jAny06JyiwOIwughDkB3rpB0pDMILKq1d8%2Bhe5BGGokB8YWHOYIAiCRJAgCIJEkCAIgkSQIAiCRJAgCIJEkCAIgkSQIAiCRJAgCEJ%2Fb5YWwmYZ7Tl95tXouJxpsQm5Xe7klplk3SnR%2BsuF7W1NKizMjO462Jmc4CP78oEtm%2FvYArxbfuBJonGEx0AmBTvXhZ2SCOqQw5sDXnrtix%2BXxyXlWYwc1B5j53RAu7bmaGtvqvV9ZWaXKDMyixxCwzLHp6RdHzN6oHkYH9gyvJlH1wg7tZGsV%2BIEPj5dMnauKzttDejVeIKCsEjuY5e9a9XmmIXDBroaL1ngj2A%2FRzg5msHCvHn0nqfL0%2B%2FVwwHPjOwkVwtwjYrJmdXWQRaRninEN9f5mzV9DKmMxPl60%2F%2FEstK2vTfGznVhp1LRhbrQqz7BXV%2Fu3blx57UJK97vhWlPu8PYqGUPj%2B%2BP73fNh8Gm5sayfYE%2BmE5SQEjNzslO9VQEedNg%2FY64Ccv%2FEYhunrY6zQvf%2F%2BrFwQqlUr7ej4SQkKidk53qkQjyzuH9R28sn8pqN10LYE0DmzLmUZkSsnWsph1O7ktI0c7JTnUnglp97Sa%2FOhafkm8xaWQnSZ3c2ZM9YWwsV6oF7AzwhTu5MSFFO5eInerkdZu6FMGSPq7aewF79LWc50IGuLR4H2Bd8PwE9XDkpauECp%2BSGxNStHMp2GmlHpToYt%2B6Uo2sYks4aSux2MQ8936BTpI03KH9nfmMv9uhHx%2FZl1yZkKKd69pOK%2FUgy2BEkMW8cQoZumorvew7paYu7cwlabg%2BndtUBfuZlUObE4Tk7FzXdsr1gOuCwYggC7tP81f2aSu9O3mlMnsbE0karqtTtdHy9xw%2BSa5MSNHOdW6n%2FBWeXBcMRQTVcuxl4eCUgW7a6RdUqwTIFTJJGm5VvgQBdmzWgVyZkKKd69JORR1geiDqgqGIYOULX6LyzfCmVAzsamI%2B3lkWhQpV81ygkmlqWCdyZULK6MJOK3Ug6oKO3mSns2eHFQLmqWQ44%2B%2BFyIir2K%2BLPJRXqHHgeAY27E7GHxHZULLa8P%2Fe6CqaQmmZGmFRObVu69nJEg52DW6atPhjihcvJ2P7npO4k1MAV2d7TJnYH50ffURctn3PKRw6dgFmpiaYNL4f%2Bj%2Bm6aaNvJSEG2m3MWp4L%2FF7WXkFVq%2F7Ga%2FMGgEjYyW27T6JoIAuuJ6aJa47dmRvPOrWDgePRLD0IlHO1u%2FdyxMTx%2FaFibERLl1JxtYdx5F2MxtB%2Fh6Y8%2BIwmJoY15n3A4cj0MbGHNGxqTh%2BKgpuHZywcP5YWFtrmm6rWJ4SkzOQm1eETh2dMOv5oXBqq%2Bnb2rLtGPx7uuPnX8NwJeY6hg32w7jRfbDh2yM4cz4WXh6uWPjq2Op8ZGbl4psth1heU%2BDh7ow504fBhZ2v1sr6XUm4GJOLkP7tMOKJdpK1U%2Bb%2FI9nsDaYHwTprrelqx%2BeuIk4tw0SZDN8GeOP9zp3RYp16GbdLsHRdLPxGHsWL74Yj8Xoh3pzhgYh9Q2Ck1JySjKwSjJ3zR63TifO3Je8IaenZmPziCgT0cGci9zhsmHic%2FOOKuGzl6v%2BJQvHspCcQMsQPr76zHkdPXNJE6pcSse%2FAuep0SkvLsYKtX1ahEr9vY6I6deZnbPvfkF9YghK2fN2mX7Fk%2BW4M6t8NQ57ogYNMwJKSb%2BHCxUS8OG81%2BvXxxmsvjUb01et4%2B1%2Ff1iv%2FXFRfmLuKCdRdjB4ehMjLSfjo093Vy7Nz8vF43654fsog8fO02Z9XL9vMjm3GK6thZWmGJ5%2FoKebtyTEf4G5uIcaM6I0jxy9i7YZfxXXzmIiOnfwx7O2ssGDeGDjYW2HitGWoKFe1WhH8PSwbO%2FbfQFRsriTzx%2F2d%2Bz33f64DXA90lRedjiJzIRpHg7wQXCHDGhsjzPX3xnYIOKZQI9otDinM3LVuhe8uv4wt36eIUeDA3o7499u%2BYm2p%2FFNfi4OdMVZ90LPWdAJ9bSXvCPGJGSwSU4pREI%2BeuEBxVCo1vt58CHu2vg1fb033D4%2BmvtpwEIMHdK9X2i%2FPGI5pk5%2BoTm%2F8s0uxdd1rCPTrLP425qneUKsFzJy%2FBm%2FMHSN%2B53Ryc0LQwDex4qPpUCrrroPnzngKr8weIX42tzDFZ2t%2Bql626J1JyGWixo9zKBO63T%2F8ziL4cjH65Cxb%2FDwG9NNEt7%2BfvQpvFv299vIozfGy7fhvnJ1su0D%2Fziz6CxG%2F8yj3h%2F1nEH4pAb0DPFqlCHo%2BaoWcvDJ0cDaTRH4msugy2QMdVXL4VF4EmSwAl5UsAgyP0Z0A6lwEqyJCNnuS35skFzCOfZ6vVqBLojc6BkD7Y7FFx%2BeJAmhnY4y%2B%2FvYI6m73FwHkmBgr8FhA7c0he9vGBa4tORZgn96e6N7VDT37vY6uPh3Qv6%2BP6OiFLHrLLyiGR2fne07TxQVJKbfqnXZbR5vqz7wpyaOp7r5u9zcz5DLEXktDRGQCvvhqX%2FXvvMlaUloGS2Xd18UUintCac2iOpVKUy8Wl5Rh%2FlvfIDIqCT3Yfs1MjasF%2Bd6298rVkgmorEYxW9ZI61p8Og6zyDB48Fv37bu0pFxrZdHSY0C%2BM8dTUvlN1DwNksKK4Brz6tMs%2BgvRVR%2Bg5ESwOirUnJCLzV1ge%2F%2FTR%2BwH3LgnGR9%2FdRXLv4lDyAAnPD%2FODf2DHO41JTOKETj2aK3prF3ij%2FHDXBqcV20Mslnf4zU2UmLL2ldxK%2FMuwpkQfbXxoPj5AxZByZgicCG0t7US1%2BWfuVDc6y%2BtfxBuYW4ipsebmm0dbO5bxpuj77w%2BDiNDejXZRmqK2K7vQ5GecQenDy2F0kgh5v%2F7fWfqte2fv1tYmmLcqGB89M%2BpzWbfLVnunPTMEiTdKISVhRLdvWx0kt%2FWghIGBo%2F6Rg1%2BRJxik%2FKxeU8Kdv58A%2FuO3oR7Rwv8vvMJMYKwsTLCW7Nqr0193K0kf6xR0SkwUirh5eGCp4YGIDH5FiIuJojC1Is1%2F%2F674zhefWmUGD19t%2BsEBlU2hXmUFx17A0XFpeKFgx%2F3n33ofnhTm6fHm9MfvP2MJsIPv4YOrg5iU%2Fw%2F6w%2BgX7AP2rSxQAWLwn89dgEjWH6aQlm5ShR5mVzjq%2FyCTGPhfaIvvLwKU%2F82AN6e7e%2FLfzsn21Zp5ys2xOHb71Pw7ktejRJBg9IEQz54z05W%2BGShL96f54Vdv6RiExNElVoQRbCNtREWzvRo1cfHRWz2%2FM9EkeLNxcKiUqxfNVdctvLj6XhuzhfYdzCMNY%2BLxb46flGAM3hgd6z55hcEDFgAI4UCw%2BshWJ8vnYE5r34FP9b05pEZF89dmxdi3synkJGZg%2BAhb8GujSVy8goR2LNzk0Vw4pi%2B2LH3ZPX%2B%2BgV7Nzot3u%2F3zmvjMOG5ZbCxNBfPGxfsbesXtNqyP3X%2BNizNlZg%2BwY1Urq4Whj4cBG8mhP00SrL5Cxy9T%2BvNooYMr5%2Bali32zzk%2FYvfAZcYmyr80YwVBQGp6ttgPZ2NjUe99ZWXniU1NBzvr%2B37nfXi32TJHB%2Bt63R5TH%2FiFF37bjY2VefVtM9pIr6HHXGu51xheX2vlXg87T80oht%2BoI5j7rDsWzffRmZ1SJEhIBlcX%2BwYv43187V0cGrwvR3vrB%2F7OI9Ga6R0PvYzVX%2F9Sazrvvj4eAX4PH9WJC3tj8thS6emK0LDbfGgsvPT3R8n4DUUE%2BSM%2FUn10rqCwnKzsAQzs5ytOhPbtfPiAdhgY7AinBrxYzJDtVC9Glm5jZVyRnVsqybxdS84j7yVa1M75Rb12DqZkp4YkglYWRnfTMookmbdzFzVPlsgE5KMZbv4mDIfmtHNDtlO9EEF7W5MToWG3JJm3w6Hp4lyQIZPNbpErE1K0c0O2U70QwfjrxZ%2F8fCy1oqxcLal8JaXmIzm1oOpMJ7L%2F18mVCanZuaHbqV6I4G9ni8KNjeRhO%2FYnSSpf7ywNv%2FdFQCGvcMmVCanZuaHbqd68dzjtdtHU9TviSqJicySRn2VfX0ZCSn6VYSWyKUBXg0YS%2BoO27ZzsVI9EMJyVZVm5MH7eB2dUuhZCbli7atbWMoTKgPNSeWCcIDsnO9VDEeScjVL9UlBcMXP2u38Iq76NQUv3EfK%2BlWdeOX6%2FYQn4jv0fJijwFrkwIQU7Jzu9H717YiQiGpsCvdXyrXsT1u74KUkZ3NMBIQNc4eFujY7OllrdV1FJBX8NIs5FZuFIaDozroL7V%2BCGxcdOk%2BGFMFaDk%2FsSurBzstOHo7fPB%2Fp3RQjU2C3TDBXesiNL8r4V1rRg8xBWsz4XcQUHtZl8S49NR2ihGdtMz%2BI2yc6b2U5bCwp9PbCbWYh3boddrIDd2eTIarlEZiilrNB59Gus5d0VsLTT5ALOCTJEMYXqKJchi%2B1pEjOs81o%2FtttYzCdnRywieWkl9sjKSwJ23qJ2Ss1hKdS%2BmtD%2BaXHUas0LpYeyWlPG%2Fiy0vCtLQcBdZlj8LT%2FnWK26OIwughDSs3OyU4IgCOJ%2B%2Fh%2BpP1%2F45f%2BumwAAAABJRU5ErkJggg%3D%3D)

```
section_contents
         ::= '{' statement* '}'
           | '<=' source_name ';'
```

referenced by:

* section_block

**statement:**

![statement](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAOcAAACpCAYAAADQpio8AAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAHsRJREFUeNrtnQdYFEcbx%2F93HB2kCyJ2RMAKqMGOXaOxY49JNMZEjRqNmmLyxXx%2BSTTRJLYkiiUaK8bYTYw9dkFFRBRFwIpIL4LA3X0zc0BA6R7ccby%2F51l2udmdnd19%2F%2FO%2BMzu7CxAEoZVIdOEgvNygpEtZsQSGVqytKAPe0d9x9tz062EJ426GJzWOT8o0fBKf8cI%2BbawMs02N9RNtrQ1P3L6b%2FvWx808DdfWcy3TlQAL%2BWUsKqiBadxpfofn%2Fvd7rvRk%2F7vo2LCLZtH%2B3Ohj0bl041DRBTRujF9aNicuQRcc8tT0VEDM06sHdgQN8TAIexD4dG3gN4bp23vV04SAc7fDFO%2BMHkooqiFXrdotzzKdHsZivNm%2Bp%2FELqbh23fdn60Nm9fZwMFszyhLeHHeztjGFqUrjf4L%2Fz9DYtbTGifwOpQgmn4NCEd2raSi49jFHe1qXzLiXTIzTF9qW%2Fb1u77dawxfPaYNzgRjDQL5s58vX5diu%2B9DYyMZDsbe2O8SROglBDKOu3NWzYt5%2B0RvMmVi%2BVF99%2B%2BXxvPZlM6uehQwIlcRKVDu%2F82Xfk3rdjmdd7WWHmF%2BjogQ0lMkh%2BYR60L4mTIMoB75W9HZViOrJ%2FA7XmO2lUExgYSGWsHbrNqxkakTgJooxcv5XwRp8utcvcxixNG7RtSzt%2Bz0cGOb4jcRJEGbl5J7lRx9b2FZJ3r86OfGbMpo4eTdGSxEkQZSAu%2FplRbQeTCsnb3dlStSBBjFSBoSTOKsTDR%2FHIyswmhWiQ%2BORnEhsLwwrJ28k%2BT%2FRmbOpZ5cX5SjMUG2OUlF6V6Dv0S4Tdeai2%2FDKzsjFs3CKER0RXSHmvhkTiytWIcm%2Bf9vQZduw%2Bo1XXQCFXQqpXMaMBc%2FNVKmHNZnU1cXwvq5fc7YU4s%2BR46OWG7UVlWlJ6dUZPKsWIwR1gbWlWIfnv%2FysAO%2FeefYkQMgWz562vdtdFovKcGrHX8uqlrRsGe7njXrYcojaW5RwIF6mvXM4S3fCHTA%2Fvn7%2BGx%2FkOtNj0qsaj6ARs%2B%2F0UIqIeo09PT4zx7SJ%2BvxMZjXW%2FHcXjJ4kwNJDBu20TjB7WGRKJqjbmHujoiWDIZFK4ujjhjdHdYGpiiEePEyCV%2FusJ9h8KxOFjVyCXK%2BDdpgmGDWoPA%2F3ihzFzz7t%2Bk2rf9naWYhtLCxNcCLyFLHa1lizfDWsrc7w5phs2bDmGVi0a4ADbT0joXfTs2gq%2BrIJYs%2BEwzl28CRdnR8yePhjGRgbw33UaCqVCbM8ZPrgjnGrbVJlr5bc9AkGhSejT2QH9ujqUue7UUMVQJr1wUcolWMoCCqf8j3AUaHMqVWLlmd4vTPklpVcV%2FrtoO5wcbdDDpyUWLtmJP%2FadE78nJKTBzrYGfJkwenXzwMrVB7Fx63GR9tu241i17pAQTe8enrgV%2FhD37j8RaT%2Bs3IvElKdiedkv%2B7Hoh50i766dm2PvnxfZerElhp4DR3%2BFhvXtMXZ4FzjWssaR40EwMjSAuZmxmOrUtoWDvaqz41cmzrffXwEzU2MhzK%2BW7ED31z5HfEIKBr7aFkdPXsVPfgfFujVtLZi1SMT2fDI00q9S1%2Bp0QBy27ruH4JtJVc7OStJLrqeUAzvBhfkcshIyFcovKb2qedKVSyahqauqOZKSmoEdu85gcH9veHk0ElPk3RjmXePxSmsXBF4Jx7hRXXGNeagmjR3RtVMz4Un79fJ6Id9sFs8sX7Uf23%2Bdg5bN6ovfeL4KRfFPtD14GIenac%2FQl3lxB3srdO7QNC%2FNrYkT0tMzhWfMzzdfjEM3Jn7OWeYtGzeshZlTVYP%2Fk1hFcfJ0iFju0rEZq4ElL2xfVWjS0BwJyZmo62hcZUPsF%2FQiwcFs4MvnPWWpxJnXcAeuMNfaR1lCenY2IthOq%2BTZa9TAgXlOVZvufGAYZsz1E%2BGjc6NauB3%2BCA3qqSq7N1kIO37yMjRrNw2tWznjtb5tMGxg%2BwJ5PWThLfeCzd3rFeykkBbf%2BdGY7Wtgv7Zo12MuqwBqo4O3G96d0Ad2NjWKbevmYm5a8NTXMDdBNrOEiqCyn5396N0mVaq8JemJWUK%2FbCWGsbmipILJioiZz7ANH7B5D5ahH5t%2FUFw6a04tzPWcvsxuIl1QTy6FO1uxG1tnFFv3mkyJKRduIEzbDCY1NR2WNUzF8mf%2F3Yz3JvQVnpKzat1fuBoSJZZ5G%2FPM4YUIvXkPFy%2FdxhffbIWVpRm6d2mRl5eZqRGUSiWSk5%2FC0tK09G0U5om%2F%2F3oCPp8zAgFXbou2J68kNvnNzO15LGH7F65fgTSlGjtG1fHQdVmu18OYDETcS2MVkAwtXC00Ut4CoagrXLIlWMEybcYOYgs7kqN6ClyvH4Yof0Be2PHl1wub%2F8JaFmszsjCeVa9vs2uTVFhI%2B4I4czNRqjI5r68HNy46trMPikvPn4coYBju8P4VNu1zdsbHFvqYzRq85zzc4Xv5Oo5ougbLSM9SzZ9lYvOOk%2BjL2pCil42FAEZGBmKZC4yHi6Ymqgd%2B%2Fz52BW09G7Mws44Qqv%2FuM4iPTymQr7WVGTxaNsTKNQfxyaxheSEn986i7VcEPIyOjUtGaw9n0YZMTkmH369%2FizQLVnHkVhDloQZrr%2FJw%2By5r99Z1sq1ykc3iNWHYsDMKH7%2FnWi5xqhNmv91ZKOrPdLAkKQv9b9%2FGs9y0i8U4uSL0MpO1QReySzO3KJHmF6d%2FcaIrRXqh5BzAAk9XEQL7s5rHu6I8aGl5f%2FYq4VISklLhw9pk48f2EL9%2F%2BP4gTGcei%2FdsSll6g%2Fr2TJyqbUJC77HtVotOm1gmSh66DmCh6PMsWzQRk6b%2FJHpJpSz05N7Uf8OcYsuTnS3H5Fm%2FiH1ygcclpODHhRNF2oC%2BbbFu0xG09pkF%2B5qW2L%2F9szIdq4WFKUYN64Reg%2F8jKprl372Ddm2aVBlx%2FnMxFmYmMowfVl%2Bj5eAekwuTRTHjLt3AvlJsUqJecn4rUqSSHDf8lGXyM8tkYWGZlJRehnBmHpt1ZqFGL3WHtWV9TQnvhNE3kL3g0VKY10pMToOjgzX09AoOoOKe9klsMjMWI1hZFX9fMyY2SWxvw9qvpSWatVn5bRPeq5offkvmYXS8EGdJt2SKIjY%2BmYlfKsRfVvK%2FpkRdYW3AntdKXO9%2BdDo8XjuMKa83whfT3Etf3gF71R7WsjIfYrOTLL8FpVi3XHrhvblcpKzA77L9qN4FIdNDg%2BIyKSm9tJin47sUY0zhA5IvhyBIkzVhbcfC7%2FWZmxuLqTD4rY3nhVMU%2BUXPb8fsPnCh6N7jxZNQ085C9NQW2vnDRF7a%2FRaFrXWNKhfSngqI5Y%2BA4b0xDTUbzvIB9Ao0Z%2FY7oDTrl1cv%2BT1pXlhbUkbquk1yPBIZXu7YnDMgOQjVhNdH%2BoiJUMGH2JVmCF%2FfLg7w8baDfSEv%2Biqygy8tS%2F3l5fYqwWZuv2UQWbnJ3b7yB74rcZS5%2FHZkotUXS3OD7LikZyW3l8314WBrVKa8b0UmV4DJMntldlvplVhl75BVmCGsvnQhE62%2BmJvqJz6IfloheV8IUo3GkijBu9LVcrOX2yu3W50Xp3GqcNl2ZKLVFxsrwxOnAipmQNnfp1RPHCkliGEzde3ELsdudVucZ%2B%2BLuN2ITLT6wt%2FUvv%2Fo%2FezMLIVa8424n4LI%2B6m5ls3vs99VU9ZGOXar2%2BJUhfC68RkIonzwTygY6EsDtu6LUGu%2BHy0MzG9ladyRqilrSY7d6rw4CQL8Ewp%2BW8Mygm8mqCW%2FRauuITwqJVeYd9jkpZDi96p8jkichEbg3zbJzFIOnfqfc%2FKXFSgX5vb8XliCU8zVXdT0vXQSJ1FlOR8sP5Canj1x0sdnlMs2hKKsbVDexhzx%2FvGCwlRiE%2FvbW6mHOVX9%2FMjIRAhNcuk61rV2U0g3%2Fh7%2B89Y9ETLvVrbo08UJLo1qoJ5jwaGGTzOy%2BWs1ceHKExw%2B9ZCJM%2FX53oxN4kkoCd4K0IGvjumMOCv6M3VExREQijWeTZUP5Jly%2FxMXHuuxqWzPBvM2JgtlwZ89luKNwBD8qQvnRSfCWj64uaI%2F7kpUsAdlgpLooRVb%2FIuJLY5dzGtsuseualohq6eytAipkq0L%2FKEEDMULvWRof0lHhElhLaFdlawqFB3MB5rnjL%2FuBQWTpwTPP7luplQiUSkBf6nSBda%2BnB8QontjtXVKnOQ9dYOcXlY%2BfV6dzwP11hIEiZMgCBInQZA4CYIgcRIEiZMgCBInQRAkToKoaujEIARt%2Bh6GrkEDO0icL01ZXypNlAw9TEBhLaHlUQlFJiROgiBInARB4iQIogqKk3oBiaqApNqJs50TvVia0H40aacaE2e6Gezp0hPajibtVGPi1JOgKV16QtvRpJ1qrs0pQTdN7To1LQP3HsQiMTGNrI%2FQWjvVnDiVGO1Tv%2FLj%2BaMnr6JN1w8xfvIyLF%2B9X2tt4p8z1xERVf4PWz14GIcjJ66SuF4CYZ%2FMTjW1f00O3wtOMcaHbL6gMne67Jf9WDBvDIYO0O7v965a%2Fxf69W6NBvXK1%2BQJvh7FKp8D6N6lBamsnOTYZzCbHKqVOPWUmCqX4JynK65cuoF9lbHPw8eDcOvOI5y7eBNRd2MwdoQPzl68gfp17ZHGQt0LgbfQo2tLNHOri70HL2L3gfOQSCRCyH16eIo8uDc7fS6UbVMTG7Yeh7GxAWa89xqSkp%2Fi181HEZ%2BQijdGd0O3zs1LVaZzAWH4Y89ZJCSlMSHWxJjhPngck8D2E4O%2FjlzGw0fxaNK4Nl7t5YXvV%2Bxh89ZYv%2FkIWydRlL9Fs%2FpYvf4QroZEokuHZnh3fG9kZmWzsl9A9OMELFm%2BW%2Bxn6qR%2BMNCnN6GWFmaX%2FdlsJrNTb2anN6uVOC%2FcQJiHO3xZXO3v5YYlSVn49vZtPKvIfVpZmEEmlcLaygx1atsKY9217zyu37yHhvUd4OrihLSnGdiw5Rj8NvyNTz%2F0hUKhxJffbENKSjp8B3cQ4pz3v83o1qk5evi0xFl2IEPGfANHR2v4DuyA2PhkTHx%2FBS6dXAwLC9Niy3Mj7D5bdzkWfDYGZqbGCLh8GxeYWJu514ORkQErp7kop7W1uSjHYiY0LtgRQzuidi0bsZ%2B6dWwxhFUe%2Ffu0wTff%2Fy4E3r1zC9ha14CBTCa2V7Vf6LZyaXB2hqGFPmZzYSok8A0MRRizz2oX1uLydRxp6wrvbAlWsBMyxdMNW1iMf1RPgev1wxDlr6bPhufi5dEIZmbG8GHCatemSd7vwwd3xKypA%2FP%2BnzHXD1%2F953V07fSv91v0404hTnEBG9TC2hXvi%2BVO7d2xc%2B8cnDu6CIYG%2BuK3zf4nceP2A7zi5VK8OG89EALs2bUVTIwNC4Sgtewt0cbTOW%2BfcrnqIz8bV32AmnYWYnnH7jP46IOheV790pVwBAVHiv87eLvicvCdvO2JwvFlQVykC%2BrJpXAX31kBRimBazLmMbkwNVk2jcc53IOyWU%2Fxlm8lhrDlaQo9NL7jhnpelTQ6wz7H2DnZWXLcvR%2BLJs61835r0tgRdyKj%2Fw3Jpf8Wy9z0xc96mLMKQJ5d8hezuBh%2F23YCLdpNR4um9Vml0QzvvNULRoYGRW4jybdvMzMjEXbn32%2B2XF4h50hXn0y5o%2FoobhQ7i7eYtZ1l3rKPtnw6UGsaIfne8q1Rw5Hp68GYhZTJLIx1rKX6jS9zj6tuuJh2bJiD%2Bw%2FicCkoHEt%2F2S9u83wya5hIV5bxqCTPVWVKpfr0RA9dVz408L0QeGfOb9uP5%2F2%2Fcetx0Y5TN7yNyduwTrVtMODVtujSoSni4lVfZ65hboLwiEflztuihgkePoxHxrNMuqBVFOq%2BK4T%2FzhuDN99bCp9%2Bn7K2nhKWlqZY%2F9M0te8nMSkNb7z3Ixxq8u%2FxqBzT2pWqtuzYkT54a%2FJS7PszAN5tm2DxgrfKlHcbj8aoW8cObX1mi%2F9PH%2FoG5ubGdHGrEBoJVXgYqs4wiedXEa8peRSdIEJFB3urCjsXPPS8%2FzBO9BzbC5H%2By7PMLMQ8SYKTo02BtmVZj4G3Tc3LEZbnf01JdQ5r1W2v5DnVQC2HlxPlfxdtR9C1yELTeLt246oZQnS5tzueh%2Ff%2BFpVWWcdAUFirk3w2ZzidBKLcUIcQQZA4CYIgcRIEiZMgCBInQZA4CYIgcRIEQeIkCBInQRBqQWdGCNHn6gjynFoIH5RMzxsSJE6CICisLY8HpUtKkOckCILESRAkToIgSJwEQZA4CYLESRAEiZMgSJwEQWgGnRiEoKvf8SgLNACDxKm1VMRLpasKNOifwlpCy6MHiiBInARBkDgJgsRJEASJMw%2FqXSSqApJqJ852TjCi605oO5q0U42JM90M9nTpCW1Hk3aqMXHqSdCULj2h7WjSTjXX5pSgmzacfLlcgXsPYsUXoAlCm%2BxUc%2BJUYrRP%2FcqP50dNWIyrIZFiOSY2CZ36fIKxE7%2FHxOkryp1nyI27CLwcXu7tM55lwv%2BP0yQELUPYJ7NTTe1fk8P3glOM8SGbL6jMnQ4d0A72dpZiefvO02jVvAFWLpn0Unn%2BdfgyHsckwsujUbm2T05Ox4yP12DYoPbiM%2FSEdpBjn8FscqhW4tRTYqpcgnOerrhy6Qb2VdZ%2B4%2BJThADCI6Jx6NhlGMhkWLJ8N9p7u8G7tUux20bejcG6347g0eME1LSzwJD%2B3mxuiTMXbiItLUPkU6OGCd4e1xOb%2FE%2BgqWtdHDp6BcHMU%2Ft0ao6xI7pg7cYjOHM%2BFA3rO2DOjCEwNTHE9hyvuWTFHtFvP3RgO9SrU5PUoUGYXfZns5nMTr2Znd6sVmHthRsIU0jgy3SywcsN85ydYVgZ%2B%2F157Z%2BIjkmAsZEBzEyNYGxsiDq1bWFhblzsds8yszBw5FdwcrTB6yN8xDZ%2FHw%2BCoZE%2BLJggTVle%2FLdaDtZi%2Fc3bT2LC1OUwYum9u3sw4e2Gz6ufMg%2BbgAF92%2BL0%2BRtY%2BvNesS4XOodvzycjQwNSh4bgdsjtkdslt09up9UxrMXl6zjS1hXe2RKssNDHFE83bGEx%2FlE9Ba7XD0OUPyCvqH071rKGSyNH6OvL4Du4Q4nrR7OwNTE5FX17esGptg06tXfPS2vqWkeEtc%2Fns2DeGLa%2Bp1gOuBLOwmkLfDxzWJ7Y9%2F4ZoGrbdGwm5r4U1lY6viyIi3RBPbkU7rzzh539UUrgmox5zMBQzQlT4%2BLM9aBs1tOjKVpKlRjClqcp9ND4jhvqeWnRKKJ6TnYYOaQTOvX5GC7Ojmj3iiveG98H9jUtiw7d9f4NTMxNC3pmc%2Baps7Oy1V5OejKlbNyBOF9RzNBuMWs7y7xln8shCNKGsmnN85w5JyRImw1y4Zdv4JNZw4QX3LDlGKbM%2BgU7Ns4VacoSSvC8Q5RUUL1DD13rDjTwvZTwe6HnAsJgYWGK7l1aYDgLYeMTU0Ua%2Fy084lG58%2BZeVCqV4PadaDrRhPZ5Tm1HwVzjjLl%2BYm5nU0PcI%2F3%2BK9UbCPr3bo3V6w%2FBq8ssWFua4e%2Fd88uUN%2B%2BcemN0N7w2YgHMzIyweMF4dOlIA6iqOxoJgXgYqs7wi%2BdXWa8p4R0%2FmaytyHtt83feKBRKPHgUJ3peDQ30y5V3XEKKmNtYmZdpu%2FyvKaGwVvvtlTxnGdn6%2Bz%2FYsftskek%2FfD1B9NIW1QHEw1J%2BG%2BRlKKsoCQprqwUjh3YSE0FoC9QhRBAkToIgSJwEQeIkCILESRAkToIgSJwEQZA4CYLESRCEWtCZEUL0GTyCPKcWwgcl04BvgsRJEASFteXxoHRJCfKcBEGQOAmCxEkQBImTIAgSJ0GQOAmCIHESBImTIAjNoBODEOj7IFUXGjii4%2BLkVNZLpQn1QQ8rUFhLaHnUQ5EPiZMgSJwEQZA4CYLEqWZ4G4N66YiqgCTHXquNODPaOcGIrjuh7eTYaUZ1EueTdDPY06UntJ0cO31SbcTJYoQwPQno082E1sPtlNtrtREnC%2BLPsj%2FdNLHv6McJ4svUBFFKY%2B0m7LW6iFMhxe%2FMfY72qV%2F57c4hY77BlasR1dbW5HIF%2FP84jazM8ldQFwJv4UbYfZ0%2FV8I%2BmZ0Ke60u4rwcgiA2C04xxodUNVcuWdnZmPHxGjxNf1buPDb5n8CRE1d1%2Flzl2Gdwjr1WOhobW6unxFS5BOc8XXHl0g3s00jbV6nEuk1H4ObihHZtXaFQKLFp%2Bwkc%2BycYMpkeRg3rhK6dmiPq%2FhPs%2FzMAk9%2Fum7dt5N0YHD4ehNdH%2BmDFqgOYPLEvjAwNcO9BLA4fC8JbY7uL9c5euMGEkInuXVpgx64zaOpWBzFPknEpKByv9vJCYnIadu45hyexSbC2MkPfnl5iXc6V4AjcvfcEcoUCew9ehKWFKT6YMgB1atuWykNu2XESp86FwtBQH83d62HcqK7Ma54R6Sv8DrLy6qNf79aQSCSiPA72VuL4zUyNMHPqQDyOScTGbceRlPQUb4%2FrgY7t3BFy4y6uh94Tac%2BeZaGukx2GDWqvc8JkdtmfzWYyO%2FXWVBk0NgiB2WyYQgJfZhcbvNwwz9kZhpUtzI%2B%2B2IijJ4Lh2aqR%2BO2TLzcKj%2FDOW70xuL83Zn26DucCwuBQ0xI%2FrTmI84H%2F9gv8tOZPPHwUD0MDfSG6y0F3xO88ZPz8q83CeDnrNh3NW96%2B6zTenLwUfhsOITk1HelMtI8fJ8K5YS0hHI%2BWDTF19ipcvHRLrH%2F1WiSmz%2FXDydMh6NPDU4hhzNtLhPBKYsXqA%2Fh9z1mMGtoZPX1aIvBKOOLjU2BnW0Ok165lLURuYmKIW3ce4aP5G7GZCbNb5xaiMhkw8n%2F4ctE2eLZoiCaNHTFh6nKkPX0GUxMjmDLxWtQwFdvb5uSnK3A75PbI7ZLbJ7dTTZVFo0%2BlXL6OI8xheWdLsMJCH1M83bCFxfhH9RS4Xj8MUf7MAVTUvj%2F%2F3xYmrjisXfk%2BDPRlzJslYdf%2B87hy6nvhATk3bz3Abvabd2sX5kU7Y8PmY3jFywUpKeni90O75ov1uEc5H3BLeN%2B%2FjlzGwFdfwYFDgcJ7clF8Ots3b79vjemOd8f3yfu%2FVYsGyM5W4DYTiKGBDO7Mi19iQm%2Fj2Vikd2Ne9PuvJ6jay6zCaNFxhmgze3k0Kvb4Qm7cE96yS0dVp3j%2FPm1U7ShLUzEf1O8VWFiolq%2BGRKGZW12sWjpF%2FN%2Fawxk9Bn6GwBNLIJWqxops3HZClLFls%2FqoV9cOLo0c4Tu4Q5UXI7syepEuqCeXwj2n82eUErgmYx4zMFRzwtS4OHM9KJv19GiKllIlhrDlaQo9NL7jhnpeFTSK6Ltlu5hBRuLi0e%2BEMDnc8NIzMuHz6rwC6%2Fbo2lLMefjK057EJWPPgQvwbtOEhXS2OeJ0w9ad%2F4hQ19zcRAjwq8X%2B6Nm1FfRZeFyPhX651LSzLJA%2F97r%2F%2B84fjRo4oA7L7xHzpEV5Rpm%2BHuo42iD6SWKJxzjxjZ6YNOMnUVYeGfgO6sBCZs%2BimxnSf4MoczMjVgZlnjBzf8vOqrC6UmPP5N5Rjf6JYkd6i1nbWeYt%2B2iqjal14nyukyioMi6si7MjTIwNMW3uavgtmwo9PSnMmPGZmxnj7OGFog32PDyE69TeHVv8T2LH7jNYMG9MXloHJs45n%2F%2BKPQcvoD9rw3m2aogHLOQ9ePgSOni7FVkOfktn7n82YNv6D4W34kz%2FyK%2FYsickpcE6x%2FsVB8%2Fv4rHvEBp2D2fO3cC0Oauxff1suLM2ryqsf9lmgXqvPz10rUVtTk0yoG9b%2FPzDu6KjY%2Bana0X7071JXZizttRKv4N568XEJuHsxZt5%2F785phuW%2FrxPeBQu1FxsrMyFeNf8elh08nBx92XzH3%2FeK7xqUSgUCmTLs0WHDYd3JvHOlvykpmXkeVLehuTLXjlCLg4eVvNIoKlrXYx%2FvYfo7IlPTBWRAg%2FbwyOiy33%2BLFh0EB7xiNRTXTxnZcMNdP1P0zDk9YX44uutmP%2FJKKxbOQ1TZ6%2FGqnWHYGpiiKTUp5j%2F0ShA1VxDlw5NUaOGKmx93rt2ZGK9GhzBwlYL8f9rzIOuXn%2BoWM%2FJyzBzykAMGvW16KgxY57b0LDgJQllbcdXus8WPclcWKt%2BmJwXihfbXAgMw8xP1sK5US3RccUrE5%2BOzUS5J43vjVETvoOlpRk%2Bmz0cUr2y1dEjh3XC8De%2FFeVybeyEX3%2BeTkqqAHQilOBhrTpfU8Lblbx9VcvBqsDv3Nv0H7EAAccXC%2FGqi7iEFGSkZ6I2a0%2FmZ8OWYzhxOgSrfpyMh9HxcGLphYXcRcHvZcbFpwhPxyuVAuFxQiqymee2sylfbysfxMDbvrXsrSGTlS8Ay%2F%2BaEgpryXOWiqIMdhXzhMMHdVCrMHPDYlgVnc7bxPnvbWY8y8TYiT8UuT73kFPfeVW0q01qF15WKyuzlyqzvoGsVPdbCRJnpdCRhahtvRpX2v54SMzvgRYWDu%2FYMIcuCImTyOW1vm0qdX%2F89gqfiOoJvaaEIEicBEGQOAmCxEkQBImTIEicBEGQOAmCIHESRFVDZwYh0OfkCF1DTxcO4lEs5vPJ0Q5f0CWtuteQzgKFtQRBEARRfv4PvSXPLW5Y%2FaoAAAAASUVORK5CYII%3D)

```
statement
         ::= basic_stmt ';'
           | from_stmt
           | if_stmt
           | keywrap_stmt
```

referenced by:

* else_stmt
* encrypt_stmt
* if_stmt
* keywrap_stmt
* section_contents

**basic_stmt:**

![basic_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAANUAAAHdCAYAAACKZDxaAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAIABJREFUeNrtnQdcFMcXx3%2FH0TsoYgcVlKIiYAEroij2irHFGqPGllhTjDExMYn%2FaIo9dmIswSS22HvviCggCIJYUBAEFKQc958ZiqAgncO79%2FVz3m2bnd15v31v3u4yAEEQZYpEGQ7C2RZyasqy5WqgctiGIlBXlgO5cno9tWYZ0bzdGDoJpUCNTgFRkPenCIBERRAkKoIgUREEQaIiCBIVQZCoCIIgUREEiarsePgoFmmp6eVSbnqajCyKyBRVq8Ywf9tKhS1%2Fl%2BgxaAECQ%2B6Xebld%2Bs%2FHnbuPSlXGiTM3ce9%2BTIm359vyMoiSUVo7z95eiIpdYB862%2BKvggotbDlRNiz7fR%2Bu%2BYWWeHu%2BLS%2BDKBkltfOWtujnbIfIdBnu8mnx7J8kU1xeMhlbaIt%2F1aWYcvEmHmdvVNjyd5kdu85h%2F%2BFrUGcH9V7%2FNnBv31TMfxIdjxVr9%2BEx%2B5awf45N62H08M5svcyI%2BfGTZ1i5bj%2FCwh%2BjaWPLYoV%2BZy8EYud%2FF5GQmIz6FuYY%2Fl4H3HsQg%2Fvss%2B%2FgFYTdjYK9bV24t2uCpb%2F%2Fhx5dm2Ot92E8jU3EyCHusGlYC79vPIRbQffQqYMDxo30wIukFLEtL2PJsl1iP9Mm9oJUSt3molJcO%2Bdikknwm0yO2rkf6MrzQK08c7rAQgtb%2Fq6xct0BIarPpg9ASkoa5nzljfmfDhZG%2FCz%2BBfT1deDSopFY9%2Bflu%2FEs4QVmTe2HpOQU9Bv2A9q3scPIoe64E%2FZIbF8UrvvfxaQZq%2FHtl8Ogra2Jy9dCcPV6KKwa1ICWlgZMTQ1Qp1ZVmBjrI5Vd%2BhYzgRw9eQMD%2B7RGfEISxkxairp1qmJA79bo7uGMhUt2wJpt69KiodiWl8G3F0YioQfNS0Jhdl6QmPIVVUGFFnen78SJk8uxiolqzdJJaOlsLeYlv0zFCuZ9uKgaWtXEzCl98eDhU9ZXiUZbVzth%2FJxd%2F11C1aoG%2BGH%2BCDHdqUNT4VGKQlDwfbatETp3dIC2liY6uznkLDNj87mI%2B%2FZoJaa59%2BFsXTcDhoa6mb%2F%2FPoWvmPDd2jYW0xcuB8OPCZVP823vhEXBq18bUkZ5iEuC%2FenANwWJ6a2iyiaDXViZP%2FSUF7I8PR132U513qUTlshCr5jYBDRi4smmkXUtEc5lG%2F%2FE6augLpWKcItn99SyQqnbdx7Awb5eifbbrbMTtu44jSYu0%2BDAwsaO7Ztg3Kgu0NQouCkkaq88jr6ejghHszHQ10a6LKPczhM9qZ5p5%2ByM90iXYyD7zijshKgXEFueYxs%2BYN%2BdWYFr2fcnb1vO7OHHbE%2FlBUjDG8JCpgY7tqI7W2cIW%2FemuhyTLgUhuLI0vLaOpugfJTxPhpGRXo7QDPQzrw3f%2FeSD7l2cRbjH4X2gP%2F86KX5raaoj6tmzEtWV72vX1s9Fpo4nFn5duUeEjtMn98nxoMXrCEhed8Flem6V5WXFljZomC7BcnYwjdkZ2sos5pg0AwGWwYjwAWT52VFuO2ffq7U1sP5lGsawS%2BsHcgniwT1WYaLKLkSeWchFDSlsuVjYzj552%2FLcZYgKBiOM%2FeSfvVZW%2BMxIA7NYDHrB0Q5evgE4WhlOMvcMbV3ssHn7CdanGiiMefP2k3BnnoOTmiYT%2FZPssPDU2VuvUqfNG%2BLjOeuEp6tqaiiWvXj%2Bskj7vXg1GDXMTVG3dlXx4X2qp3GJmYJjIV7o3agSH5Ohga5IeKSmpb%2FV86kazO46sZDNh9nvkvg09LxzBynZyy6%2FxakUYOfTWzXGj8w85hQkrtxn3udtYinC8nzJOoBvnWxEqOjDrhgu5eWxissPX4%2FAqIm%2F4cgJPyQnp6FmDVN8%2F9XwzMzZhJ4YM3mp8E784m9vUydnu47tmsCtXWO06jibeTwNuLK%2BjAY7KUXh6dNEsc9aNaogIyMDGqxDumHFVLFs5JCO%2BHDaCuzYeQ4d2thjHus7FYfWrRoxkRugRYeZLEbJwLWTS6Chqdri4h6KC4q14YhrQdhbhE0KtfOseQWKS5Ll9pJYIatYIT%2FmV0hhy4sRps1lX%2B1ZSNGlrMO%2F0rxOz5MRGuzKXs3MKM98niiIZV7EvJpxvld%2Bnnbn%2FR2zKobFi9FZVP7g0VMWRmq8sU%2FuFWOeJuRk8EoC7%2F%2FxxIa%2BnnaJts%2F9Ov27Hv4x2zjEvk6x4%2Fi2COuWyM75fS0uLnaiJrD96ApLYRfLem8rpLDlRcUgGT8l6mCSoz0cfG%2FBr7Kc%2BFo1q%2BQ7X09XS3wK4nVBcL78dgsCg%2FN%2FYsPYSBdrl06GGhNiQaLR0dYslaA43OMSLOxjdoYMNGF217so65fUznN7rpzwr7CCyipdfiIcL53tsEUtAwPYpJ8yNuSCuUPJmisJws4k2MLtrhjiKDHZ21f87XY5jjEX60pNTpS%2FqTE7Y%2FZW4WKu6B2yTuMtFns2pCYnyhtuZ9zelF5UOs%2BFizSjJicqALMse1NuUZ2%2FL%2BJbbWpvogLQzrI35RZVZqhLf1KYqKgIsOIfs6L3AgiCREUQJCqCIFERBFFylOZpSxr%2BhSBPVYbwhz5pkDKCREUQFP69Gx6LmpQgT0UQJCqCIEhUBEGiIggSFUEQJCqCIFERBImKIFQRpbj5S3%2Fvu%2FKjSjfmleaJitL8MU2ifFG1h50p%2FCMqLJpQlYiCREUQJCqCIFERBImqgqDXNAiltC%2BFicq1Nv1BTUI57UthokrWhzk1PaGM9qUwUUklsKemJ5TRvhTXp5LAXRG75aMMpqWml0u56WmyEm3Lx%2BiNfBCDJzHxpIZ33L4UKyo5hrpZVnzc22PQAgSG3C%2Fzcrv0n487dx8Vul5CQhIGjlgkhkTlhIQ%2BQquOszDmo6WY%2FeWmMq1T4O1IXPG9U%2BLtU1LT4PPvWTHI%2BLuEsCtmX4ravyIfU%2FJP1MFM9v0tVAgtbQ2816%2BNGEmes3HLUQzo44q5swaV%2Bb4OHbsuPGBzR6sSbZ%2BQmIyPP1uH%2Fr1dIZW%2BO8naLLvyZ5%2FqKiUqqRyTZRJc4KPWF3HU8HJhx65z2H%2F4GtTVpXivfxu4t28q5vNBsles3YfHfLBs9s%2BxaT2MHt6ZrZfp3B8%2FeYaV6%2FYjLPwxmja2LHLop6GuLgxdysq5fuMuzl0MgkWdaliybBe6dnZEfHwSXqakisG7T5y%2BCTubOujYrslby4yIfIINm4%2FiYVScGIe4Xw8XVDc3xpkLgUhkwuBlG%2BjrYNyoLtjicwp2jerg8InruHEzHB3aNsb7g93E9mfZ%2BvUszDH74%2F5iEG7upTg%2Fr9gNNYlEiMuybrVKLShmTz3Z13RmXy7Mvm6rVPh3KQjBGRJ4sbby5qPWW1lBq6LrsHLdAfEZMrAdendrgTlfeeO%2Fg1fEsmfxL6DPDLFP95bo3b2FEN%2FPK3aJZUnJKeg37Adm%2FGkYOdRdGGwK%2B10U%2BMj0i5mR8zL09bXFwNmGBjpi8Gw9XW0hBF6P2fM2ISY2UdSjsP5Yn8ELUaO6Kd5%2Fz02Uc%2BSEn%2FCIxkZ6YiBwPq9GdROx%2FpYdpzBm8lJoaWkwETvhl5V74Nb9CzxiguzdrSUuXA7GL0xEnGpVMwcK59vzjzbbprLC7YfbEbcnblfcvlQx%2FINvAI62tIFLugTLjTQwyckWW%2FkYrdIMBFgGI8IHkJXXvnk%2FYRUT1Jqlk9DS2VrMS36ZihXM%2B%2FTo2hwNrWpi5pS%2Bou9z73402rra4er1ULHerv8uoWpVA%2Fwwf4SY7tShKZb%2B%2Fl%2FxDaF%2BDdSuWYV5wfrwYiFhNs2a1MPvv34EiaTwkIt7zNhnz9G9i7Mw%2FHat7XKWNbatK7xi7rI5C%2BYOQw%2B2vmgDvzCYmujji5leYjotXYZ%2F9lwQvzu0ayy%2BB%2FZpzcK%2FyvXwDautNLwhLGRqsONJCXamhrCe30115qGuBipOUAoXVbbHYl8ejvZwUJOjP%2Fs9NUMK6zBbWDiX411xHhbFxCagERNPNo2sa4lwjhMUfB8Tp6%2BCulQKm4a1RHZPLcuwbt95AAf7euV2TsyYhyiKoLK9yFCv9mjv%2Bbm4ELi2bIQJYzxZ%2BGdScOit9qpsHublhntdmazcrmVl9u5bWOZgbhHsSEKYlZxn3snT9xb8KoPgK837VFknxK%2BiGkpbR1P0jxKeJ8OIhUnZQuNGxfnuJx9x9Z81tZ%2BY3vnfRfz518nMZIOmOqKePas0V23uMT%2F7ZACu%2BoXij20n8NH01fjnz0%2BzPPLbt31du7mns3%2BXZfJPFV5WVNkHajU11NHWxQ6bt5%2FICQc3bz8J9%2FZNsvoqMtHvyA4LT519Nch5q%2BYNcfykv%2FB0HL7sxfOXCjmO%2Bw%2Be4vzl2%2BLCwJMsg%2Fq1ZeFgoljGM4xh4VElTolzL8bDvtAi3CogKqGnUsgV%2FusRGDXxN9GxT05OQ80apvj%2Bq%2BFi2bQJPUWHnnsnbpP2NnVytuPZODfW32jVcTbzeBpwbdEIGhpShRxDBqvc9M%2FWIV2WITJ%2FvI%2B15LvMN217eDbH7xsPwrnDDJgY6%2BHo7gXF8%2BZamhg11B19hiwUSZX%2FLRhVaCaSUNCTvDxcK8swgJdXmtfpeTJCg3kubpS5eZGUgti4RJHe5p7tdXjaXcL6J2ZVDBXekFxMPBNYq0YVqOXqM3EvdZ8dHz82Lc2SZe9i456z%2BFqOKiYGJdo%2B9%2Bv0FRn%2BlbWdkacqBrVqVsl3Pk9H809BvC5CzpffbkFgcP5PbBgb6WLt0snFqttf%2F54Vn4JYsnAM6tauKoSff59JIpIZpYFnBwkSlcJYMLdsn44Z1K%2BN%2BBCUqCAIEhVBECQqgiBREQSJiiAIEhVBkKgIgkRFEASJiiAqEKV5okLVhmshyFOVK%2FyhSVUaVIwgUREEhX%2FvsseiJiXIUxEEiYogCBIVQZCoCIJERRAEiYogSFQEQaIiCFVEKW7%2BltXf51Yl6EY5iapQSvPHNFUNeviYwj%2BinLw7eXgSFUGQqAiCREUQxDstKso%2BEUppXwoTlWttaFO7E8poXwoTVbI%2BzKnpCWW0L4WJSiqBPTU9oYz2pbg%2BlQTu70oDJT5PxtO4zHF009NkYuRFotL3qNxVT1RyDHWzfDf6Vdt2nMaXC7aI3xH3o%2BHe68tSl%2Fn37vN4%2FqLkg29fv3EXN26Fk3jyQdgVsy%2FVExXgn6iDmara8LO%2F3ISnWaPbl4R%2F917A3gNXSEH5RRaZduWvqP0r7Nk%2FqRyTZRJccLLB9WtB2FtR%2B01LTYf39hO4dj0U%2Bvo66NShKbq4N8OZ8wHYs%2F8yop8moIqpAXp2bYEObUsflvv8exbHT9%2BEuroabBvVwcihHXHwqC%2FSM2RY530ExkZ66OTmABNjfRw7eQONGtbCpi3HxMDdU8b3REpqGjZsPoromHgMf89N1PVO2CNcuxEGdakalizbJcYe5ssIgNlTT%2FY1ndmXC7Ov2yrlqS4FIThDAi%2BJBN7OtphrZQWtitjvB1OX4%2Fgpfwzo0xr2NnWwYu1%2BMT%2Fq8TNh0COHuKOpvSU%2BnLYc%2FgERpdoXF8da78Pw6tcaXTs74fadB7j%2F4CmqmhqKAa5rVDcVg1zr62kjkoWVX%2F2wFStZfdq1toOUCcZrxI%2BYNXcjGtvWhXOzBhg%2FbYUQvY62pthGX09HbF%2FQINqqBLcfbkfcnrhdcftSOU%2FF8Q3A0ZY2cEmXYLmRBiY52WIri4WPSTMQYBmMCB9AVpb7432QS9dCcO3UEmGYnOwr%2FMC%2BrUUS4s7dR9DUlMKqQQ3Rb2liZ1Hi%2FQUERcKmYW24tW0sRNSji7OY39CqJqQSNXTv4gSLOtWyRB2HurXM4L36YzHt0bGZGJX%2B1P6FMDTUFfO2%2F30GgazM9m3s0bBBTWhpaTDBquYg214s2AlvCAuZGux4UkICDJEDN9WZh7oaqDhBKVxU2R6L25CjPRzU5OjPfk%2FNkMI6zBYWzmV8Vzwk9BGsmViyBSVctVrmLv70OYn%2F%2FfIvrJnB165ZBTHMI8hkGaXa38hh7hg7aSkau05FC0dr9OrWAgN6uxYcEktfHa4BC01fh4er6aWs0%2Bu8q0%2Bqh0HUO4KdsRBmJeeZd%2FL0vQW%2FylC3SvM%2BVdYJ8StPw%2BAhU3x80psd2%2BfJ%2BPybzdi%2FYx7sWL%2BH8yELE0sLL%2Bv8kUUIvB2JS1dDMG%2FhFtF3cm%2FfpEzOmVxeej3Qy4pK1KdSBC7NG4ow6%2FDx62I6I0OOvQcuQ86%2BZekZ0NLUEPPD7z1h%2FZ%2BHpd7foWPXmYhfiATFiCEdYclCvdis%2B11GRrq4ExZV4rKNDHVFwoKofKir0sEaGelh1S8TMf3z9dDR2oqEF8lwbFIPPT1bYMqHPdCl73yYVTUUGblsgZUGnuiYOnsNGtSrjicx8WjG9tW7e8tMTziqCyZ%2BshKmJgaYNK476lsW76ma%2FiyM%2FGP7CbToOJP1xari782fkjVXEhTi%2Bnm4VpZhBy%2BvuK%2FT8ywc9xa5%2By4xsQlIS5WhRnWTMjvWlympiI5JgIGeDoyN9fIsS0hIYsvTREq8JKQz7%2FrocSyqmxlDQ7Po18fcr9Mrc%2FhX1nZGnqoQateq8sY8nuouDoPH%2FCQMOz9aOFphzif9oa2lKdLe%2BcGzeoalaTx1tQLLJij8eyfZtn4mnQRCtRMVBEGiIggSFUEQJCqCIFERBImKIEhUBEGQqAiCREUQyorSPFFBw8MQ5KnKEP7QJL0XRJCoCILCv3fDY1GTEuSpCIJERRAEiYogSFQEQaIiCIJERRAkKoIgURGEKqIUN3%2Ff1b8HTijnDXuleaKiuH9Mk1A8yvoQNIV%2FhMKjDGWLNEhUBEGiIggSFUGQqCoIek2DUEr7UpioXGtDm9qdUEb7UpiokvVhTk1PKKN9KUxUUgnsqekJZbQvxfWpJHCnpieU0b4UJyo5hrpZVnzcy4cgHThikRiDV5U5duoGHjx8WuLt%2BWDjp87eqpTHJuyK2ZfqiQrwT9RBhQ9FqKujhff6tYGermrnSX5esQc3bkWUePtLV0OwesPBSnlsWXblr6j9K%2BzZP6kck2USXHCywfVrQdhbEfu87n8Xx07eEL81NKTie9OWY3Br3wQWtc3E9OVrIYh5mohuHk7Cm%2F2z%2BzxcmjfCuj8OQyaTY%2BIHntDR1sSaTYfFlX5g39bo26OV2PbshUAkJafg8ZNnOHzcT4wr%2FMmk3kUaSzg1LR3r%2FziCa35h0NfThlOzBhg%2BqANi455ji88ptGllg42sri%2BSXmLs%2B53h2tKmSMd88swt7N5%2FSWxX37I6Rgx2w52wR3gUFSvmB96OhEOTemjjYoMVa%2FajR9fm%2BH3jITyLfyH2Y1m3GtZ4H0ZQ8H10dXfEqGHuYgDwA0euCW%2B1ZNkusZ%2Fpk%2FtUCkExe%2BrJq8Psy4XZ122V8lSXghCcIYGXRAJvZ1vMtbKCVnnvk49Ez0eCX8wMISUlLVNUW4%2Fj3r3onHWu%2BIZi%2F%2BGr4veT6HgsXLwDP%2F76D1o1bwgTEz0MGbsYEz5ZBesGNZgh2uLjz9bhbsRjsf4ZJqqJbFlQyAP0ZMYZwcodP3VFkeo2%2F%2FttuHA5WBg9L%2FcgM1q5XI6nsYn48Ze%2Fsei3f9Hc0Qq2jepg%2BLhfhEEXBr9AfPzZWrh3aIoBvV2RmpomRGtkpAdNDQ0hdj4Qt7GhHpKTUsV5mTVvI5rYWcCmYS2MnPArho1bArMqhvDs5Ijvl%2BzAedZwUnUpTE30oa2tIbavDIN5c%2FvhdsTtidsVty%2BV81Qc3wAcZRdcl3QJlhtpYJKTLbayWPiYNAMBlsGI8AFkZbm%2FBvWqo7q5CeZ85V3kbbjBbV03I8ebbNpyHP%2F5fJnj2fawq70%2FC6PqWWRmcN8b0Bbfzh0mfnt0bIambaYJj1arZpW37udW4D10cW%2BGtq52YpqLIBs95rmy6yDiZra%2FPfsvY8r4Hm8tMyAoEjXY8Xp0dGAiUhf1yaZKFQO0Zt6Pe2ROHPOInL82zoK2lqb4%2Fef2k1g4b3iOVzx9PgB%2BN8PFdEvnhszbxcGLhdKKwIsFO%2BENYSFTgx1PSkiAIXLgpjrzUFcDFScohYsq22Nx%2B3O0h4OaHP3Z76kZUliH2cLCuRI8daGm9qoK3DD5Jzf6zPulyzLyF6SxHkyN9RH1%2BFmhopr8YXd88vl6EeI5s9BvmFcHtGttl%2B%2B69SzNEfUkrtC69%2BzWAj67zqFxqykixOvEPNYH73tAPSv0zf94XwUvBga6bxxrWpqsXM5zcZ9UD4NYP4K1TgizkvPMO3n63oJfZQhBK837VFknxK8iGiQ3LFxAWnp6uRxTOjPAxOcvYWqqX%2Bi63Iv4nlyCANZ3OXHaHyPG%2F4JTBxbmu25sXCLqZnnKt1HFxAB7t89FROQTXL0ehp%2BX70Z6eoYQMCdDXrzT9voVTl6Gb2wo08uKKv9ArVlVI9b3uJPZh4qJx6lzpUsT8058Nqs3HkR95lWyQ8O3sXvfJciZWTk0tsT4MV2hq6eF%2BKyyZEwIL5JSxO%2FgOw9FEiQ7bHsbvP9z%2F8FTWNSphv69XFi%2F0FoIMjOs1UXo3UclPk5DAx3RZ0wvJ8%2F1LqOu6idg4phuGDt5KXawMElDXV0kIErD2YtBcO4wgwlBBhPWmV%2Fz26QibXfwqC9mz9uERta1mLE%2BwaB%2BbdHYti5CQh8hlXnSLn2%2FgoyFmTwrN3f2INg1qlNomfwiMXrSUtSpWVV4Y34bYf3yKWLZqGGd8NH0Vdjy1ynhJadP6l2s42zfxl6U19yNHWtGBvzP%2F0ZqKsCjVwg8XCtLd8%2FLK%2Brr9PzK7eoxG6F%2Bq3P6R4nPk4Wx1jA3hbp6yZ33j7%2F8g4TEJMyfM1gYdGH9qNdJTGT1SHgBE9YP42l1DhdVr8HfIujycpGqNzLSzUkkFAUuxIdRsdDS0kA15pVzw9P%2FsbHPReq%2FpPAkjDGrr55u8ZO3uV%2BnL4%2Fwr6ztjDxVPqHQsVP%2BuOJ7Bx3aNM6TcOCpdv4pKzQ01fMI6uGjWEyds7bA9XloNtSrPQxYSMU%2FBWFezTjP9KfzvXEnLCrfdatWMcCqnydCKlUrMOXNb4Tr1irdnYziXjgo%2FFMiarLGN2Ud96ED26NPz1blsg9%2B4zQt9c2kR80aptjhPbtEZVZnQvr%2Bq%2FfzXfbD%2FBFkwSQqxcHvK00c61mu%2B%2BB9oLKGe65%2BPV3IUt8h6HV6giBREQSJiiBIVARBkKgIgkRFECQqgiBIVAShCJTm5q%2ByDstCkKdSCPyhSWUcPIwgUREEASV79o%2B8FUGeiiBIVARBkKgIgkRFECQqgiBIVARBoiIIEhVBqCpKcfO3NH%2F2mSgZdKNdyUXFKeof0yRKDz28TOEfUU7RAUUIJCqCIFERBImKIAiFioqyR4RS2pfCROVaG9rU7oQy2pfCRJWsD3NqekIZ7UthopJKYE9NTyijfSmuTyWBu7I1JB89kY9OSFSKHpW76olKjqFulsrVr%2Frok1U4fPx6uZXPhyrlI0KWFD5Uqc%2B%2FZ%2FMdmE6ZEHbF7Ev1RAX4J%2BpgJl1Si87p87ew4c9jJd4%2BXSbDx5%2BtyxnpXlnJsit%2FRe1fYc%2F%2BSeWYLJPggpMNrl8Lwt6K2u%2Bq9QfEyOp%2FsSt22N0o9Ovlgk7tm2KN92ExHrBzswb4eGLvnAG1b4c8wDrvI2Iw6pbO1hg3qgt0tDMHsubGuZqV53vjrhjV%2FmlcYp59Xboagi07TiEmJgGuLRth%2FGjPIg3UzQenXr%2F5KCIfxKBqFUP08mwOa6uaOH7KH%2FfZsiXLdkFTUwOTP%2ByOv3efh2WdajhzIUDU37WlDT4Y6YHN20%2FgxOmbYmjUTz8eAGNjPeGlOCvW7Ye2lga6d2kOm4a1lEpQzJ56sq%2FpzL5cmH3dVilPxaKY4AwJvCQSeDvbYq6VFbQqYr8r1x7A%2BGkrUdPcBO1a22PmFxvRa%2FB3IjTq072lENsWn5Ni3Yj70Rgw4kfYNKqFCWO64mZABNt2RU5ZYyYtxY1bERg1zB0WdczECPfZnDxzC9PmrEFXd0dMHt8D5y4G4ZsftxUeFcvlGPD%2Bj2J0%2BpFDOqK%2BpTkOHrsODakUxkZ6YvBrPjB2rZqmYv2%2Fd58T9eD15yJZyy4O7T0%2FZxeDh0yMLRBwOxLfL9kh1jXLGp2%2BZnVTUYaurpbSiInbD7cjbk%2Fcrrh9qZyn4vgG4Ci7sLqkS7DcSAOTnGyxlcXCx6QZCLAMRoQP6waUx35XLBmPJnYW4vfBo75CTO8PdssU0r1o%2BN0MF7%2F%2F2HpciGLM8M5iurmTFRxafyy8VxLzUoFBkbhyanHOSPd79l%2FO2cdvq%2FZg3pzB6ObhJKarfj4E%2FYf9gG%2B%2BeHuon5CQJDxUNw9n4UXauNjmLHN0qI8U1h%2Fy6tcmzzafzRiAwQPaZXrWOw%2BQnJyKH7%2FOHGRbR0cTS1f%2Fl9nXaNdYfPft0Up4rncZLxbshDeEhUwNdjwpIQGGyIGb6sxDXQ1UnKAULqpsj8W%2BPBzt4aAmR3%2F2e2qGFNZhtrBwLqe74mpqr4o10M%2BbK9Fn0zzU49yNeIJWLOTLRltLE3Vrm7H5jxH37AUaMaPPFtTrBIc%2BxBcLNuPrH155J%2B59CsOIeSM%2B4He3AV%2FDqn4NtGD7nzDGk%2B23asGhtJpann1wUb06Hh3Wl8oot%2FZT1JPqYRD7jWAtGcKs5DzzTp6%2Bt%2BBXGQRfad6nyjohfhXdsBKJpMBpLrDEFy%2FzdoKfJwvDTWKGm5iYXGC5fJ3%2FLRiFtq52xa7T3FmDMG1CL1z1C8X2f86I8O7Irq%2Bz48PiHU%2Bu61L2Mrm87HRALytWruxfpce9fRPs3HtRCIlz%2FLQ%2FE1kynJo1QHNHKwSG3Bd9Fk4g%2B%2BZ9sGy6dnbCr6v24nmWKHkae%2F%2Fha4XuM%2FppAk6cuQkDAx24tW2M4YM6IDYrAWJooCu8p6yEnkdDXSqSLKHhUdS4quCpKiO9u7XElWuhaOPxKSwsquH%2B%2FRis%2BGmCSBbUra2FGZP7oNvAb2BiqIfaLDzj4WE2n37SH3PmeaN5hxkwNdZHXMILkWXM7mO9jXnfbRFi5Jm7h49isXDecDHfw81B9I%2Bau82Apqa%2FwD3%2BAAAgAElEQVQ6Lh79X7G98vgxXTF07GLWp9LH3Jle6M36k0TZohDXzcO1sgwbeHnl%2BTp9fPwLJDBvVd3MGBqaea9DcXHPkfwyVQggP7g44p49z3fbt8GfzkhJSUMNc9M30vD3HzxFlSoGOan94sLrnJ6RAbMqhiXaPvfr9JU5%2FCtrOyNPVYbw5AH%2F5IeJiT5M3rIt71vlTlDsPXAZG7ccL3D9b%2BcOE1m%2Falnp7%2FyoXatKqY6H15kgUSkNPT1biA9BiQqCIEhUBEGiIggSFUEQJCqCIFERBImKIEhUBEGQqAiiEqM0T1TQ8C4EeaoyhD80Se%2F1ECQqgqDw793wWNSkBHkqgiBREQRBoiIIEhVBkKgIgiBREQSJiiBIVAShiijFzV9F%2FT1vouxRhhv4SvNERXn%2BMU2iYlCWh6Ip%2FCMqXdTxrkceJCqCIFERBImKIEhUFQS9pkEopX0pTFSutaFN7U4oo30pTFTJ%2BjCnpieU0b4UJiqpBPbU9IQy2pfi%2BlQSuFPTE8poX4oTlRxD3SypX6VI9h26KgbuLim3Qx7gwpXgSndcwq6YfameqAD%2FRB3MJNNWHAsX78CdsEcl3v7EmZvYvO1EpTuuLLvyV9T%2BFfbsn1SOyTIJLjjZ4Pq1IOytqP2uWn8A7dvY469%2FzyLsbhT69XIRo8av8T6MK7534NysAT6e2Dtn8OrIBzFYx5bdCopEU3tLTPzAE1VNMwegPnryhhjD92VKGhrUq46RQ93F4NT8Cu697TiiYxJQvZoxBg9sB7tGdXDVNxQ%2Bu87iSXQ8TIz10cW9Gbp2csyp27Xrodj29xk8jn6Gti62SEuX4aMPuollaanpWP%2FnUZy7GAQDfR2MGNIRLZ2ti3TMB4%2F6Cq%2BUzsqzql9D1POaXyieJbzAX%2F%2BcwXlWZqvmDUUdN%2F91Eh3bN8GajYfEcU0Y3VWMEbxm0yGERzxB3x6t4NWvjTiGk2dv4vGTeCxZtgs6OlqYONZT4YJi9tSTfU1n9uXC7Ou2SnmqS0EIzpDASyKBt7Mt5lpZQasi9rty7QGMn7YSNc1N0K61PWZ%2BsRG9Bn8HmSwDfbq3FGLb4nNSrPv4yTP0G%2FY96ltWx6yp%2FcS84R%2F8DLlcjtPnAvDpfG8hCm5ofBT6GzfD8ezZC%2FR%2F%2FwfYNqyNYV4dUM3MGEdP3Mgsj4mlvoU53h%2FshhZOVpj%2BxXqcvRAoll2%2FcRfDPvwZlhbVhNGHRz7BinX7c%2Bo9YfoqBDBhTxrXHZ07OuCDycsQfOdhocd7%2BPh1zP9%2BK3p0bY5e3VogNu45K%2BceTIz0oa6mxupnhDq1qoqBwuPin2PRr%2F%2Fg6x%2B2obmjFWrWMMXQcUswlu3LorYZ3No2xpyvvBF4OxIa6lIYGepBV1dLbF%2BzholCxcTth9sRtyduV9y%2BVM5TcXwDcLSlDVzSJVhupIFJTrbYymLhY9IMBFgGI8IHkJXHflcsGY8mdhY5V3EuJm7onIh70fBj4uBs3HIMPZkxcq%2FA4UJo1uYThDIPd4sZZp2aVYWX09BUz%2FE4fFtZega6dnYSXqtD21dJqO5dnIV4ecilraUh6nCVeac2zCutZB503AiPHM9Us7oJdu27JH5zI%2FYPiMD5wz9CKs28Dl66GoL%2FDl5BQ6vebz3WW4GRsKhbDe6sntz7erJ6ZaPPPJ5buyZwbdFITIeFR7F6aeKvjbMgYdbJ67px81Es%2F%2BlD2LCLBOfAkWu4cSsCtsyrNWtSD1ImTO65KhovFuyEN4SFTA12PCkhAYbIgZvqzENdDYRCO3oKf%2FUj64ri4WgPBzU5%2BrPfUzOksA6zhYVzOd0VV1N7VayBft5ciT6bfhgVK36HhD4UHfEDR3xzluvoaOJFUgr69XTBzr0X0aT1NDgw4%2FJg3mPU0E5CKJ06NEVLt5nCENu1tsOEMZ4wZSHUrn0XmdfYhnp1zZmhm%2BHBw1hhuMKgmVC5x8s3IcA8UgwLJdt0%2BTTP%2FEFFMOaBfVpjDwtRG7tOgZNDfXTp6CguINnifCNpJoEQlAjR2Tp6b5wfHRGWljeFPakeBrE8gtU0hFnJeeadPH1vwa8y9OkqzftUWSfErzwa4G1kG1B%2B03p62hg9rBNmTO6T77YH%2FvkKdyMei77S4mU7xbZj3%2B%2BM5YvH42lcopjP%2ByKz523E6l8%2Bwqy5G7FhxVThmThz5m3KJW4dxBSQiePL6tapihP%2FfVfs46tdqwqO7v5GeFfuFf%2F327%2FMs0pFaJqZhZWX6nzJ5eXzlsa7%2FLIiPVD7Fjw7OeFP1nGPYP2b3Bmv%2BPgXok8V9TgO9VgfaWDf1swLNGD9lUTm3R7huv9dVDExEImIvj1bITb2ubDdtDQZtFjYx3n4KFaEdNl4sHU3bjkq5vn6hWH5mn05y3hCgqe%2BfVh%2FLxueQOHrFcbJM7fwJCZeJFK4Z%2BPJFl4fjpGRrhBbSTE00BUXlYwMevG6Unqqykg3DydhdF37fw1T1rFPfJGMGuam8Nk0Swhq3NTlqMs68MkvU0V4983coSK58cGUZdBUVxed%2F2es87%2F8p%2FGiPzP74%2F54b9RPMKtqyLyglvCE2fD%2BFC9z%2FNQVMDbWQyc3B2icD8zxVBuZh%2Fvks%2FVYuGSH6I8lJaVi8cLRhR5D5MMYjP94BSzqmIlkSo3qphiR1X8c%2B74HPv1qE5b9vk9cGPr3cinW%2BeH9SC5%2B5w7ToaujhbOHfiCjgYKe5OXhWlm6d15eeb5On848zKMncTBmIuEG%2Fvp8bW1NkZTIzaOoONFf4uFXbnj2LYn1yV6f%2Fzp79l%2FGuj%2BOYOeWz%2FLM56LlIRjP2hUVno6Pin4m%2BoPZtwOy4UJLSEgSmb6Swr0mv1DwJEdpyP06fVnYR1nbGXmqsjxJGlKRNi7qfE6N6vmnmLlH45%2FXuXc%2FBjPnboCNdS0hGp4Eyc8TmVczzjM9acZqPI6Oz3dfPH2%2FaMFIkZ0sqJ76zFvq65XuwZaCyqbwj1Ao1cwMM%2B9PsT4K73f9u%2BVTcX%2BsMHhShCBREfnAQ6ceXZzpRCgBlP0jCBIVQZCoCIJERRAEiYogSFQEQaIiCIJERRCKQGlu%2FirLMCwEeapKAX9oUhkGCyNIVARBKHP4l%2B2xqEkJ8lQEQaIiCIJERRAkKoIgUREEQaIiCBIVQZCoCEIVUYqbv6X5s89EyaAb7UouKk55%2FjFNIi%2F08DKFf0Q5RQcUIZCoCIJERRAkKoIgFCoqyh4RSmlfChOVa21oU7sTymhfChNVsj7MqekJZbQvhYlKKoE9NT2hjPaluD6VBO7U9IQy2pfiRCXHUDdL6lcVlRdJKfh79%2FlSlcEH1c49KLiyIuyK2ZfqiQrwT9TBTJJL0YiJTcCsuRtLVcbK9ftx%2BdodpT9XWXblr6j9K%2BzZP6kck2USXHCywfVrQdhbUftNTUvH%2Bj%2BO4NzFIBga6GLk0I5o4WQtlm3%2F5wyaNamHh1Gx8PULQ%2B%2FuLREdEy%2FG341%2BmoAqpgbo3sUZHds1EeunpKZhnfcRXPe%2FK8bN5eUMGdhOLOMjza%2FZdBg3A%2B%2BJcXwnjPEscBzg3PBBr9f%2FeRRXr4eKMp2aNcDwQR3g8%2B9ZyDJkWLJsl1hvUL%2B2om4PHj2FXA78s%2Bc8qpubYMaUPrgVECmOJTUtDVPG94RDY0tcvBqMe%2FeiceDINdyLjIZtozro5uGkdIJi9tSTfU1n9uXC7Ou2SnmqS0EIzpDASyKBt7Mt5lpZQasi9jt%2B2goEhTzA5A97oJNbU4yZtBQhoY%2FEsm1%2Fn8aICb9gw%2BajSHzxEskvUxH15BkaMlGMHOIujHPiJ6tw%2FcZdsf4X32zGNb9QtqwjWre0wf7DV8X8uLjn6Dv0%2B0wjn9wHhoa6eG%2F0%2F5CenlFo%2Feb%2FuE0IfsRgN7RxscXBI77IyJCjWlUj1k%2BQiEGr%2BUdLWwO%2B%2FmGYOnstjp66ge4ezgi%2F9wSe%2Fb8WHql1q0aoWsUQYycvZaKTw1BfB9o6mjA1NhDbm5rqK5WYuP1wO%2BL2xO2K25fKeSqObwCOMlt0SZdguZEGJjnZYiuLhY9JMxBgGYwIH0BWlvu7FXQPAbcjcf7wIqip8XuD1rh4JRj7Dl3BtIm9xDofjuqKse93ztmmiZ2FEMOdsIfQ1JQygdXEtRuhaNa0HgKCItGvp4swfs7Avq3F91YmTj5v3EgPMd3S2Rp%2F7zoP%2F1vhcHSo%2F%2FY6Bkais5sD2rraiekBvV3Fd4d2jSGVqMGrX5s867t3aIJfvh8rfnNPOO3Tddi2PjOqfpmSij%2B2ncCT6HjhmaqZGaFlc2sM7NP6nReRFwt2whvCQqYGO56UYK05hDnsm%2BrMQ10NVJygFC6qbI%2FFvjwc7eGgJkd%2F9ntqhhTWYbawcC7ju%2BK3Qx4iOjoBrT3m5Jk%2FeEC7nN%2FmzPByw73XD0v%2BhlWDmuwKX4VtHw%2BZLPPhbO7tZs3biLV%2FHIaTQwO8%2F54b8xA2CA59iEPHruPshcA8ZXEjL4zJH3bHx5%2Btw6atx%2BDMQr%2BhA9ujfZuCs8Nqaq%2BCDX3mjXLDB%2BdW15AiLU1Wbu2nqCfVwyD2G8EMJIRZyXnmnTx9b8GvMgi%2B0rxPlXVC%2FMqzYQ30tWFpUQ3H9iwoUrlJySn4bP4f2Ln1cxH6cT6avjpnOe9feTCvcot5rGMsBBv2wRKcP%2FKj6AsNYh5l%2FqeDi30s3Ev5nlyCgOD7OHHaHyMn%2FIqT%2Bxcyu5GIMK60yDPKVgP0smLlyv5VOC7NG4k%2B0o5d53Lm3bsfI5IS%2BcH7MukyGbQ0NcR0xP1o1h%2B7n7N8176L4puHghPGerLwUB3xCUnw7OQo9nGb9d2yOX%2F5Np7ExBdax937LkHOzJSLePyYrtBjF4L4hBeiT5SWLkPkg5gSH7%2BRoR5Cw6PI6lXFU1UEBgY62LBiCqZ%2Fth7f%2FeTDwiMNJCenYvHC%2FN9k5R6H97V6eC2AWVVDkS3MFhjnv4NXMWeeN2wa1sbd8McYOdQdjaxric%2F0Sb3Rb%2FgPMGbb8HtMVaoY5PR13gYPG2fP2yTKiLj3RPR%2FeL8uM0xtC4%2B%2BX0FPVxvLF48v9vHz5MfYyctENrOtqy1%2B%2BnY0KaAcUIjr5uFaWYYNvLzivk7%2FmHksiUQiOu%2BF8TQuESkv01CzhukbyxKYZ4pPTIKpiQEz9rwJTJksQ6TnjZiweAawqCQmJuMZ804mxvpC2Lnh96vUJGpsfyXL3vF%2BXXRMgsgAlpTcr9NX5vCvrO2MPFUhmFczLvK6VZhgCoKLpSDBSKVqeYz3UVQcpsxeU2BZ%2FXq1wjCvDsKj8k9%2BVDU1LNVx8%2BRFaQRFkKgqFTzlvcN7Np0ISlQQBEGiIggSFUGQqAiCIFERBImKIEhUBEGQqAiCREUQlR2leaKChnchyFOVIfyhSXqvhyBREQSFf%2B%2BGx6ImJchTEQSJiiAIEhVBkKgIgkRFEASJiiBIVARBoiIIVUQpbv4q6u95EwWjyjfileaJiuL%2BMU2i%2FFD1h5sp%2FCPKLXpQ1QiCREUQJCqCIFERBImqgqDXNAiltC%2BFicq1NrSp3QlltC%2BFiSpZH%2BbU9IQy2pfCRCWVwJ6anlBG%2B1Jcn0oCd2VqxPsPniI9PSPfZXxkxNi452TpKmJfihOVHEPdLJWnX9Wh%2Bxd48Cj%2FQa43bjmGBYu2l9u%2BE58n4589F0pVxokzN8VA4cqAsCtmX6onKsA%2FUQczQZSamKcJmDNvU6nKWLF2P676hirF%2BciyK39F7V9hz%2F5J5Zgsk%2BCCkw2uXwvC3orab2paOtb%2FcQTnLgaJ0eZHDu2IFk7WYtn2f86gkVUtnDx7ExeuBMPJoT4%2BntALGprqSEtNx0%2FLdopxe5NfporR48eP6ppnbN57kTFYtf6gCAX79GgpRpbPD17Gmk2HcDPwHuwa1caEMZ6obm5S5Lpf8wsTA2w7OzYQYwT%2F9e9ZpMlkWLJsl1hv8IB2iHoch0fsk87m%2F7vnohgEfMaUPvC%2FFSGOMz1dhinje6CpvaU41kjmpfYfvorwiMews6kDz85O76SgmD31ZF%2FTmX25MPu6rVKe6lIQgjMk8JJI4O1si7lWVtCqiP2On7YCQSEPMPnDHujk1hRjJi1FSOgjsWzb36cx%2BqPfxKj1fbq3xK7%2FLuF3ZvzCoJkRpqSkwaNjMwwZ2B5%2B%2FuGY%2FkXeh3jn%2F7ANDepVR8f2jTFv4VYcPn79jf3zvlXfYQuFkc%2Bc0hd6TByDx%2FwkRrIvjHnfbcFFJoARg93QxsUWBw5fE%2FOrVTWCRA4xQDb%2FaGqp49qNMEyZtQYnTt9Ejy7OCL0bha795mP1hoNo08oGpiYG%2BGDKcsjlchixC4OWlgZMjfXF9qZvGTi8ssLth9sRtyduV9y%2BVM5TcXwDcLSlDVzSJVhupIFJTrbYymLhY9IMBFgGI8IHkJXl%2Fm4F3UPA7UicP7wIamr83qC1MNJ9h65g2sRemcL4fDATVCvxO%2B7ZC1zxvSN%2B6%2BlqYf5nQ%2FA0LhF3wh6hU4em%2BG11Xge7fvlkWNSpJn5HRyfAZ%2Bc5IcLcbPE5hfat7fHBCA8x3dLZGv%2FsPi%2B8lkNjy7fWn9fds5MT2rraiekBvV0z%2BxDtGmPh4h3w6tcmz%2Fqd2UXj5%2B%2FHit%2Fm1YwxY%2B4GbF03Q0y%2FSErB5u0nEM1CR9tGdVDNzBitWjRC%2F14u74SIvFiwE94QFjI12PGkBGvNIey6clOdeairgYoTlMJFle2x2JeHoz0c1OToz35PzZDCOswWFs5lfFf8dshDYeytPebkmc%2FDpZywVO2V8zY01EEaC7mESJjxTfx4pQipGttZIDU1DbL0gr0L91hnLwW%2BMT8k9CEOn%2FDD6XMBeebzkLIwJo%2FrIbwjT3zw0HT4oA45Ass3DJG%2BOhYDfZ08y%2FhFQsqWp6fJyrV9y%2BtJ9TCIciOYgYQwKznPvJOn7y34VQbBV5r3qbJOiF95NpyBvjYsLarh2J4FRSpXkkvTq9YdgKmpAXy8Z4vwkHuNIaMXvzUjZ2yo98Z8Ee71b4t5c94r9nF2cW8G35NLEBB8H8dP%2BeP9D3%2FB6QPfi%2FrwMK60lEUZr6OKLyuq1AO1Ls0bIerJM%2BzYde5VcuF%2BDHxZx7%2FQJEFqOrQ01YUB8%2F7PkRNv6j85OS0ntOLJgK6dHd9Yx7OTIwsLz%2Bb04zg8acI9YWHs3ncJcmaiPEwcP6YrdJi3iU98IRIuKcxzPnj4tMTnxshQV%2FS7CCXyVBUBz9RtWDEF0z9bj%2B9%2B8oE265wnJ6di8cLC31QdO6IzvEYugmO7T4SwuEDfWGfyUvCLfeyzRHT3cMaQAe3fWKd9G3vRf%2BszdCGMmRi4AKtWNcDW9YXfXThwxBez520SmcfwiCfC49nb1BXLeKaxU5950NXRwupfJhb73IwY3BHjpi4X%2FTve51u0YCSpo4QoxDXzcK0swwJeXnFfp3%2FMPBYXRzUzoyJvw9PqUdHPRHaM90nyg6fTtXU0UNXU8K1lcW%2F3MCoWRkxYhsxLFBX%2BdMazhBcwMdYXafXcxMQmQCpRg4mJfonO48uUVETHJIgMYGnI%2FTq9IsO%2FsrYz8lSFwLNhxYXfryrM4GrXqlKksniSIHdZPHSb9um6Atfnmb4hA9sJb5v73lhuChNyYWhraZZaUIQKi6qyUatmFezwnk0nghIVBEGQqAiCREUQJCqCIFERBEGiIggSFUGQqAiCIFERRGVAaZ6oUPXhWwjyVGUKf2hSlQcZI0hUBEHh37vksahJCfJUBEGiIgiCREUQJCqCIFERBEGiIggSFUGQqAhCFVGKm7%2Fl9fe6iTehG%2BwqIipOcf%2BYJlF86KFlCv%2BIcooKKDIgUREEiYogSFQEQVQKUVEWiVBK%2B1KYqFxrQ5vanVBG%2B1KYqJL1YU5NTyijfSlMVFIJ7KnpCWW0L8X1qSRwp6YnlNG%2BFCcqOYa6WSpnv%2BppXCL%2BO3ilTMq64nsHgbcjS7x9bNxz7D1wWaX0JOyK2ZfqiQrwT9TBTGVs1PDwJ%2Fhm0fYyKWvb36dx6Nj1Em9%2FLzIa83%2FYplKiyrIrf0XtX2HP%2FknlmCyT4IKTDa5fC8LeitrvqvUH0Kd7K%2BEBQkIfYuQwd5gY6WPr36dw9MQNqEvVMHhgO7i3byrWfxITj7WbDiP83hOYmuijaydHdGzXRCy7GXgP3luOI%2FJhDFo4WmHiB92go62Jv3aeRUJiMpYs2yXWGz2sU6GDW98KuofN20%2FiaWwiatYwxZAB7ZCRkYGbAfcQwYTBB97mQ5i%2B178tVm84iHat7fDXv2cRdjcKfXq0QpeOzfD7pkPiuJwc6uOTj%2FpAXV1N1OX585c5deHHW8XEQGkFxeypJ%2FuazuzLhdnXbZXyVJeCEJwhgZdEAm9nW8y1soJWRex35doDGDjiR%2Bw7fBXxCUlixPmvFm7FgcO%2BGDeqCwb0aY3Z8zbh7IVAsf6wsUsgl8uZMNxhY10bB474ivl%2BN8Mx%2BqPf4NqqETPg3ggJe4QZn28Qy%2FiI9%2BpZA2Xzj7qG9K11ehIdz%2Bq0CA6NLcVg2Vy8J8%2FchK6eNvR0tWBspCfKMatqlHlhWHcAH05dgZrmJmjfxh6zv9yEHoMWID1dxi4YLbFj1zkm0BOZdWHbSNVf1UVTXTmHeeb2w%2B2I2xO3K25fKuepOL4BONrSBi7pEiw30sAkJ1tsZbHwMWkGAiyDEeEDyMpjv99%2BOSzH2%2FD%2Bz1%2F%2FnoHvmZ%2Bhq5Op65DQR9j530W0at4It%2B88wHfzhqOlszVcWWWzWbF2P6aO74l%2BPV3EdMMGNeHQ7mMm0rFwa9NYlOnVr02R6hMaHgUNqRRd3R2FR8uuG6eepbkQw%2BtlLV88XoiQw8PDHl2cMXJoZt%2F83v0YJvq7mf2Lto2x%2Ba8TRa7Lu4IXC3bCG8JCpgY7npSQAEPkLHhQZx7qaqDiBKVwUWV7LPbl4WgPBzU5%2BrPfUzOksA6zhYVzOd0V554kx6DDovAyJRXuPb%2FMs04HZow8fJoxuQ8Gj%2F6JGXc1ODtYYcLYrqhvWR3BTGyXrgRj%2BZp9OdvUqGaCF0kpxa5Pi2ZWaNncGk7tp8POtg7at7bHR2O7wcBAp%2BAQQ%2B3VqTHQz7sen45Ml5Vruyn6SfUwiP1HsLMQwqzkPPNOnr634FcZBF9pYoGsE%2BJX0Q1soK8NHeahzh3%2BMY%2BhZjNtYi%2BMHeGB6zfC8M%2BeCxgydjEuHv0f9JnhTp3wylPlhoUgLGQsRiOw8HDt0smi%2F3bteqjoMz14%2BBS%2FLRonlhdWlkTyluli1qWo0MuKlTP7VyloaFVLdNyX%2Ff5fzrzopwk4z1zo8xcvsf%2FwNeizvk1bVzuMYv2quLjnoo%2FFQzXet%2BEpaw5PJGSn0Q0NdRETk4Bnz14UqQ4BtyNFooL3fzw7O6G7h3NOuUaGerjD%2BmslxYjVJTY2UdSbUDFPpbAspFQNG1ZMxZRZv4ssHxfQs8QkzJs9CE3sLfHT0p349CtvWFiYITIyBt%2FPH8E8gQQTxnji0eNYtPaYA1NjfcQlvIBj03ro0bU5rOrXEAmENp6fisTAjj%2FmoEG96gXW4WVyKsZOWQY9XW2x%2F8TnyVj960eZfYe%2BbTBo5CK0dJ8l%2Bm2b13xSrOOrZ2GOju2boG23z0Rdtm9k5VjVJMsvRxTiwnm4VpbhAy%2BvLF6n5x4qPU2GGtVN8syPiU1AMjP86mbG0NDMex1KfpmKGLadWVVDaGtpvpHV02LrGxnpFWn%2FPOTj8NR5bnidHj2JQw1zU9HPKwk8tNTSKHpd8iP36%2FTvQvhX1nZGnqoEmFUxzHd%2BVVPDArfh96V4du5tCRGezDh%2B%2BmaBZWxe87EQ5Otiyt3nKmgfRU7OVDWiBiZRKQ%2BTxnUXH4ISFQRBkKgIgkRFECQqgiBIVARBoiIIEhVBECQqgiBREcQ7gtI8UUHDvBDkqcoQ%2FtAkvd9DkKgIgsK%2Fd8NjUZMS5KkIgkRFEASJiiBIVARBoiIIgkRFECQqgiBREYQqohQ3fxX9d72JwlGlG%2FNK80RFWfwxTaJ8ULWHnSn8IyosmlCViIJERRAkKoIgUREEiaqCoNc0CKW0L4WJyrU2tKndCWW0L4WJKlkf5tT0hDLal8JEJZXAnpqeUEb7UlyfSgJ3anpCGe1LcaKSY6ibJfWrXocPeL1n%2F%2BUyKYuPdH8z8F6Jt%2BcDge%2Fed%2BmdO4fCrph9qZ6oAP9EHcwkGeUl8mEM5i3cUiZl%2Bew6h%2F2Hr5Z4%2BwdRT%2FHlt1veuXOYZVf%2Bitq%2Fwp79k8oxWSbBBScbXL8WhL0Vtd%2FUtHSs%2F%2BMIzl0MgqGBLkYO7YgWTtZi2fZ%2FzqCRVS2cPHsTF64Ew8mhPj6e0Ctn8Gw%2BGDXfNvJ%2BDKpVM8bAPq6wt6mLlesOoF%2FPVrh0NQR3wh7BqVkDPHj0FMO8OuTs97r%2FXdwJfYSBfVtj538XUd3cBBcv3xbbOLL9TBnfA1qaGvD59xySklKwZNkusd0IVr%2B3jTnMCQq%2BD%2B9tJ8SA3jWrm2DwgHaQSCS4cTNcjEnMy%2BL7G%2BrVHms2HUbrVo3wz%2B4LCL7zEL27tYCnhxPWeR%2FBpWvBcLCvh%2BmTeotj9vn3LJKSX9Vl%2BGC3Sj92MLOnnuxrOrMvF2Zft1XKU10KQnCGBF6s7b2dbTHXygpaFbHf8dNWICjkASZ%2F2AOd3JpizKSlCGHGztn292mM%2Fug3YZB9urfErv8u4fdNh3LCsp6DvsXLlDR49WsDIyZI7y3HxbIVa%2Fdh4IhFOHDEF%2FEJSTAx1seXC7bkjDbP%2BeHnv4WBcnbuvYgPpyxHWroMvZhR8%2B0WLPpLLDMzM4SaVE0MnM0%2FGlLpW4%2FnaVwi%2Br%2F%2FIxrb1hWiqcIEeOyUP3R1taCnpw0DAx1Rjjm7CHDWsOMZN2UFzKoaomP7xvjs6z%2FQw2sBO65Udsyt2DFfxMYtxzLrwgQkzVUXTfXK%2B%2Fw1tx9uR9yeuF1x%2B1I5T8XxDcDRljZwSZdguZEGJjnZYiuLhY9JMxBgGYwIH0BWlvu7FXQPAbcjcf7wIqip8XuD1rjIPNK%2BQ1cwbWIvsc78zwcL4xJCYn2KK753Muop8zUAAAxXSURBVAXHvFjDBjUx%2F9PBmXF728bIyHj1fOh3Xw5Hh7avEk4e7s3wp88pzJ7WD6F3o%2BDHvMa6ZVNyls%2F%2BuB%2BGv%2BcmftezNMeoib9hwRdDRbkbNh8Vwi0K4eFPxHfXzo6oYmIgts%2BmQb3qMDXRf6Os3xZ9gOaOVuL3sZP%2BrN6NMW6kh5h%2B%2BChW1FUcY7vG%2BH3DoSLXpSLxYsFOeENYyNRgx5MSrDWHsNa4qc481NVAxQlK4aLK9ljcBh3t4aAmR3%2F2e2qGFNZhtrBwLuO74rdDHiI6OgGtPebkmc%2FDpZywVO2V8zY01EEaCxc5IaEP0cTeIq%2BbV3tVvWpmeUO0USxs%2B2j6akz%2FqDc2sSv%2Fe8ww9XRzOWPJq23rW1ZHAvNwyS9Ti31MzZrWQztXOzRvPwN2NnXQrrUdJo7xhJGRXsHhSa596%2BvnzRVxz8Y9aHlRVk%2Bqh0GUE8GOJIRZyXnmnTx9b8GvMgi%2B0vjzrBPiV54NZcAMyNKiGo7tWVCkciW5NG2gryNCu6LiylywCfMSPFmwY%2Fd57PP58q0ZP10dLWhraYrQszhmx8Oz1b9MRExsAq76hmLNxkOYc88bq36eKJbLCylLIpEUOM1%2Fy%2BVl%2B7aGKrysqFIP1Lo0b4SoJ8%2Bwgxl6Nvfux8DXL6zQbTt1aIq9%2By8j8kGMmH7%2B4iXru9x46zYjh3TEl9%2F%2BCWeHBrCsWy3PsoQsgaanZ2DFuv3o5uEkPJ%2BhoS7iEl6IvlJRCAp%2BgBu3wkUyo2snR%2FT0bIFYJlKOsaGeSJyUFEN9XcQ%2FTxKCJd5BT1UR8NBmw4opmP7Zenz3kw%2FzDBpITk7F4oWFv5navo09xo3qgi795sOEGeuzxCRMGN0V7u2bFrhN%2F96uIj0%2B5v1Obyzz3noc6%2F44IkI%2BnmRYneVZLGqbwcPNAe08P4eWhjq2rp8Bm4a135LNTMPoj5aKY%2BHelIt1xc8TxLIBfVwx8P0f0dJ9FupZmGP7huLdwahdqwo8OzmhfbcvoKWpjs1rPhHZTqKwCEcB8HCtLMMAXl5xX6d%2FzDwWD2%2BqmRUvRZySmoYn0fGoUc0E6hpvz8wdP%2B2Ped9txan93%2BUJq3hSonNHB%2FTr6YIXSS%2FzTVPz9D3Pthkb6xWpXjzBwBMnXAi54Z7w0ePYItW3IIpbl9fJ%2FTp9RYZ%2FZW1n5KkKITvFXFz4vSSeXi4Kv7P%2Bzahh7m%2F0W7LhiYs8yYtcZAtt9YaDOHy84K4m97zcQ9WsYZp%2FA6urFbm%2BBVHZ701R%2BKcicA%2FRn3mibl2c31j2wYjOBYrgdcazEJN%2FCBIVnVjmIQq6v9PW1Y5OkBJDr9MTBImKIEhUBEGiIgiCREUQJCqCIFERBEGiIghFoDQ3f1VtuBaCPFW5wh%2BaVKVBxQgSFUFQ%2BPcueyxqUoI8FUGQqAiCIFERBImKIEhUBEGQqAiCREUQJCqCUEWU4uZvWf19bkJxKNONe6V5oqK4f0yTqDwo28PQFP4RlSbaUJaIg0RFECQqgiBREQSJqgLgsTO9pkGUJxJAMX00RYnqpWttaFO7E%2BVFln29VCVRRSfrw5yanigvsuwrWmVExXxysFQCe2p6orzg9sXtTGVExYLd8%2Bw%2Fd0XsO%2BpxHFKzRpwnlLpH5S7sTFVElaGGv5m7GupmWfH9qv7DfsD1G3crTMCHj1%2BvdPb2Iiklz2DiJeHU2VsIv%2FekUupJ2BWzL2FnqiIq31vg4236J%2BpgJpSYgNv38b9fd1a6esXGJWLmlxtLVcaqDQdw%2BWpIpTzvWXbln2VnFY7Cnv2TyjFZJsEFJxtcvxaEvQrp28nl2PDnUdg2rA3XljZiIOo%2F%2FzopBsBWV5diyMB26NiuCSLuR%2BO%2FA1fw0QfdcrblV%2BkjJ%2FzwwQgPMSL86o0HERL6CMaGeujQrjG6ujvi3z3nER0TjyXLdoltJoz1hK6OFnbvu4Td%2By9BTSLBgD6t0bWTo1geFh6Fc5duo1P7pth78Ar09bRFHfig32s2HYJ%2FwD00sqqJCWM8izS8aVpqOtaz47t6PVSMLezsaIVhXu3h8%2B9ZZMgycurFR3x8%2BjQRkQ9iwIcn%2Fnv3eTEm8owpfREYFIltf59hIXMaJn%2FYA82a1MMlJqbwiGgcOOortrFh5697PsOwKgJmTz3Z13RmXy6KqoPCbv5eCkJwhgRerBG9nW0x18oKWhUtqE%2Fn%2F4FjJ%2F3h1KyBmPf5N3%2Fg6Mkb%2BHB0VzFy%2FIwvNuDClWBUZwa2ct1%2BXLz6qt%2B7ct0BMSI8Z9y0FYiJScDoYe5o2sQSBw5fFcZZtaoRNDTVxUDW%2FCOVqmHjn8ewmBmzV9826Mv2Mf%2F7rdix81yWqB7j%2ByU7MPzDJbjPjDXmaQKePXuBPkMWwtyMGfnkPjA20sOgUf8TYwoXxjeL%2FsLZC4EYMdgN7Vrb4xATgUwmRzUzI1G%2F7HppaWnguv9dTJ29BofZhaKbhzPusQtJtwFfY%2Fna%2FWjdqhHbxhhjJy8TFx5DAx3o6GjA1ERfbG9qaqBwMXH74XbE7YnbFbcvRdVFoU%2Bp%2BwbgKHMQLukSLDfSwCQnW2xlsfAxaQYCLIMR4QPIymvf877bykTxFOtXTIGmhjqeRMdj538Xcf3Mz9DW0hTr3A55gF1snkvzhsxjtIf3luNo5dwQiYnJYv6hnV9nhnlB9zBqqLvwdvwzfFAHMb%2Bdqx3Ong%2FMM%2FbvyvX7sejrUejQNjP5ye9OLlm2EwP7thbT3NPt%2FetL6Ghn1mHV%2BgOszEYYN6qLmG7pbI1%2F9lyAHxOBs2ODtx7jrcB7cGvfOGeM4f69Mi%2FeHdo2hkTtzTGJO7Zvgl9%2F%2BED8rl2zCibNXI3tGzIj9JTUNHhvPS68JvdM3JO1dLIucFzj8saLBTvhDWEhU4NdVlJiCDuXN9WZh7oaqDhBKVxU2R6LfXk42sNBTY7%2B7PfUDCmsw2xh4VxOT138tHQnbtwKx%2BVjPwlBce6EPULyy1S4dZ%2BbZ93OHR3E9%2Fvsas%2BXRTPvwcM3lxaNULd2VbFsJguTpsz6XYRk3OvxkLCxbd18w7H7D56ikXXNnHk8nAtlHiobQwPdHEFxgu88xMFj1%2BHSaXaesl6mpBZ6nJM%2B7I6PP12LP7adgJNDAwxlF4ZsMecbkktfBS76%2BnlzSFqaGtBgIXFauqxc7aGoT6qHZV6PIpiBhDArOc%2B8k6ei%2BlCVTlSvJS%2F8yrMhsmnIDJn3babOWYO1SycLY%2BJGZKCvg%2FNHfmSh0Zta5mFOu9Z22OpzSmTOvp07LGfZSOalBvVvC7%2Bb4djH%2BkI8POMeLzvMzDnZGlJhnAnM01U3N8nsVLPfBnoFJ0F5v8qL9bu%2B%2FnxIsc9Lpw5N4XvqZwQER%2BLE6ZsYNfFXnNj3LdSYl8pdrxKH0OVgB8rwsqJKPlDbu1tLrPplAuLjkzD9i%2FXCwOwa1RXGvYL1IbJ5EhOP85dv50yPYn2m31btZUYpEQLLhodjXCw8TBzP%2BmMvXiQjJSUNRszrPHwci6TkFLEeF6t7hybYvP1EzrZ%2FsN%2FuzPgLwrOzE3bsPoeg4Ac583g%2Fj4erhcE9qkyegab2lqyf2EVcOJ6xY%2Bb1krE%2BGU%2FAlBQjFqZy705UYk9V0fB%2B08aVU9H%2F%2FR8x%2F%2FttwhNsWDEVk2etwe8bDolsWfzzJHz9KfMQLTK36dDGHoaGuhg9rFMeb7bO%2BzC%2B%2FO5PWNevibsslJvPtuFer1nTerC1ro1W7rOgJlHD0b3fCA83auJvcOvxhUgamJjoif0WROtWNpg5uS%2Br5w8wZmLg95hMTfWxdd2MQo%2BRZydnz9vEws1aiLj3hPWpXOHQ2FIs46Fg137z2XFqY9n%2FxhX7%2FPHkx%2BiPlgrh8jouWUhDGWWjFE%2BK8%2FCvLF%2Bn5%2F2m9DQZalQ3yTM%2F9G4Uer73La6cWCxEl5vYuOfM4F%2BKzBr3WrnhN4G58RoY6OTMexQVJzJw2WFgYchkGXgYFSu8DBd2UUl8nsy80wuYGOuLUDI3MbEJQuw8i1cSeL8uOiZBJDXyC5mLSu7X6ZUh%2FFOn68qbmFUxzHf%2B7xsPYVDfNm8IisMNsyDjzE84rwu2MHi%2Fj%2FfrcguVe9WC6NuzlchCco%2FJP%2FlR1dSw1N4%2Bd50IElWxaetiK1LalQEu1B3es6lRSFTvNr26taCTQBQKvU5PECQqgiBREQSJiiAIEhVBkKgIgkRFEASJiiAUgdLc%2FFW24ViIdxepMhzEoxh8zT81zTCfmvTdb0sK%2FwiCIAiiPPk%2FPvfPgDjCXHUAAAAASUVORK5CYII%3D)

```
basic_stmt
         ::= load_stmt
           | load_ifr_stmt
           | call_stmt
           | jump_sp_stmt
           | mode_stmt
           | message_stmt
           | erase_stmt
           | enable_stmt
           | reset_stmt
           | encrypt_stmt
           | keystore_stmt
```

referenced by:

* in_from_stmt
* statement

**load_stmt:**

![load_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAasAAAAlCAYAAAD83MZxAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAADbxJREFUeNrtnQl8TNcex3%2BTzCSRWBISxB4EIfZEKBpLmiCeoqFIKdWmiigJ8jSK0jZ42lheLS26PKpF7ErLp4qKrdRaxJJaYkkkYiJC1nf%2BJ%2BZKppMMkWQk%2Ft987mfm3nPuuXf%2B%2F3vOfzlnJgDDMAzDPOeoTHHR1i7IKq0CPXKm8GRamuXE8mf9sH5Yj0%2BD2lQf9o%2B9y0udAt06vsVyYvkzrB%2FWYxFgxqIv%2FKiRPT6WP8P6YT2ysWIYhmFeMNhYMQzDMGysGIZhGIaNFcMwDMPGimEYhmHYWDEMwzAMGyuGYRiGjRXzXHD9RgLSUtOLpN30tAwWcAmU%2F63YRDx4mMrK4f5ReoyVhyuq5FfJWHlREvTBcuw%2FfM5gGT0kC5dug3fvaWjbdSL6%2BIdh7YZIg3XnLNgAvyGzEXv7bq7ja9bvk8dpe3PEPEz55HvsO3CmxCnSt%2F8MnDl%2FrdDb9e47DReibxTpvcfFa%2FHTL0dKdEd6HuXv%2F044DhyOMlov5no8ft1zolQPdM%2BDfmisMZXzYEodP6v90J0vjZUY86%2B3dsHqvBo1Vl6UHD8VjYSEJINlI4IWYfO2w5g%2BeRDWfDcRAUN9EBYegc%2F%2FuzFXvZQHqVj67Q7cSbyHDZsP5Cq7GnMbKhUQPLoXBg%2FoBBsbK4wMWoKQqd%2BxK1NMXIy%2BiU%2FmrGFBmIgTpy8jfOFmFkQRkpWVhbGTlkGrTXnhdFxQ%2B9HGBX1aN8bV9AxE0778bUBVttHql5EhCl2wXm2OwIOncEt3krFyUxB58Cz2Rv6FyJ2zUMmunDxWs7o9HOzLw%2B%2FN2Rg8sDMcKpWXx7ftOAqXhjXg388TX337CwKG%2BeRqy17Ua9emkXzv1ak5hvl3hY%2FwmNq6N0Cfnm1LZOdYuzFSfm61UNbrfdujy8vN5PHYuLsiGv0Jt8SrSvy1bOaEYW94iXpmSupo0bJtuPT3LTRzrfNUKY74O0lYvGw7Tv51GY0b1hTOgzeqVrHLvh8R8dau5YA9QmdHj12EeytnjH6nB9Qac%2BlxJmqTFSdj%2BGAvVKhgU6IHJ1PIX6u9j4Xi3NNnrsrnPene%2FRxO39%2F4IWKvvH65cmXg5dkMPbu542FqGjZtO4QbNxMU%2BY9%2B1xfHTkQjYtN%2BxN2%2Bi4p2ZdHNq5XsG6WF4tbPmkcZn8XLt6OscIi7vdIKVSvbYf6SLYiNvYvMrEw0d3XC8CFesNCocT%2FloexL74g%2BRPqhOuNG9RI6TZGO99HjF1G%2FXjU4VraFZwdXNHSuLts%2FeCQKq9buRXy8Vo5p5MBnZGYY1DFdpzh4WvtBRipDhfkZWaiR8wedcs1ZZWUbL2r0miFLaKy8OPnt91Po%2BFJjxVDpcGtZXyow8uDjVF6EeDBf69VOPiDkxZ%2BNism37coOFeDf3zPPlOLzziLxkNM20K8jenV3l1Hi1p%2F%2FkGWJd5NRtmwZvNqjDXr1cJedNnxh9gNMHaSP%2F0w8eJiGNwd1QTlR76F4%2FySkpqXDb%2FAsWf%2F9ET1hYaFG70FhuJf8QJav3rAPAWMWwtzMTA6SG7YewOz567PlbV8BGnNz6WzQptaoS%2FRAaAr5Z2RkYuDwz3D5ahyG%2BneBo3ASku49UMrJ6NSu6SCf6w4eLgidvhI7dh0TA4AK9hXLi4FLo8ifjsXGJaJ%2BXUcMEU5fq%2Bb1EDjxKzkQlgZMoR9yoolqjhWljG2sLaUzUcbKQvQHNzk%2Bbfn5MMI%2Bj5D1ku8%2FxGfCsND1%2Fjx%2BCbcTtDI6GxwwF6fPXpHXr%2BdUVX6OqAvX5Tm79p7EuJBl8OnSEqMCfPH7gb%2Fw8ZzVeeq42KNLI%2FZDF0kJ878OZKj0UBtpVFpCY%2BWmiLSo8%2Bm8dn3oeGycVvGUDv4RhS%2FmvCs9Gm%2BhyIhNkQgd3y%2Ff9uvUqowt2w%2BXyHQDeWRfLRiFNq2dlTQoedy%2BPm5oUL8axgf2ljnsK9fi0KFdYxwRkQ6xcesh2NuXw8xpQ%2BR%2BV%2BF9L%2Fhy6xNdd%2Beu41CpVJgeOkjuk1dH8yUkwwGvdZTHJk%2FsLztlto5sMX7yN%2Fgg2A%2BeHV2l59evT%2FtSke4xhfz3RJ5GgohsN%2F0QCnPzbB905Zo9SjlFRdTe%2BYs3xACpQQsRMRw9dgmvdG6Blzwa4dip6FzyJ4eCDCDVtxSORxMRKVN9j9YNWD8F0E8nEf0Qvbq3kc6wjpCxfXHz1h1EX74Fz%2Fau0sDkZMWXY5VxjrJJNG2x9rsQJdJbt3G%2FUnfeoi2YOmkAfLq2lPt2IQMwYNgcTPv3AIM6NpkO9O2HCtvSgen6kdQTGSsdmcAxIZJuWUbK09MRLS5apjg%2FMM0tJSUZzv%2BSR1murJV8v2HLAenNkBdJkMFaL45NCvKDmVne3sWdxGTY2ZYt8P2Z6pelSSbkhTUUnU4HpQgobUGcjbqG94IWQy0imUYNqsvVTGaPBrdzF2LQvIlTga5L7TfIcU15XbFPnVBJB6gey7uu8AoppUKDR1Hwosn%2F3PkYuDaurRgqfbbvPIrQGStRo1ol1K1TRQ7EutSRISgF%2BPHs1bJuLRGR3RADKhkv1o9Tod0LZXlGjF0kU4CNnGvIhUb6Mnawf2zYLom%2B5FzPUTFU%2BkRdvI4Ppq%2FA1E9XKcesRQRXlDyLHsl%2BiBHBNz0LfuI101hD6jxyjJHixBjx6iUaXCpex%2BVXrlFj1tNEVoXxoFJqYmZ4BNLTM3MpjwbA8xdjZHl2bno%2FatesjMhDZ5U691NS5Yo%2FSiMaFKIQG6WpfL3dCnx%2FhfHPyQoiJ6syFlIe2nspyrwPdVBKWRC0kKGHd2tMGNMn25hvPYiVq3fL9%2BRB30xMLNC9knOg7zzQPVSvXsmwM5BwTzgDNtKAkQ0rbJv1osnf0kIDbVLek%2FcTPvwG4WHDlXmnaWGr%2FhFx6KAl3iFTvsX3y4KV6GPcpGWsn2fQjyE5z5q7To5BU0Jel%2Fu%2F%2FHoM8xZvzrePxd3W5llOjvi8mcOV%2Bff8rl2cetTXU077IV6XiEB%2F%2BYM0vCVG8bezVLhrKAVImOk3Il7WiAZcxHZNbQ6Xo2cQZKzcFIstfH1aywnC0On%2Fk%2FMlMt8soqExIUvlZCl5%2BeQlXb4aK0L%2BkbKj6rbevh6I2Lz%2FH21SJ6WJZVrCniliUprsLGmQTDq0bYwVP%2F6mPKArftwtZNJU7qemZcDSUqOkP%2FbsO62c6%2BHWALt2n5Sep0wtibLkHPMe%2BUGTvIePnseFS9nLeK%2FFxMt5Rd3EtTRe2uwJf5qUXrR8uxgUsp2BCuWsZVo3KSkFJR1Tyb%2BNmzMOHzmPv6%2FEyn2a54iNTVTuIY2ua6FRUuN%2FnohWzq1Q3hoxQl%2B6ZdViwEBaerpyn6RLWrRRGjCVfsgpKy%2FkTNGUjtTUxzKmMYzmnPKjfVsXXLkaJxdQUD%2Bjz3D2wuP5925dW2Luoi3KPDGNZ7SIRNHx9Xi5oMZU5GU%2FIk%2FgFL2KYNZZqGONqJckKl%2FLL7KiRsjSHdSIRgwYIGPlRUbA%2Bwtz7VNOdvkXgVi1PBjBoV%2BjadsxMmUXn5CEbl4tEfYop0yTo7SowsrSItf5ZKwGB4Tj0ylvyP1NPx2SG6UFadKSVj4FvttT6dwljZkfDcHQ9%2BZj52%2FHkZKSJtOgYVOzPystfnhr9ALpLZKj1aRRTeW8zh2bolNHV3h0nig8UA3auTeERij7SaA5vmmTBqK3fxic6zri3IXrCBr1Klxdail1lny9Xeb4aaLarUU9zJkxVEnD0EDQzjsEajMzbPwxFLVrOJTYAdEU8m%2FSqJZ0rjr1nIzyNmXQQMjU0kqjDJQ0N0L3RBP9VuJ4zhS3e8v6qFnTHm06TZD7%2B3bMRHBgb%2FT1nynr04IDS8uSvejF1PohRgzzEdedBzu7spgQ2AeBAb4Y8t5cOU4RzV3r5Hs%2BLZL4cv5IzApfhwVLtso5sxqOlZTU76RgP0wUEbSbZzAqCv3e0SbjFRFJdxdjoNRxDXu4e45XdKyLJosJo%2Fbj0bEgD1fMEj5DiH6kpXoUpt0XjSwWjRhM5xkrL0j4Xpj%2Fjjrhzj0k338AWxHWF7MCcpHz3z0XVprjWeREnpRGeJI5J3QJWmlEk%2FFVKtsaXL5KnrdKGG7d0v%2BngQwROQ00GFJaQkf%2Fof%2BRCy28u7SQHjx1PEPXtRKeJnmgLP%2BCyZ%2B%2BPkAetaHFR5R5SEpOkavBDHHj5h1hmKyUPkT9KkXos3q1Stw%2FCkk%2FpINUEbVWfjQXRdHb7XitvIendY4pQ%2BHeZTxWLg2SXxXRQZEVfae0qoMtNBbqfHVcHHosqP2g1YJktMQFRojrWMtPIsIxp%2FwaMVZuauh7ILQxuclrkKFlszb5TLzqd17iw4%2B%2Fx5kow78AYFvBGksXjJbvrctYwrq6Zb559ZxGzNh1Wf5PJ3%2F9r3LkqmdrI7e8cKxq949%2BhVLcr0yhH33509L1vJwHQ9BcIi2dpyhp977T8rtZOQ2VsT6mr%2BPioKD2I2ekpaQBjTX0PBsqpniYMXnQM50%2F8u3ucKpThQVpIvkzpUM%2FA%2Fu9jOMno%2BX3wcaN%2FJdc7v6886z2Q3e%2Bmh8zpjjQfc%2BEYZiC06Kpk9xeRPhX1xmGYRg2VgzDMAzDxophGIZhY8UwDMMwbKwYhmEYho0VwzAMw8aKYRiGYdhYMQzDMC86JvtScM7fl2JYTix%2FhvXD5Ie5KS564zY%2Boq2aA6aVVsHS52M5sfwZ1g%2FrsXDgNCDDMAzDMAzDMMyz8n9uqXH4%2FMp%2BvQAAAABJRU5ErkJggg%3D%3D)

```
load_stmt
         ::= LOAD load_opt load_data load_target
```

referenced by:

* basic_stmt

**load_opt:**

![load_opt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAANUAAAB9CAYAAAA1DyYAAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAEgdJREFUeNrtnQdYVMf6xt9lQTpYKGJQUBEFK6BgiYagKKKiqCTYIhdbVNBEY7wa9apRE3M16t%2BuN0SNLRd7j8ZuRDRWFAELYFdsiCgCu%2FufGWADXspCWBaW7%2Fc8y9nTZmfPvO%2F5vplzlgMQBFGqSLThS7g5QVFZGuz8de1oM21GV1u%2ByJ8nw7S%2BsVq2DybFVgB06BBUvKhcmSIzmYogCDIVQZCpCIJMRRBkKoIgyFQEQaYiCDIVQRCqIe6o8GgC68ireFzQRkWtryjEJz7GhKlrlfMzJgeicaM6%2BObb9Yi98UAsq17NBI4OtdC7R2vUs6%2Bp3HZD%2BHFs3x35P2XOmTZQbD9o%2BELI5DKsXDgKpiaGYt2xU1dxOjIGwQM7ImTC6gLrlVMPQrP8XZ3n7C9MlSHDAzcnbNWVIjS%2FQotaX1GwtamBWVMGoKPfVOz5dQoc6tmI5VHRifBwc4RXh6Z49jwFh49fQRf%2FGZg3Owg9fT3ENnfuJkG%2Fii5ChvvmKdOmZjUxPXfhBj6oVR0rf%2F4NX4X2EsuePn2F67H3ULWqMcaH%2BIllmZlyBAbPw5J5w1HTqqpYVruWBSm6HFBSnbs7wV8mwf9lylCDzRoJU0my0sAAmQz%2BrNDt7xda1PqKgh4zBRd%2Bjhn0q%2Bgp13GDtXFvJN5392mFHl3dMXzMUrRyaYBaNln7WFqaK7fJjwlj%2FPHFpJ8QNMALFtXNlMsN9Kso98tIzxRT1%2Bb1YFfbipRcjiiuznPMJFPANveNY3luqFVkzRdYaFHrtQketZwa1cbe3%2F7EsKDOYllSUjIizsbk2a6Js50y3WvkaIsuXi5YvGIvS%2Bn6kUorKEXpvCAz5Wuqggot7odqC%2Fa1LXHvwTPlfHTMXcxfsut%2F%2BlSmDobK%2BfEs9fPuOQ3DBncmdWqbuSTYz%2FKMmQWZqVBT5SAHLrF46KMoYn1mJuLZhxpq20F9mZyK%2BnVtlPMftW%2BChd8NKXSfOrYWCPBvx8y3A%2B08nNRWN7pTvezgOmepYbdMBfqyqbyoA69bQG55mu14n007sQL%2Fw6ZfFrZeTxdzcyJVACBNcISdTAfObEMvtk0%2Ftu1VXQVGs8wprqII7MHD5yzVi8Wk8X2Lve%2FYkT3Q3mcSLGqYqa2h6ceKxYN1aR0zJVjKDloTJpZNTDFHpHJE28chMRyQ5aej3Dpn05UGeghLy0AwCyRDFRIkg0esokyVU4giq5BIPSmcuFnYh31Z2PrcZYgKxuE2e8tfexwcMMlcDxNYDnrGxRkBF6NxuDwf%2FJSUt4g4F4sZ32%2FGwEBPODesXewyLJmZggd2wuo1B9G6VUNStIZhuuvIUrZwpt8fkzPQ%2FeZNvMtZd66QoFKAzsd5NMHcDBkmFmSu3KYKL8wsKqzPl%2BwvMMu1kUgVw9kZo7W6IlZRxN64j0EjFor3PQJnY%2BWCkXBtUT%2FrSE0OEy8jQ300dPwAoSO6IbBP%2B7wHYPsf4pWb3Zu%2FUZaRm5HBPli3%2BSgpuhxEKG4ohQKfXYjBHhV2KVLn2csKNJckO%2By9YYWsYIXMza%2BQotYXI02bwiYdWOpSqr14HrYr28%2FpKf1TWRsH2eQEO16zVNi2RDrnF325uViDfM4%2BJ%2Bs6la4UdQsrpKj1qmL6FvNSDDHapTGaX7yGy9TkhFrTPqYzyNGU6c5Ple1LqvPckYvP6%2BRaWNROf5tjCUhj59eNOnL0oSYn1I3QGdOb0J3q5igxOfuX%2FQ21ChxhIbYNNTmhfqkxnTG9lbmZy%2FoDWafxGss9HanJCXXDdcb1pvWmMnwtQqQlNTlRBlhm6027TRVxT%2BS3BtTeRBlgkK037TZVVqpLw8FEWWWAZX87F%2F3ylyDIVARBpiIIMhVBECVHax6lQ4%2BZIShSlSL85lK6wZQgUxEEpX8VI2JRkxIUqQiCTEUQBJmKIMhUBEGmIgiCTEUQZCqCIFMRRGVEKy7%2B0v8V1x604QK%2B1txRURn%2Bmaa2oy03RVP6R5S7rKOiZx5kKoIgUxEEmYogyFRlBP1Mg9BKfWnMVG1s6R9qEtqpL42Z6q0JrKnpCW3Ul8ZMJZWgMTU9oY360lyfSgIvanpCG%2FWlOVMp0N%2FTvuzz3n5D5uPKtQSVtuXP9017l14uNfMkKRkHfr9A5skHoSumr8pnKiAqxRBflfWH9vFrA2vLqkV7XqHAF5N%2BwqtXb8ulcOJu3sfchdvIQfmQrasoTX2%2Bxu79kyoQIpPgDH9qvYpPDS8Vnj1PgUSSNdr62%2BGLMDUxFE%2BtP3IiCnZ1LDEhtBfMzY0RvuO02GZF2AGYGBvAx9sVzg1rF1n%2B%2FkMXcOjoJWRkZMKjVUME9GoL%2FSp6OB0Zg43hJ%2FA6NQ2dPJthwCcfiXokJ6di7aaj6OzlgtVrDyLpaTIGBXrC%2B%2BMWWQJJeYtVbDmvY1UzY3Ro54xuXVoifOdpPHuWgh%2BX7BTbDQvqLL5LYbxLz0DYL4cRcTYG5mZGCOrfEW4u9ZF4Lwlb2fcdNpiVYZpVBo%2BCcrkCvp3dsGvfWVhamuPchRuIPBeHFs3qInRENxjoV8HjJy%2Bxc28k%2BvZqJ6YyuRxDP%2FPWmKGYnrqzyTimr9ZMX7GVKlKxdo2TSxDAdLWOP7XewQH6ZfG53CSPnrxQmip49GI8ePQcfl1bIepaIr7993%2FFOksLMzGtZVMdtT%2BwgLFR0dVb%2FtMBzJm%2FBV4dmqKjZ3PsP3geCYlPcPJ0NEaNW8GWNcPg%2Fh9j87ZT%2BH7BVrHPy1ep%2BGHRdkye8QtcmtdDK9cGGDZ2Ge4%2FeCbWjxq%2FAg8ePsc%2FBngJMXPTivrVMIOunlTUjb90daVF1m9oyFLcvP0QIcO7wbN9UwSNWoT4xMews7VEdOxdjP8m66bkS1fiMXnmejRrbC%2Fmd%2B0%2Fi%2BFjluLduwz4%2Bbrj0JHLmP7dZrHu4eMXov4Bg%2BfiZvxDYXRNwPXDdcT1xHXF9VXpIhXnYjQOuzdC60wJlprrYbSrEzbxZ7RK5Yi2j0NiOCBTdx0%2BD%2FbBF6N6iPf8LM0FIvLyD5uIqV9Xd1ixs3RRZGbKsWjFbmxcPQ6uLeqLZb26eYiz%2FSxm1NFMyP7dW4vltrUs0LXPDIxnUZFTRU8XW9dPVEbQHXvPsH5fIj6oVQNXr9%2FBTP8P0YYdKP7qH9BBWb%2FDx68gwL%2BdSt%2FzUlQ8bsU%2FwtoVY6GjI4G7WwOcOReLfcz4o4f5YsGcIejadyYWLd%2BNX7f9gcU%2FDIPtBzWU%2B48P6YWgAVl9f4e6Nug%2FdD7mTBsk5vUN9LB9%2FSSYsehXVgSwZCfBEXYyHTjzQQl25PopgKu6LEKdv645Q2ncVDkRi028XRqjuY4Cvdn7MXIpGtx2gp1bGVwV15H%2B9RE8JcrIKJmPH7Pox1O1nLO7snwm4Fvxj0VqlUOD%2BjZIZ%2BnhQxYhxUAVM1OOoThmpkaQybLqwY03bnKYMLtri3oIHtgJzZvYF7t%2BN24%2BEKlaW%2B%2BJeZbXsbVUnlCWL%2FgcPr1nsEjmi3atnfIOpuVqiXr21iKNTU3NekghTwNL21BF3al%2BO%2BthbomsWjeYSiJYdPK5eA2Xy0Ofrtz8nir7gFxWRwOUBbzfxY3xMiUVFtXN8qwzNTFAyuu%2FBjy4IGUyOYzZPjnCLIiBrO%2FFB1d4arrv0Hl8GvRvXDy1QDmYoir8s%2BrXrYmDO6YXuM1W1k9r6mzH%2BkZnMTK4K6pWNc53uxfJr4WRjIzUl7FX5B8r0g21BcANws%2B%2BvA%2BiCnxwo6WLA5at3q9cFnk%2BTkQHr4%2BaYdOWkyJF5Pyy%2BZiINu%2BbL1%2Bh74oQ6SFP10YN6YrUN2l4l5Yh6vaIlZ365p1K9Wvn0Qh37iex1DJSuSzx7hNcvpog3u%2FcF4ljp65i24Z%2FiigV%2BvUqkbrmkJzyRkz5yWAp%2B45dOrpAKiX5lOtIVR4ZEdQFQSMXoVo1E0wI9UffXm0L3X7R3CEYMXY5XD78ElJdHRga6CN87QSM%2Bbw7W74M7bpMhLmpsTDGmuVjVarD2k1HMHX2RjjWr4X4hMeY9vWnIoJwUzVvUhceHSdAKtHBgW3%2Fgk3NaoWa%2FudlYzB%2BUhhmzv1VGJUPPCz4fogYWZzy7QZW14kwMtTHrKkD4Jvdv%2FpytJ%2FYf8N%2Fj2PtxqN4m5YuRkFXLRpFAinohKyJD%2BXpWmmGd16eun5O%2F%2FJlKtIzM2FlYa7yPk%2BeJouzeI1qpnmWJz17hTQmSj5aVxxevHiN18yIfESSp115%2B3IvhRFyhsJV4dHjF6wvqaPydxoaugTt2ziLQRGeuhbnWBSH3D%2BnLw19lLbOKFKVEjn9ioNHLmHVmoMFbjdt4ifKQYqCRMeHwUsCj5T8lR%2FWVlkXsucv2YmIswVfltmy7mvl%2B5rW1UpUD25e%2FiLIVKVCZ68W4lVeGR%2FSU21l8xFHVS4rEGQqQkXaejSig1AMaPiGIMhUBEGmIggyFUEQZCqCIFMRBJmKIAgyFUFoAq25%2BKstj2EhKFKVC%2FhNk9rwsDCCTEUQhDanfzkRi5qUoEhFEGQqgiDIVARBpiIIMhVBEGQqgiBTEQSZiiAqI1px8bc8%2FNvnsoYudJOp1I66%2FplmeYRuHqb0j1BTdK6MEZpMRRBkKoIgyFQEQaYS8L4AjV4R6kSSrbNKY6q0NrYwoHYn1EW2vtIqk6mS3prAmpqeUBfZ%2BkqqNKZiMTlOKkFjanpCXXB9cZ1VGlOxZDeC%2FfGipifUKDIvobPKYiq5DraycNXf0157%2B1XnL97CtZg7JG4NIHTF9CV0VllMdfEaLrNJVIohvtLWhg3f%2BQf2H7pACtcA2bqKytZZmaOxe%2F%2BkCoTIJDjj2giXLsRgT1l9bnpGJsJ%2B%2BR2nI2NgZmqEwf0%2FRivXBmLdr9tOiafAHzkZhUtXbqND28YYPMALa9YfxsmI67CrY4mJX%2FSGqYkhUt%2B8w8qwA%2BjSyQU%2FrfsdL16%2BxqBAT3h1aCae9n7laoJ4Pu6PS3bCpmZ11LW3Fg%2Bw7tXNQ1kXXoeXyanw7exGTiglmJ66s8k4pq%2FWmqqDxi7%2Bno1BnFyCAIkE69ycMMXBAWXyhOYRY5chhok%2BZHg3dPRshuDRi3Hj1kOxbvPWk2JeV6oDH29XLF65Fx91nYw795%2FCr2srkdLxB1ZzUt%2BkiffTZm1E8yb2cG1eH8NCl%2BHq9TswMtKHsbEBzMyMxJPora3MUZW9%2F3rqGqSkvFXWZdqcTXTzXinB9cN1xPXEdcX1pam6aPQu9YvROOzeCK0zJVhqrofRrk7gKjsilSPaPg6J4YCsND%2BP93GiY%2B8i4tAP0NHh1wYbIPLPOOw7%2BCfGjuwhtpk%2BORA9fbOiyZWoBBgyg0z%2FZ6CY5wbYtOVE3jRv3cTssoCb8Q%2BxY88ZTJnwCerXrQmLGmYI8G%2Bn3Laps51IC%2FmDqSPPx%2BFVyhv4dHQhR5SAAJbsJDjCTqYD5%2BxBiX6sfa7qsgh1%2FrrmDKVxU%2BVELDbxdmmM5joK9Gbvx8ilaHDbCXZupXzXReyNB0hKeoW23hPzLA%2Fs0%2F6vtFTnr%2BBtwtI8mVyunOdpX0ZmwT6vZ2etjHr5Mbi%2FFxYs2yVMtWbDEXwW%2BDGk0r%2BXLFTWO9VvZ53jEplAbjCVRLDo5KOpPlS5M9V7gxeX1SksUxMD2NtZ4cjub1UqVyIpfP59nr94jerVTJTzCkXeavl6u%2BFf323Cjr2ROHoiCrOnDvzbx41%2BrFj%2BqFQ31LZu2RCPnrzElp2nlcvu3HuKi5dvl7jMV6%2FeKMvZyczi26WlmDdnfahb8Y%2FynsH0pBj4qSe%2B%2BuZnMTiR24CE9qBbmb6sqakhfl4WinGTwjB7XjgM9PXw9m065s8p%2BS9p%2FfrNRnp6phj9GxfSkxnXUSzv27Md%2Bg6aC3evCahnb43NYVlXDz5hfSw%2BIhg8qBOpj0ylHXi4OeKPg9%2FjMYtYEpbPWVmaK9dt3zApz7Z8wCE3Pp1cxSs3x%2FbOxtPnr2BibCCG0HNoUN8G54%2FPx8MnL2BjVU25%2FMzZWLi7NUATpzqkPjKVdmFtVbXUyrKyMM%2F%2F4LJ0jw%2Bp52bVmoMIHdGNlEd9KuJ9zFgqufC7IcrhdFXgF4yHB3Vm%2FamWdAApUhHvY6BfJc81KFUwNtIv9j4ERSqCIFPRISAIMhVBkKkIgkxFEASZiiDIVARBpiIIQhW05uIvPV6GKC9IteFLPHyKGfxVyxLTK1sD8u9NMqb0jyAIgiBU5%2F8BExVPjF8CsmIAAAAASUVORK5CYII%3D)

```
load_opt ::= IDENT
           | int_const_expr
           | empty
```

referenced by:

* load_stmt

**load_data:**

![load_data](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAX8AAAD1CAYAAAC4GPVtAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAIABJREFUeNrt3QdcE2cDBvAnDAEBcYAbwQ24CjhwK%2B49qXvUvWet1dpha9vPVuuoWke11Wq14qzaWltXHbi3qKgobsWFoKiQ5HvfF4hQUUCBAHn%2B%2FmLI3eVyubs877jLBSAiIpOjyQpvwtsdem7KrOHwmayxTxJldBZZ5Y0c2rWIWzOTq1izF1cCUTox4yqgjNaKY0uOiOFPREQMfyIiYvgTERHDn4iIGP5ERMTwJyIihj8REcOfiIhMLvyrlEW%2B102U1PjMpFPvqThx%2BnKypvVfuwdPnz3PkO%2FjTmgYNv9zhHswkYl52zyOe74K%2Fygtbni7Y%2BWrZprU%2BMykXcuqyOeUM8np9Ho9RoxbiEePIjPk%2Bwi6cB2Tp6%2FhJ4HIxLxpHld2RxtvD1yN1uKSfKyu7aOJKQT8tFox0h1rLcwxdP8p3I57UlLjM5N798Oh0cRcO%2ByvrUdhb2eDc%2BevY9u%2FJ%2BFSxAljhraGg4Mt%2FNftVdPMXbQZdrbWaNzACx6lnZOc%2F59%2FH8Hf248hKioaVSqVhl%2FrarDKZom9%2B8%2FiV%2F9%2FEfH4KerXKY8u79ZWyxEW9hiLl29HQ19PLFi8BaF3w9CtYx00qPuOml94eCTmi%2BFyGXPmsEWt6h5o1qgi%2FNfvxb174fhu1no1Xd%2BeDdV7eZ1nz6Ow6JetCDhwFg45sqNn53rw9iyOkGuhWC3eb98eYh72MfOQrQqdTo%2BmDb3x%2Bx8H4OTkgINHzmP%2FwSC8U74ohvZvBmurbLh95yHWb9qP9q2rq3utToc%2B3RvwE0qURlKaxzL0tRrM1OpROP6FUxL0%2BetjCgM502uJlSxJjc8MZJjfuvPAEP69Bn%2BPG7fuo2WTSjh5OgRffLtSjXNyzKHuCxbIDedCjrDNbpXkvH9YuBlfTV0F31rlUK9OBfy55TAuh9zBrr2BGDRqrhhWHj0618WKNbvxv2mr1XMePnqMb2asxfiJv8CzQjFU8iqJvsPn4PqNe2r8oNFzcePmfbzXxVeFrixc1PLlyQELS3O1bPJmIfaApPQZMhsXgm9iSL9mqFOzHHoOmoFLIbfhUtgJgeeuYvRHMRfHO3biEsZ%2FvhTly7iqx7%2F%2FeQD9hs3Gs2dRaNm0Mv7edhyffb1Cjbt5%2B4Fafr8ek3Hh0k1VIBFR2ksqj%2BNq%2BlpgDWTw%2F4dFEjNVJUtS4zNzS2BAr8YYMaiF%2BlvWemWQSXVqlFX3LZtURl5R601KdLQOM%2BZuwK8LRsHrneJqWOtmVVTteZIoUAaLwG3T3EcNL1zQEU3aTcRo0cqQsllaYPXSsYYWybpN%2B3BCFESFCubBqTNX8HmbGqha2U3dOvvVMizf1p0n4NemerLe57GTl3Dx0i0snjscZmYaVPYuiX0Hz%2BEPUUAN7tsU077qjSbtP8eMHzbgtzV78P03fVG4UB7D80cPaY2eogCSShQtgM59puKrT7qpx1bWlli7dBxyiNYEERmtEIjJYw3%2BjAY%2B%2F29NP1nhH0cnMkM0DRrrkxgfHY1L4kVtMuOKMzN%2Fcfl42RUSFaV9o%2FncFq0J2UUTV1s2zF8E7cVLt1WXSpySxQvgeVQ0booWh2rGidCPC34ph312aLUxyyELiFHjF6lCyeudYujVtT4qlHVN8fKdv3BDddFUazA2wfAiotYfV%2FD9MG0AGredKFoGTVHdxz1hUzPeVfaLueZT3VePxU2S3T%2BpHfy8sidRysg8Fh%2FTZtF6tBf3uqQ%2BQBav6FPaK554XdzXFzP8UdyPfN14UXGdHFfz9wPML5eCi9YMHmJCXzFNJzHtKQs9Bh84i6C0eNMZISjkcQEZ4A%2FDH8Mxd44E4%2BztrBEe8eLAsQxOrVYHW%2FGcuAB9la7v1lYHqWWX1B9%2FH0aHnt%2Fi6O5pMSW%2BPvlvW75W8aL5sWXdZ6%2BcZvX6vSjn4YL1mw5gYK8myJnTNtHpHoRFqMDPnoyusDfFH3UhUyQa96WiNZgtdv6y4tO9XCTbNnMdAl2DEOIPaBPLu%2Fh5LO7niYb4oqdR6CUq5n30GoQl1uWjKqb%2FnYm48xczcBe3axbmcD9yBqOSGh%2B%2Fy0cu4MEgBB85i41yXFgUXMXzdmo12OfpgXqZZSPIIJe1WdlHnhzyIHFFzxKYs%2BBPw7D9h4NUbdu3dnksX7VLdQ1Jv6zYoWrv%2Fy0kEg3k3wNUt5DsphnUuwkeP3mKZ2LLymW7Jeb9%2BMmzZC1f9SpuuHI9FOs27TcMC7l6B8dPXVZ%2Fr%2F9jP3bsPoU1yz5Utf6hH8xXXVZxwsKfqHtZaM0W77FRPU%2BYm%2FNrIkSpReajzEmZlzI3ZX7KHJV5Ghf8ycnrvSdwSt6bm6OkqB%2F6i%2BnCxcTXXlfzlzORJcd%2BSzGTRPrwkxqfqAsXINNpkpeb6iLyFyWbT1q1AFJb%2F56N0HPgDOTKZYcxQ9ugfetqr51%2BxuTe6D%2F8B3jWGAlzCzPYWFvBf%2FEYDBvQXAyfg%2BqNxsLB3lYF%2BM8%2FDE%2FWMixevg0ff%2FkrShUviEuXb%2BOTDzqoGrkM%2Fwpli6JKvTEw15hh85pPUSB%2FrtcWTj%2FNGYbR4xbh88m%2FqQJFHsCd9r%2Fe6kyiCV8sE8s6FtltrDDp4y5oGtv%2FP3JwS%2FX8ZSt3YvGv2xH59Lk662n%2BjEH8tBKlYo1fK4JahHV3GfjJeEqSeRw7bFSVspgcpcXY%2F7YENLHNiCdiJnPFTCYnNpOkxqege2aCuKslmvQNU7vbJ61%2BxvHhw8d4Hh2NvI4OyX7OnbthqlacJ5d9guGh9x7hqQhPeXZOSjx4EIEIUWDIM5Bkd0t8smUhAzvuFM3kuHX7AczE8iX3PfUZOgs1q3qog8uyyyol6yIl4v%2BMI7t9yJSIDNsi7v4V%2B%2F2kZEz7RnkszwaShYD4YA0Qr5Nd1fxFc6Ho62aS1Pjkso%2FElHAbDPYsgwpHT%2BN4Ztgocf3eW7Ydw%2Fyft7xyuk%2FGvms42PuqcJSnZ74J2fKQt8TkyxvzhbWps9Yj4MC5V85j1ZIPDH%2Fnz5frjZZDFjLyRkSp2N0j8hA6lBP52DI5079pHsdvCRi6fZKaUWqdxrnjMp56e%2BBXMx3aiYfHM9MGauj7jrplVKOHtEqzecszjJJzuisRpZzKQw1%2BlfmYghB%2FY3HPT%2F8jdnpsE02WqtzkmUe1Km4oUawAVwRRmkSiyEORi%2Ble6KT3C2r1OK0BSnGTExGpA6%2FyYO%2FpLB%2F%2BNhGqyeHETU5EpDjF5mLWDv%2BAa6pfy5rbm4hIsY7Nxawd%2FlBdXDyNj4goliY2F7N8%2BBMRkZEx%2FImIGP5ERMTwJyKiLMkiq7yR%2BNeFISIiE6j5y4uA8UJgREQmFv5ERJQyFlnpzbD2T0TEmj8RETH8iYiI4U9ExPAnIiKGPxERMfyJiIjhT0REDH8iIspsssSXvLzd0%2F%2BHEMi4%2BIU%2BIoa%2FcmjXIm5NE8GL%2BBG9PXb7UKZt7bHFR8TwJyIihj8RETH8iYgow4Q%2Fz9YgIlNntBw0WvhXLQxrbnciMmXGzEGjhX%2BkHfJx0xORKTNmDhot%2FM01KMNNT0SmzJg5aLw%2Bfw18uemJyKQZMQeN9w1fPTrXccVHOy7jaXq%2B7P0HEfhu9nrs2XcGkZHPUbhgHvhULo2BvZvg88m%2F4eKlW4k%2Br2HdCqhVvSwmTFpmGFa8aH6827o6vD2Lq8enz17Bp1%2BtMIyfMqknXIvkxYhxC3Ht%2Bj3MnNwHBQvkVuNOBobg52XbMPXL9wzTnzt%2FHfN%2B%2BgtHjl%2BEVqtHkcKOqFbFDZ3b10KuXHZJvrf3Bs3E2BFt4VaqcILhPyzcjK07T6i%2FnQvlQetmPvh%2B%2FqZXzmfFwtH46IuluHj5doLhNtbZ8Mv8ETh%2F8SbGTfzlxXpwzYf2rauhklfJl%2BYl3%2Fv9%2B%2BH4ac4wmJu%2FqGt8N2u9eH9O6nlEpkjkn3W4yEHTC3%2BRf%2BE2eF%2FcT0q38kavR4ee36Jk8YL4%2Ftt%2ByGGfHcdPXsLSlTvRqul9dHm3Fh4%2FjimLpsxch2Ii3Nu28FGP8%2BXNiXsixE6J0P5pzlA8f67FvkPn0K7HZGz8bQLKuhdBiWIFMG5kO7Ts9CW2b5yEQvljgl6%2BhpmZBlNF4MWF%2FaNHT3D81GXDsm3fdRIDR87F0P7NMLhvU1haWuDYiWAsWb4d9nY26N6pbpLv7%2BDRC3gUHvnS8I5ta4hCL1wVTh%2BK5TMTITx6SMvYAuuqKAx%2Fx8LvB79oilqY4cTpENSpWRa1qnm8GG5uru4jIiLVe1oybziiorTYfzgIfmK9rv91PCqUdTVMfyH4Jv7efgzZbaywKyAQdWqUfVHQXbgh1gnPNCbTFZt%2FJ8Utv0mFv7keQ7Qa7PNyw7EjZ7ExPV7z2o17CDx3FcsWjkJeRwc1TNauWzSphOhoHSwsXoRR7tz2cBbjqlZ2MwyT4S%2BDMW5Y7RplsGf%2FGezaG6jC3yqbJQrkz6XGFRItCstsL1bvsAHNMfaTJaKF0VgVEvFFiwB9f8LPmPDBu%2Bj6bm3DcLlsLZtWVq2VtyFbDQ45bEXN3UoVYpJTnhyG8dkszBO8zziykExseExB8GI91KpeBgH7z%2BHfPacThP%2Fq9QFo3rAiHBxsxd97E4Q%2FkSkTuddc3I0SOegjcvCcMZbBaFWvA2cRpNPAT6PBEm93TChRAlZp%2FZoy%2BGQQzpy7ESFX7yQsBS1SvipkaN8NfYQizk5JTisLmx6d6%2BKb6WteGnf0ZDAePnyMDq2rJ%2Frc3Mno8kkL5y%2FeQIDYUHG3A4fPJ74eRMEZek%2BuB8cEraw1GwPQtlVV1Xra%2FM9RPH7yjJ96Mmky52TeydyT%2BSdz0BS7fXA0EFtF5dEnWoPZDpYY7OWO5dBjm7kOga5BCPEHtKn5etksLbBo1lB8%2BtVy%2FLR0K%2BztbeBVoRje61IPDeq%2Bk6x5PI2MUv3V0r5DQXB3c0YjX89kPXdwn6ao2nAsjp28lGD47TsPkdcph6GlEPU8Gus27TeM9xTL%2BN%2FWQnr48%2B%2FDOHjkguFxXJ%2B%2F9OzZi%2FVw4Mh5FHPNh2YNKhqm3XfwHDTiX2WvktCIPd2lSF788dch%2BLWpzgQgk%2BEnGsmXS8FFawYPeXBXA3TSA6csRI3%2F8BnjBb%2FRwz%2BuBSDuGniWQQUzPdrKHhKdOUoGu8PFOw2%2B%2FVbZuyT%2BXP2JqmmfOhOi%2BqJ7D5mFX38chRpVPZI9n6vX7%2BLMuavYuuGLZLcacuTIjkG9m%2BB%2F01ZjaL9mhuF2djZ4EPZY1ZZlUEbrdNgrVoy0c89pDB%2FQ3CjhP2xAC8Mxj1e5fvO%2BOni9df3nsLA0NwxftT5AdZutWrdXPS6YPxdW%2FR6Q6uHPK3tSRhYMtX%2BGiCA7L9IsQNT2Gx89jeMZYdkyzPX8Y1fI8fQKgJw5bVXYy9uR48E4ciI4WeFvbWOJUUNaqb9HjV%2BEngNmYPXSD1WtODl6dauPhb%2F8owodQ82%2BXFE8exqljh3I%2FnM5r2lf91bjOvWemiF3aiurF%2BvBwtwMPcR6WLNsHGyzW%2BHps%2BfYtOUQ6teuYCjE5DGUtRsCcPPWA8NxkdTAH3UhejMmdbqF7G4Z%2F%2FlSVWuPI8%2BAkWe8VPIskeL5Tf6suzqTZfDoedDpklf%2ByGAfOaglFi75xzBMHhDt36sRRorC5NDRF90sMkQjHj%2FN8Ov1y4%2B7qvcwcOQP0Gp12LL1GJwLOmLWlH6qEJO36eJWyasU1m7cx08dEWv%2B6St%2F3py4JoK%2FZpPxyJPLXp2xEhn5DONHtXvlWS2vI%2FvoF8wcjOYdJuHzb35Dy8aV0F8EoOTbYgJ%2BmTcSpUoUfOl5ndrVxNxFmxMM%2B2B4W3VGTp8hs1TXj6xZPwx7LJartOqqSq42Xb5O8LhbxzrqVNFl%2Fv%2Fi%2BbModO4zFb%2F%2BODpZ8xo6Zr66xbGztca5w3Ne3okszbFgxiCxHr7Ep18vx5WroWjdvMpL08lhPy39B4P6NFGPv525Vt3iFHPNj12bv%2BKnkigdGKXJLLtpUrO5LueXkp9xlAdUb4U%2BVH87F3LMcBvlxs370Op0yOvkoE4fpYTi%2F4wju30os0vtPGTNP4kae0YM%2FThx3wKO7zNRoz515mqi09vbWatv0BIRMfyzmM%2FGdeJKIKJUw%2B%2FXExEx%2FImIiOFPREQMfyIiYvgTERHDn4iIGP5ERMTwJyIihj8RERlRlvmGb%2FzrvRARkQnU%2FOVFkXiBLyIiEwt%2FIiJKmSx1YTfW%2FomIWPMnIiKGPxERMfyJiBj%2BRETE8CciIoY%2FEREx%2FImIiOFPRESZTZb4kpe3O%2FSmssH4RTYiYvjHc2jXoiy%2FsXjxOiJKLez2yYStHFNq6RARw5%2BIiBj%2BRETE8CciokwR%2FjxrhYhMndFy0GjhX7UwrLndiciUGTMHjRb%2BkXbIx01PRKbMmDlotPA316AMNz0RmTJj5qDx%2Bvw18OWmJyKTZsQcNN43fPXoXMcVH%2B24jKfp9ZKXQm5jzMeLDY8nju%2BIMm5F8NEXS3Hu%2FA01LHcuO5QqURBtW%2FigmGt%2Bw7TL%2FHdi7Yb9L83zq0%2B6qum79ZsOrU6LedMHwd7ORo3bsfsU9u4%2Fi15d62HImAWvXK645SAi0yHyzzpc5KDphT9wMtwG74v7Sen1goUL5MGkCV1Qr%2BXH2PjbBJQoViBmQQJDUMW7FHxrlcO9%2B%2BHYuvMEGrWZiClf9kSrplXUNFeuhsIqmwWG9GuaYJ4F8udS9wePnEehgrkx76e%2F8P7Q1mrY3buPcObcNeTMaYvRQ1qqYdHROnTsNQWzpvRD%2Frw51TDngo78JBCZmNj8Oylu%2BU0q%2FM31GKLVYJ%2BXG44dOYuN6fGaliK8ZUDHhbZVNkvDOFkQVK3spv5u3rgSWjSpjH7DZqOSZ0kULBDzHCcnB8M0iRkzrA1GjFuInl184Zg7h2G4tVU2w%2FOinkere68KxeDinJefACITJHKvubgbJXLQR%2BTgOWMsg9H6%2FA%2BcRZBOAz%2BNBku83TGhRAlYZaSNI1sB7m7O2PTXIcOw0NAwBIgFj38Lj4g0jHcrVRiNfD3x%2FdxN3LuJ6CUy52TeydyT%2BSdz0FjLYtSreh4NxFZRIfaJ1mC2gyUGe7ljOfTYZq5DoGsQQvwBrTGXz9XZCddu3DM8Djx7FVNn%2FZ5gGtnnb1%2FCxvB49NDWaNDqE%2FTt0ZB7OpGJ8wPML5eCi9YMHvLgrgbopAdOWYga%2F%2BEzxgt%2Bo4d%2FXAtA3DXwLIMKZnq0FX8P05mjZLA7XLyN%2FC3gh2GPUbxoAcPj2jXLYvrXvV%2F7nCKFHeHXprooJNahehX3NFs2XtmTKOMLhvqchoggOy%2FSLEDU9hsfPY3jGWHZMsz1%2FGNXyButlLQIwhs37yPgwDmMG90%2Bxc8dPrAFajYeB8c8OdJsffFHXYjobfDCbv8RHh6JLduOwa%2FHN%2BjasQ48SjuneB5OIvR7da2Pn5dt4wologzJwpTe7Lnz19Gt%2F3T1d4uOX2LetIHweqe4ejxq%2FCJ1y25jhdKlCmFo%2F2bo2K5mguf7r92jbvFtWPGRYR7xDezVGEtWbOceRkQZklG6DmQ3TWp2W8j5mdrPOLLbhyhrSO08TC52%2BxARmSCGPxERw5%2BIiBj%2BRETE8CciIoY%2FEREx%2FImIiOFPREQMfyIiYvgTERHDn4iI0lOWubBb%2FOveEBGRCdT85UWReKEzIiITC38iIkqZLHU9f9b%2BiYhY8yciIoY%2FEREx%2FImIGP5ERMTwJyIihj8RETH8iYiI4U9ERJlNlviSl7c79NyU6YtfqCNi%2BGcIh3Yt4tZMJ7yIHlHmx24feuPWFltcRAx%2FIiJi%2BBMREcOfiIgY%2FrF4tggRmTqj5aDRwr9qYVhzuxORKTNmDhot%2FCPtkI%2BbnohMmTFz0Gjhb65BGW56IjJlxsxB4%2FX5a%2BDLTf%2FmQu89wuMnz7giiDIzI%2Bag8cJfj851XDN3v78M4D%2B2HE4wbMHPWzDjhw1p%2Ftojxv6ITX8dUn%2F7r92Dz%2F63IsnnbBLLeu9BOD9wRBmAyj%2BRg6YX%2FsDJcBu8n5k3XvDlW5j0rX%2BCYV4ViqNKpdLpuhwe7s6oU6NsktN9Mfk3XLp8m586ogwgNv9OGuv1jXZtH3M9hmg12OflhmNHzmJjer3u8VOXsXzVv7j%2FIAKFC%2BZBZ79aKFGsgKFmvH7TfkRFRaNpA2%2F4talueN7%2Bw0FYu2EfwsMjUdbDBZ3a1VQ17rDwx%2Fhu1no1Te9u9fH02XM8ex5teF7QhRtYuORvXL95H5W9S6Jvz4awsc6mxs2ctxEN63rit7W7cTboGhrX80SPzilvBT5%2FFo2IiEjDY9ka2fzPEWi1OpQsXhA9xTzl8oeFP8GK1bvw757TqFq5tLi58RNIZAQi95qLu1EiB31EDp4zqZr%2FgbMI0mngp9Fgibc7JpQoAau0fs3rN%2B6hU%2B%2Bp8Ba1844ivB1yZMe%2Fe0%2BrcQsW%2F405C%2F5Atw51RFjWww%2BLNotCYpca99fWo%2Bg%2FbA7eKVcUzRtXwplzVxFw8BycHB1gYWYO50KO6mZuYY7dAWew7d8T6nkh10LRrtv%2FUKpkIQzo1QinAkPQT8wnzvdzN2HAyDmqEJLB%2F%2FW01dix%2B1SK39fRk8H4%2Fc%2BDhuD%2Fcoo%2FWjSppG6h98Jw5vw15M5lBwtzM%2BR1yqmWNYd470SUvmTOybyTuSfzT%2BagydX8VWgFYquofPpEazDbwRKDvdyxHHpsM9ch0DUIIf6ANjVf70LwLVhls0AjEbQy%2FHxrlVPDdTo9ZszdgE0rJ8DFOa8aNjK8JZau3IlO7Wti%2BpwNGP%2B%2BH96NbQk0aeClnpM7t51oKRxI0EKIb%2BmKHWjo66laBFJFrxKoUG0Ezp2%2FjtKiQJAWzhqK4kXzq78PHrmAo8eDk9WF8yqnz15BMdd8qFuzPCwszNC4vpdhnG12a%2FWeK3qW4KeQKB34AeaXS8FFawYPeXBXA3TSA6csRI3%2F8BnjBb%2FRwz%2BuBSDuGniWQQUzPdqKv4fpzFEy2B0u3qn87beqVUqjfBlXvFNjJMp4FEGtah6iRt4YT548w4MHEejQc0qC6WWXiXT%2B4g3xPJeETSazpBftUshtVPYqaXhsbZUNRQo7IfjybUP4x5%2BPvb0NoqLfrrzr0LYm%2Fvz7CMpWHapaODL8u7xbO1nL%2ByZ4ZU%2BiVwuG%2BnyEiE%2FfeZFmAaK23%2FjoaRzPCMuWYa7nH7tC3milJDeAsllaYPHc4bh95yEOH7uounbk359%2B2BEa0Q7btOpj5Mll%2F9Lz7O1s8PDRk5eGa2TZpH%2F1S9vaWuNRvL54KVw8trdL%2FCQnuQxvq0hhR2zb8IUosG7iyPGLmDx9DaysLA2tFr0%2BdbM6qR91eU3NZ7Axm7xEqaGyG0rJnguxX5cV%2B3Wa9lykNpO6sNvJwBCcDbqOfHlzomlDbzTy9VQHfmW4V%2FdxxzfT1iA6WhcT0uGR2L4r5kB8vTrl1Smc0VHa2JbATdXvn8M%2BuzrdU06bmHq1yqtuofDYAkD254c%2FjoTXO8XT7D3KZZbLVLJ4AdEKqIGy7kXEe4w5vVMe47h46Va6rnP5ATgYhGB5UP%2FIGYwKi4Kr%2BKDslAf7PT1Qj%2FFBmZXcf%2BV%2BLPdnuV%2FL%2FVvu53J%2Fz%2BjBn6Fq%2FunhSeQz9B82TfX3yzNu5Jekfvx%2BsBo3c3IfDP1gAcpXH46cItQfPHqM%2Fj0boW7Ncvh4zLsYMmY%2BKtQcAQe77Hj6PAqLZg1FhXKu8KlUCj4NPoCluTnWrxif4PXkAVfZj1%2B9wYdwccmLa9fuYs6UAchuk3bHtkOuhGLgyLlwLZIXj0Sh5CxaAp3b11Lj%2BnRvgI%2B%2BWKqOYcgD3iMGtUj3bXDhAuQ30ybJs7xEzcNfHvNhC4AyY41fq4e%2FaEh3T8%2BzFVOTUa4oJ7tpUvM3YOX8UvIzjteu31N94AUL5H5p3MOHj1XtXJ6B899uGHlc4HlUtGo5xHcnNAzWVpavPIMmLOyx6v7J75QTltnSvryNeh6NW6EPkT271UvdWLIVEhHxFAXy53rj%2Bcf%2FGce32Y7yrAdxV0vMoyHjhDITse9uEXf%2Fin13UkbLQ9b8X6NwoTyvHJczp626JSZXLrtEh%2Bd1cnjt6zk42Kpbcq3duA%2FLVv77yvGTJ3Y3nCGUGFnAyNM5EyO7uOQtI7CPxJRwGwyWB%2FszykEwoiS7e8T%2BCh3Kif23ZWZ%2BHxbclBlPm%2BY%2B6pbV7biMp94e%2BNVMh3YAw58yB7W%2FavCr3H8z9fvgpiSj0mObHqjKFUGZZ5cV%2B6vYbzN9IcZNScak1eO0BijFNUGZhdxf5X7L8Cd6CzYRkFeac%2BKaoEzEKXa%2FZfgTvamAa6rflD%2FpSZmJdex%2By%2FAnegt6GPFHrInegCZ2v2X4ExERw5%2BIiBj%2BRETE8CciIqPLMt%2FwjX%2B9GTJtWfk3BlL7mlimsk8Y49o5DP903LD8YRGKk5IL%2FZlyBScrridWDJOH3T5EmaxVw0oO1xtr%2FmzaERGx5k9ERAx%2FIiJi%2BFMGxks8UGaRJS7twPCnjOJp1cK8uBtlfLH76dOs8F4Y%2FpQRhEbaIR9XA2V0sftpKMOfKBWINnSQuQZluCYoo5P7qdxfGf5EqUADBIj%2FfLkmKBPsrL5qf80C%2BAPuZHQ6M6w202FzHVd8lN4%2Fij1q%2FCJcuXY3wbCyHkXw2Ycd0XPgTEQ8jlmcPLntUb92efi1qZ5g2qALNzBz7kYcPnYBGo0ZqlQsiRGDW8KlcMyPk926%2FQBDxixA%2FTrlMaBXY8Pzbt56gKEfLEDdmmUxuG%2FTDL19LoXcxpiPFxseTxzfEWXciuCjL5bi3PkbaljuXHYoVaIg2rbwQTHX%2FIZpl%2FnvxNoN%2B1%2Ba51efdFXTd%2Bs3HVqdFvOmD4K9nY0at2P3Kezdfxa9utZT6%2B5V4pYjvYj90zpcj85if23M8CdKBUdP47i3O06G2%2BB98XBSer728VOX0KxhRVStXNowzMHBVt0fOHIeHwxrg9IlC%2BJC8C189d0q3LrzEEP7N1PjzwZdR%2BvOX6FXt%2FoYKQJfp9Nj2codaOb3Bf7w%2FwRFCjsi8ulzHD56AedFIdGhTQ22cGJZAAANE0lEQVTkEiEpLVi8BafPXoFzoTwZfvsULpAHkyZ0Qb2WH2PjbxNQolgBNfxkYAiqeJeCb61yuHc%2FHFt3nkCjNhMx5cueaNW0iprmytVQWGWzwJB%2BCQu4AvlzqfuDYh0XKpgb8376C%2B8Pba2G3b37CGfOXUPOnLYYPaSlGhYdrUPHXlMwa0o%2F5M%2BbUw1zLuiYrushdv88KfdXhj9RKjHXY4hWg31ebjh25Cw2pudrly5ZSIS%2FW6LjZCugomcJNf5BWAR27DppCP%2FJ01ejVbMq%2BGB4G8P0n43rpAqI72avx%2FSve6thVtaWaNG0EhYu%2FUcF3KNHT7BpyyG0ae6DyMhnGX7bWIrwlgEdF9pW2SwN42RBELfumjeuhBZNKqPfsNmo5FkSBQvEPMfJyeGV61caIwrYEeMWomcXXzjmzmEYbm2VzfC8qOfR6t6rQjG4OOdN93Ug9svmsqEo9lOfrPKZY58%2FZQgHziJIp4GfRoMlohUwoUQJWKXXa587fx0BYgHibs%2BeRyU6neyqcXaO6c6RtfxdewPRtuXLWSBDfeeuUwmG9X%2BvEX5ZvkN1Iy1evh3tW1WDnW3WO7tVtgLc3Zyx6a9DhmGhoWEJ1q%2B8hUdEGsa7lSqMRr6e%2BH7upgz3fuR%2BKPdHuV%2FK%2FVPup1llW7HmTxmn%2BycQW0VFzydag9kOlhjs5Y7l0GObuQ6BrkEI8Qe0afG6G0VQ7T1wzvB4znf9kdfRQf29YvUu%2FLvnNG7dfog9%2B89g%2BaL31fAIEV6ySyeuCyK%2B%2FPly4e79R9DrX3wXyLmQI%2BrULIsFP2%2BB%2F7q92LhyAuYu2pwlt6OrKCCv3bhneBx49iqmzvo9wTSyz9%2B%2BhI3h8WjRImrQ6hP07dHQqMvuJxqhl0vBRWsGj9iDu53EVjxlIWr8h89kneBn%2BFOGbAGIuwaeZVDBTI%2B24u9hOnOUDHaHi3cafQt49JBWaNao4ivHR2t1WLMhAN9%2F20%2F140s21tlgZqbBo%2FDIl6YPD38C2%2BzW0GgSLu6gPk3QsM2neK9LPXWA9G1k5CtUPgx7jOJFCxge1xaFXlwX2KvI9SoPpk%2BdtQ7Vq7in2bIltd6CY769GyK23HmxtwWI2n7jrNLHz%2FCnzNEKiPnAHU%2BLD3hKdGxXU%2FX5l3EvgpHjFsKliBM8SjurfvCy7i6q66ech0uC5%2BzedwZe7xR7aV7y2MLIQa3QoW2Nt16u1LiCbVoUIDdu3keAaEWNG90%2Bxc8dPrAFajYeB8c8OdJsv%2BKVf19gnz9RMjRr6I1BfZuge%2F%2Fp6vRNSZ7BMnPeRgQcfNFltH3XSfy4%2BG8M7pP46ZsjBrUwnOmSlYSLFtCWbcfg1%2BMbdO1YRxWQKeUkQr9X1%2Fr4edk27nCs%2BRNlHMP6N8fF4FvoMWAG1iwbp7qKwh49Qf9hc1RLQKfTqem%2B%2B6oXqvu4Z5n3LQ%2BIdxOFntSi45eYN22gaNkUV4%2Fl9yTkLbuNFUqXKqTOhJKtpfj81%2B5Rt%2Fg2rPjIMI%2F4BvZqjCUrtnNnSwdGaQLJ5iabX5SW%2B1d6%2FjyhPPPn%2Bs2YA5zywG5aif9zhKnV7WNqP%2BOYEXPHWHnImj%2FRW5IHftMy9InSZL%2FlKiAiYvgTERHDn4iIGP5ERMTwJyIihj8RETH8iYiI4U9ERAx%2FIiJi%2BBMRUTri5R0oS4p%2FPRfieiLW%2FMkEyItk8cKBXE%2FE8CcioowgI%2F8EHRGRKeQha%2F5ERCaI4U9ExPAnIiKGPxERMfyJiIjhT0REDH8iImL4ExFRhpUlru3DL41lHrycABHDP1Ud2rWIWzOD40XEiDIOdvtQurfS2FIjYvgTERHDn4iIGP5ERJSlwl%2F2%2BfKsDyIydZrYPDSZ8H9atTCsud2JyJTF5uBTUwr%2F0Eg75OOmJyJTFpuDoSYT%2FqKNE2SuQRlueiIyZTIHZR6aTPhrgADxny83PRGZNJGDKg%2BNwCjf8NWZYbWZDpvruOKjHZfTt79r1PhFuHLtrvrb0tIcZdyc0aOzL5wLOaphnftMxfPn2pi%2F%2FWqhbQsfLFm%2BHb%2F%2FeRDvda2HZg29DfPq2GsK5kwdgNy57AzDflmxA%2Bv%2FOIDPxnVEWfcihuE7dp%2FCrPl%2FxJT25mYoVbwgenbxRfGi%2BRH1PBoDRs1Fn%2B71UbWym%2BE5h45ewPyf%2FlKvYSGW9VW0Wh06vDfF8Di7TTZ4li8m5tcA9vY2atiHny1B4%2FpeqFOjbKLPX7jkb6zduB8PHkYgX96c6NC2hnr%2Fcb6btR57D5wzPC5dsiA6ta%2BV4D0SUfKJ%2FLMO16OzyMPGJlPzP3oax8XdyXAbvJ%2Fer3381CVUq1wao4e0RN8eDRF8%2BTa69p1mGP%2FNxJ64E%2FoQLRpXRIM6FdSwy1fuiFAMxxeTf1NBHWffoSBRUEQlmP%2FcRZvxMOwxflu9O8Hwu3cf4e69MPW6%2FXo2xPOoaDR79wvcuRsGy2wWqF29jAjoXwzzj47WYeynS1C%2F7juvDX5JL9qNAQfOqrCW85f3f209qp4f52RgiFqGxAwf%2ByNWrtuLCWP84L%2FkAwzp1xQz5m7Al1P8DdMEXbyBIoUd1fxHDGwOnU6Ptl2%2BRnhEJD%2FFRG8gNv9OxuahaYS%2Fqv3qMURWxL3c0Dy9X7t0yUKqhu1bqxz6iiC%2BcfO%2BYVzhQnlUi8AxTw5DrVmqV7uCqhH%2FsnLHK%2Bcra%2Boy1L%2BY0BnrN%2B1HdJQ2wXhbW2v1uvVql8fkid2RzcICh49eVOO6dqgDOztr%2FPDTZvV4weItyJXTDn6tqyX7fXmWL6rmL2v4fm2q48at%2B0kXxMeD8ceWw1g6fwSq%2B7irFlADUeAsmj0U83%2F%2BC9eu3zNMK8fJ%2Bdeo6oH3h7XG4yfPEBb2hJ9iohSKzb1RsTloFEYLf1FRDdJp4KfRYIm3OyaUKAGr9Hrtc%2Bevq5ryzt2n8cOPf2L00FbJet640e0x84eNKvQSs2r9XrRp7gOfiqVgkz0btu8%2B%2Bcp5hYnWwZPIZ3Ap4hSzIcw0%2BN9n3TF7%2Fh9q2WYt2KQKCI0m%2BV%2BHOHriknru39uPYe3GfaoGnxTZHVVVtITy58uVYHgZtyIoXrQAdu8LNAy7ev2umr%2B8fT11lWphyMKSiJJH5pzMO5l7Mv9kDhprWYx6Vc%2BjgdgqKpI%2B0RrMdrDEYC93LIce28x1CHQNQog%2FoE2L19341yFD%2F3Xw5VsieM3wbpsaCfruEyNDvVwZF%2FwoauXDB7ZIME5212zYfBCrl4xVgS0LgVXrA1QtOs6t2w9V37m0%2BZ%2BjorZfGx6lnQ3jy3m4qL72jr2nYnj%2F5up4QEosWvoPrK2yqX6gq1fv4p8dx1GnetnXdhuF3nv0UvDHyZ8vp%2BqWirN3%2F1nD8ZIbN%2B4hj2MOXLx0K8XLSWQq%2FADzy6XgojWDR%2BzB3U564JSFHj6Hzxgv%2BI0e%2FnEtAHHXwLMMKpjp0Vb8PUxnjpLB7nDxTqNvAY8e0grNGlVUf8uDnX2HzcZ3s9dj0oQuST73w1Ht0L77N%2BjesW6C4f%2FsPKHuT54OUTeN%2BPf3tmN49OgJcuTInmBa2f%2F%2BPCoKY0e2e2n%2Bg%2Fo0wcJf%2FkH3znVT%2FL6%2B%2F6YvirrEfH1Ctk6atv8cK9ftSXDg9r9ss1vhbryAjy884insbV90fcmCaeTglobH8pjAuIm%2FYOXPY1K8rLyyJ5mC4Jhv74aIIDsvIiFA1PYbG6uPP8OFv6EVELNC3milvE2QyDNv3ilXFPsPJa8Qlt0hdWuUw%2FfzNyUYvvr3vXArUUi0KM4ahuXJY69aGXHhK2vSo0TBI48FdO77HYa8Px8LZg5WXT5x5MFf1Q2kebseORnq8tiGPFj9Ol4VimPlmj3qWEU2yxe7w%2F0HETgdeOW1BaJ87rpN%2B99o%2BfijLkTGZfIXdpO18BWrdqFW9eR%2F5%2ByDEW3wq%2F%2B%2F0EbH9Eo9fPgY23aexExR8572dW%2FDrXe3%2Bli9fu%2FLJa6lORbMGISgCzfw%2BTe%2Fpfp7kmcKbd91Ejt3n0Ktah6vnVae0SQLqQ8%2BWYynz56rYbK1Is8AqlyxJCqUdU30eSHXQtUB4VrV%2BF09oszIwhTfdL%2Fhcwx%2FywOWndvXUqd9SrWajMeV63cxfuJS3L33SH0H4L9ci%2BRF6%2BZV1Dn90u9%2FHlCth0IFEx78bNW0Cr6aukodKP0vBwdbLJk3HM07TEJRMb%2FEXielajQaZ%2FjbrVQhfPVpN3VmTpzhH%2F6obnFkgbd84Wj8%2BuMojP7oJ5SvOhy5c9nj3v1w%2BNYuj28%2F75dg%2FlO%2BX6duqlUjpmvZrDLGj27PTxFRJpQlmt6y24c%2F4%2Fj2HjyIQMSTp8iZwzbBaa6pJf7POLLbh4g1f0rCiHELE5xvH59suUz%2FuneqvE6uXHbqRkQMf8oAUivciYji8Je8iIgY%2FkRExPAnIiKGPxERMfyJiIjhT0REDH8iImL4ExERw5%2BIiIwoy3zDN%2F51Y4iI6PXMs8KbuHkXE%2BWtoBM%2B4ybNPNuMa4HIeNjtQ0RERERkCv4P0mcxEcIS6ucAAAAASUVORK5CYII%3D)

```
load_data
         ::= int_const_expr
           | STRING_LITERAL
           | IDENT
           | section_list ( FROM IDENT )?
           | BINARY_BLOB
```

referenced by:

* load_stmt

**load_target:**

![load_target](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAR0AAABRCAYAAADvh3LYAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAEcpJREFUeNrtnQdUVVfWx%2F%2Bv0EFFmgUDRkVRbIA19oJmaUxsoyb2Fo1RR41xYuZLNGtm1Ilx1IkxGY0FY1TQWMZoEhF1grEBmoiKiAICgoAgSOeV75xDERV4IK%2FC%2Fq311iv33dPuPv%2B79773vQMQBEHoEYmxNEQdOtfs4IWLi29GZUy9fTezTXpmoUVqen612%2Bdgb6GwsTJ77NjY4lz0%2Fbw1Zy7lhtWFA1Tdcamr%2FSdIdHTCqV0%2B84%2Bfjv88KibLZuSgFujj64wmztZwdrCsdhkpj%2FKRnJKLkNAUHA26r7A0l4UmpuVODovAXVM9ODUZl7rYf4JER%2FtncfUqacDmQwe274saN3lMK0wc2RLmZtJal1tYpML%2B4zHYvj8qP69IPSb0uvKkSXk3tRwXU%2B8%2FUbeRGbLy9o0fBew4cGfc%2Bo%2B7wa9PM8hk2tFAXk5nz8bw7eQoP%2FVr4kQne1XCg1RcNZWDUttxMfX%2BEyQ6Ogsd%2Fr371nI%2BsTq2tddJHS6OVvDt6Cj98UzCKCcHdXyyCUw8bY6LKfafINHRTfgQOtds877Lp4f1dzXnZ3JdwideXoFSEnErY0QzJ4SyM3600YZVOhgXU%2Bo%2FUT%2BQGqJSfjUmOu6JDc9V6IN3J7WFublUrlLjgI8XWhnrwdDVuJhK%2FwkSHZ1x807GtOH9m2slaVwdeD3dOzvxrLkcSqw31oOhq3Exlf4TJDo64%2Fa9rFZ9fF30WqdfPxGuWLFHn64d0NkYD4Yux8UU%2Bk%2BQ6OiMR%2BkFls2bWOu1zvatGxW%2FkCBFqsJYYzwYuhwXU%2Bg%2FQaKjM9KzCiQODS30WqerS9lktmWPocZ4MHQ5LqbQf6IeiU4PL1Tp02vaXlNUSjWkMv3el1han1qNxuzpFWM8GLocF1PoP2Hc1FYHSvcXolOkxAMfTwRUVqim7bpk56FYHAt6gCKFSivlSYrP9C711XDqe%2F%2BJl%2BdldaC7J0b7tEe8QokY%2Fl5eYohcfMYrlWyjJw7LZVh4KQIPyxlqldt1SURUFvx%2FiIOLgyWmjH4F08a6oYmjZW2LldVz%2B5HRFCJe4oRVIx3gYqOUYDNz4F2hfvq5vPyX1MXvKy1U03ZdsHa5F%2Fr5OmIXE57126OwcecdDO%2FfBDPHuaNvN0eyBILQM5p0oDKxqVB0Kiu0ppVqEzO5FG8ObSYed%2BKysetgHAJOxON4cBI83G2xf3MPtGhqTZZAEIYWHwlOKoDPKhObKkWnFBVwjflTw9UatisUiGGVWum6ky1dbdDLuzH%2BiHyMi9fSEZOQi%2BwcxUuVxdqrrs8GU9%2F7T2gPrgMs9BqhUGMce1ZpMix5JbHbb2zHRPY8hBW4nT0vqWq7mRzrauLp1NTgk1LzRV7nuyP3kZyWL3I6H85tK3I8L5vfCbtV9d96jAdksR5wU0rRnn1zEPvyJNboCLkaCy5HIsrQQnD593QUsaPcoU0DNGpgpvX%2BE%2FWL7u3goZBgCzMKL2aE%2B5glBstUuOkehbhAQFmRfZbXAfb8jaUZduQXYSZzRGarJcgE93g0iU5pIeriQi6ZyeDJxYRVtqSq7bocjE27o7F2ayQUzGfr4%2BuIf3zghdcHNIFcx5fcxUBH4R57yR%2FHW7fGRw3NsJzFqhe7tsf4qzdx2pBGMmXZFaRnFuLQll7o151yW8TLw%2Bx5MJtegWxGbcgswsjoaBSUbrtShVNSiQ4s7eGFdUVKrKhMfMqLTqAGMQnUp9iUkpJWgOlj3TF9nBvatrQz2IEpORB%2F824nQspAdmboqSuPhyD06eFwwVGrMTU8Esercz7WpAMln1UqPqWik8cKSahCTDRt1xl%2FX9bBqA4SPzDM89vAPJ4v2Vs%2FQ7XjdtAwmjFErSmx4w3VFJwa6cDz4sM8pHlloiOXoWVVhWjaXt%2Bwy8P6J1ZYwH84efUGfqcRIUwyrOI%2F%2FFWhI7PnUdX5%2FsvqQHnx4e%2Bl5T7UtJPW4Lfk81v%2B9Ul2TpHWyjobi3wW2H6v7R9O6nJctNl%2Fom4g7JfZsbDn6ovHS1O6v0F%2B8NnIzlzxKLNAr3Xeic3SboFqBDN56GUq46L1%2FhMmj7BfZsd6FzuDhCc2Zo8Tk3P1Wufl39PEs0SNJyi5BFirWFiNGyxG9TCVcdF2%2FwnTh9svt%2BN6IToO9hbnQkL1myI6FfKgWN0lSGFPta7cKluU4WQq46Lt%2FhN1AqcSO677osNXoPwxOEHB12fSBzEJTxCbkF3aY37fzf3alnkhQcTBlqYwLrroP1EnsCyx47ovOnzJW3MzaShfEE4f%2FGVdWPlANoef%2BLUTEmv3rl5djYuO%2Bk%2FUiQhL%2Fz%2BHkRqqt3zJW74C5fXbGTqt55%2F%2FicDduCelE%2B4ee%2FiopDhkrFag7XExtf4TdR%2BDiQ5fY7uwSD32%2FU8vKnUlPHzCBZT3GiQIYdJ%2BxZjvrdHmuJhi%2F4m6j0H%2FzCkxRX3HwV4VfzI4YVRugVLStb2DVpYW5jmMeR9fQMiVh%2BXDir1s0vmxHk9KSoFWVK6ZE1YlpWG1sY2LvvpPmDa6sl9NyA3d8fCb2OnrqZLuOXT36%2F3HYuQ9uzhieH9XeLRqALdmttUqIzdfwZdvweVrqQgKecAmXfbz2Ze94pfiEswIZZ6EKRhETcalLvafqLvIjaERobfwrXcHdaKyUBl47vJDGXto5795eA6DhRTg%2FwkkxbSwG%2FjJlA5OrcfFxPtP1E2kxtKQcDYhJDJ0YS9%2FZpPlEQsmItgjnk2anBoUk832iZGqWRnAYTVgIf6IXI7e4SY64Wo4LnWu%2FwR5OjolrNj1H81%2FiFbyuyY%2FqNj0ksCmmkXYqtV4rJaAryx3WS3D6tA6kDStwbjUyf4TJDo6p%2BTqCn98QoeIxoWg8IogCIJEhyAIEh2CIAgSHYIgSHQIgiDRIQiCINEhCIJEhyAIombIaQiMB1pfnNBEXVgOmkTHyAj9dQcNAlEhvn1nUnhFEIT%2BvWFT94hJdAiCINEhCIJEhyAIgkTHCND6MjQEoScMsvwMiU7tye%2Flqt0F9whCH5TYbb4h6ibRqR2pebZwoWEgTI0Su00l0TG92CpKJkEHGgnC1OB2y%2B2XRMf0guILfGkXY29nVlYuMjKyK90en5gGlYpuhq5nxjtI2C%2BJjmkhludV4%2B0B7sad19nufwpr%2F1XxSsJFhQr0HPwhHmfm0AGtJwh7ZXZrqOWlSXRqQckfpV9%2FYoUPaDQIU6HEXq8banlp%2Bu1VbWNjNd5XSnDRux2uhUfiuL7q3Rt4DqHh0chkoVOzpo0xc%2FJgvOrepGz7voO%2F4qegcDg7NcSj9CdwcmhQti0uPgVfbf8JKamP0aVjy2fKDTh8Hp06uCM5JQPh1%2B5i5PBu8GjdDD%2BfvorDxy8iP78IwwZ3xaRxfcX3c%2FMKsH33KUTcuo8Gdlbo2a0txr3ZW2w7eOQ3BP%2FvOuRyKdp5uGL6O4NgbWWhsW9hV%2B9iT8BZpLN29%2B3dQfRNJpMiv6AQX207iTnT%2FHD851AkJadjyYJRkEgqv2vhzt0khF6NRv%2FXOuBHtk%2BDBtZ4c0R3fPHvo3iY8pj1p1C0be6MYbC1KXZY%2F7XlGEYM88V3B87ibkyyeP32%2BH5lZfLyDvwQwsYvE316ekKpUmHezOFiW2GRAjv2BOG3S5FoyOqa9vYg%2BHZtbTT2yux0JHtayuy2p6HaQJ5OLbkciSiVBOOZ3fv7eOKvrVvDQh%2F1pqRkoruPB2ZPHQpzMznGvLNWGDxn09b%2F4pudP4nJ37tHOyE6paQ%2BysKoCf8QE2LyhAEvlBvAJtO0%2BRvxrX8QnuTkI49NSv99Z7Dhy6OYOLYvq2%2BImFS7vw8W31%2F28U5ERiViOptc3bzbCKHj7Nl%2FFv%2FZ9QvGvdUbw4Z4s8n%2FAPfj0zT269ofMZj23ib07t4Os6YMxakz17Dys%2B%2FEtvy8InzB2vHWO2vExE9j%2FVJrSEVF30vC378IxJR3NyIx6RHSWP95OUqlCn6DumAiE8%2FQa9FY8cnusn02bDmK%2BUu3ChEfMqAzVq3Zh4uhUWWCyMtq1bIJE5SBuBf3EF9%2F%2B3Qdw7mLvsLtO4l4f%2B4IDOzXCTPe2yzaYGi4XXL75HbK7ZXbraHaQp6ONsKsmzjN5khPhQRbGpphgbcn9rGYOVimwk33KMQFAkpt18nP8NlMFLhBD%2B7fCbv2BrNJnQr3Fs7YyiZBwO7lwmPhxMQ%2BFGd1zvcB59Ddtw1WLhsn3vfr1R7%2F3HT4mbJns8k%2BZ7qfeK1ms3r6vE3Yv%2FMDtG3TXHz2waK3RB38LH4zMp55CX5C3DgTxvQRzzci7zMPojkG9vUSnsgIP59q55%2B4gP1p9GvivWdbV3QbuAwfLRlb9p1dWxehRXPHao%2BVg70dThz8P1iYm5V99smKCUy0stj4JbM2dmIie%2BqZffy%2F%2FjOaN3MQr89fuiW8vp6%2BHti64yTmM6%2Bm1LNxdmqEk7%2BEidfXb8YxwUnA%2BV%2FWQSqVsJNCG1xiYnXiVBgWvTtSrzY5njnhsR5wU0rRviRpPInpc4SceThhtwwnOCQ6WvZ42NNQsQqnGmPY60UqGdrc84Sbj5bvWuZn6ZWr9%2BAX5gV09moJ%2B0Y2QhwUChUSH6YjJzcfHdu7VbhvJDsLl4pRZTg7Nyx7%2FfhxDlLSMjF13kaxpGgpbq84i%2BfF899gnsgebPnmBLy7tBJnf%2B7xTJs0ELMWfAmvXovg26U13ni9W1nYVRX3YpNF%2BFbWFhYe2tlZIy4hFW6uTmWf1QQeUpUXnOSHGZi35GvhAXbwbIG8vEIRIj0TAkifBgF2tlZQKIvPGzHMs%2FnT6D4V1hMV%2FYCJeyZ6D13xzOflQzNtoemX5veK7zaOY0fsDjtsF5h3M%2Fyqkaz2SqKjba%2Fn6SqcWjekUs6dv4EzIREI%2BXktbKyLo7lTZ4urtGSTi1%2F%2B5l4QnyzPY2FhhifZedVuk5W1ucinHNm7Ek2b2L%2BwfcwbPTFimA8ibtxHEGvDxBlfIPTseuahtMBvQetw63Y8roRH41MWotg3shVeWVXYsjZnZeeWvedCmptTUJZv0QZbtp1E86aNceT7j8pCujmLt1T6%2FfI5I1sbKxaiZlbcdtbGlu4uOH3sM53bmSn%2FmRfldEyQwsIiyJj7zhO0nJALN5GTXXxHu4tzI%2BERBB45L94%2FyniCy%2BF3yvbtzryQEywc4KLEOVmSg6kMSwtz9H%2FNi4VgP0BRVHy25%2FuePveHeH3kx0uQSaTw6doK781%2BHQqVknlaBSIXk5mZI8RnysQBaOnmIhLDmhjUryMCfjhflp8KOBwiEuWvumvvxm9eNhffUlE7%2Fb8%2Fqr0vz%2FHs%2FC5YJM55yMUT26XwPFQS86IOHXt6%2Bwv30LioEeTpmDSD%2B3XCdv8gdO27lImCmbg6Ym7%2B9FCuXT0Vcxd%2FJc7oIon4atOnsT4LcfhVHO%2B%2BSyBlHsywQV011rdhzUwsXrENHV9bDPsGNsjIyhF5F%2B618CtUf1nlj3ZtXEXuaMn8UXBt7iBEb%2BHybUIsePK6s5c7Ro3orrGuWZOH4PeIWPQasgIuLIziyeJtmxdUeYWqpvDk%2B4QZn8O731LxvoevR7X35fkcftVqzsIv0djeDgP6euFSWHGKxM7OCju2LMSylTvwt88DREjHr45tWDOLjLa850hDYDzw8Komf1ea%2BOARrKwsmPHbvrCNX8rmOYumzvaQm8le2J6UnCHO9hXtWxncc8lioVnzpg4iUfr85w6N7Z65JM4vcaemZcHW2hL2Nain1EPLZR7T83Vp09vhyfXn21xT%2BG0Eew%2Bcw8E9z%2BZxeN6Ii7qzY0Ottbn835WacnhFno4JU3p1pSL4RLJuXvlkqig%2Fo4mGDW3Eo7qf89Cs%2FFUmLk6zFlaeO%2BEJ5DnThorX%2FIoTf1QFF9ap726qMlTjIV9F8NsManIFrJTY%2BylY8ak%2F2rZuVhxeHr%2BEjetmv%2FC9Ji72ZKAkOoSh4cJ00P9DrZXHhVWb5VUHnjObOnEAYuJSYGlphqP7V4p8FUGiQxA6wcrSXNyhTLw8dPWKIAgSHYIgSHQIgiBIdAiCINEhCIIg0SEIgkSHIAgSHYIgCN1DNwcaGeV%2FX0MQdREZDYHxkJSG1fzRzAmraDQITbZC4RVBEARBEISx8f%2FrTwtRODMf6gAAAABJRU5ErkJggg%3D%3D)

```
load_target
         ::= '>' ( '.' | address_or_range )
```

referenced by:

* load_stmt

**section_list:**

![section_list](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAL0AAABRCAYAAACHUafJAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAADXBJREFUeNrtnQlYFEcWx%2F89wykgcmoAxQRQQREFYjDiEQweiZv9vI%2F1WmNiNsZ4bDySTbJxN18SjdENJsbEIzGXBx5rlJjEeLOe4BERFJEjAoqA3PfM9FY1R0CBmdEZZhje7%2Ft6enqqu7q76t%2Bv3qvprgYIoo0hmOqJiTEvmu88dXp%2BfGLe9Gs3CnzuFlRaZt8tv%2B98nRwsFTbW5vnOjpbHkn4ve%2F%2FImdJYkgWJvtVx8Kugv%2B0%2FdPPDxJRCm1FhnREa7IpOru3g6mR137p3cstx%2B04pomPuYO%2BvvyusLOQxGTmlU2PjcIPkQaI3fusuviPbEbFr%2B8atieOmjvHCpFGPwsJcpvH2lVUqbNufgo3bEsvLqsQxMZeVB0gipofclE7GzzF3x%2Bbt18et%2BsfjGBbqBrlcu2uarx%2Fg64jg3s5mB09kTHJxUKVnZuMCyYREb7QuzdotCYu54P27OzxUXh2drRHs7yyLOpL%2BnIuTePM2CZ9Eb4xBa8TWs4eGD%2Faw4BZeF3Dhl1UohbiEvGfdXBDDLH4SycU0kJnCSfBemqS0Ihvuw%2BuSOZO7w8JCZqYSsT2oF7xILiR6oyH%2Bet6MEYPdtQpaNYHn1y%2FAhUf7ZlBiFcmFRG80XEsu9AoN7qiXvIcNktwlazaF9u2JAJIMid4oyL1bYeXeqZ1e8vbz7lD9RcAdmQpjSTIkeqPgbmGF4GRvqZe8PTrWXUy2bAonybR%2BzEzhJFRKETK5fv5nq81XFOEomEh5kegJjRCqLb01lQS5N20NORUBiZ4gSPQEQT69hvA%2BcJmIMRDRny36sMkTRngXaJAvO0JCE3g5pbHpOqvFUyoBuy9cwSUSPaNfD3RTCPhUUKEXK6WtrKgi5CrEd01EWiSg1LUQE24U4W5%2BJTw6WcPTXfu%2B%2FdgE033wRpeMZ%2FFPajd4KmXwY4thzKD9FOiLODMRc89eRWKbFX1fPwxViohkKlpdUIVRSUmoqE07p6d9zloag6S0YuzbMOCBRE9ohmSwEpHMvvJpv7c3Xrc3x2KlgNOs3sdfiMehNufTcwvPrv5IUcR0Zj3frS94fXEru1wSfL8AR4T0cSRltiC8fnk98%2Frm9c7rv82Jnl3xn7DZ6vNXsb%2Bl9hkdkyPN58%2F0JhUaiJr6Xl1T%2F21H9DU3bvnblbXsnYsnzuXAz6c9wgd0JPUZkJp69zfUDXwG8emlG7cEfH80FeU6yU8uaHQrwptzfWFuLoOgRShaXFJFKtUxvN6D%2FPB9zQ18Ld6jYxBLLwL92cdhXeXXwc5CkVugPiRwdbKEQ3tzrfK%2BnlpIKtWPCA5LOmgr7g0ztN2YYb6is%2BbSxjw%2F43apXo717KXqOEAQUQQNu1AJDWI6Vv9cB20pkHWxLkaWrjJzcrA8Fh2TpZcDPRidWW2YBNxhsyySq26oqX%2BXtiR6q1PpuvHnOXxksqjD6Qo%2Bbo0uSUkvQmp6cW1J8f7m30muuqGm%2Fq3akuiFatdeN%2FCh%2BCzMZTF8oCZdsmxFbH0ftIQbfpKrLkM7w%2Fy7bTI3nPGh%2BPjIZJev5ekkv5VfxOFGWlFt9SSzKUglwy7SauvHZETPx56srBLHvvLP08qHFT4X%2FI76rYaAaGaSzhnLDVMEib6OM5eVPxaXKV6Y8%2FpJce3XCdDWx%2Bc%2B%2FMR5RxsKXsR37HO4KMcSkotpYHKPC56Px5fBvirZN7turN%2F2Q4pZSB9njBjsgW5e7eHpZttg3dJyBR8%2BBGcvZuPX6Ewm%2BuJ7vc7vmJUPEwT8NYZGMSbRGzMxCdgU2FPMUFYqI4%2BdzZKzSbtnW7kPz1wa9m2EKMOM2Cv4iaRC7o3xW3wmVEGOPuzrz0zEucwnj2PTTSbmkkZWL2ZpKTKRrQvsEQFL6UFwMzx5ngRPlr61BbdsNlp6Kqv6Po9hUDHZC7C5Z1VbUUS%2BKICP7HSW%2Be%2FLYyhoJdG3Zmp6Xfj0NlU5QQ%2BGEyR6giDREwSJniBI9ARBoicIEj1BkOgJwnCYxJ9TNL5ky2EKwxqazD%2ByMSc2kyL1TPDAWeTeEG0P3qq29paVRE9QIEsQJHqCINHrBOptIQRD6cBQoq8Y0tUwA%2F0QxkF%2FD6n%2By9uS6HNLbA0zpBthHJTZgo%2BXnt2WRJ%2BsUBnuTRSE4ZEL6Ml8m8Q2I3p2sjGCCqFU9S1PRmYubmbkQBQNHFbxoVWAUwYT%2FRO90OyrOdSlay16AVGCgAlA6%2F5LOzu3ED%2F%2BEtvgtw1f%2FYKPP9tndMdaWaXAnye%2Fh9FTP8BfZq9GcUm5wY5FiudETNF2mMSH1WHt9tJtCFVKZAb5YpeZHPPOxN0%2FHLW6dG25EI8jQX6QBfthbEw8drZW0Sen3sa7H0bimWFBdb8FBnix8jK%2BYewPH%2FsNFRVVOHNoJQTBsLamyBqvsdllbYdJfFAd9vPFaKWACIUSTmyxnVl1SyNZ%2FPGsrkazTPfcm6m69AdAxfJcxFrYL%2Fv0QMzFq0htqQK%2FFJeKrTuP425eMTzcnDBl%2FCB4P%2FaIlBbFrPbeqDOoYlbxmfAgjB89oG67M7GJ2LPvNIqKytDLzxOTxw5E5J7%2FoaCoBKs%2F2Sut8%2Fy0p1FeUYmKSkXddolJmdj09UFk3LqLfkE%2BeGHmMFhbWUhpEZ%2Fvx7Cn%2BmL7nmhcTUzHiKF9MWNKmEbnsXPvSfj16IycnELEXryBkex4e3Rzx8EjF7GbHWdpaQXCw%2Fpg6oTByGPnunXnCcnar%2Fn0B7aeR4MLtSUJ7IFRbLZILiJEe49IOx3Wil0pwqN%2B56jZPb62WXOZqkvXBmbhDwT6IYKd%2FAk2n3I%2BHidawp%2Bd%2FPxHWL5sEpyc2uPylVQcP3lFEv2GLQfx3%2F2nsWzhWKhUIpav2AaFUoXJ4wbi50MXsPTtLVi2aCzs29vgwMFYnDp3DS7O9jCTydHZ3bk6OGMFEn0qAUUlZQgb5I%2B09GyMnfYBFrz8HP408nF8vfUIXnx1Hb75YoG0%2Ftr1Udj9wylMm%2FQUunZ2wftrdsGziyuGhPbSSPQpEVnwecwNPt5uKCurwPeRx%2FHlt4fw%2Bt%2FHwdLCDP9euQPl5ZWYOCYUDg62uJ2VJx2rk5Ndi4vd2xuW%2FD2yXPDM4o2PTXjwIFadDpsSe6OibypTbXeqKUzo7wX1QKogYlegLwtuRWxXyXHOvgTJunoJW32Skm9LYhjOLGr79u0kYUrNDhP5x%2Bv3IWrHm%2FDs7Cr9trDoOXy745gk%2Bv%2Bs24c3XhuPCTWWf2R4oLSNo6MtaxnONmgR6vPttqMYFtZXagE4wYHeCHhyAa5dz0B3H3fpt02fzIPXo52k7%2BfOJ%2BHCpWSNRM%2BZMTkML88eWbf84oJ1%2BOqzV9GzRxdpecmC0fiItUKzp4cjuI8XCgpKmjxWXdPgjeHVQetkphv%2BxvCQhxF8szoUcIC1sf9qSuzNir7OBwEuyvh4jmrSFQqksJ1aP8wJsEIZyT5GylSSz8fv5tM5%2FZ%2Fojt49u6JP6EL09OuCQU%2F64aVZIyRXgLsAE2c2fMOnj5ebNL9%2BI5Nt59mwB0Cm3i9OSctCv0CfumUrSwt08XBhsUBWnejr52NnZ40qhebxgKuL%2FR9%2BcnEZMpkLNWvuWmkIt1q4C6cP1N1pmfxHvdav407MAl%2FTdd1yHbK8n1WIGMfmKnX9UmZNCPAk2zCDzZ9mGW5k84XNpZubYYUuAlx9VUAtFuxAt6yfj6w7%2BZIf%2FNnmn6Tv%2F2TuDg%2Fuona%2BBSeH%2B5t%2BO1tr5BeWNlJOrASa6fqzsbFCIRNjgyCOLdvZNv5n9MMEmNbsgjIzlyNyy1J2YTnrvcwN8TDJvfVcX4ds%2FrmVOTaXV2EWM8SzRQEF4Ba%2FqS7L%2BpmwWSTLwJdN6cxt8T2fgEXq0g0peG24HJ%2FGAsYMdHTtIAVyw5nrwQNaLuoBIb5YuWY3FIrqMe15wHrkxGXp%2B9AhvaWuSEWVssby30LCtZtob9dO6rbk6zbG0EG9JfenqEb4R6PjJH8%2FkLkauoYLnu9vVcQeVNUE0iWsBfv1qOkNydmUDk%2F%2Bhjg%2Bl8vhw2xRJFuviK2c3pyl55nwK%2BYMKz%2FfRoSsLt3oKWXB3pxX10j%2BPO9B4aLYuHZudU%2FKitmYt2QDeg%2BYjw5MzHmFJZgzczieGuiPtxZPwCuLv0DAwAWwt22H8soqbGa%2BeIB%2FV4Q83g0h4Utgzkp677Y3GuyPB6%2FcTx8Qvgyenq5IT8%2FBulUvoZ21pV7O78N3Z2LB0k3wZ%2BfgaG8rncO0iUPw9JAAU9K8Wh3W%2FLboiV5YwezU0nstv1DTbJSyTNazTBp1U9SlGxre7GnzuGB6Rq7kS7s94nhfWn5%2BiWSNuS98r7vB%2FX7e7cdbivrcyS5g%2Frq5dDE1Bg8guZvTyaUDzC30%2F4Rm7f7cH3HSKPbQlPqPCxrIvXkgHfI%2Fpbj42QG%2FxI67up%2BeNQ%2BPNpeJuvTWhod708Fdhw420tQYvNtPXUDZGPb2NtKkKXv2n8Z3O443mb5i%2BfS6Hh9d7K%2B18KA6rG%2F569wbdRmZkuBbA6NHhUgToVsd1m5PT04RbQ4SPUGiJwgSPUGQ6AmCRE8QJHqCINETBImeIAyHyQzVbSrDSBP6R24KJ3ErB8v55OaCd6hKW67Myb0hCIIgjJP%2FAwvxQyIMYiCIAAAAAElFTkSuQmCC)

```
section_list
         ::= section_ref ( ',' section_ref )*
```

referenced by:

* load_data

**section_ref:**

![section_ref](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAQsAAABFCAYAAABdcMP6AAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAD4pJREFUeNrtnQtYVNXax%2F%2BbmUGuIoJ4I7XwBmqJoFInLTE9VN610iLT9Jh%2BmJqni%2Fl58tNjF8W0zEqNrNMpb0ilkqaGZZp4QZRAVEQQgVRQ7vfbfO%2FawDQDowzDMDX0%2Fp5ns2f2Xnut2S9r%2Fff7rr32XgDDMIwBSGyClouPJ9RshZbJ6fPmb7tKNnvLJurIZjZCC8N3yPN%2FSLlWbHqGsUyv0dyeI4sFwzAsFgzDsFgwDMNiwTAMiwXDMCwWDMOwWDAMw7BYMAxjGPIIzsF90f5EHG7cLlFD%2BxnLJyu7AGs%2B3IVfjp9HcXEZ3Du5wG9QL8yZ8Sjs7Vrhw0%2F24scjcfWO%2B2jNC3BzdZI%2F7z1wGlt3%2FoxLl6%2FBxcURfXt3wdSnhyHkPweRmn5Lb7mj%2Fu6L%2FIJiHP7lnPz97q5uCP73NPlzSWkZPg75HuH7o1BYWAL3zq6YHjgcj4%2F00Ry%2FZMVXuJCQjrfeCETP7p3kbckpN7Dyva%2BxYe2cBs87jX7Xgtc%2FRRd3V6x56%2FeRkZ98fgDObRwwadwDmm3pv93C%2FEWfYugDXpg3e5ROPk9NX40eHh2xYskzmm1l5RWYEbSefrcL3l76rLwt6J8bcSMzV%2BfYdq6t8fGa2c32v21q%2B609XhaL8kr85uOJMKUCL%2BrLtKH9jGWjVqvx1LRgquyd8EHwLLR2tENMbDK%2B3HEYYx%2FLkhtBYtI1tG%2FnhMCnHtI51qm1nbx%2Bd%2F0ubAn9GUtfewre992DnNxCfBt%2BAu99tAdB%2F3iMBKhUTvfmuztxb59uGB3gK3%2Fv2KGtXF5WTgESSWRefnGcvL2qSo2pL7yPcmpwq5Y9Bzc3J5w%2BexmLlv4H165nYebUEXK6uPirJDZFWPX%2B1wj5YK68rYCERaQ1hCL6XXHnU3A1LROHfo6F%2F9B%2B8vYkEpz2RaU6ab%2Fec1w%2Brw2f7cfsGQGwVv3%2BtMTxUxcQG5%2BCKZOGoA%2BJpCBsVySiziYiO7dAky465jLZ8GEMIBvV0spa1az%2FX2Pb7yBPjK%2BUsK6iEi701U4%2BW6k6HHmishLjKdNv6mba0H7GskmjK2b8xVR89elCjZcgrrSjHx2IiooqTbrO5G3cP6h3veOvpt3Euo3hCN%2B%2BBP28usrb7iIvQHzOpcbl5GSvSetMn%2B%2Fu4lYvHycSDDvyYNq7tZG%2Ff%2F9DNC5cTMMvB9%2BBo4OtJs%2FWjraY89IGTJ44BA72NvL2F6YHYPmq7TgTkyQLVWNRUYVeGDQG76wJw7AhfSFJ%2Bp%2FRCtt9DEsXTcYbb27FwR9jdDwcwXNThmHdhu%2Bw8b05sgBv%2Bny%2FvO0oeWvaePa6S68dm4vGtt9akahUw117QLlOn4W6OiwRmaZRpjuE%2B9GY%2FYxlIhqos7MDVfRwpKRm6MapSisdNzzy5AWdpbSsHD8diYVnD3eNUOiIgJZQNAYRlozw768RilqGDekHpUqBqDOJmm1CQIJmPoa314YZbYMnxv2NwoZy7N53Uu%2F%2BmLgryMkppBCkDyaM9iOv4Vi9NJMnPoiTpxNwOfk69kecobCoMzy6daiX7jwJs7YNow30gprsQTbQfoVI%2BHghtZKcKAih0NdncYdMZSVqaD97GpaNcKc3r38RS9%2Fais%2B%2BjIAjNT7hJk9%2FZjhGDOuvSXeKGmjdeFv0WVzPyEGnjm1N%2Bpsyb%2Baid0%2F3%2BldJuup3IHHLrPM7pgf6I%2BSLg%2FiZREYIX2NRKKzwyvwJeGt1KB4f4Vtv%2F9e7IzH28cFyuglj%2FPA%2BeVLZ2QU6Zdm0ssbzgY9g%2FabvcPnKdbz5r0DZO6rLNxSeaff%2FyH0W%2FT3MF3bWbb8S9lUAy%2Bt6EgaJRS3kgJ6l60qAuoH9FRVIpkJtudlZLoN8emBf2Bvy1VPE8Eci4zFj7npsCVmIB%2B%2F3ktOMo8ay%2BJ%2BT6h0rwgERbpgSkWd%2BfrHefXm03b4mBNFuqC%2BJUIK8i3eWTTWqzMdGDMBHn%2BzF1rAjOttFKCb6X0RnZ%2Bg3v2jCqV17T2LaM%2F46aac97Y%2FBj7wK7353y56WPrEQNqztG2kqTXnyVLRfClEer1BjEq2rGspIeZsY5xgdmE7rRyjDEFq%2FdKf9dGFaWetZPEEifaUnulZawYsS%2BlOaKZQ2TqlGEHlcCdwsDWy8vdGzQsKHZL%2B%2BZL%2BtVCUOKaoQ3y0BKaFAZXNVpDZt7GVxEEt0TBKif03SiMVty%2FH2wOp13yLzVh7aubQ2yfl733sP%2Frv9Jzn21%2B5DEC7%2BDfJkxP56YcCEIdi4eb98V8ao2J7KeX3hRMx7LQRD%2F9ZHKySKg5VCQlZ2Po5RJRaIzuCwPZH1xEJ4Zf965Ul49nI3Sz0x5CU4deuBdvul9UYbFTaXlON5uvDPVEvI1ReC1OuzEJnQKpQy8KQljcILz%2BjzWNjQfu0QRFTkUwlIir6AcLEvtxzd6LjDlRKOe3thOMuAAQ2F7CTsJewm7CfsKOwp7GqoUDSGs7HJWLz8S6Sm39RsO3fhKi2pGOjdvcHjB%2Fv0xAByo%2Bcs%2BBgZWuGBCAmWr9xu1G%2BaNPYB5OYVYUVwKCrKq085g0ITcZtz%2FGg%2FdOzgXP%2FKp6RQYt44fPrFD0bbQgijuAX73fdRmm07dx2T72CsfXuGZvl47Wz8eu4KkijcqIu4I9KfPIs%2FG7drv8d%2BRZxYKxToQdocSunyKXHanTwLkYlQmhMqykRPH0RD%2B%2FWSmAhx%2F2nFgN5yyBJKV0w%2F9jDu7FFQ7BhK%2F7SpQiDMUaboA0gjoRjy6GK4ODvKcbm41bmYrrLavfZirIVYtDkesUq%2BS7F5%2FVx5zIPf8Ffh1s4J%2BYXF5Ko7YMH%2FjG6w%2FGUkKNvI9Rei8Oys9%2FDfTQvkK%2FS2zS%2Fj5SWfoe8D89CmtT1uZeVj%2FCg%2FLF8y5bZ5iTs4H4Xswy3yAoxl0UsTMerJFfJnMQbkQMRZWYS0EXYa4ueFsN2RtG98o%2FJ%2FdtZane9iHMaJiODm%2Fjc32H5rti0c3Bcr6V%2FxWl1PQ6pxU4ookw2UyUp9mTS0vxHx1RJaDSXXaSTLwm1tdEBclMlGK0wRzzbmtXrlZRW4npkjfxYCYAxiIFXmzTzY2FibLCS5mZUnDxRrSw1UDBD7q6P9Wj0DwxCj2q%2B4WyJEgwqYTeVUj7Mgd%2BTuO2XS0H5DcSzG6nxbBHn3wX1nziGGpaFO%2BEF2QRX6kZ3G%2FBHlq6yVRouEdkdjU%2FOoi2tb40XnyWnB8gAvvV6cTw%2B8On98i69XxrZfbU9DE4Y0lJGpbov%2BdAUlPl7YYlWFifSVxaJuB5Kwi4Qtwk5sDdOw4%2FNX%2FvI2aGr7rT3e%2FA%2BSqXGIdP5%2Brsb6TEN2IfuwJZg%2F5cXM3AVWqnGOYqCebPr6CLsI%2B7AlGBYLwrZAdmnasen10q7GPgzDYhGZJsfjNmx6vdjU2IdhWCyqQ3OeNvH2kQhPOciwWDAMw2LBMAyLBcMwDIsFwzCGomypJ6aOmqXaGXl8fnxC9tSLl3N7ZOWWtcrMKjG4Y9XFuVWFva0qx7Vtq8OJV4vf%2FvFE0WlLtIP2cwQMw2JRh4Of%2B8xZ8P63wQnJefaj%2FO%2FCuNld0MHNDm4uht%2BxzbhVoryeUeR6NCpjYkr61bFjHraLSr9ZFHg6DpctxQ61Dxk15QUpDNMixUKt%2Fj%2BrHevCtq%2FaEDcpcIIHVr0%2BENYq4yItISxiudezLWZO7qncFp7sF7ItIc63n3pCVGzlPq46DIuFBSOEYvP2S5PeXTIQ%2FXo5myxfIThTx3vA26utzdylx%2Ff4emFWVDw2W4pdDHmMmWEaosV0cIrQg678k4IX%2B5pUKLQR%2Ba5f5qdQKq1CvL3AnQEMi4XFhR9Rs1ThEanBgXT1by6h0BaMp8feIykhbSQP41GuQgyLRTO3b5hwyLe465GYkm8%2FeZR53nv4wpResLa2Ulapsd2nL0z1Dnce6s2wWOih5H530z1MFn8p%2B7mAhzob3ZnZWEQ5g%2B5rJ1q3EpVYbYo8a%2BzBD5ExLBZ1yCx2MN1sZheT8jwe9DXv5Ggjh8qT8Iq5Uh6UX4fXRGrskclVkmGx0I1BEhQS%2Bpgqv1tZpTadO9iZ9Ry8urepDR4yal4T2CSEPYRduEoyLBa6wXmkmIDIVPll5ZVKLk7mfeuze3uNOIn560aYwCj%2Bsl0YhsXid6qsEEbuxdMPdzNNv0VVpVqeMcqshqspT62GmOSzS1Pyku1A9pDtwjAsFr9TMw1AbL4tXrZ0A0rVnkWTOkxq7BDL0yMwLBb6YnQ15tJq4YDeGNUC7Kgw9sCa819YYw%2BGYbGoi5jCsErCE5KEL8RMZd27wyydDjl55Zi5%2BDQGjInA%2FH%2FHIK%2BgXN6elVMmbwvZnmyW8xfnK85bnL%2BwA0%2FpyPzZ%2BUOfDTkTjwgx96mYLdxJhaABnsbNFt4Yln0Qjz0R13CfpxO27L6KK2mF2PmhH1KvFdNSBFsbRbOc6x1ml%2Fc7fZ6FgmGxMMjDoNUIMVbBSo0J9HlelQI9kjzR1acZXuy798fr%2BPuQ9vhi9UCs2nQRwZ8k4MkXT6CkpBIKhYShg4ybeq%2Bhx8CTqkdnptAJXaKziiRvIoD7KBgWC2O8jOqGE9McDbWWgqIKZOWWoUc3B%2Fn7K%2F%2FohcLiSmzamiTf3Xhjrifu6mjceA1%2BspNhsWhB2FGIEb17OFo7qOTvEjXvZfO9sCSot%2FxdpeS3DDIMiwVhZSXp9RxYJBjGgPbDJmAYhsWCYRgWC52TUEjykG9zUlBYzrWHYbGwNNo4Wlfcyi01a5mXruRx7WFYLCwNR3tVTvr1IrOWeTLmpryW1MhHMwweYxgWi2bAxbnV4aNRN8xa5sGjv8lrtYQMWt3gqsSwWFgAYsaw7w6lVZSVV5mlvOS0fFxJK6i1YBL9vcpViWGxsADE1ILWKquobeHmeQhs0UqtmQzVKBSOBlclhsXCQhBTC4ZsSyiJvZjdrOWs2hSHyyn5tUKRRIsPv7SG%2BSugaCknci0D2R1dpTMHjqRP9u3natXe1bZZhGKHtvciYY8E3IyOxzquSgyLhSV5FxnqSy7OVan7DqWNKSqtlLy9XOQnSZuK6KOY%2Fb%2BROHrqhnb48RWJxUiy4BQhVFyVmJZOi3xS0tcTMyRJ2qBSWSn9%2Brsi4CF39PRoja6dHAw6vqikQkwvgJNnM%2FHD0d9ILAp0E1QLhb8kYUZUPHiSZIbFwpIZ0AcBqEKoVO09mSYmEX0UEo7SOkCtwHPR5%2FA9VyGGwxBL78PIRGKnDthBDduDlnbkBSSRcJRSYxdP2lobmE0BHZNupcZJtYRYNdDVSkIm5TCZhOIUVx%2BGPYsWhvwWruqJgEaScHSms3ZvhDeRRunT6dMBcdeD327FMAzDMHfg%2FwEp%2FejCVVvQAwAAAABJRU5ErkJggg%3D%3D)

```
section_ref
         ::= '~'? SECTION_NAME
```

referenced by:

* section_list

**erase_stmt:**

![erase_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAATsAAABRCAYAAACtxAFPAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAEQhJREFUeNrtnQdcVFf2x3%2FDgIKKBgsWNGABQbAgimDvJqtiib3HFo0tahL%2BcRPXJOYf3USjrkRdjYloNEGsa4sFJVEQe5dgBbFRohQFgWH2ngszMLQZXBBGzvfzGd7MK%2Fe9ue%2Fc3z3n3DsPgGEYpgygKImTujlBXdYq%2Buz1kqlrvh%2FM626%2FhmJaUic%2B88f6MmMorTqML%2FXXWJbuB%2FP62a8hmPCtfHXeE3tQDNsvix3DMAyLHcMwDIsdwzAMix3DMAyLHcMwLHYMwzAsdgzDMCx2DKMhPv45njxJzHf7vfsxSE%2FnqYfMq0H%2BgqKNC2qGXMHj%2FHbSt704mTNvPSIiY3TWVba0wHqfGbj%2B5z189tUW7fpGDWph6ID2cG3eIFc50%2BauwfOkF%2FI4hSLrly9JySn415q9OBhwAYmJSahevTI8Wjlg8rhesK5RBf47g%2FDL9uO5ylvwyTC4OL3JFlQA63wP4XHUUyz%2BYmyubakpafDo9jEuB69AVatKXFkMikt%2FNMdLsUtV4YGbE7aZKjEjr0L1bS9OLl65g949W8HTvXGWQosLIeISknA1NALrV05HSooKJ0%2F%2FiYGjFmGv%2F2do0riedv9rQhSPB1%2BHiYlC7uPp7qjdNuOjfyNelLNowWjUtH4DYTcf4Fchbleuh6NrjWaIfBAr95s73Uvnut60qc5WyDCvgJfVH3cnDFApsCJNhWriYwUpdoqMcHawSoUBotAdOQvVt724aWxvoyNQ2TFTKrXbOrV3xu%2FBV3E86JqO2JF35vU3dyiVCvjvCtbur1arcejoBfj7eqOVayO5rp4QsW6dmiEtLV17fLWqlvmev6zx89ZAnDl3E3EiRK1TuyrGj%2BqGBna1tNu3%2BP%2BBA4fPSa849q8E1KhWWbst%2FF4Uvl93AFHRT9GiaX2dcv12nEAzZzs8inqCcxduoc9breHQqA5%2BO3IeO%2FacRHJyKnp1c8XwQR3k%2FuSlr9twSHRKEdLT92jdGIP6tdXe74DfL4tO0QSODnUxbmRXVLAor%2Fe7nT1%2FCxv9juEvcd0d2jrL76ZUmiD5RQq%2BX7sfk8b2xJ7fzuDho78we5qXToSQkxu3HuLM%2BZvo1M4Ze8UxlStXQL%2Fe7ljyr13S200WEQVd2%2BR3e6FSRXN5zHc%2Bu9G7Vyts%2BvUYbt15JN%2BPGNxRWyaVRx1xVHQc2ns4QZWejinj35LbUlLTsH7jYQSFhKKKONfYEV21Nm3sFFZ%2FNCKnUqNu9h%2B46eTs1BlhLRUaKQr1I%2FevMNuLiz9v3EfwqVDt6%2FS5G3nulya6gNjYBNSrW0O7TqVKl43lHS9PDOjrKQ2PjFdWojBW%2B4Y2WPvTQYSG3deN702zqoYabfbz04vyUWWRqKg4uLs5YOKYHihnZoqBIxfJhkYsX%2FUfrPnxgBSdtm0cZb1piI6Nh9fQ%2F5cNcdTQzrnK9RONeOzUZfjB9zASniXL9ILvlqNYunIXhr3TQZyvu2zMGzYHZHjaf%2F9R3rNxolG3bmkvBZbY%2BMsx%2FFvcz0H926JX95ZCdB4g4l6M3u914dIdjH1%2FOdqKTm3C6B6yE5z3xSa5LTkpFUvEdfQf%2BbUUnBjxvdR6Uo03bz%2FEV0u2YvR7y3D%2FYSxixPencsgee3ZtgWFCtM9cuAnv%2BRu0xyz12YWpc1bJzqN75%2BZY8PUWnDwTphViKqth%2FVpCyLrgdvhjrP7hgPbYyTO%2Fl%2B1k%2BuTe6NKxGd59f4W8htcJffpDIufWBPdUwHaQ0OWVsyugUKmk%2BrYXt6dHvWnQqT91cnZk4JqcGzUIgvZp6mwrjUnDH8HXRM9pgRbNMjwJ8jjIW%2Bj3tzby86qlU%2FD3LzehR%2F%2F5MC9fDk2b2GLIwHaygWkIE0a0ZOXu3Dm7ymUvZ0ceTaIQI2pI5AH%2F9HOAEJNo2NWzxirR%2BPw2fCQ9NOLO3cfSiyE2%2BwXCvZU95s0dJD939GyCfy7XNa2JQmQmjeup9brHTVmOX378UHr2xIcz%2B8tzkNdyLfSe8Ip6SlElhg5sL5eU1nB0sEGXDi6yM%2Bvd083g%2FCIJ55AB7eRnp8Z10brLXHwy%2Bx3tPj%2Btmik9f0OpZmWJff6foXw5M%2B26%2Bd5DhVjGi%2Fp7JK6xmRD3QzrH%2BK7%2BADZ1qsn3J0KuSy%2BXcsir1u%2FHVOHFaTw56xpvYP%2FBs%2FL95WvhQugiceLgYpmqcXezR4gQyX2HzmLme31eOxvMpT8K7Bfd7Rc5PTmDxE6DCOQuCP%2FmLbWe7WlpuCNOalFcX27u9H7SpS%2BIiPsxUpSO7PlShh4atu0KEp5eNWwVYZImTPXfGawVO%2FuGteH300eyAYeGRcowYP5Xm2WIMHJwJ7mPp2hQa5ZNLZLvYsxPjiCvZN7nG3FQeD3NXerD6o2KUpQo5L%2F%2F%2BC88e54sO4u8CBX3RiOC%2BWFtXUX7%2FunTZ4iKicOYKctEGJMVLtq%2BaS2Xs6b2FZ7XRvis2YeWLRpKb4c6wLHDu2DCtJVw8ZyJVi0aoe%2FbrbXhbUHcvvtIhsnaaxGdoqVlBYRHRsM2M1KgdYWBQtfsQvfo8RNMmb1aerzOTvWQlJQi7Sw7JiZZtmtZyQJpokXLjkN4ckMGtM%2FzPJRnfiw87rY9vHXWZw%2BBi4rSZL%2BkP8IyeqepMUgs9Y7rm%2BYTIweJA%2B%2BLZXdR4DqxnF3QdhHNLC6MZ1eUFWZhXg5zhBgSH3zyA8ZNXY5tG72ll%2Fbs%2BQsR3pzH2z1aCq8vVO5TvVpl7NwXInvX6lWz8kmUN6EcB70ihIGfv3hbK3ZFib6HIA4GlHcdYKsyQROxZ1ex83BRWVdM1ZgmvkJYcRiNofcj8MRVHD1%2BBcd%2FW4SKFTJyYIeOXZRLc9GoaRoJdRrUSHNSvrwZEhKTDL%2BvFcrJTmvnz%2FNQu5ZVru0D%2B3qIDtANV65G4LC4hmHvLsGZY98Kj6wegg4vliP1p8%2FdxD9EKGj1RiXphRZEJXHN8YlZqQkS8OfPXmjzaUWBz9r9sKldFTs3f6INnSfN8sk%2FV5UtJ0jRSXRsXN7XLq6xvl1NHNn9RbELTFE%2FxNPdEQ5pCviIQl2EEW4RlhigTMc1uzCEbxX9a172mV1%2FxHKNuRnWJ6divOgmJqoViMsrhM2Vs6NCxGKrKMBJvCJFeOp07jrm6NteUtNScvLN52NR3swMMz5aKxseufkO9nWw4p%2BT8N3XE%2BRr%2BeKJwiuxw849IYh9kiB62lXSo9NAc7%2BCToaWWHKXbvDpMNw%2BF4o9VLdxqbAT9R6oUuCkaxN0K8n6TUlJhVKESZp85vHga3iWmCzf00g2eUBbd2Z40FS3p7LlVt2F17VP3A8SQ2J%2FZo4tP6iz6tTORYS622UulqBjjwReku937g2BUmECN9eGeH%2Fi20hLV8nOjXJtcXHPpOiNHtYZ9W1rygEHfXTt2BR%2B209o849%2BO47LAZgGdkWXlqaySfQ1Ynrk90sGH0s5vB83BcgBGQptacBEA%2BUZHwqvcdvuYO068khJTEszZM9k12TfZOdk72T3ZP8aoTNEn4Iu4QotlUrYi0Bjq9gvQewcWZBnR4WQUoaYiULyEDB924uNybO%2B1%2FlM87JoflZOzMqZYt3K6egz%2BEss%2FMZPTjnp39sj1379e7cRYW0QRg7pBBPRYPoMWSh7R3PhJT55mihHyDQ5IJkzPHAaNo6ndStjw8fafFFxcvMmXojFwpaOMmWwVdi1R3F5ePro1rEZ1vkehmuHOUKMzGSHUK5clgkt%2BnyMvFc%2BmQ2xUYPaWR6rCCVpcKhlh9kwER5br66ues%2B39OvxmOW9Fk3bzYJV5Yp4Ev9M5tXIS6MR1%2F9b4AtH%2B7oyNzh7qhfq2lSTYkudHYkUDYpQx%2BbV213vuSaM6o6LV%2B7Cs7s3aopwlQYh1q6YVuCIa2GhQZ2h736Dlh0z%2FIc2rRwMPpbydTQKO2nGSmH%2FlujcwQUhZzPMwDJz3unceeul3VPoTKO9S0XnXlohj04lhEmI0xgSOEP8AH36k7luThsXLBb9o3dOT0%2BR6SY%2BF4WsFoXkGY7q2%2F4yYVNpegw4eYE0YkbUtraCqZmySMvP%2Fljr%2FyUMEPX2KeX2RRk9izqMLcz9uP8gFhYW5fOcDExTQignlV89Pnz0RHo3hZlITJ5avAiBbWpXkwn4nOtpalD2qSU02h4dE49KFcxhVcgJy%2BSRPhceYs5zFaV3R4M2Oa%2B5sNAMg59%2FDYT%2FRt08HeUFqTOxrl6l1NlvDps7KBa%2Fi%2FIWGrDvS%2BkPjdaS6IkLniLOkzHPTriD9QsqRN92Y4eMup4RTBK2TMK3CRaY5uqM5uev4mJJXYdmtDAvqAFXsMm%2FEeeVf9NHlSoV5cvQ9RQCZ7%2BfJIoTZuSfG6OBiUlje8j3NIJKr4IgQR%2Fz3vICQ2IKrfOCpuu8jK3djYiC9z980bhRnYwwfk8Ili2emGu%2FWjWtSr0dk%2F0iHU2FPXsZsv%2FL6k92T08bxuor6HUWOmPi2F0kuzXBZpN00HyIi1wjhoulv%2B%2FHRVYeCXpRlmcIlBMdM6wz7oRHwdzcDLt%2BmSfzkUbpXJD9KrCZ7LkQovXSaI435aZgZKgRIFz6D7giyhY060Df9CvjMWF4KtRY9spFls3IuFCpcVUBOHBNMMYK2S%2FZMYsdU3APnyhd8hpcE4wRUyPTjlnsmPwJjpR5DnOuCcaIMc%2B0YxY7pkDUABRcDYxxR7Kv%2FmdnLHYMw5QJWOwYhmGxYxiGYbFjGIYxIkpsUnH239sxJQ%2FfD4Y9u2KAfkxc1M%2FFYvh%2BMAyHsQzDMIzxYcyPdmeYkrJf9uwYhuEwlmEYhsWOYRiGxY5hGIbFjmEYhsWOYRiGxY5hGIbFjmEYJn%2F4H%2B4wRjVJmX%2FWxrDYMf8TpemflucHP6yA4TCWKVNeKP9cjmGxYxiGYbFjGIbFjmEYhsWOKYXwv1NkjJUS%2BTeKLHbGS7JnXf5H2YzxkWm3ySVxbhY74yQ6qRJqcjUwxkam3Uaz2DGGxrBhSgWcuSYYY4PsluyXxY4xCAUQLP505ZpgjNB4u0r7ZbFjDCHdBNuEezeis13J5e2852%2FAiIlLkJKaprPeZ%2B0%2BbPILzPOY0ZOX4cath3wDyyjSXoXdSvtlsWMM4fxVXBSLywkW%2BLAkzh95PxY794bgbng0Dh%2B9qLPt5u2HiLiXd0rm9LkbSExM4htYRsm018uZ9stixxiGUo3pYjGnpSP6vOpzb%2F9PMHp1c8Xg%2Fm2xbXcw3wxGL5l2OifTbksEFjsj5VQowtIVGKxQwNfNCZ82aoTyr%2BrcJHADvTzFywMBgZfw9OkzviFMnpBdkn2SnZK9kt2W1LXwU0%2BMOZy9hiPujvBIU8CnihmmtXTCFqgRoEzHNbswhG8FVEV9zguX7yA%2B%2Fjk6eDaBUmkCF2db7N5%2FCmOGd%2BEbwmCwCDruOsBWZYImmYMRw9XAFVM1PM5eLzmhY7F7TTw8sejh6ozmJmoMFO9npithf9sJtm7F8CuLbbuCYfumNbZnhq81a1SB%2F%2B6gVy52%2FOST0sntjF9HhAvDuyGsL1h4c2%2BVVI6Oxe519fIyDOqljMpQ4UhLVWHX3hC09XBEkFBZwrKSBQ4du4i7EVGwEyL4quCHeDIsdkyxcfT4ZVhaWmD1d1N11sfEJsg83tzp%2FbiSGBY7xvjxFyHsgL4eudbTum%2BX78CcaV7yM821o5eGWjWtcDZwiXzfZ%2BhCnWPHj%2BqOLz8dwZXLFDscCjAyjDW2x7JzGMsUFp56wjAMix3DMAyLHcMwDIsdwzAMix3DMAyLHcMwDIsdwzAMix3DMAyLHcMwLHYMwzAsdgzDMK8F%2FCAARpL9d6cM8zqi5CpgHsbgc3rVqYEFxnTNfOcYDmMZhmEYhmHKIv8Ff9i5XBG%2Fx4YAAAAASUVORK5CYII%3D)

```
erase_stmt
         ::= ERASE ( address_or_range | ALL )
```

referenced by:

* basic_stmt

**address_or_range:**

![address_or_range](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAYsAAABFCAYAAAC7dcr7AAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAFSVJREFUeNrtnQdYFcfax%2F%2BnIAgCKiC22LCBFVGxRQlGBTUEY0miJhJ7rIl86tWbosZrol6vlxsLVxMTYhcbGsvViJoYFBQrFhAFVFRApCPllG9mDoegD3AOCIf2%2FniWPWd3dnZ2dt%2F3P%2B%2FMnl2AIAiCIHQgqYidOtlDTVVfPQi9XTHXEEEQhkVeUTu%2B9McWqv0qTvc3J1IlEEQNQUpVQLxulEiRIkGQWBAEQRAEiQVBEARBYkEQBEGQWBAEQRAkFgRBEASJBUEQBEFiQRAEQZBYEARBEDVKLJw7wra4RLrWlycfTlqD6zej9Urrf%2BBPZGXnVMqKjk9IwfHfLtMVRxCEQXld%2F63dXohFrhKPneyxp6hMda0vT0Z69IatTV2d6dRqNT5b9CNSU19UyhMWERmLlf%2FeT1cuQRAGpbT%2Bu6c9Rjg54KFCiSj%2BXTwbSqIRjdFKJVtpjwNyGWYHhyFOu5Gu9eVJ4vM0SCSaZ9X979QVmNepjfC7sQj8%2FQaaN7PB%2FNmesLQ0g%2F%2FBIJHGd8tx1DEzgdugbnBo94bO%2FI%2BdvIyTp68iN1cB5x7tMNqzD4xrGSEo%2BA52%2BP%2BO9IwsvO3SGePGDBDlSEnJgN%2FO0xjs6ojNfieQ8CwFH33ggkFvdRX5paW9wCa2nJexroUZ%2Bvd1wLAh3eEfEITExDT8a12ASDfFa7A4luLIzsnFlq2ncD7kDiwtTOE1diCcHO0Q8ygB%2B9jxTpnA8jDX5MGjFpVKjaGDnXDoaAhsbCxx8fJdBF%2BMQNfOLTF72jCYGNdCXHwyAo4EY5RnXzFXqlSY%2FPEgsiiCqKaU1H9zkVBK8B%2BlGk0LPsjnpTELtUY8eKaPClMiXevLA%2B78n8Yn5YvFxJnf4%2FHT5%2FBw74EbN2Pwzeo9Yp2NtYWYN25UH280sYaZqbHOvDf%2BeBwr1uyFa%2F9OGOjSBcdOhCI6Jh5%2FBN3CjHm%2BbFlnTBj7FnbtP4fv1u4T2ySnZmCVzwEsXroVjl1aoUe3NpgydwNiHyeK9TO8ffH4yXN8Ms5VOGkuRqJ8VhaQG8lE2fgkZ2dMF5NnrUfk%2FSeYNXUYXN7sBK8ZPoiKiUPzpja4Ff4Q3n%2FXPIzx6vUoLF62DZ07tBDfDx0LwdQ565GdnQuPoT1xMvAalny7S6x7Epckyj96wkpERj0RAkYQRPVHl%2F%2FWRhJKYD%2B4ULyCXEemQol0rTdkpDF9ohs%2Bm%2FGO%2BMxb1dzxcVz6dRRzD%2FeeaMBa1bpQKFTw8T2MHZvnoVtXO7HMc5izaJ0vZwI0kznoEcN7ieVNG1vDfeRSeLMohlPLSI592xbmRzwHj1zAdSZcTRpbIez2Aywb0Q%2B9e7YX09jR%2FfPLd%2BrsdYwe0Vev47x6Iwr3op7Cz3cupFIJejq1wYWL4TjKBG3mlKFYu2IS3Ectg8%2FGw9i9%2F098v2oKmjaxyt%2Fee5YnvJhgcVq3bISxk9dgxVcfie%2FGJkY4sG0RLFi0QhBEjRUNjf%2BW4JgCWPZqJKGXWGhRMZ%2FFQg83tY71CgWi2E5rG%2BJApbK%2FXp%2FAu2Zyc5WlyieORSu8y0jbGs%2FPnznme1FxootHSxu7RsjJVeAJi2hEWMdEQisUHAtzUyiVmnJwQZm3eIsQsW5dW2Hi%2BLfRpWOLEpfvbuRj0WXUZ9DCl5Y3Y1GFVig3rp0Ot%2FeWsshjKPr2sn859CzwlolWLWxFd1oGmzi8O6qshYKePEsQVQvuv5mbGKZQYxSbq3QZsLyIPq4gtmEsm7%2FNMvyBzT8vbj1raK8sSWRRGRwLH9fgDj85LQPW9S1eWmdexwRp6X8NlHNHq1SqYMa20Trcohg%2FZoAYlOddZEdPhuJ9r9W4cm6tRtHV%2Bh8235ddy4Y4cXBJkWn2BQShk0NzBBwJwacT3VG3rlmh6ZJS0oVAmOrRNVdadL0EaTQgi26L5kopHFhKV5b4Q1YbYXI1ZobcQQSZLkGUnJ7t0VYhwXpmTx2ZPe1knjVQpsKtFhGI8QeUhfnbgv6bzf9rYoQtWbmYyBr%2Bk9USpBTWBSUa0q9mwmb%2BLAN7Nj2Sy2B%2F%2BTbm6VpvqC6o4uCOn7eWeR%2B%2FPvBB8e6OrbFh87H8ZcGhEaI17zqgM3bu%2FUN0VXG27jojooNXRaVQB37ovOim4t1GMya5IyMzC9nsTPCyPWV5Z2Rm61W%2Bvs7t8SA2AQePBOcvi3kYj2th0eJzwNFgnDkXhv3b%2FyaiitkLNokuNC0paZlizkVuPTvGIQMdIZNV3M9q%2BIV7MQL3L9%2FBr%2FyaSclFC3Y9nVVKcMHRAQPJ7AmiZHC74fbD7YjbE7crbl%2FczrRCoY9%2FD7qOMD6XydCGtWf9Wbo0lvhRcZEFz4QrTbARy6QQAdC1vsKZ5jUEXp%2F6oF69Opg%2FewRGefYpNr3PykmYNncjHPt9DplcitomxvD3m48504ez5RvQd8hCWJqbCYf%2F88a5epXBb2cgvvzHDrS1a4yo6Dh8teB90eLnYtGlY0s4D5wPmUSK4%2Fu%2FRqOG9YoVs582zIH3oi1YtnK3ECA%2BYL32u0niTqsvvtnOyroQprWNsfzLcRiaN37x%2BUwPsf32PWfht%2BM0XmTliLvCNvnMqFTnKjISXDWXd2svujL9WQupF0UYBKF%2FRKFkjp0594%2B5QOjTXtPlv%2FOWzXPuiJW5Six8NdKQ5IUpmSwTX5ZJod1JutaXFB4WlddrVZOTM5CjUKCBtaXe28Q%2FSxGtbqt65i8tT0hMRRZztvzupZKQlJSOdCYw%2FA4t3v1TEB65cAevveVVH57GJUHKyqfvMU2evQ5v9nYQg%2Bm8C60kdVESCr5W9XXexc2uhy%2FYrD%2FLYzC5AYLQy2ZOsNnvzGaW65G2VP6b3y3FRYMZ9nS2H1MRWbBwpGVxmehaX5nQ9tufCLyKTT%2BfKDLdVwvH5A9uF%2BVM%2Be2upYFHNnwqDNsGmh8YrlkXgPMh4UXmsfeXBfmfG9rWK1U5uCjxqbJj%2FgL%2FTKuNmY4d0OXKTVwjV0AQxXQ%2FMTuBCp2Y3Xjok760%2FrtgpJHfDaUro6oiFAUZ7NpVTJUV71nvllve%2FA4sfW4friyciUaWkwN2SFUYyb6SWBBEMQg7kWAHt5sSOP1So92eHiRYDenj3B6tWzWqWoVWI5CFyr3p7BGELlNhdsLsxeAiRVVPVAaUatyUAG2pJgiieLidcHshsSBqJLXTRahrQzVBEDqxybMXEgui5nH%2Bkeh%2FNaGaIAidmOTZC4kFUSNRA6W%2F%2FZYgahCSPHshsSAIgiAqFyQWBEEQBIkFQRAEQWJBEARBGAB5Re244HOFCMJQqC9NNdp7%2FsLcWxFJH4ffS2nzPCXHOOF5ls6Bdat6xgqz2kbJ1vWNz0Y%2BePHt6eDM0PIuK70jpPrwOs9Oq9Fioa04MgbCkJz82enTz3wOro6ISjUb7voGPKc3Q8MGpmhgpfuO3fjELPnT%2BEzrc5fiR8bEPnjXw8X0UuyzzPGhYbhXnmUurwduEtQwrjKRBUEYLJpQL5Hu%2Bc%2B%2B3at8w0aNf88Oqxb1QC2jkvXAckHhU2f7%2Bpj8QVv5rl%2Bjev2wKyKseyf1e5duKI9RLRP6RIlVOcKoULGoDqEZUfnhQrFl991Ra77ogU7t6r12flxoPh5hB0eH%2Biazvr5wuLsDpl66BQoBiGoNDXAT1Rre9cQigFGrF3cvE6EoCM9v3dJeMrlc%2BoOjA2gQjiCxIIiqCB%2FM%2FvXUw9XjWRRQ1kJRUDDGvttKIofkvyzCcKdaJ0gsCMIA%2Fh1l%2BMgPftdTZEya2QfDW5Zroad92A61aknlKjV2O3WEHZ1GohypkEd9kFgQlY2s3k3L7mGCt%2B4mTXAb0KTEg9klheffs4sNt2I5lPgnnUaivMizj6yK2DeJBVGZSHhRB7ZllVn4%2FVS7ft1tDVLwwf0b8xl%2FsXo%2F8dpLgigH8uwjgcSCqNGw2DpCJkGHssov8Xm2SZOGpgYpu0PrutpOgvi818MSRJnD7YPbCYkFUaORAOfZP9eyyu95arbEytLYIGVvapsvSnXYNIjOJlFORuIq7ITEgqjJqKTYx8KLsS4tymbcQqVUQyozzE95tPtRq1GfzZoZuu4%2BnLQG129G65XW%2F8CfyMrOqZTXQHxCCo7%2FdpmMoRCEXTD7EHZCYkHUZK7cxDU2u5FWG%2F9XhaMjHlnYGnq%2FIz16w9amrs50aqZmny36EampLypl%2FUVExmLlv%2FeTMRRCnl3cyLMTg0OP%2ByAqFTI1ZikluNCtPa5evoNfq%2BphGHqHic%2FTIJFoopv%2FnboC8zq1EX43FoG%2F30DzZjaYP9sTlpZm8D8YJNL4bjmOOmYmcBvUDQ7t3tCZ%2F7GTl3Hy9FXk5irg3KMdRnv2gXEtIwQF38EO%2F9%2BRnpGFt106Y9yYAaIcKSkZ8Nt5GoNdHbHZ7wQSnqXgow9cMOitrhrHl%2FYCm9hyXsa6Fmbo39cBw4Z0h39AEBIT0%2FCvdQEi3RSvweJYiiM7Jxdbtp7C%2BZA7sLQwhdfYgXBytEPMowTsY8c7ZQLLw1yTB49aVCo1hg52wqGjIbCxscTFy3cRfDECXTu3xOxpw2BiXAtx8ckIOBKMUZ59xVypUmHyxxXXu8jsYTibzWP20auiykCRBVGpYPYeoZJgNPM3vzjZ44vWrWFMtaIb7vyfxifli8XEmd%2Fj8dPn8HDvgRs3Y%2FDN6j1inY21hZg3blQfbzSxhpmp7urd%2BONxrFizF679O2GgSxccOxGK6Jh4%2FBF0CzPm%2BbJlnTFh7FvYtf8cvlur6SFJTs3AKp8DWLx0Kxy7tEKPbm0wZe4GxD5OFOtnePvi8ZPn%2BGScq3DSXIxE%2BawsIDeSibLxSS7XrbuTZ61H5P0nmDV1GFze7ASvGT6IiolD86Y2uBX%2BEN5%2F1zyJ5er1KCxetg2dO7QQ3w8dC8HUOeuRnZ0Lj6E9cTLwGpZ8u0usexKXJMo%2FesJKREY9EQJWEfDrn9sBtwduF9w%2BKuoao8iCqHzdUbdwqmd79FJIsN7SCDO72WMn1AiUqXCrRQRi%2FAEl1VLxTJ%2Fohs9mvCM%2B81Y1d3wcl34dxdzDvScasFa1LhQKFXx8D2PH5nno1lXze0PPYc6idb6cCdBM5qBHDNc0dps2tob7yKXwZlEMp5aRHPu2LcyPeA4euYDrTLiaNLZC2O0HWDaiH3qzE82nsaP755fv1NnrGD2ir17HefVGFO5FPYWf71xIpRL0dGqDCxfDcZQJ2swpQ7F2xSS4j1oGn42HsXv%2Fn%2Fh%2B1RQ0bWKVv733LE94jdPcU9G6ZSOMnbwGK776SHw3NjHCgW2LYGFharDzNppFpdFt0VwphUPeYPaHaiBMziKK0NsVJxQkFkSljjDYbBD%2FzYJUjffY5zkqGdrct0dzJ1T%2BB1BW9OP3Cw7s866Z3NzS6Wsci1Z4l5G2NZ6fP3PM96LiRBePljZ2jZCTq8ATFtFwuEhohYJjYW4KpVJTDi4o8xZvESLWrWsrTBz%2FNrp0bFHi8t2NfCy6jPoMWvjS8mYsqtAK5ca10%2BH23lIWeQxF3172L6UrUDy0amErutMyMjS%2FeePdUWUtFLqui%2FuaX2fHsGLdZVf5eRZNuFXUGAWJBVG1ogyNoVwrD8N8SZyuPUeuQo0ObSxQ18II9x9k4ElCFhpam8CuuVmJ910WT1SuDO974eMa3OEnp2XAur7FS%2BvM65ggLf2vgXLuaJVKFczYNlqHWxTjxwwQg%2FK8i%2BzoyVC877UaV86tFev4ILy%2B8H3ZtWyIEweXFJlmX0AQOjk0R8CREHw60R116xZ%2BPpNS0oVAmJqWX89nVX7SNo1ZEATjI%2B%2BL8JwehOt3UsR33x33xfcNO%2B5Vq%2BPkjp%2B3lnkfvz7wQfHujq2xYfNfr%2BwIDo0QrXnXAZ2xc%2B8foquKs3XXGREdvCoqhTrwQ%2BdFNxXvNpoxyR0ZmVnIzsoVZXvK8s7IzNarfH2d2%2BNBbAIOHgnOXxbzMB7XwqLF54CjwThzLgz7t%2F9NRBWzF2wSXWhaUtIyxZyL3Hp2jEMGOkImI7dIkQVBEJjmNQRen%2FqgXr06mD97BEZ59ik2vc%2FKSZg2dyMc%2B30OmVyK2ibG8PebjznTh7PlG9B3yEJYmpsJh%2F%2Fzxrl6lcFvZyC%2B%2FMcOtLVrjKjoOHy14H3R4udi0aVjSzgPnA%2BZRIrj%2B79Go4b1ihWznzbMgfeiLVi2crcQID5gvfa7SeJOqy%2B%2B2c7KuhCmtY2x%2FMtxGJo3fvH5TA%2Bx%2FfY9Z%2BG34zReZOWIu8I2%2BcygC6SohgZVAVFd4d04lw69Y7D9dfc4XKbdDaL85fRa1eTkDOQoFGhgban3NvHPUkSr26qe%2BUvLExJTkcWcLb97qSQkJaUjnQkMv0OLd%2F8UhEcu3MFrb3nVh6dxSZCy8ul7TJNnr8ObvR3EYDrvQitJXZTouijwWlV6Ux5BEFUKbb%2F9icCr2PTziSLTfbVwTP7gdlHOlN%2FuWhp4ZMOnwrBtoPmB4Zp1ATgfEl5kHnt%2FWZD%2FuaFt6d5ZwkWJTwSJBVFD4XcEGeqRH%2BkZuVWyjga7dhVTZcV71rvllje%2FA0uf24cJEguiureezWspElOy5Tb1Tcp9X3ejU6nCqxh9nNtTJZSk8UVVQFRXzM2MkmOfZhpkXyHXnom5RA3%2BU1%2F60SBBYkEQVQWresZnz12KM8i%2BTp57LOZqCeLZLI5qnyCxIIgqQuSDF98eCXykyMlVlet%2Boh6lIfpRutai7rP%2FD6j2CRILgqginA7ODK1lJL2069eoct3P31aG%2FvVFjQweaFDtEyQWBFGFiH2WOf6HXRFZN8KTyiX%2FVZvCcC8mTSsU99nkVFEvpyEIEguCKCWhzJfn5KpHzvr6grKsBYMLxZ6CUYsE5yTAxcry4DeCILEgiBIQfEN5NP2FYsq0RUHq73%2B5jdcdw%2BBjFO%2FPPvOyUKixnf0fopZhAdU4UR2h31kQNYLLt%2FBTd3uVdOu%2Be767DkXJe3W1htuApmhrZ4HmjesUu21mlgLh91MRcjUBv517zMQi%2FeUEXCj4uwck%2BOQSi2SotonqCD0biqhRdOsAN6jgL9G8%2BrT2a2XGxygkOMfmbiyimHD5Jo6XZVkrwyPKibKlKj8bSkanj6hJPElAZOOG2MPcsB2bbFg0cJ9ZbzYzYR5l19KxeTpLGytVI0QtwQ3myZtLJUhgW37AhOJimZf1GZbyqbENltCZqybXHzufVbXs1A1F1LzWnaaraIR4C58KI9nnwSzakLA%2FXW85qqNWI5kJBX%2FKXQiLJpZeosFsgiAIgiAIDf8Pd8fA4bgNvA8AAAAASUVORK5CYII%3D)

```
address_or_range
         ::= int_const_expr ( '..' int_const_expr )?
```

referenced by:

* erase_stmt
* keystore_stmt
* load_target

**symbol_ref:**

![symbol_ref](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAR0AAAAlCAYAAAB%2FND0PAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAACaVJREFUeNrtXQtYVFUe%2F915IQ8fPIURNEB5KK4hovSVj6iUfLPaJ7thtlSofVoZuaWZK22t62qbpX2fFKG19S1iZqu4bduW%2BS1p6GgaCo4ohDxUnvIQRWbm7rkzw%2BygwAjNmbkznB%2Ff5cy9557%2F%2Bc15%2FM7%2FnLkPgIGBgcGG4OyRaUwk%2BP5SwCeK6JYxr0qVf3b0h%2BcLzzc8ob7YOKq%2B8ZZLTf3NbvP09nTRuLvKr%2Fl4uRy%2BcOnGxkP5rSfsUS53y9sefFn7pAuZvb6s6r9ZTl%2BhEyanULX%2F9a6Y5S%2B888Xm86VN7rPjgzB%2F2XD4%2B7nBz3tAt2mq627KrlS3%2BuSpqheUVV6aN3eam6qytjX5xBlctFW59Ia3vfiy9kkPUntkqvTFhtSUeU5fqe%2Fv%2FIf%2Buwrb5VqkW81L4DdIRnvV5WzbVbR6xrRAxRtp4xEX7Yuhvq5wd%2Bt5HBHihfNix%2Flg0exgiY5HYEFRQ6qfD3eyqpq%2FQNW76QNve%2FBl7ZMuJGyG6XjIeXfv7qzdxQvfWheLJxJDoZD3rRqFdEL6916PG%2BCm4A5MGI0UMfO2NV8GJjoMxqlJZvb5hZvXTsDYcE%2Br2BTsbE%2BPk8pkksxoSh3ZmrxtwZeBiQ4DDIuvud%2BUb04mo721BMe8I%2F92XggnA5dBPIhHxc6bJl8GJjoMRgi%2F9lwoa3ZPmh1Mxf7S34RDoZDIdDx2x0QhVOy8afFlYKLDYERhccOShKnD%2BryGYwmC3YnjfIXfUGXQYovYedPiy8BEh8EIdUlT6AMThlLNY%2FoUpRC4ku2B6DEYJ3beNPgyMNFhMKKuvm3AMH83qnmMHjnE8IFDtUSHBWLnTYMvAxMdBiPqm9o478EuVPMIHGoSBw%2ByPSJ23jT4MtCF%2FoqsSVEYmn8GV7s7yVI8LZSWXcXq1z4y7aevTcKYiOF49Y%2BfQF1cpT%2Fm5emBsJFK%2FHpOHELu8Ted%2B%2Bmew9h3IP8Om39an6w%2Ff3HqVmh1WmRsfRYDPVz1cd%2FlncGR%2FHNISX4IK1Z%2F0C2vDh62hk7LQyK1fNV6S6sGG94pRGFxE67UtmGQhwzzpyuxcvFISC2k77DP8%2FDirHTF%2Bt3y7tOoSYEva590dKAjvb6S2rWoionEXpkUK7syaime2qgb4I031j2Oh%2Ba%2Bhtzd6zAyJEB%2FvKCwDJNiwhA%2FZSxx3ZvxzeGfMCMxHVvefBLzZk7Sn3OpvAYuChlWpM7sZDPA3%2FCT7fGTxRim9ELGzq%2Fw0sr5%2BmO1tU0oUldgyBB3pK2Yqz%2Bm0eiQlLIF27ekwt%2FP4MoHKX1EPZLU1rfho8%2FLEBU2CN6eCpwqvIazRIDa2nR4eWn4XdngDJ6Dq6OMnvbg29%2FaZ191YGIkErUc3tVo4U12Ddeec4Zp1mNaLRKJ0X23G7UUTwtyUilCwXdUhotCbooTKvi%2BiRH6z7MTYjHn0YlIfe49xEaPgjLAkMbXd7DpnK6w%2BrlEvLDmQzz5eDx8vAaZjg9wUZjStd%2FS6MPx40IwIsjPITqgj5cLvv1kCsaGD9bvP7v%2BR%2Bz5sgInzjb01pTNb5PJzCnF6aJGJEzxx6wH%2FUXNt7%2B1z97qQIfYEEc30PwW2k5rOrzBPRWMVhCjOYI71Jt4e0IYVSIjgnDwK5XpWE1NI44eO9dpa265YYqPCAvEjPhobNtx0KnmzB5kLOkQnHYyEpZVteo%2Fj4sYInru36vqkJ1bjgJ1o1PViTO1T0s6IIhNzGiUa4HPIQhOV2s6PRjVK5qleFtPu7rDPUG%2BqKiqM%2B0XnivHW9v33zFnHjjy%2F154GnFdH5m3Hs8sme50C3YHD13BX7PO46dzjZg5zR%2BrUkaJnnN4yEA0NN3CcKWr09WHs7XPO3SAw5fE73r9ds%2FmrkTHtAAInCKuUAJvIV6jQSnJ1O6t5FrjdYQGB5j2p06OwtaNT%2FWYZnigDx5LvJ9U%2Fhe4f1IkNW72eEZL1melesHZ%2BFIUnl4U7BC8X1kW7nDl3N%2Fbp6ADZOo1S8NjIQl1lgzJupm7HSEJK0n4MDGYScJVPcXLZdjUG0%2BHRsOoulxP3FM11qQt7HXa55fPweSENfDxHkStUq3xsKTeltuDcX5Q%2Brki9ldeDsP7XEkz6hoMnk5QgJtDlHN%2FaZ%2B3l4u5DpAwY4AcWTfbkUIckad5Do1dTa3uEJ0OI7zBSL5cikhBTEhmq3qKt%2Bfo0dx8A0ePq5H%2B52wkJ03D6PCgXtvwJZWZkvwwPtj1b8TFhsNZICf%2B7nClG1pvahyG86YdauQeuoy0p8J%2BsdcjBjhj%2B7SgAy9OisKmdi1e7k58zEVnjwUx2WNrsVEXV2Lx0q36z3OS3kTG28sx%2Fl7DfX0vrs3Sb26uLggPG4aVS2chacHkzoT3fa%2FfzHEg%2B1WTDXMsT0nAx9mHnGoNIePvJSi%2FfANSaQTui%2FYGA2ufVoBFHTAe61Z8OKPb1EqM7CBGupwmWYrvi%2Fva3x4HaS23X7V%2FDn3ecw84FG8qfFn7hLV0QPh1SxAfksEyko%2FhOh2ZFME9GbEUz8DA4Pzoqw6Yez7CvsTsoKVEDHaGcMm%2FcEsBTbRcb3co3jT4MtDRgY707IZPB8KQgQpNXWMb1TyKf25yKN40%2BDJQHjxZETgOBrrLr1VeaaWax7HTtfqQ49FMAq3YedPgy8BEh8EIb0%2BXw3kqujPdr%2FMMd0fzHKpJcFXsvGnwZWCiw2CE8IbLg99WaG6166jYL61oxs8VLR0to4T8vyRm3rT4MjDRYTBCeKWuQi5RZeeWUrH%2FyiazN%2FbyuC44EmLmTYsvAxMdBjMIr9TNzD5%2Fs0DdYFW7f3n%2FDC6WNXd04BKyxegk2CtW3rT5MjDRYTBCeIf3rXZ%2BwYo%2F%2FKC1ZgfOMfdCOORxwPEfz%2BK0GHnbgi8DEx0GM%2BQXaP%2FZckPzzNI1R%2FhtHxehr2slwprIopXfde7APD4l%2F2fwUvxebLxtzZeBDmSsCBwTJwuxc0KkTvK3vRd3ZO8vlcXd64OEqYEICx2EEUqPLtMIN36qS5pw7FQN%2FpNXRTpxS%2BcThA7MIZ7j8DsV8UzszVsMfBmsD84emYr5mSfUpkVFdMp6%2FBgkQIc9nOFRnX17ppGwJkKmKCRMIB7DkpNn8S%2Fa5fGLeFPmy9onXUjt8QUv1yJd2JS%2B2NBfKlX4vlTs1uCC0h85pJuEks2XjPolpPW0kSYkeLGKbpK1kHMqJTyO8RwKSA8bIeFQQ1IkkQ583Cbl0TveNuXL2iebXjFYGqUMU4tE4Q2XxhfOTSdeBEf%2B3LtJ4sHzuEY6sPDQ5GPEW0hX2WERthe8RcGXgYGBgcEB8T%2B8KKbBbcdKYwAAAABJRU5ErkJggg%3D%3D)

```
symbol_ref
         ::= IDENT '?' ':' IDENT
```

referenced by:

* call_target

**load_ifr_stmt:**

![load_ifr_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAesAAAAlCAYAAABiZsHRAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAEJ9JREFUeNrtnQdcFMcex393HKCABQELYsUS7Ah2o8beo4KJsRIbxlgiPDVqipo8jRrDQ2OJGhJLjA171KdG45OgIFiJBVFEQRGQDlLuuDczeBcgwJ1IuYP%2F9%2FMZdtnZm92Z%2Bd%2B%2FzMzuAQRBEARB6DSSsriogx2U5bVBA%2B8UX5vqQztVtPoSpS8X%2BaEMmG544NLlubeD4ybee5DQNDYhwzg6Nk3ra1qYG8tNKxvGW9YwvhDy%2BOXK836pgaT3CF2R7%2FyQlVVlAy56lbsOdHx7coVqp4pWX6Ls5CInZ352%2BOgTz8NrgkMTTYf2rocRM%2Bqjdk0T1LSopHUZUS%2FSZJFRqZY%2BAVFOYRGP3x3eyyQgIiZ1fGAQHpDeI8pSvnXOWJdXVN5zWXheVF%2BiPMuFUrlUum%2Bd997Vm4Ocx4%2ByxepFHWBkKC1SWdyw89TGrgamjmkm23M8tPO2PcFBjq2VowJuKU5SDxK6pvek1OwEQegD3FB77b3vvPazDpg40rbIhjovvBxe3oblnSuZGEmOObbAZGptQtcgY00QhM7Dh75Z5Ou8ZrEjWjc3L5Fr8HK%2FX9bZQCaTbrMng02QsSYIgtAevpjs%2BO9P1oxn0W9JGeqcBnvsu40lMkh%2BYBH2IGp9gow1QRCEFvBV3yFhSaZjhjYqleu5ftAcRkZSWZYSex1awZZ6gCBjTRAEoYHb9%2BMmDexZt9jmqDXBr9OxrRVfOSSDAt9SDxBkrAmCIDRw72GibXfHWqV6zf49rPmmMkvd7VuiLfUCQcaaIAiiEF7EpleqW9ukVK%2FZokn17B0JoqRZcKJeIMhYEwRBFEJsYrrEoppxqV7TppbaOTBjqR%2F1AlHWiJeidGqFWn5BeF7QSZrySxK3xV4YPbIbunRo%2Fo88eaYCW7afxuHjfkhMSkWd2uYYN7onnEd0%2Fce5364%2FjMtXgrHxO1fUtKymPr7%2F0J%2FYyxLH1MQYDepZYUAfe3TrbKc3nRga9hzzP9%2Bu%2Fn%2FZ4jFo%2BVZ9LPlqF%2B7df5rrXNtGtbFq2UTMmLcJMS%2BSxLEa5mbo2b0lPnDqAalUP95t8sGUtVjk5oQ2LRtqPJf38bDBHVDJ2Ejn6hEVnYCrNx5gYN%2F2pI0KIEuhhNSgdOVSdT2lEjUkZfDyKJLv8sOb2k%2FV50VkzWzeUwc77OMH8ztZU35JciMoFLGxSfnmzXDbhGMnr2D5Z2Oxf8cCTHcZgJUe3vju%2ByO5znuZloFt288gLj4Zh49dzpX3JCIGEvZtdJ81HBPG9IKpaSXMdPsBC7%2FcoTfCYFPHAl9%2FNg6X%2FO9iibszmjSuI47fuh0G%2BzaNRN1Uadx7PUTe1RsP0adnG3GsV%2FdWWLf5OFZ7HtSbOjsN74JaVtU1nqdk2vaTRT8iMfGlTtYjOCQCq%2F5zEETx8JP3Ixw9%2BxSZ8qxiKU%2BSHVnXIvkm%2BS4qRbWfHe0w0qEFnsgVCFVH1pLs4fDRCgXLtMMhmQFm5%2FQENOWXBb5%2Bd3HR9zZ8z66ChXkVcaxeXUtYWVaF86TVmPDBO7CyqCqOnzxzFXbNbUTUvZVF4tM%2FHJCrLEt2XpeOb4n9vr3a4sNxfTBg1FJ07tAMI4d21nlhMDSSoa51DbHPRxeMjQzVedxwq%2BqWlxbN64k8ntLSM7DX2wefztOP6bkXzIGTSLKjn%2F%2F%2Bfg1VzCrj3v0InPvfLTSob4X5s0egWjVT7D%2FsK87Z7HUKZswRG9ivvai3JrjMnDl%2FHZmZcnTq0ByjR3QV7crlbvf%2B%2FyE5JY3JShvm%2FPQU95GQkILtv55H%2F972QsaiYxKE89fvnXaivKSkl2IUiN9j9aqm6NGtBYYMcMT%2BI7548SJJ7WBOc%2Bkv6lIY6RmZ8Nr5u3DOqlU1gcvYPnCwt0VYeDS8WX2nTWJlVMku49TZq8jKUmJwfwccPeEPK6tquHL1PvyuBKMdc%2BRmuw4REdnzqHgc%2Bc0PziO6ia0iKwtTJ%2Brf6G9QcCJ2HAxDLYtKmDCyPiY5NUBty0pvWqwByTfJ9xs4fK9lP7mRVkiwTqGETc6ffsk1Z63MNt680PD8PAFN%2BaXJHz5BeLtrC7WhVuFo3wR1alZnQndHfcybCQz3VLkgPwiNxN3giELLrsk6nAvpgVdfBH0m5OEzIfSqlPoyPd%2FznkXGoX49K72pF1dOkVFxamU2%2BeP1eBoZi%2BGDOuDWX2H4as0%2BkcedN451nRrCmeNTHZrY9OMprFh7AL17tEYf5rydPB2IR2FRwjmc6baZHWuDSWPfwZ6DPvjGw1t8Jj4xBas9D2Hxsp2wb9sYHdo3xbS5GxHx9IXIn%2Bm%2BGU%2BfxTJHsLdQIlxZivtjjqLM0EDcG08ymWa7MHXWBtGvs6YPQa%2B3W8NlpqeYCmlgY4Xb957AfUn2j0VcvxmKxct3qYdSj570x%2FQ5G5CenonhgzvizLkbWLpyT3b%2FP48T9z960iqEhD4TClYf%2BWZ%2BK2xb4YCmjczw7bZg2A89iw8XBuDilRi9qgfJd%2FmTb032UxVJK4CD4IY6DzINhQpPQFN%2BWUTa3LOrXSv%2Ftxnx41HRiWKfz5n4BQRjw7euwvPknqH3UV8s%2BdfoQstvWL8mjp%2B6ovfG%2BvS567h2M1T9%2F3crJqO%2BTfYXmrdD4PUQxDAv%2FtyFm9i1dZ7e1nPG5IH4ZOYwsc%2B9bv7F5PAhfs7wQR2FE6YJuTwLnpuPYfdWN7Rvl%2F0%2BjBFDOgnv%2FWumID9mCkQ12mJjbYlBTsvgzqIcjpGhDN67FqojosO%2FXcZNpljrWlsg6M5jLB%2FZXT2SMXZ0D%2FX9%2Fc7anq%2FL0Ibrt0KFw7l981yxvqCjQ1NcvnIPJ5jC%2FXjaYHismIJBzsvhuekY9h78E%2BtXT4NNXQv1591njYALU6hi1KVRHYyduhYrvpgg%2FjeuZIhDuxahalUTvZUDQ5kU7%2FazFul%2BWDJ%2BPhCGfSee4Pi5Z2jW0Ax71nVCvTomJN8k32XGP%2BynBCflwPK8kbRWxlpFFms7FnoPVGrIl8sRyi5auTQrzOeW%2BdBLfiQlp6GKWfbQ1%2BHjl4XXyYd8ONxgH2LHFrk5F7qYKi4%2BBebVzYp8f7ry27Uzpw7C%2B6O6F9zHSiUOHruEr5eMU89162N9cy5A4kNnmZmKIpXznEUzXK7yLuzhsvIg9LkYglPR1LYOMjLleMYiHjHcxZSYSpFxqlYxgUKRfR9c4fHFklzJtm%2FXGJPH90XbVg1f%2B%2F7uhzwVQ3pd%2By3Mdby%2BjZVakW%2FymIGBo5axyGTwPxZK5rg9NG5YSwx3prDE4cOFxa3IylIuGtmYokv7Grh5Nx6Xr8ciNDyV1VdO8k3yrRPyze0nu90hciWcJVwVazhfVsAYuy%2F7YATb9mUFbmPbeYXlM4dr1etE1sUh%2BO3b2oohGu4pymTSHMIYj%2FsPIkQ%2B58CRS2hQryZ8%2Fe%2Bqz0l9mYE%2FL98Rw%2Bj5NiJrNu41DunvWOT7K46fTitpBeE0vKtYBc6nDvjwERdulbddHuurDdyZ4wopPikFljWq5srjDmBS8t8OIlcECkWWcBxVCqEgxr%2FXU0zF8CHME2cC8b7LGlzz8cj2tJXaV5tfi6%2FoP314aYHn8Gmf1i0a4Mhv%2Fvho8iBUr26av0OakCwUmIlJyT0WVRZy8Sw6Tcxb7zr8GJExaWLOesH05mIOu6jz1yTfJN9FlYu8%2FZ7TfrLtDyzg90rLxGRmxaYqJUjIbwhcOFR5C2Gb%2FawAO5bCZQawu3oHbpryy2Kx2ZABDmJYZsnyncL748SzaHjOwm3o3aMNmjWxxt3gcIQ9icLW9TPhsXKKOvFhH28WTeYlM0Mu5kEmzfAUj4tMmdgXFQE%2BVPWpmxNcPlqHx%2BEx5apuXDFxb5rPgWkDX7TDnZeNW%2F%2F%2BSWO%2FwGDhBPbu2Qa%2FHrgoHETOzj1%2FiOghr9LLV8EcvSTklQ%2FrzZwyCCmpaUhn31B%2Bb5Gs7JTUdK3ur1unt%2FA4Ipo5k37qY1zGbwQ9EvtHTviJ9RwHf%2FlURB2zF2wRzqeKhKRUseVKeAOrI39M0cCg%2FLxuwXN7CNoPOyvmq5s0NIPXN464drwv5k9rVhwLzUi%2BSb6L3lcF2E%2FfmwjiWwMDNGV%2BzX52XhI7ObywyJoXwi29nyErJB8DrCm%2FxJg%2Bd2Ou%2F3kHeG2YjV%2B93OG%2B5Ce07jxHDFnzFZQD%2B9pj5dKJr6JqX7GoLO%2Fzh9xYT5jugRVfjBf%2F81WEPPGhIO7V8WcCZ7sOzbWqWpfhKzAnuP5H7A8b82%2F84PHRa0fIfNgq5GEkJrp64MjuxeJLXV5wdRnAHBFPmJubYf7skfk%2Bh59L4a%2BaAte5m2DffR4MZFJUrmSM%2FdvnY86Moez4RnQbsBDVqpgKhfTzprla3cP2X8%2Fh83%2FvRjNba4Q%2Beo4vFrwvIgKuzNq2aoROfebDQCLFqYNfihX9hSnbnzbOgfsiLyxftVcoSL6gxuObKUIOPvvqF3avC2FS2Rhffz4Og1%2FN7837eLj4%2FC%2F7LmD77vPicUa%2BaniL58xyZbyiYtLh4tQQLs4N0LxRlQrhbJN864V8a7Sfr465dWqFVZkKLMwbaUtehemprJDNrJB8h7M15RdlOCjgolextUJsXLIQrOqsozU9FlCSOL49udiHzYqznSpyffmoS4ZcnuuFOJoVf4LwyvM%2BcRD9IhFpTBnw1a2vQxyT02Qmp3wFb14Hkkc2XAGpHknRhsjncZCy%2B9O2TlNnf4%2B3u7QQi334EOfrtEWZy8XRYaUv38OPkXyTfL%2BxfBfVfvLV4txoswvMYNcxEZE1C8cbFVaIpvyyhr%2BBiyeCKAjVvBZfHb%2Fl59MFnvfFwvfUi28K%2BrKrnt9%2FXXjkY16AnNaqmf0CjLXfH8El%2F3sFlnFgxwL1fkFPQ2iCK02eCJJvku%2BSp6j2M2ekLcrJcVDThwhC7%2Bnfu51Iuor7rHdLrGw%2B1aHN4z26Bl8JXdqvHE1OyST5JvkuFt7Ufqo%2BLwNBEBWCrp3e0s%2BosYqR%2FEVCusyqRuktELv%2FKJEEhuRbt5xW6mKCIHSZKqaG8RGRqaV6Tf8b2U9FSJTgr7pSUC8QZKwJgiAKwcLc%2BIJPQOnOxJ3xyf61OqUEUWxD04AEGWuCIIjCCHn8cuVv58LlGZlZpXK90PAkPApPVmnIh%2BzvY%2BoFgow1QRBEIZz3Sw00MpQG7DkeWirX%2B3RV4N%2F%2FKJHCA23qBYKMNUEQhAYiYlLHb9sTnHbrXlyJXmf1liA8CEtSGeqHLDlkSeFNPUCQsSYIgtBAILOhGZlKp1lfXlaUlMHmhnpfzuhdAh8JcOXaX7hBPUCQsSYIgtACv1uKE8kv5dNcF%2Fkq1%2B%2B4g%2BKaw%2BZz1O%2FP%2FiO3oVbiF%2FZ3gNIAC6jlCV2AnrMmCEJvuHobPznaZUl3ej%2FYvOdoqKxzO0sM7GmDZrZV0cBau7cYpqbJce9hIvyvR%2BOsz1NmrJNzn8ANtQS9JRJ8GMAiemp1okIb65zvVyWonUguCG0JuIMf27dURigyFPsv%2BD83YKl4fhCAz1FL4MP2BiqlmBT4F06RfBO6gkFZXPRZDJbxZG2FpeW1YXn9KlI7VbT6EqUnF%2FmWG40Q69rYxwysLUtWLAp%2BKAHSmbHlAYiRlsUks89ESJXwV0pwSwk0kEoQzUoYc%2FUvXCG9R5SVfOtUZE0QBPEmBGYPUY%2B0b4m20iw4sf3%2ByGLmWgJtf9%2FVTKlEPDPU%2FFcm%2FJUGWBZAi8kIgiAIgiCIovB%2FIcjMsZpBK2oAAAAASUVORK5CYII%3D)

```
load_ifr_stmt
         ::= LOAD IFR int_const_expr '>' int_const_expr
```

referenced by:

* basic_stmt

**call_stmt:**

![call_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXUAAABFCAYAAAC18HbRAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAD5VJREFUeNrtnQlYVdXext%2FDYQZBEWcMTBwAlRBFcw69Zmllpo%2FD560%2BNL%2B8DqkN3OtzLZtupV60kq73fmpl5YSpXUm9mZppaaKIqDghgoIigwo4cw7nrrUYAkQOkxy2vL%2FnOe7D3vusdfz%2F93nXu%2F57n30AQgghDww6S3Qa6AMTQ185Dh6vuVwx%2FtrKFyGVwdpSHR%2FYvZzRryDd%2BoYw%2FvU8X4RUFCuGQBtId02HzXwRQlEnhBCKOiGEEIo6IYQQijohhBCKOiGEEIo6IYRQ1AkhhFDULUPOtZvIvJKjnhtyjUi5kMlMM%2F6E1B9R79EJzcrbydz2usbqdbsx592V6nlScjqCn5pToddJIfr%2BPwd4VNTT%2BMceS0RM7FkmkFiE6ups4euVqAszdSHQB2vv1ai57Q8KSUlpePujNTy66mn8I7cewIbIfUwEsQhV1dkgHzwb6IvzBiOUI1H3ftHli%2Fsoo1Fs9MEGaz2m%2FXYUlwpfZG77ff2P3jFgxZqfEB1zBs7ODhjYvwsGBz%2BCPXvjsGlLFNIzs9HYrQGGPd4d%2Ffv4VauvtRt%2FQXbODYQt%2Fk79%2FdzwXvh246%2BYPPEJONjbqnVZWdfx%2BTc7MHXSUBw7cQ6J5y7BZAL%2BvXk%2FGro6YeaUp9G6lbva9%2FadXCxb8SP2RZ1U214cF4yuj7TV1oFmwfi%2F%2BD8DkZp2Bd%2Bs3YVLaVfh5GiPAX074dlhPdX2M2dTse%2FASQT37YJI4fCdnewxdmRfnEvOwPKvf0T8mYsICmwn8mPC%2F4q2XFwc1eukcG%2F%2B4SCMxjw8MzQIzzzZQ%2BQxDVHRp2EQ62T%2Fbo0aiP6DqTSk1qiszkoxN%2BrwidEEj%2BI3pChRUzfli7xsNLmsEcPc9vvBxOnh2PnzETz3TC%2F4dWyNz5ZuUetTL11Fh%2Fat8MLYYHTx88KkV8JxJC6pWn01dXeFtYikFGX5cHN1xradh7Ex8rffhWfDLzgUmyD2s0Ls0UTMCF2GXXuOYsigrrh9OxfjJoQpsVDvfepiJTxyAOjfpxNemPwxziZd0tSBZsn424jnGRnZaNncTYh1PxXD9%2BZHqMFEkpCYir%2F9fR3GTwpDckoGMsQAI0s4z4x9H1Y6HUL%2BOEi1t%2BDTjcgSg4Xk439swopVO5XIjx%2FdHws%2B%2BU4NyPZ2NmJQcFADg%2By7ebOGVBliEczpbKEzNwLrIQW9FNZmGlUjhrnt98u5yxrnfuGeon8OK3LK40cPUMuRwkXLk3DxZy%2FC1lYP77YtVD20s69nlfsbIERj9fo9GPVs76J10q19%2FvV25QCl4%2FtSCML7c8YXbX%2BsX2cs%2FGCCej5COEj%2FvjMKRF8vROcSvlwyA1ZWOuUY9%2B4%2FoRzilJee1MTBVRfi36%2B3n3rEJ1xEekYWAv0fxsGYeDz1RHe1vZEYeL%2BPmCNEOf%2F9Lf7XZvh3aoM3Q0erv4NFfuZ9kn8I38k1qEFp99YP0LSJq1qXlp6lnPvTTwbBp4OHGpiL909IHRD3fJ3VYYsBeKe0M6%2BQqBci%2FGaMsPJDTGa2Gww4Kzp1qOn%2F1GkxfW4nxKJQUNTUwir%2FNtXfROzC%2FEUb0M67JTxaNlYurdAh1yRyev7OvDU4dDhBuT293kqIjG%2FZwbQRLrOluyoV3LhxW7nZXn8ILbGP10PVm9zU5p3%2F6kL8d4hZwhtvfoEWwq17t2mOhKQ0NGvaqGi7SwOHIkGXyJmQFOeykG7%2Bxs3beHrM%2ByXWd%2Bnkdd9iyDs1kuoidVZ86oYaTBgplnnmDijre9R2fhUvTBHLQaLBpWI5s7ztNtb4qDJOvaIHupwKZ2XduGu9vGRu9jtfY8u6N%2BHbobVaN2l6ePVrWmLKLt14caRgjBnRF1%2Bs2qHei6yLy%2F3uxZWsa2jU0Fnt01aI0A8b59Zogmvixxe0FP%2FQt77EW6Fjipz5RwvX49r1W%2Fdso4GzvRpgyv7%2F5PuO7ZvehZOjXdnuyGSq1XyNAvSJ7eFptIKv2DNY7DxWvIOj1iZMERO7U5S0B4Ogjmhv0CFc5LeTyO8q8Qncoc9DnNcpJEUAxrI%2Bl8V1Viz%2FaW%2BD5bdyESKM9ESTDllllV6U8SrdiFhEiAZ8xCPZWg%2Bf6OOYZW77%2FTpp2rNbe%2BF2r2Dbzpj8EUuMUZFbo2ASS6MhD3a2Nmq9PMl1Mv5CtfuTJ9IyM3Nw9er1EuufH%2FcYIrccUKWI0lNzKTCFDnX9pn3IzTWiW1dv9O7REedS0vHd5t%2Fr8Unn0xBzRDuXzNWF%2BMsTtfb2%2Bf3IennUofhy2xg0wF%2BdNP1l33HEnTyv6ulGg%2FrMqJKLf%2Bc2mP%2Fx%2BqKcyb527TlW4Pod1TmQ2kR%2BoKNOISH6BCLlZykrF17ic7bLqMO%2BAF8MpBxqH5lHmU%2BZV5lfmWeZb5n3QkGviA7%2FGoujcqnXo53wHhFivxyxc3J5Tl02IkeE32xEI2UItbntNY6rqxOWLJqMWbOXw8FuFbKv30SA%2BFAOG9Id0yYNxeDhc9HE3UVdWVIoMNVBOmt5BUfvIX%2BGrbU1Ila8Ae%2BHW8DTowkC%2FB8WrtRDudfinDiZjB4DX1eCZyMC8%2F8fT4GtmLrYulrj8%2FBpeHX253j7wzVqnazXLvxwgmYOxroQ%2F9CZz%2BHlGUtUP7a21kKYyz%2BB2edRX7w2bbiaSchS0egRfdRSnnSVLAmbjGlv%2FAtder8CV2dHXMm%2BjhmTn1L9ylLbFyu3o9uAV9G8WSNErvlrrcc8Ph63xeK9rh1VaTNCOLyedOzaduhGIcBChJ%2BXQl6Rcd6czhasm9WjEz4SHjK0tHPXFdj%2BG6KRJaKRMsso5rZXZfpf2Z9TS07JFCLjKKbXv5fuMy5nCydnRIvmjWo0EfLkmZ0QEClqheWGoODX8f3av%2BJhr%2BZF%2B321%2Bifs3H0ESz%2BdipSLmaq2XFZpRrpdK72VurqjKhT%2FebSaKr9oKf7yMtJskYN7xbc85Cxi8PC3ELc%2FXF2xVMjlK9fUeQ%2BPVo1L7C8d%2FIXUy2jWtKEaiC2ZL5EnOar0E20MpjxqE5HDH8TiZ5HD9yqwb5V0Vl4dI8VdHGgvi34c1VErTEyb8hoxt702KP3hk7i7uVSqjTEhC2AwlH0yr3uAt3CFI4qm6cWR35AM9G9bQtBL1LCEEyy8Nr0spOvTOpaMvxT3QoGvCCOfnydmWM1VOUV%2BoUheUlpc0CVujZzVozTyRHh5uaxNGtzEghwHTAnwg%2F%2BhYzhMidRY2UXkDXnoLPL4dEX2r6rOFnfuReUXcw1ZWtBritXLX6vS6%2BQVHvLSxdL06tFRCH0zHr33Of6V5U8Th%2BBMQqr6ItGn815CYEBbTcbrp0TcCvTFSqs8PCf%2BpKhrDJU3HVbKPFZCnKtM4eutGXrzyOuny0LWgOWD1C2C%2B3VRjwcCE3aIKfkMZlWLqcOjOhMW1fpgwtATUncxmnBMB7RnJLSHzJvMH0WdEFKEwzU1pW7CSGiSJgX5o6gTQvLZm6zqsfaMhCaxL8gfRZ0QUoQJqP5lrMQi6AryR1EnhBBCUSeEEIo6Q0AIIRR1QgghdRCLffmo%2BP0xCONPag%2Fe4%2F3e1MS9leqlqBcGjgeXZQ9cxr%2F%2BUtkbutHoaAeWXwghpNgsRutmx6L3fnkQpjqcahJC6NQJIYRQ1AkhhFDUCdE6vFWA9rDILQIo6oRog1uPevCmXlqiIF%2B3LNE3RZ2Quk%2F6TWfwJ7Y0REG%2B0inqhJC7EHP4U3od%2FBgJ7SDzJfNGUSeE3IUO2Cv%2BCdbK%2B825dhOZV3LUc0OuESkXMutj0oJV3ijqhJDS5FnhW2HXxw3w0kZdffW63Zjz7kr1PCk5HcFPzalX%2BVJ5EvlSeaOoE0JKc%2BgYDovFkRwHvMZoaGCmkp%2BnIwV5q3WsmQJC6j56E6YaddjXtSNiok8gsrb6zb1jwIo1PyE65gycnR0wsH8XDA5%2BBHv2xmHTliikZ2ajsVsDDHu8O%2Fr3qV7Z%2F9r1Wwhb%2FB3S0rOQazDCz6c1XnphMBzsbWEw5OGTJZsw4Y%2BDsHX7IVXSmTZpKAx5eVj65TZERZ%2BGZ%2BumeMjDHT2DOqCzr6dF8iTyM0wsZol89bTUsUJRJ0QD7D%2BBUwG%2BGCWm1hGBPgjLysX8%2BHjcvt%2F9TpweDqMxDyFCTJNTMvDZ0i1K1FMvXUWH9q3wpFc3nEtOx6RXwrHuq9Bqiel1IerW1no8MTgQdrbWWLJsK84nZ2D%2Buy%2FCYDTg70LwI%2F9zAP6dvODoaAeTDnhpWrh67fNjH8PlKzlY%2BNm%2F4eRkX%2Bui7u0NO1cbvC4FPU%2BHUQePW%2BYkKUWdEA1xKA7bgzqip0GHcCEgU7r6YBVM2KHPQ5zXKSRFAMaa7C%2F2WCL2Cwcc%2FXOYcsuS8aMHqOXI4b3USdD4sxdha6uHd9sWiIk9Wy0xbda0IWa%2FOhJpGVk4k3ARA%2Fp2xvpNJc81%2FnPRn9BO9CU5EpeE6NgEHNodJgYBG7Vu8w8HayUXo8TkKbE9PI1W8C04KTrWBBy1Fg7dkoJOUSdEg45dLP4Q4Ad%2FKxNGiOfT8%2FRol%2BADz8Aa%2Ftbp6TMXlYAWCrrEyiq%2Fi28idmH%2Bog1o590SHi0bIyMzWzn66nBezARenvkP5dh9OrRGTs7Nu9ps6u5S9DwhMRVtPJsWCXpNYu5OjQn53xZNEtE4LaK%2BV7jzIZaqoVPUCXkQXHu%2BgFRJRCp6a1lnJ3tkZd24a728ZHH2O19jy7o34SvEVzJpeni1%2F0%2BLPtuk2pPlFsleMYL9ee5X99y%2FgbODGkzuB1q%2BgymvfiGElEnPbu2ReukKtu2MUX%2Fn5ZkQuTUKJrE0GvKKHHLiuTScjL9Q7f5ycw2ws8tvU5Z2tu%2BKLXf%2F7l3biQHmFpau2KZc%2B%2Bpvd%2BPwkcR6nzc6dUJImbi6OmHJosmYNXs5HOxWIfv6TQR0boNhQ7qrK08GD5%2BLJu4uaCj2q4kSyP%2BFPI5xIWHY%2BmM0TGIuEfhI23L3l0592eKpeG%2FeWiwTwt6vlx%2B8PJtCr6%2FfXpV3fiOkniHLL5X9ObvklEwh8o5KSAvJuJyN3DtGtGjeqMbe263bd5CekQ33xi4lavkVQc4k%2Bjz%2BFyz8MAQ9AttXuu%2FiP2en5fILnTohxCwerRrftc7dzaVSbYwJWaCuNy%2BL7gHeCJ05AvZ2tmjdyr3Cbc79cDUyM7OFQ2%2BGX%2FYeR8sWbgjq2q5e54qiTgipFVYvr%2FkvxI4a3gvRMQnqhOnLE4YguG9n6HT1uwBBUSeEaBa%2Fjg%2BpB%2FkdXv1CCCEUdUIIIRR1QgghFHVCCCEUdUIIoagTQgihqBNCCKGoE0IIqUn45SNC6iHF73NCHiz0DAEh9YuLGXhbPlo2wVxG494x0up7Z%2FmFEEIIIYSQush%2FASUBhLJAZsxPAAAAAElFTkSuQmCC)

```
call_stmt
         ::= call_type call_target call_arg?
```

referenced by:

* basic_stmt

**call_type:**

![call_type](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAJcAAABRCAYAAADfLjTQAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAACQ1JREFUeNrtnQ9UVFUex78zA%2FJXQcxU0CACAkJdwaNSSa1hS5tr%2FoFaUzOVXd3Q3cLdPB5r28rTUUtPpLbGgrrmyiqbHvNP4UkrOwaGoq1%2FGxH8CyZ%2F4p9CMjNv733MzILMP5B5M%2FPm9zlnzpt597773vv9vu9377vvzb0AQdgJhRxOIiEGglwccuysPHzC8ZDLiRz9ZoPLn8PIsXNkFbmUFLydLwrLJRKTuAgSF0HiIggSF0HiIkhcBEHiIkhchBwQe%2BhHx2HAkVP40Vwma%2Bmuxon%2FliN7036cOFkOP18vRD4QjNRJiRiXNMyY5%2FMvSpCz%2BQu8lP4UWz%2FUuP7MD1ewas0u5K5d0KncjVsOQKPR4ncvPunS9rlbfxu2FyNXqxYVCTHYzleaymwt3ZUoOHAcz81%2BF%2FG%2FCMfW3Ex8uHo%2Bhg8Nw9srt3cUyr8Ooq7%2BJjbnfdlhfX3DLRwtKTVZ9sXLN3Dh4nWXv%2Fi66%2B9RMZicEIsr7PoqN0YuRVv1mKbVssQY7PRQYWF75VpLdxU0Gh2Wvr0Fry9%2BDjOefcy4PvKBQfjtlEeNvyuv%2F4SSExewe9trSEl9EzU%2FNaJf395uU5111d9cVFoFPtAKGNz%2BwVWHB9dC22%2BzhVpLd3ZOn7uMqpoGpD6T2CktIMDP%2BH3H7kIk%2F3I4oqNCkDAsHLv2HsGcGclu12ay5m9zojIpLnOFdnWnzsqNqjoEBfrD26uXxXyffFqIJZlTxe%2BTJyYiL%2F%2BQW4rLrL8V%2BEwDvGVOVBbFZUDH2r4sPqYIVtI1GpSznfo4u5H8%2FbzR1NQCnU6AUmn6talTZy%2FjQnklblTXI3%2FnYTTf%2Blls%2BJeWVSIifJBkx%2BqMb0ZwfzOrPa0RkMqWOmsH6GGmzv2WbXiNLZNZgTls%2BYqldE8PrDBErjRAdTEKoVolYlnGcSzPNJb3lIeAjO%2FOQe1IR8TFhop3c4eLzmLsw7Em8%2Fxn17eIiRrSodHO22Q8mi1%2BeYpkjrTXS4OjohGlUWAdKzyOGS2PWe6gSoczYWpcyge0puzZ3t9s%2BZG3Jza0tGIOCyzpggL14BHMmrgMhQhthRzxVCGGi4bt7BVL6e3LEA9QjTL2lX%2F2RERgSYAn%2FsLq5qIRsUg7fgYHHHXl9fb3wdwXkvHqXzchd91CxD44RFx%2FTn0Na7P3ImtFOnbtOYL1WX%2FA6IQo43Z7C47irZXb8OqfJrt09cbs%2FwSryvKZH1fXt2JCaSl%2BNqQVWwgyZvydye4mV7A7y8XmRNZeXPmWRGNDukn0J7AsPlqsQvPZlTPGXhHMFpZkpsLLyxNTpi%2BHv783tFodBBbgp6Ul4evDp%2BHZywOj4iM7bMMb94uWbkTR0bbDrq5tQEh0x7dG83IXicuP%2F%2F2V%2BDHA%2B9HUJX93uLB4xOLCEgS8UHIOe2zYxKq%2F9evMikyhD4O3WCHrWSErTBViLb0L1ddrbJHEQn6P9jLyMN7V15y5qCqu10KlVCJ4UJBTRJb2rzn3dLXIbLSfLQ6xcpfZkLdb%2Fub9Ylxk7MDns%2F34ipGL3e3db6kQa%2Bk2V0vNeK%2FRBxkjHsLw46fxvSMdqVIpMSTkHre42%2BP2Zq3xocz%2BE23J311%2Ft49k%2FLey3UprG901X11EC7setyp1mApCMkR7M7uL9rddJN3GsL30D67Z3QkLuYnkckn7qRK53SUXtdQ7ZI3K06xOjiKXSwe3N7e77MXl0ySGzP7kcknpr7e7vMVVeFWs973J35Lirbe7vMXV1gSQz1%2FWXadmlP5xEr2JSpC4CBIXQZC4CPsjmyGU5Db8EEUuJ4E%2F5JXToGkkLoJwl2rREMHIpRS5CBIXQZC4CBIXQeIiCBIXQeIiSFwE0ZPIohNVTnP%2FGJBDhzDN%2FeOEyOUhPFWLThyNXT0ik7gIEhdB4iIIh4uL%2Fl4mHQ75W5kjxdWSOJj%2BGCsFeju3uJO4qpr9XX9Me1dAb%2BcqtxEXi9FqlQIPkevtD7czt7fbiIs1Agr5YLzkekmMPU60twNwSA%2B9TolPlDp8%2FngYlto6IFlPseajveLYp5wFv%2F81Hn80Dtt3HkZFZS1efuk3HfJOT1%2BNZa9Px%2F2hA%2FCPTftRcPAEspbPRUhwP2Mew%2FpV78xG6OD%2B2LG7CFvzD4lpvj69MGJYOObOTEafPr6S25nZ17tRwPPM3iluE7n0Q1aebPTBn6Xe91Pj47FowURU19SjurpBXHflWjXUpRWd8hYVq9F0s037ZZd%2BFGfg%2BDD3M2N6Y1Mzsv%2B5H98dU%2BOWPt%2B1ihrotDpxH9NSk8RBetNmrRTHvpcavX1POmqIUIf1c6kE8Gm%2FMuOjMUHK%2FfKJChJHRcPPr%2Bs3q89OegS79xWLU7xwtmz7GpMnjIHijgkTgoL8xX1wIed8kMFEeQU%2FnL8qqX31ds3U2xluJS4%2BXLhOgTSFApv5KM8REfBy9uZLYIAfpk56GNkbC9B6W4OP875E%2Bqzxlu%2FWWm5DEARxeHJJLh5mR25PblduX0cOy%2B7QtyL4hAd8XHo%2Bo0OAJzLiY0zP6OBMzHvxSSRPegP9gnrjsbFxuPeegE55amubUMi8yqfPW7%2BhQJzHMTxsoF2Ox8KMJWOOnXWcsBwuLkMEY4vxfDhrpQA%2B%2F8kfdSpElsUgNEGiXnwlu8wFE53YPOLcOUfQwAF98atxI7D8%2FR04tO8dk%2BWdL6vAqrWfwsfbU6waZ894otvHZu3NiLK23vdL7CjPM2sVsmiV4uhh2J1GXHc08r%2B3hwNM3rFq%2F79J30B%2F1sBv6NgYbmzG7VYNggI7z7O4cN7T4nxA9w02PY796JFRyFnTM00dV35p0K0eXPP2D4dPzlnO7v5CQtq6FJIeiUXx8VIUl5w35l2Xsw8PRgZj0MC%2BncoJu%2B9ezJ%2BTAsJFIpcUzJqfJYqqru4mpj6TiDEj20Ys5%2B2h5W%2FMxMx57yOwjx%2Bam28jIMAX2VkZpJC7QBZvJtg69w9vQ12tqBHv%2BvgMZnfC7wCvV9XBQ6UyGbGkwp5zAFHksteVxBrulub74TOWuct8QNTmIkhcBEHiIkhcBImLIEhcBImLIHERBImLIHERcoXm%2FiHshkoOJ1FZjTf5J7g%2F%2FiY3B%2FHzomqRIAhCKv4HzYyIi4%2Bc2EMAAAAASUVORK5CYII%3D)

```
call_type
         ::= CALL
           | JUMP
```

referenced by:

* call_stmt

**call_target:**

![call_target](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAANUAAAB9CAYAAAA1DyYAAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAE6FJREFUeNrtnQlcVNUex3%2FDsO8qqCgGbgi4IJCCkYjgAm7hQu5JuIuiaebTzJdmvSx96lMT62laphnupqk910xEc0FxQxRIBRVREZF1Zt45BxjBUMAYhpn5fz%2Bfy13OuWfO5fx%2F9%2F8%2FZ%2B6dAxAEUaVItOEiPF2goKbUDk5f1nyb1NeWxvjjtzVkkRrO6x3DtOI69KgpiZoWdWh65EGiIggSFUGQqAiCREUQBImKIEhUBEGiIgiCREUQahOVVyvUe1mm8tI1icEjF%2BH8xaQK5Y3a9jtycvNq5HXcS8vA3v%2BdIQuuQv6unRefL0SVL0OKpwt%2BelGh5aVrEv37dEA9W%2Bty8ykUCkyZuRqPH2fXyOuIT7iNBUu2khKqkFe18%2FYu6OvpipsFMiTyffHsn6RQXCEyGUt0wTZ9KSbFxOFu8UnlpWsS6Q8yIZEUPrO578BZWJib4Oq12zh49AIcXrPF9EnBsLIyQ9T24yJP5Jq9MDczRmBXD7i2aFRu%2Bb%2F8ega%2FHjqH%2FPwCeLVrgZDgN2BkaIDjMVewIeoonmTloItfGwx9u5OoR0ZGFtZtPIRu%2Fu74Zt1%2BpN3PwPBBfujaua0oLzMzG1%2Bz47yO1pZm8PVxRc%2FuryNqx3Gkp2fi38t3iHyjQ7uJa3kZuXn5WPP9AUSfvAIrS1OEDgmAp3tTJN9KwxZ2vaNHsDIsCsvgXlAuV6BHN0%2Fs3HMStrZWOHXmGmJOxaNtm8aYNLYnjI0McffeI%2BzYHYMBwT5iLZPLMeqdrhopqsraOReTTIL%2FyBSwL%2FlgVak%2BlaJQZLzQW2Uptrx0TYCL5M69h0pRhYUvQ8qdB%2BgT1A4XLibjky9%2FEmm2NpZi3cCuNho1tIGZqVG5Za9cvRefLdoMf9%2FWCPBzwy%2F7TyMp%2BR5%2BO34JE6ZGsmNtMGJIZ%2Fy49Rg%2BX7xFnPPocRa%2BWLoNs%2BZ%2BD3e3Jmjn0RyjJ3%2BF2ynpIn3CtEikpD7Au0P9hTFz0Yr61bGEvoFU1I0v%2BswCymPUxBVIuJGKiWN6wq9ja4ROWIrE5LtwsLfFpas3Me3DwoeSz51PxKx569GmpaPY3%2FnLSYyJWIHc3Hz06dEevx6Mxcf%2F%2BlGkpd59KOofMmIBEhJThdA1nfLsvNgzyYCt4IJ6Dv1yChWKLS9dkz3XuLBATJnQW2zzuzQ3EI7fm63Euk9Qe9Rld%2BnyKCiQY2nkLmz4Zio82jYVx4J7eom7%2FXwm1HBmyH17eYvj9g1sENR%2FLqYxr8gxNNDHlvUzlB50%2B%2B4TrN%2BXjIYN6iDu8p%2BY1%2FdNdGjvLJYhIb7K%2Bh04ch4hfX0qdJ3nLiTieuIdrIucDD09Cdp7NseJU1exhwk%2FfHQPLP5sJIIGzMPSlbuwaevvWPbFaNg3rKM8f9rEYIQyYXOaNbbDkFGL8Nmc4WLfyNgA29bPhCXzftrEX%2Bxcgl8KgHnPe6YKiaoYOWsL5soCFeWkFxQgkX2oiUaO1Eifvb7DQ6J8Fli%2FCneZ9%2BOhWvHdXVk%2BM%2BDriXdFaFVM86Z2yGPhYSrzkCLsYGIqFhTH0sIUMllhPbjwps5aI8Tu0bYJwoZ1gVsrx0rX71pCigjV3ug6o9Tx15iXKr6hrFw8DoH95jJP1gM%2B3i6lQ6MSbzk1cawnwtgstnB4GFjVgqpJT6pzO2eX37NAgQFsLS%2BvYvoviC2PsxNvs3UXVuB%2F2fq9l6WzG%2B2CYk8VAkiTnOAg04Mry%2BjP8gxmeeP0FQhnoXy8Ki66JjQA73dxYTzKzIJNbctSaRbmxsh88mzAgxukTCaHGTun2DBfxDDW9%2BKDKzw03fPraQwM%2FRJnjy1WDqZUFP5ZTRvXx%2F7tH78wzxbWT2vt6sD6RicxPiwI1tZmZeZ7mPFECMm0AiHxq1LVLysyJ%2B9UIMEKVmgr9l%2FbyCzmoFSOS47xSI4CZGXZUUk7Z%2BtVzCGvyclHGHMkoxSsO1xW6PeXPhUvhI8kswJc2HKLhXUuZy5jannpJUM%2FXkHWl71x5gp%2B5mkZ%2BXBk5x1hHboT7q4I0JhOKxMIv%2FvyPkhF4IMbr7s3w1ff%2FKI8FnM6XngH%2F05tsHHzbyJE5Hz%2F42HhbZ4XX5mGvjNahIc8XJswMghZT3OQy1qW1%2B0OKzvraW6F6ufj5Yw%2Fb6ex0DJGeSz55j3ExiWJ7R17YnD4WBy2%2FvAP4aUmffC1CF2Lych8Ktb8ZrCCXWP3AHdIpZrxNSe3O25%2F3A65PXK75PbJ7bRYUBXRwfHziONrqRTN2f0siuXLZJlvvcxT8UK4ImNY%2F9eljD5SeellkpAA3urzPZxFqBjF7hjeqvJYVc3Y0O4IHb8UtWqZY%2FqkvhgQ%2FMZL8y9dMBJjJ6%2BE%2B5vvQaqvBxNjI0Stm46Icb3Y8a%2Fg030GrCzMhDDWrpxcoTqs23gQH326AU5NGyAx6S7mfDBQeBAuKrdWjeEVMB1SiR72bv0n7OrXeqnov%2F0qAtNmrsG8BZuEUPnAw%2BLPR4qRxdmf%2FMDqOgOmJkaY%2F9FQ9CjqX70X3kec%2F8NPR7BuwyFk5%2BSJUdCvl07QCEFxD8X6QFFMBO9wIVXglHLtvOjYVK9WWMB6CzOe91ySIrf3lBUSyQpZUFYh5aVXIkybzVa%2BzLV3q%2BrwT1Wv0z96lIU81mmsa2NV4XPu3c8Qd%2FE6tSxKHU9Lf4wcZpR8tK4yPHz4BE%2BYEPmIJA%2B7SvflHgkhFA%2BFV4Q7dx%2ByvqReha9p1KTl6NjBVQyK8NC1Mv%2BLylDydfqqCv%2BYbexnq6OsvPkVyPtKds5HB7m4WIXHsc8xFZ6KubfGLyukvPSKYpGNhZkmCHdvCbezFxGrCXe64n7F%2FoPn8PXa%2FS%2FMN2fG28pBihcZHR8GfxW4p%2BRLWdSrW%2FhF9qLlOxB98uoLy9j83QfK7fr1ar1SPbh4%2BaIpcDuDHK2Z3fWpSP5XtfOSnksZ%2FpVXUFUNlx9OQo6nKzboydGf7cZCg%2Bjm31YsNZVpE99SWdl8xLEiXyvUuJFdbmcSbOB2VwlxvDLF51d%2FT1OBg8zFdgChMbzh5YxmTew0rt7Czpi9VbuYq%2FsDWafxIos9nchUCVXD7Yzbm9aLyuSJcJG21ORENWBbZG%2FaLaroWyK%2BNab2JqoB4yJ7025RFYa62vFz04QmRIDV%2F7QNvflLECQqgiBREQSJiiCIV0drptLRlmlYCPJUNQL%2B8KU2TBZGkKgIgtDm8K%2FYY1GTEuSpCIJERRAEiYogSFQEQaIiCIJERRAkKoIgURGELqIVX%2F7WpN%2Fd1nboC3YdERVHVT%2BmSTyDHlqm8I9QUVRAkQGJiiBIVARBoiIIokaIikaRCK20L7WJqoM9%2FaAmoZ32pTZRZZtr3sz2hOagTvtSm6ikErSkpie00b7U16eSwF9bGzT1zkPk5xVU%2Bjw%2Bn%2B6t2%2BkqrRufCfHm7fvIyMjS9h6Vv%2B6JSoEhfo7a2a%2FqPWg%2BLl65Wenz%2BLShfF5gVcFng3zdbxrCJixD5Jp9WqsnYVfMvtT1%2Bep8TOlCpgneZ%2Bv5IKqFpZG78OW8UPQOaqfV11lkVxfYUl%2BnRCVVYKJMghN81voKzhpeJcTGJWHj5qN48PAJ7BvUwZAQXxgaGuDnvacwYVSQMl%2FSn%2Ffwv8OxGPVOVxw%2BFieO%2FXkzDb8eOgeXFo0wZUJvsb1zzymYGBti%2BuRgODSq%2B8zr3HuIjz%2BPQcL1VDGt6TuDOyvTok9ewYaoo8h8koOATm0wbGAnSCSVGwHmE2jv2B2DAcE%2BYi2Ty0Vd%2BcTfq9buY9eZCHs7G4wfFYjGDvWw78BZ3Ei6i2MnLuPa9RS8M6QzbGpbap2gmD31YqupzL68mX1d1anwj9lVvFyCEGZL3%2FFZ65s1g8pnaL6dko7BIxfB060pBvXvCCtLUxw9fhH16lohcvVexJyOV%2BZdyfZTUh%2BI7cO%2FXcCYiBW4nngHfYLas%2F04%2BAbNwp79Z9DFzw15efmY8o%2FVpT7r04WbUb%2ButRDU4hU7sWnrMXH8WPQljH8vEp1922AEM%2Byftv%2BOzxZtrny%2FjYWKXyzdhpARC5CQmIr09Ezk5Oah3%2FDPYaAvxZTxfdDCqSH6Df2ciTcbtazNoS%2FVQ53aFmjU0AaG%2Blr163Tg9sPtiNsTtytuX7oY%2FuHsJRxo7wzvAglWWBkg3MMFG%2FkcrVI5LjnGIzmK9d2r8vMSbtyBkaE%2Buge4w5IJyt%2B3tTJt0ICO%2BG7DIXh5OiEzM1vc%2Ffdt%2F1iZPmygH%2BbMGCi28woKsGV7NFYtGV94d3RrgqD%2B80p91rIvRqNtm8ZiOycnD5t3HMfAfm9i1bf7ET66B%2Fr19hZp3MC7952L9yOCK309RsYG2LZ%2BprgWzpad0WhoVxtTiybVbu%2FZHLv3%2FoHfmXcK7OIBU1MjBDAxe7o31XgRhbBgJ8kJDjI9uPJBCebnByuAOH3moU5fVp%2Bg1C6qYo%2FFVl3dW8JNT4F%2BbDtCLkXzGy5w8Kzib8U7eLVAm5aOaPvme2jp%2Bhp833DFuLBAWJibYPggP%2Fj1mI209McspDsJ73Yt4GD%2FbBZVqfSZU7cwMylVLj%2B%2FQPZi%2FTdtYofvNx0R24nJd0WYprzDsrQCWYHwioYGlWsOYyNDpaA4PKw7dSYB3gEflMqXny%2Br8nZT95PqNwonc0tmBnKNWUk0806BZy8itiYIvsbEAEX%2FkFhVNjA32nWRk0V%2F5PS561i5Zq%2FYXjj%2FXeExfH1cseGnI9i66wQ%2B%2BfDFg0eV7f88ycqGtbWZ2DY3M2bh2FNlWtbTXMhkCpgzYebl5v%2Bt%2F6GZqTELK1tj5b%2FHqby96GXFGtinUgcXLiXjSvxt1oeyRo9unuju7y4GLIoZMcQfy1btFtsdmRf7O2Sz%2Fg0nl%2FW31jMvxT%2BL49%2BpDTZu%2Fg0FBXKxv37TYbR2dYBtnb8%2FaNC1c1scOByLP84mKI%2Bdv5gkvCOhg56qOnianYuxEYtFyMRH7LiX%2BO%2BycGV6J5%2BWsLIyw7tDAyrtjZ5n6szVrAw9PHqcBR8vZ4wN7SaOTxrbE%2BOmrBTfR1lbmokRwLUrI6rk%2BpydGmLBvBEYGb6c9Z8MkcM8nwkLEdcy70xUH2px4Txcq8rwgZdXmdfp%2BVMLenoSNGCd%2BpLw0b1eA%2Bfj1KGFIkz7u%2FB%2Bkr6BFHVtrP6SxvtufACDh52qgD81Yc7CwVq1zKuszJKv02tC%2BFfVdkae6iXYN6xT5vFv1u3H28E%2BVSIozvOiLUl54d7wMUuQnZNXZppbK0d89MHbLz1fVWIlSFSVwsfLRQxD1wS%2B%2F3oKNQiJSvPR9sd3iOqBXqcnCBIVQZCoCIJERRAEiYogSFQEQaIiCIJERRDqQGu%2B%2FKVpXgjyVFUIf2iS3u8hSFQEQeGfZngsalKCPBVBkKgIgiBREQSJiiBIVARBkKgIgkRFECQqgtBFtOLLX3X%2Frnd1Ql9wk6iqjcr8mKamQg8NU%2FhHqMgr65JnJlERBEGiIggSFUGQqMqE9wloFItQJZIiO9MZUeV0sIcxtTuhKorsK0eXRJWWbY561PSEqiiyrzSdERXzyfFSCVpS0xOqgtsXtzOdERULdqPZH39qekKFRuYv7EwNqOWJCrketujJsdfPER8eTqq%2BuJdPKD39o3XK%2FbmzBqGl82v48JP1uHotRRyrXcscTs0aoF9vbzRxrK%2FM%2B0PUEWzbFfOXMj%2BbM0zk5zMfyuQyrFoyARbmJiLt8LE4HI%2B5grBhAZg4%2FZsX1qu4HkTVwOzKOFOBIczOAnVGVGcvItbTBRcyTfA%2B251fXZ9rb1cH82cPRUCfj%2FDzptlo1sROHOez1nt5OsHftzXSH2TiwJHz6N53LhZ%2BGoq3eniJPH%2FeTIORoT4mjulRqky7%2BrXE%2BtSZa2jYoDZWfbsP708KFsfu33%2BMy1dvwdraDNMm9hHH%2BKz0g8IWYvnCMahf11oca9SAphKtSors6gK3M50RlYh5FZgok%2BCEhzPOnbmCn6vjMw2YKLjhF4vByNBAmcYF1qG9s9juFdgOvYPaY0zECrRzb66cu9fW1kqZpyymR%2FTFlJmrETrUHza1n83pa2xkqDwvP69ArD3cmsChUV1SQBXD7KkXW01l9uWtrjqo7cvfk1cQL5cgRCLBd8xrzW7WDEY1qXG413JxboTd%2B%2F5QHktLy0A0q3jJJfNJtjLd2cke3f3dsSxyN1l3NcPth9sRtyduV9y%2B1FUXtT6lfvYSDrAbuHeBBCusDBDu4YKNUOCgVI5LjvFIjgJk6qyfYyNb3EpJV%2B5funITi5bv%2FEufyqKZiXJ%2FGgv9ur41B6NHdCNLVyEhLNhJcoKDTA%2BuRYMSgxVAnD7zUKcvq09QahdVscdiq67uLeGmp0A%2Fth0hl6L5DRc4eKr5qYtHGVlo2thOud%2BpYyss%2BdfIl57zmr0NQvr6MPFtF7Pdqwpdf1L9RuHTEsnMQK4xK4lm3ilQXX2oGieqkoMXbBVbUwwsJfUBC%2B%2BuYua0AZU%2Bd%2FL43ugYOBM2dSxV9v%2BilxVrLvRA7XNkZmZj%2F8FzCBnxBYYN8oNri0aVLsOWiSlsWBes%2FeEg%2FUN1EH1dutir125j%2BNglYrv3oE%2BxavF4eLRtKvanzlojFlMTI7RwaohJY3tiUP%2BOpc6P2va7WEqy68cPlWWUZHxYIL778RBZmA6iFSEED%2F907XV6Cv8o%2FCMIEhVBECQqgiBREQSJiiAIEhVBkKgIgkRFEASJiiBIVARBoiIInUVrHqilaWaImoJUGy4i9T7m8qWBLT7WlYbj10vmS%2BEfQRAEQVSe%2FwP8o%2BhF5LkMhAAAAABJRU5ErkJggg%3D%3D)

```
call_target
         ::= int_const_expr
           | symbol_ref
           | IDENT
```

referenced by:

* call_stmt
* jump_sp_stmt

**call_arg:**

![call_arg](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAATEAAABFCAYAAAAiodELAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAEFtJREFUeNrtnQd4VFXax%2F9T0kgjjUCIUkJLTEIJHRQMEupmQYgr4ApLUaSIwCKWXQTWZRdRWFSEDxXFQouAqJQPJIgiJSTUQEyBJJCQ3nsyM3fPuTOJYR%2BSmQm5M0nm%2FT3Pfe7MLeeee%2B77%2Fu%2F7ntsAgiCIFoysuVREiHrB6ptz55fcjM9%2FPu5WYfe8wiqb7LyKeuvn5mKjsrezKnB3tTmdeKf8X6culEXT4SQIy%2FO3ZiFiJz4PeumHk3c3xCcV2U8MfgTD%2B7dD%2B3Zt0M7Ntt51snIrkJFVhjNRWTj04x2VrbUiKi2n7LnoGNwiEyUIy%2FE3s4qYIKyW73t%2F%2F95PdsdPfe5pHzw7sQusreRGl1NVrcGeH5LwyZ74ivJq4emo6%2BqjZKoEYRn%2BpjDnxv1cc%2Fft2Jsw9d03ByBkuBcUisZpKl%2Bvt68r%2Bge6K0%2F8kvash4sm9V42LpPZEkTr9zeziRgPaT%2FYGbuCN2hAT5cmKdPT3Q79A9zlh0%2Blhnq4CXczSMgIotX7m1lEjHcqvr878uSYEd7W%2FIzQlPCGLa9Uy2Ji8yd4eSCKnSESyYQJi04jW7m%2Fyc3RqPyqSGJKsT3PyaXgxWk9YW0tV2oE7A3yhw%2BZMWHJtHZ%2FM4uI3UzInzl2RMdGdSoaAi93YG8PftVCCTXeJTMmLJnW7m9mEbG420U%2Bw%2Ft7SrqNkCfEsNmODcP7PobeZMqEpdLa%2Fc0sIpabV2nbsX0bSbfh162t9ocMWXINppApE5ZKa%2Fc3s4hYXlGlzM3Zxqh1cvIqcTe9DAVF1QYt7%2B1Ze9Ac2DCaTJmwVAz1N0GA6GN8qKrSGLUNc%2FqbKGKD%2FNFgrKlvvrFo1ALkRtyjkpBSgqA%2FnsSTM34WG9igHdOVzw6MKxs9SqZMWCqG%2BpuMLbLpswT0Cz2Jpf%2B8apyQNMLfHlZXatYXRaxajXtBvthXX6H65kvNkrVXUVahxruvBSKgp7NR68q0ZwZPMmWC0M%2BGlYEI7OWMfUdSceLXTKPXN8bfGqsrA30xOcgPd1VqJPH%2FSt2GuZiFqdVspi8OKhVYfCEGmXUq1uB8Kfk5MgcXr%2BVhcB9XTApp9D0uCjJPgjDAUVhEtW65PybO%2BxUbP0nA6GGekvmbsbrCxUstw%2FsssPSG8Pt05X05sfZ%2FvYXqmy8FR09niOPpoZQREoQpGMQChq6P2iP6Rj4ycirQ3t1W0u3p05X6xOuBIlZfocZutCm5FlcojgcEupB1EYSJGBDggtt3ShETVyS5iNWrKzIcVQFr6xOvBkWsBg1whcV7YwU981UqJLGN2kmxY%2FkFVeLYzcXmocph9RPINAnCMNxdtf6WV1hlcn%2FjusJSzQkqAVPZWKOvIGU9uepZtmIaGz%2FFCvyEjZc2NN9KifXGRGLG7KCDg7aK5RVquDhZNfqgRMc2%2FNqhMJbHJ%2FdAJ7UcfmzJYLbwNFbJGKWAhZG%2FIZ7MmjAHA3uhh0qGLcwe%2FZk97maeE6HQ4GbneKSEA2qpBKWsTFu0vZ1SEn97UL3q6gob%2F5%2BtFXZUVGM2C5TmCjIUgkdk%2BkSsphBBW8gFKwV8uTixjS1taL6UB7FzR3tcvlGAmPhCeLWTLqwVDSIet9lPPvzQrRted7bCCpaLn%2B%2Frh7DLN3GSXIowJczuRrFUKpz53cbCakxMTERlzbyLEm%2Bb%2Bxun6yNtJN9PPbqybJA%2F1lersbI%2BMasrYuF6xCnclOJVQ%2FAQDxw8nob9R9MQMtx0d0roDObtfr3ElDmcnREHU0RGmDIC4wImCHj%2B0m%2F4wZTbTkkrQ1RMvhg09PJxknpzenVFN61eMau5Y7%2BcFZKqZIVcisWyBxSkb75kTA7pKHYsfh%2BRjtjEIpMbk86ANrKI7ENyLcJU6Oxto6kFjLPh4zjx7v35033EG2AlxChd4fP5cgoFurP6hfP1a0WMFdKloUL0zZcSG2s51v3VH9UqDRa8dRnFpSqTG5RjufhkfgA9SE6YJI3U2lmAzu5MCs96%2BI2uft2dMDuss6Tbaqyu1IgZX782nTREAZuy8vwRBWMePfrDqA744t0BKCyuRmp6GXy76Q9xS0qrm6y%2BPyWjIsgPu3QPtl4lNyOkRLQzGXZxuzOlv%2FHoi18KfH9VHwzt5yYGEIbSGH97WF2pWV9pjoPU1tFalVtYqfRwNbyjftyI9kZtIyG5iVNPARHs%2BL5CLkZIDbOzITIB%2FzG1v%2FHUccqYjo3aRpP7mzEibY6NOtpbFaRllEm6jcirOdoDI6AYBl6KbrCPQsANdox7kIsRUsPtjNubJftbsxcxNxeb02eipO1eO3HmnvasJkMWGz30xuxKxDI8yMUIE%2BChszeL9bdmL2L8C8KHI1JV%2FPt1UpCUWozk1JKaPeT3fd152DLPpYr9E7bkX4QJsNXZm8X6W7MXMf4JdGsreRT%2FAKcUvLY%2Bum4HQyk%2FUTRNV0Xz%2BGI6YQkZZdM9JtdC%2Fa15ixiHfwKdf0H4elx%2Bk5b7zvYY3EoprmnQ22wI0sixn%2FyCsGRas7%2BZTcSi2b5XVQtTFr11Xt1UDcsbdF%2Fds40MZ9gp7eLlG3RbBGHZtGZ%2FM%2BvLAtOyhAQ3F83doxGpoWWVallfP7dGfVqd5%2BTz3zyHMxcz64a1X7NGDWF7OC09C01y1Lw8sDo9B2vIJQgpkcrOWpq%2FGYrS3Afs0k181t9XI%2F9y%2F61te75LUg7u446xI7zRw8cJnbwcHrhOWYWKf4YKkVey8eOZe6xRS%2B5fQNugwTIZ%2FhLFzkDkFgTRev1N2RwaNioWn%2FZ7TEhTV6nDT0dmKtjQuHeT8ZychbTg70CTY2b0DRxrzgZF7zhrRelabMu56NPa%2FE3ZXBr2EmuAIH%2F0Eb8gLOBxpurpbLKzIIMr%2B29fz2olzHKyZQLiNTKUMUUYKAccBCWGXmohEVjULztIAVo4%2FR%2Bf3fIislbkb8rm1LDR2oaYzB%2BA1T2nGAIN03pZvY3qIAgoYA3Pv9wZKSiwJoo68QkzRtUtKSJrLf6mbI6Nq7u6wYdV5B4EQf7WEHI6hARBtGRIxAiCIBGzIOjRI0JqmvSRIxIx4n%2BpGOJND4ET0qGzrwpqCRIxqcgud4AnNQMhFTr7yqaWIBGTKpeMV8jwGLUEIRXcvridUUuQiEmCDDjHH6%2BgliAkNLJg0c4IEjEpEF8xImD6yM6m7xebNuc9XLuRbNCy4Qd%2FRUVlVbNsw6zsQhz78RIZ0wMQ7YrZF706ikRMMnQ3BV4vtsNfTb3tKaFD4OnRVn%2FKKwh45fVPUVRU3izbMD4xDev%2Fc4CM6QHo7Oo6vTrKOJTUBMahELBILcN5%2FmVwU37YNDevGDLdl0z%2F%2F%2BRlODrYIS4hDRE%2FX0enRz2wYvEkODvbI%2Fzbs%2BIy23Ycg4O9LcaO7ge%2Fno%2FoLf%2FoiUs4ceoKqqtVGDSgJ8ImDYWNtRXOXvgNu8J%2FRklpBZ4aGYgZz4wQ61FYWIqdu08hJLgvPt55HNk5hfjzsyMx%2Bsk%2BWocsLsd2Np3Xsa2TPZ4Y5ocJY%2Foj%2FNBZ5OYWY%2BOHh8Tl5s0KEfelISqrqrHjy5M4F%2FkbnJ3aYNb0UQjq64OU1GzsZ%2Fs7byYrw1FbBo%2FyNBoB40OC8N2RSHh4OOPipQRcuBiPPoFdsPjFCbC1sUZmVgEOHb6AqZOGiWO1RoO5z482m10xe5rIRsuYfQ0mL6NITFKYH%2FGHX8OYH38R5Iu%2FdesGG1Nsl4tSRlZ%2BrYjNXvgB7mXkIXTcAFy%2FkYJ%2FbNgnzvNw136T06uDKx7p6A77Nvqrt%2FXTY1j33jcIfiIAo0b2xtHj0UhOycIvZ29iwbJtbFogZk5%2FEnsOnMG%2FN2kznYKiUryz%2BSDeWPMl%2BvbuigH9umPeko%2BQdi9XnL9g%2BTbcS8%2FDX2YEi%2BLBRVKsn5sTlFYKsW58UCr1v9Ju7qItSLydjkUvTMDIxwMwa8FmJKVkopO3B27G3cXyN7UP0V%2B5loQ31n6FwMc6i%2F%2B%2FOxqJF17egsrKaoSOH4gTEVex%2Bl97xHnpmfli%2FcNmrkdiUroorOaA2w%2B3I25P3K64fZGXUSQmfVp5EycH9sJglQxbnK2wsJ8vdvPvUio0uNk5HinhJvhk1fzZY%2FHKgj%2BIv3kUwh1S7FcZ7i%2BOQ8cNRDsWhehDpdJg87bvsevjZejXx0ecNmnCIDGaeZsJ40ImHJMnaoMDby93jJuyBstZ1MextlJi%2F1crayPEbw%2BfxzUmqB293BATewdrJw%2FHENZQfJge9kRt%2FU6evoawycMM2s8r15NwKykDO7ctgVwuw8Cg7jh%2FMQ5HmNAunDcem9bNwbipa7F56%2FfYe%2BBXfPDOPHh3dKtdf%2FmiSZg1Q3stpluXDpg%2B9z2sW%2FVn8b%2BNrRUOfvU6nFh0ZyrCWDCf3AOd1HL46TrxpwlAjJJFYNGxJGAkYiaOyNhotPgGAAFPs98vaxToftsXnYJMcFd%2F3a858xSrurpxupnJojue%2BtVEL7XlM8G4lZQppmo1dPfpgCqWbqazCJDDxatGwDhOjm2gVmvrwYVu2Rs7RHHt16crZj%2F3FHr7dza6fgmJ98TUb%2BjolfdNf9Tbo1bAt26aj7FPr2GR2ngMG%2Bx733J1qoeunT3FtLi0VHsvKU8rm1rA9L0j7rb2bvwUVq0EZiXnWPQ1lvrASMTMG5X9%2FgaAJjd4U8D7zbgQFRSXwt3V6b55jg62KC75%2FQIBFwC1WgN7tk6NENTHc8%2BMEC9G8FT3yIlo%2FGnWBlw%2Bs0mcxy8%2BGArflk%2BX9jj%2B7ep6l9l%2F6CwC%2FDrh0OFIvDR7HNq2ffCbZPILS0ThatNGuh6AlvQqHuoTI5olXJB4dMH7kAyBXwzo37cbPvr4aO20C9HxYvQTPCIQu7%2F5RUw5OV%2Fu%2BUmMpv5X7B4oLN%2BdE9NNnv4tmDMOpWUVqKyoFuuWwcouLas0qH7DBvXCnbRslqpeqJ2WcjcLV2OSxd%2BHjlzAT2dicODr18QobPGr28VUuIbCYu2Xr7n4bmH7OGZUXygUZPYUiRHNmhdnjcGslzbDxcUBKxZPxtRJQxtcfvP6OXhxyVb0Hb4UCqUcdrY2CN%2B5Ai%2FPn8imf4RhY1bC2dFeFKLPty4xqA47d0fg7%2F%2FchR4%2BXkhKzsSqV%2F8kRkhcxHr7d8GgUSugkMlx7MBb6NDepUGR%2Feyjl7H89R1Yu36vKIy8o37Tv%2BeIVz7%2F9o%2BvWV1Xoo2dDd7%2B%2BwyM1%2FWPLV0YKq7%2F9b7T2LnrFMorqsSrtNs3LyADaW0nbmoC88HTSaleT11QUIoqlQrt3J0NXicrp1CMUtxcHO%2Bbnp1bhAomAvxqojHk55eghAkfv2LK07i68EiPC0%2FNrRGGkJGZDzmrn6H7NHfxh3h8iJ94EYGnwsa0hTHUfT01pZMUiRFNRE2%2F0PGIK9j%2B%2BfF6l1u18pnaTv36nJzfFtEYeCTIhwfh2U574%2B57Hx7Cuci4esv45otXa3%2B393RpVD24WPKBIBEjWiAhwX3EobmyfNEfJSubXxE15DYTgkSMIJolQwf1okawAOgyDUEQJGIEQRAkYgRBECRiBEGQiBEEQZCIEQRBkIgRBEGQiBEE0bqhm13NTN3n7giCMB4FNYH5SM%2FBGj54eWA1tUbrOabUCpROEgRBEARBWAb%2FBY6yiu7i22%2BMAAAAAElFTkSuQmCC)

```
call_arg ::= '(' int_const_expr? ')'
```

referenced by:

* call_stmt
* jump_sp_stmt

**jump_sp_stmt:**

![jump_sp_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAfsAAABFCAYAAABNPE9jAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAFqVJREFUeNrtnQlcVFX7x3%2FsoLjv%2B4YLuCLuS5qae2apmaapuOa%2BvGX5fysz317N3EqNzCjTXMI0c9dXSy13cd9XFHdQAREVhvmf58BMgMgMiODg7%2Fv5DHe49865d85z7vk9z3POvQMQQgghJEtjlxkH9fGEkVWfOvafSD9bsf7ZLtgubN9ehKQGx8w68L7t%2Fqx9K6nV2Jf1T9guaC9C0ow9q8A2kKiLkRdhu6C9CKHYE0IIIYRiTwghhFDsCSGEEEKxJ4QQQgjFnhBCCCEUe0IIIYRQ7AkhhBBCsSeE2AYR96IQeidCv4%2BJNuDK1VBWCiEZhH6CXt0qKLT7KG48aSdL258lX3%2B7Blv%2FPqbfDx3QFk0bVcEvK%2F7G1Wu3MXLwq4n2fbvfNEz86G2UKVUI3%2F24ERu2HMTMSX1RrGg%2B8z6m9VM%2F74NSxQtg%2BapdWBSwTW%2FL5uYM72pl0bdnC%2BTMmc3iuUmH5ffDBqxatwdh4feRN487fGp4YECflihRLD82quPMVccT3FydUMWrFPr3aqn3sxW69Z2KD0d3QrXKpS3uG6Ds8mrb2nB1cX7uvsfNW2EIPHQOrVvU5FWfSSxZth0HDl%2FAnGkDERR8C207T8Cp%2FXMsfk4chF17TqFdq1qZct6Hj11ErMGIGtXK0Igkw3la%2FTV9Xkf2SrOu%2BnjiF1mZ3M6Wtj9L2rxSE2OGdkBIaBhCQsL1ustXQnD67NXH9t219zTuRT7Q788H3cCxk5cw5%2Ft1iSKLufM3Ys%2F%2B07gfv59EF7GGWH2Mbp1fwq59p9Gl1xeIjbX8kKtxExZi3ab9GD%2BuGwJ%2Beh8fjOqEiMgo7FbnIdy4eRfhygmQsnu%2B9TKOn7yMDm%2F9Bw8fRdtMQ%2BvUoT4KFchtcT%2Bj0YiRH36vvm%2FUc%2Fk9Tp%2B9gskzlrPnsEGCgm7i08lLM%2B34q9fvw4rVu2gIkimkVX%2FreOJ1Hy9cjjHggjmyt4tL53cxGNRGT6xwdMCwhJ6Epe3PEo%2ByRfQre3bXVH%2F2zY4NsUJF7iMHd0CBfDmxcOlWvN6%2BHr79cUOi%2FfLmdUf9OpX0%2B0b1POFZZyhOnQmGZ8USKZa%2FccsBTPr0HdSvXVH%2FL9H8Sw0rIyYm1ryPZAhMZb%2FcqIouO%2FDgOfO6553Q2xGws4v77Y4Nmw8gh7ubqpsr2LLtCEqVLID3hnVErlzZEfDbDr2Pn%2F96uCtbtVZOmpeF%2BhPWbQrEpj8OIjo6BnVVPXbp2AAuzk7YsfukzriI89aiaTW8%2FWYTfR5hYZGYv%2FgPtGzmje%2BU43YrJEw5Uk3xyss14hy6iDiHTs4xd87syh5eOiIMWLkDoaERmDZrpd6vf%2B%2BW%2BrukhDhl%2Fgs2Y%2Beek8il7Ni7e3P4eJfTUemv6vtKliZHjrgy1v8vUDuIbVv64Pe1e1CgQC7sDTyjHT%2BJCIcNbKczHuIArlyzG51V25SlITYW%2Fd55xfY6oEcx%2BGnpn7otu6t6bN6kmrJJDfy18zhWrduLW6HhyJc3B9q3qo0mjSo%2F1bF%2B%2Be1vhEfcN9uu99vNcf3mHfz8y1Zdn9mzuaJp4yr62hbOXbiunPZTaNa4GlZv2KfbY7fOjXEpOAT%2BC%2F%2BHs%2BeuoY5Pee2g9lFlmbJ4IuhrN%2B6HQTn%2Fr7Wrg9fa1sXFSze1HWPUOjl%2B3jw51PGbUYFIhpFa%2FRWRN9jhK4MRxRM%2BmDnRmL0xTvyl0ODkPAlL2583cisR6qTEY%2B4PG3TntECJRL9eKXesUQ8e6U7AxcXJYvkVKxTXwnPkeFCiTICjY%2FJTIR4qQYtWlfc8prmfhIi3dKwmsfcd8jWuXr%2BNDm1q48ixIHw25Re9rUD%2BnHpZtEhe7fRkz%2BZisexvvl%2BPz6cuQ7OXqqJ50%2BpYpzraiyqK277jOAaP9lPrqqFX95exZPlfmDT9V%2F2Zu%2BGR%2BGLmCoz7dAG8q5dF7Zrl0X%2FEHPP47%2BAxfnqIp4%2FqkEVkxZnQ56ecPUcnB31u8nJUV4wl%2Bg2djbPnr2HogHZKTKqi9%2BCZuBB0Qw%2F%2FHD91GWP%2BL%2B5HYw4evqCzPKahjt%2FX7cGA4bPx8GE0OrStg01bDmH8f5fobddu3NHn36XXZJy9cE07ILZIP%2FX9%2FlAOX6fXGqBypRKYMy8ug3b9xl11XRRDr27NdH0MGDFbXx9PQ8H8ubS9TLZzUu8ly1e0cF6djWuinOiJUwK0k6Gzehev63bVY8A0BF8JQYhyPGQo4LVu%2F4G9chh9e7bQ5X359W8IU06EMPObVfhJXcsi%2Fj26NsGXX63UTpur6gfcs7tph0GOXbhQbhCSGVjSX1MkbwCWQ4Q%2BCY4WCtWehKXtGRnpp5aBKoJr0fETHWU0Ud6%2FdBxJuX37no7eZNzdz3%2BDEp9qKFu6sMWyp07sgw%2BV6LR%2F8zM42DugsldJFV3U1RGgvX1cNCxpfClbIlT%2FhZtRo0oZVK9qu2N%2Fg3xbm%2BdKSFQrwiXIXAqhQ5s6KFggl8VyJPsx028VFn03GjVrlNPrOrarq52micqBGKIE1hSpFS%2BaH206fYoxwzrq%2F52dHPHrwrHmjMNva3bhsHI8ZG7G0ROXMOH1RjpzIq%2FuXV4yn9%2FmrYfR5fWGVn3Pg0cu6Ahxvt8IbUuJBHftPaUjvyH922L6533RpvMELRJLl%2F%2BNr7%2Foj%2BLF%2FpkbMmZoR3ME6FGmCLr3m4rPP%2B6p%2F3dxdcKKhR9aNS%2FkeUTGsPeoaDdw2zS4ucY5rj26NtXLzsq5lrks4sg4OzvAo1wR7QxV9SqV5uOJ7cThS2g7yaDJS5wxye74KMdv%2F8GzeFU5oUKeXO5YE%2FCR2bGeNXctqqtr7%2BOxXfX%2F4mB%2B8VVc232knHBxVrav%2F6%2B57cocD4n0xVnzrFhcO27Wth1CMkj04%2FTXDutigAlJI3mrxN5ErOrzVIza2mhhe0wMLqiDumXUlxXv3JjMt5KI3CSyJgoXyoNWzbwxacZybFv7ebLlnTl%2FFVNn%2Fa4n0ckcgT49mlt1HtK5L5g7EvejHuo5BCIG02b%2FroV9%2BMD2ep%2FLV0N02S7Ojkp8KuqUbdJzTA2Z%2FYtZ9g7%2FnLuktqNVx54Wbty8o1PuSSf%2BSd2cu3BDp8hNlFeCIR3yteu349Jayv4moRdy5sgGgyHuPMQhGD3OXzshNWuUhW%2BPFqqTL53q8zuj7Ckp4gavjE20vqSK6k2OzjfTB6H1G5%2FqiaMN63kmTr0lMHHZ0oV0m4iMnyciApTeQp%2BR7eLMuWvaJiahN9lN%2BDlgK6bMWIHyHkWVk5ZPR9WSFk9vZBjp%2FY9%2FRBEV3XuUKYzzQTdRqGCeBG3CLVEGTTIyItrJIdG%2FXMMynyYh1dLQbmzlOia2j%2BivuuraxRjRWS0tzjJLVuzVB3eoD15RyxaqwHlqOSql7SrQmpyayD4tDV1mw5rIk9tddyIJEeEQQcibO8djn5XxUumcShbPn2zZdWtVwLyvh6a50rO5uaCGitbldefuPRw4dN68rXKlklj20%2FvpZuD9J2CXFToaSYuKYN%2BNiET%2BvDkTbcvh7qonU5oQoRTBkHkbJsF8Ej3ebKInFcoQw9pN%2B9G19xQc%2BGu62Rm0FjlWOSUiG38b%2F8R9fl25Q0esK9fswbu%2BbZA7d%2FZk97sTdk8LTzYrhjZsoV2I7cLC7j%2B2XmymJ60u%2B9g8X0OGM54WaSdJbTf2k%2Fn4ZOxb5kh%2B8vTl5sm5ySFtKmmf8c%2F3iYtTNq%2F67InDT6lpO%2Blhry6Aw8UKKGWwh5fas5nauZs6g6OORgzZcxKnKXVZgzqVUCHGDrOVfaso%2By5WV%2BAWh1gcL30aQQGAIbnrMqH%2BquW3Kkb1fxANXxV49zPaISy5FL52yJMWohYBqgBP9Qp2dIBn4AmMtrT9WaXwZfxckPE28cyLxadJZdLV3gNn9cQZE7PnrUXF8kWVp5%2FnsXJKlyyo08%2FpTc8B03Ho6EXz%2FzdDwvDHtqOo5e3xwjVa6ZAlWpW0qjXIpD6ppznf%2FXO3xO79p3U03axJNSxett080XHBkj91dJ7UKUhWgH%2FfqdP8knYf3LcNIu8%2FwEN1Jci5XVdlR95%2FaNX5NaxbCZeu3MJva3ab1wVdvmm298q1u%2FHnX0ex%2FOcPdFQ%2F7P25ieZtmMaCxUmZrb5jq%2BbecHDIGo%2B1qKec4%2Bs37uiJldoRV9979fq9MKqlQdlMJlgKMrntVDJ3zaQWsZ3Mbbh7N9K8TubguLo6mfsH6Q9SokXT6nqy3t%2B7Tuj5FjJeb4iJywZJ6l6G1qbMXG7OQsixtv51zJw5kiGdjEQ6%2Br2ncT7wJFZLHxsWjdKq%2F91qsMMuby80B7F5xI5iT7Gr2FfsLPYWu5uE3hp93nEYR2Xp4IDyyicNUPtFqJ2DU4rspRDxFHY7qUKSEXBL29OdXoPiJkTJhdfptfq6kxFkPH3SJz3Rc%2BAMPeM6KuqREo9smDtzSIYaK1%2B%2BnDpydFIVIjOCb6tOp7uKLAf2af1CNt6BvVuh97szkSePO94b9roev02JmZP7YuCIb%2BDdaBQcHO3h5uqCgPnvYfig9mr9HDRsNRa5cmTXgv3jNyOsOof5i7fgo%2F8sQoVyRXHh4g18%2FH5XHXGLYMiYbd3m78HBzh7rl3%2BSrGOY0Bn5Yc5wjPnQHxMmL9UOhIzbTp%2FUV8%2F0%2F%2FdnP6tzHauzOvJsh7bx4%2FejhnTQn5eZ4vMX%2FaEdVoly584cnGXsLHXjN%2BNdPVzi5rIY4ZFR8FZi2b51bQwb0A4tO47XEzZlgqxJ%2BJ8GybDIjP6GrT%2BAs6Ojvs117KhOGDTSTx%2FH2dlRCXbKE%2Bca1ffCv4Z11JkHGXLo%2BkYjvXSKn6jpN%2B1d7bBVazgCudyz4U54JEa%2B%2B6o%2BrszM%2F3HRZtRqOkYPC65e%2Bu8Mr%2FOzZyFe6sSalfTQaYCKCOsxwrftiN6ghFmJ8zsi8Nb4f5b0N37d6LpVMDnagLFJI327%2BDTBfVWInyok2XS8pe1pSRfu2%2B5vcT9JnQVfDdWdRnK3SYl3f%2F3WXTgqlyaljvtZE3wlVM8hKFQwtxaF9KZWY1%2Br03%2FpWf9pQRyzRzExyU6EfBKSEZGoN1%2BexEMwcvvWAyWWMgs6Ndy5cw%2F3lIMgQpD0zgfJHIhAm26ZswaJYu3V%2BVn7nfoNm4XGSlxkQpekllNTF7bWLqTti6Od8PoMuR2urk1Dul%2BTMmlO5r6Is6GzJ2GRCL8XpecGJJzDYQ2SdWjZ8RMc3zM70d0zt1XbuX%2F%2FYaLJlqYMjdyF8jTXeHrZS9lJvI2XVBktKZu2ibKhPG1tm7LhRCv2TZP%2Bymx9EX3V0Aap42TTrVY5t2VSKsTS9meFXMApdfRO6sJPrRBYy5qN%2B%2FHDws1P3D7x391RqULc0EjSjuFFxjRunfDpgcnx8dg3zZPzniSGcrtcWpDMQp4nPKVQOmth6qyV2Lnn1BPLSDjPQqK5tCBOhbyyMsm1fWuGWxLylu%2BXiZ5NkZDa3h4qin8jrp0kuctDRN8k%2FNbQ%2BZ0v4FG2sE7Ly4Ny5JbKpLfJytMtk3vCpTijz6qvSS05ovBlhBuGeFdG9QPHcIi9jm0hdkMsqio7drBm%2F7Tqb8JIX5eTYKWlD71QtGvpo18kbcgDVuT1vDJm6GvPrGy5A8Ca2w9JHEv8%2F5UhxxncrzXOnb%2BuH5Ajt0rKA5JskT8v4oGPFxbZx6KT%2Bpdib2Nou9lhkdgxFaKdZkyfd2TVE5K%2BNKhbiZXwHCLPz5BXlsCILUZgJK1qi6ZDfTsjZmS4k8GqJ4QQ28JgxDE7oAJrwvYQu4n9KPaEEEJSxO2eTs0WYE3YJAXi7UexJ4QQ8mR2BuvxXlfWhE3iGm8%2Fij0hhJAUkSc42bEabBK7ePtR7AkhhBBCsSeEEEIIxZ4QQgghFHtCCCHkBSDTHqqT8DnRhPVP2C5I5vI8%2FPT180p6%2FPbECyn2popj48rchsv6J2wXJCHP6gey6ABnPkzjE0IIISkgDrCtO8GZ%2Bmz8rJAayQqRHCFsF4RkbRjZE0IIIRR7QgghhFDsCSGEZDR8ZK7tkSmPyqXYE0KI7fKgfnH%2BGI4tEW%2BvB5lxbIo9IYTYJrei3FGI1WA7xNvrFsWeEEKIVRiB0w52qMyasB3EXmI3ij0hhBCrsAN2qj%2FNbOV8I%2B5FIfROhH4fE23AlauhL6LRmmm7UewJIYRYQ6w9flXhffempW1j3H7Jsu346LNF%2Bn1Q8C00e%2FWjF8pe2k7KXtpuFHtCCCHWcOAYDqnFkQg3%2FIu18fwTb6cj8XbLcBxpAkIIsU0cjBhqsMOumpVwMPAkVmfUcaMfxeCnpX8i8OA5uLu7oXmTamjZrAb%2B2nkcq9btxa3QcOTLmwPtW9VGk0ZPN63gXuQDTJu1EjdvhSE6xoDKniXQv1dLuLk6IyYmFl%2F5rULfni2wfvMBPTQwbEA7xMTGYt78TdgbeAalShREyeL5Ua9ORVT1KpUpdlL2aa8Wo5W96mVWW6HYE0KIjbLnJE57e6GLPRDg44lpYdGYcvYsHj7r4%2FYbPhsGQyx8lcgGXwnBnHnrtNhfv3EXFSsUQ9vStXAp%2BBYGjJiNZQvGPpXIRiqxd3R0QJuWPnBxdoTf9%2BtxOTgEUz7rjRhDDKYqR2D1hn2oXqU0smVzgdEO6D9stv7sO91exu07EZg%2B53dkz%2B6a4WLv4QGXXE54T4Q%2B1g5d9p%2FInMl5FHtCCLFxDhzH5jqVUC%2FGDrOVsAyp6YnFMGKLQyyOlz6NoADAkJ7HO3zsIvaoiDlw2zQdXQs9ujbVy84dG%2BjJd2cvXIOzswM8yhXBwcMXnkpkCxXMjXFjOuNmSBjOnb%2BGpo2rYvmqxHPcvp0xGOXVsYQjx4MQePg8DmyfppwDJ71u7cb9GWKLLoDDxQooZbCHV%2FxkvG5G4KijiugzU%2Bgp9oQQkkUifLV4xbsyqtsb8YZ6PzzWAeXPe6KUTzo%2FZe%2FMuWtaWE1CL9jbxx3i54CtmDJjBcp7FEXxovkQEhquMwBPw%2BUrIRg06hsd4XtWLIGIiKjHyiyYP6f5%2FfmL11GmVEGz0Kcnln757nzc0%2FGCVG2cUbW%2BU0XzrTNrjJ5iTwghWTXKjxOWNImLtT%2Fh6p7dFWFh9x9bL7fWjZuwEOuWfQwvJcrCgOGzn%2Fo7zZizSpcnaXthp%2FJsPhi%2F4In753B3007Gs8CWfxGSs%2FEJIYRYTb1aFXD9xh1s%2BuOg%2Fj821ojV6%2FfCqJaGmFhzRH3x0k2cOnv1qY8XHR0DF5e4MmWIYPPWwynuX7tmeeV4PMC8nzbpKH%2FJr9tx6MjFF95ujOwJIYRYTa5c2eE3412MHucPN5fFCI%2BMgnfVMmjfuraeCd%2By43gUyJ8TudV%2B6ZFKH%2BjbCt19p2H9%2FwJhNAI%2BNcqluL9E9t%2FPGoqJX%2FyC75Xgv9SgMkqXKggHhxc7tuUvJhFCCNFp%2FH3b%2FVP1meAroUr8s2mBNRFyOxzRjwwoUjhPup3bg4ePcCskHPnz5Uw0V8AaJPPQqNWHmD7JF3V9KqT62LUa%2B5rf23Ian5E9IYSQNFG8WL7H1uXPmzNVZbzl%2B6W%2BXz45ant7YOyoN%2BDq4owSxfJbXeb4SUsQGhquIvpC%2BHvnCRQtkhd1apZ%2FoW1FsSeEEJJpLPFP%2FwcAdunYAIEHz%2BuJeoP6tkazxlVhZ%2FdiJ7Ip9oQQQrIUlSuV1C%2FyD5yNTwghhFDsCSGEEEKxJ4QQQgjFnhBCCCEUe0IIIYRQ7AkhhBBCsSeEEEIIxZ4QQgh5keBDdQghhGgSPgeeZC0cWAWEEEKuheBTeRUtgPGsjSfXka2eO9P4hBBCCCGEEEKILfP%2FjM3JwNSc4lkAAAAASUVORK5CYII%3D)

```
jump_sp_stmt
         ::= JUMP_SP int_const_expr call_target call_arg?
```

referenced by:

* basic_stmt

**from_stmt:**

![from_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAcMAAABHCAYAAAB70CykAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAFThJREFUeNrtnQdYFMf7x79XAOlKsYBdqWJUwBZrjFGsiGhEY0wkxm5MNDGxpBgTfYzlH03MTxNDookllhijpseuCIIlIlUBURQRQTood%2Fuf2ZMTFDwOODiO9%2BOzLruzO7M3O%2B98552Z3QUIgiAIop4joSwgCMPGyw0C5YJ%2BEx5FdXFtI6csIAjDJ%2BxEEGWCnuLdJ5AyQQ%2BQUhYQBEHUvvdOHjyJIUEQBEGQGBIEQRAEiSFBEARBkBgSBEEQBIkhQRAEQZAYEgRBEASJIUEQBEGQGBIEYWjcSsnA9eQ0KBRKygyCxJAgiLrB%2BNfW4L%2FLiVWOh4vfhClrMOzFZXhl%2Bjqk3M7Qy9%2BbkZGDA7%2BfrVIc%2Fxy9iJu30qnw1HHodWwEQajxH9kTTewbVjme0HNxSLx2B2ePrIZMpr9t7us30%2FDB8u0YMaRrpeNY88V%2BzJ%2FjC4dmNlSASAwJgjAE7qZnQyJRvTP6z3%2FPw9LCFDFxyTh8%2FBJatbTHO3NGwdra%2FKlx5OUX4vtthwFBwLr%2FHUCb1k3Qu6c79vxyGuP9%2B2D%2FbyEoKHyAaZMHIzUtE5uC%2FsTl6CR4uLXEVLavsZ21GM%2BOPSfg5twc%2Fxy7iIuXEtC3lwcmje8vxn0yOBKtWzbBu2%2BNhoV5A42%2Fi1%2FT5q1%2FIyIyCVaWpujh7YIxo57F7n2nkZdXiLVf7hePmzThOcRdvYXs7Hzcy8zFoT%2FDWDqNMX%2B2L4LPxmDv%2FtOQMnF%2Fc8ZIuDo74vipy7h95x72HTiD%2FyIS0fmZthjQtyMVpDoIdZMSBKFmY9AfSEnNUIth4KwvcDMlHSOZ53Tp8jUsW7VLYxzcE7RpZAGZXIYWjnaws7FCGhO9Vev2wX%2FSSkQzcU27m4X8gvvwm7BCPGfu9OFQKgX4T1zJhPK%2BSgz3HsfkWethbCTH4IGeWL%2FxAPoPXYzkm3fZ9XRDaHisWsQ0seD9LYiKuYFXJwxANy9n%2FP7POXG%2Fvb2VKG78OvliJJPhTGgMZs7biPALVzF8sDcuMCEeMPJ9bN99HP36eMDExAgz528Uz%2BcNA3599nZW4vmNNDQUCPIMCYKog0wP9MGbM0eIf1syj%2BozJmiaMDE2wrPdXBETm4yxfr3EfVEx12FkJMPPP7yr9ix%2FZt6UtZUZ3l%2Fworjdk50TzIToj3%2FOY9Sw7uK%2BZYsnYLiPqguTe4dWlo%2BOVyiVzLM7VaHfwT3P114eiGe7u4rbLz68rv69PfDdj%2F%2Bqr7MYX5b%2ByqWTxL%2FNzEywdsN%2BbNk4V9we2K8TPPvOE0W7k0drNGpoIXq%2BA%2Ft3ogJDYkgQhC7p0gGdpAJGQ0BPtunEllaoge%2BRSmWPkuDC9eCBotJxGRvLS3WxJly7DWcnx1LHODs5ID4h5VH60kedV%2BaPdYfyLtyiCs5SnTtjBN77aCs2fPMbvDq3x6TxzzEP0al877ZEuhbmpqXCLCxU2zwvGphUb35X4MsVPPwaW%2BLY3Q9WSvDz%2Bcu4SBZCYkgQBg1zlpyLJNggUcKD1YI7WFW4XqZEZOtYXNvNnKNqqmBrBT7Wx8fmSsK3yxsDLB7LLLGjwmlxT3PIC564HJmEv49eRMDk1Qg7tkYVp4bcqUgyvIu3OtD0kd%2BxTKcTndFKIYU72xzAGkh%2FeLohQi5gVmg0YsliqtDwoywgCD31Bt3xvEKCM6x2PJb5AK3PRWHeuWgcPBuL%2BIoKoT7DuyhPnYnCteup4nZiUipOh0Sjf5%2Fqn4Dyy6EQyCRSeHZuh5lThkAQBOTkFsCKebsZWbm4m5Fd6bitrc1wtYQ3q0v4fef3n5cDXh54ueDlg5cTXl7IasgzJAiD8wgVAnazOnsSr%2FgM8Te6ODli4Tx%2FDB27DE5tHRAXfxOL5o%2BBc3uHak9r7%2F5gsZvU1ak5EhJvY860YWjZ3E4Me6F%2FJ%2FTxWQQTIzl2BM3XOu7JLz2POe98jS3bD2PIIC98%2BO64GsvDK1dQyFafeLriAvNsdrNy04M8xMohoSwgCP3Dyw1%2FsdXx8Ch8Ug1xCWEngvT2t%2BbmFSKdeWa2NpYwMzXRWTqZmbnIyskvMx3%2BiAcXQ%2BtKzgblj27wB%2FgdHWy1Pte7T6D6b03dpBru8xK26sviGEQWRJ4hQdR5%2BGQZKNHRMh8j9fH6bqfew6y3vy43fNSwbpg4rn%2BF4zM3MxGXysKfC1y49Idyw18O6Affod1FoStP7IqfbawsXFx1KeQVgZWX1dmmmMXLD02qITEkiDqPVAl%2F5h9sP5qIAn28viaNG2LP1gV6cz1O7Zrp1fXUFry8eLlju1h%2BQGKotd1RFhCEfiEAPdl%2FhykniEoUnsNi%2BSFIDAmiriOBOHnmMuUEoS283PDyQzlBYkgQhoC9aQ5uUzYQ2vKw3NhTTpAYEoQh0CD4hn6OFxL6zcNy04BygsSQIAwBPr1eoGwgKoEAemSOxJAgCIIgSAwJgiAIgsSQIAiCIEgMCYIgCEJr6A00BFEPKPn%2BS4IgyDMkiHoHf%2FlzVV4ATRDkGeoIff3YaHVVPJRPtZtvZSGETTXaE3xmbmRsxqSYq5lO6Zn3Te6kF2hM07aRSZG5qdE9OxuTY1eS8lccCckLp2qDqO8Yoj3VWjepPn9SprLooivKEPOpJvKtJH9%2F7zXjzXW%2FrIpNyDIfPqAFRk1viaaNzdDYVvOzyal3C%2BQpqXl2J8NS%2Fa8lJ%2FmO7G8WlpyWNzE8AlepwUHURwzVnmjMUEdeL1U8tZ9vgvCRdNf6vT99tjFizMTR7fDZwq4wNtJuZIAbOF%2BecbPBlABn%2Bc6DCT0274yN8O4ojA67pPid7hxRb7xBA7cnGjMkDBZuuEE%2FxY1Zs6QrJvm109pwH4efz%2BPZ8HGPBmbGkgPe7qBZKQTZk4HYE4khYZDwrhzW4hyzapE3Oro0qta4eXxfLu0hk8ulm7uQIBJkTwZhTySGhMHBB%2FcP%2Fnt91UTW6qxuwy1pwBN820rkkGxiLdohlOsE2VPdticSQ8Lg4LPcrlzLNg8Y3kan6Uwb7wJjY6lcKeAnLw%2B0q876h%2B4iUUmq%2FSXvBmBPJIZE%2FSQyLuMVn36OVR7T0ASPv1sne177yKHA6mqMurB%2Fa%2FoMD6E9PZuL5aaA7InEkCAQE5%2FVrrd3kxpJa1BfB74yZUvvLh3QqZqivZtrQR9oJbQn3wK84N8heyIxJAjcTS9s4NjUrEbScm%2FfUPWHBKlSJfyrKdr4IiWc6U4S2iKToIMAxJI9kRgSBNKzCiW21iaVOvdmagGu38pDXoGiQsc3b6KuJCzY8kJ1XD%2BrzMIkSvSmO0lojQQDJEBwbdlTSprKfnLyiiqVli7sqaKID91390CTkAjcLu8gTeG6ZN6iICTdSCu1z8O9JT56LwCvzliPnFxV97itjSUG9nsGY%2F16lTo29spNrN94EOEXrkAikaK7txPenDUSrZqreqFSbmdg9jvfYGD%2FZzA90Ed93q2UDMxZ8A2e6%2BOBWa8P1evyn3DtNt55f4t6e%2BmiAHRwbYnFy35ETNxNcZ9NIws4t3fA6BE90LZ1U%2FWx23Yfw74DIU%2FEufyDieLxL0%2F9HAqlAps%2BnwlLC1Mx7OjJCJwOiUbgxOfFvCuP4uuoaZQKAVKZds%2Fuxybm4OX5oYhPyhW3N37iCf%2FBjppbkw%2FTEQTYSKrpJRaCBIdYK3U9%2B%2FNj0GQaooLwceZsAROUUvjUlj2NeyMEkXFZkLPjA8e2wafzO2jnnVXCnqqqT8Xni4k9UOCmlxv2ymWYU1akmsJ1ycWIBAwb5I2e3VzU%2B6ytzcV16Lk4LHjDDy5ODrgSn4Lla%2FcgJfUe5kwbJoZHxyZj1ITlCHx5IN5iAqhUCti26yiGjV2G33Z%2FgJbN7ZBfcB%2Fh568gjonmOL%2FeaNTIQjz3my1%2F4XJ0Elo42uq9ETRvZotPlryE50e%2Bj4M%2FLUH7ts3E%2FZcir6G7lzMG9O2Iu%2BnZ%2BPfYfxjstxSrP30VvkO7i8ckXb8DE2M5Zk8tLfjNmqqmUJ9leezoYINN3%2F2Jt%2BeMEvelpWUhKuYGGjY0x%2FzZI8V9RUVKBASuxperp6JpY1VXRwsHuzpTkazdHCsKYcDwFuLi0sZCywa52JI1rY5rOR%2BJI17ukHq7wz8sEnuomicqQrYp3uZmf%2F4yLtbWNaxb0gm37xZi7rIL%2BHpnPCb6toBbe6tKOLgVt6fK6lM3N%2FgpJFhfpACv5M3kDxPm3aVjFQr4sUj3PR6ppnBd4%2BLkyMTQtcww7iV6d2kvhmdk5uDoiUtqMVz5%2BV74DuuOBXP91Md%2FtHC8KJhrN%2BzH5yteE%2FeZNDDCiKFd8e2P%2F4gVflZWHg79FQa%2F4T2Qn1%2Bo90ZgxMSMC1axiJkYG6nDuDAW591wn64YMaQbpr6xAV27OMGhmeoce3vrcvOX8w5rcLy58Fu8%2BtIA2Nk8KtgNTIzV5z24r%2BoW8ezUFq1aNK5zFUlquuo%2BTw1og44u1pWNRlZdjXFmc%2FNY6%2Fi7zq4IuxCNRKrqiafh6YrhvCNNJqBHbV5HZ3dVQ7hvV3vs%2BytZFEa39tCpPWmrT8UiyBze5iX7XUqNGQoqt5RHeoNFuou7j9qE64qYuGQEh0arl8L7D8o8jndttmih6v7kXuCJ05EYPfLJssFF7tiJiFL7pk0ejB92HBW7XbfsOIIxvs%2FCwtzwZrdzL9HNtQUO%2FRmm3nfnTmap%2FOVLdk6%2BOtzVuTkGD%2BiCLzYeMtjKpHiMw8rCSC%2Buh3mEvwvMYFltcMLTHX2ouifKon17mLC6eIlEgq2sBTWWmW6sPlyXpYW8lF3VBJr0iYuglzuuK4CfwYXwMeQaIhWVVlO4rj3Fg6ziPh0ao97%2Bau00NLZTtd537j2B46cuI%2BX2PZwKicKOoLdVN4FV5rwLtLjLriRNmzRCWnoWBOFRs6CFox369%2FHAN9%2F%2Fhd2%2FnMbBXUuwMegPgzSg1qzBcOPmXfV2ZPR1rPny11LH8DFDy%2FaPeinmM4%2F5Bd8P8PorgwwmHxSsaZhwIxfHz6bhv%2BhMPOtpi5YOZnpzfecisdzLFYkSAXs93RDG1j8pZThrnYv4o4nV%2BywZUTcYy7ylRGe0Ukjh%2FnCyzHhWi0XImUcYHqUfQsjh4%2B07fr2ODVuvwq6RCZxbW8CmoXFNi6JKnyT4nUnyx497ghUSQ3VfDXCBuY4%2BgobwoiIksERNdfXj5s%2F2xbDB3uWGFymU%2BPlAML5YNVUcB%2BSYNjCGVCpBVnb%2BE8dnZ%2BfB3KwBJJLSg8IzpwzBIL8PMfml58UJJ1VBn79FeC8zF%2B3aNFNv92ONgOIu4%2FLg%2BconJ6358hf06u6ms2uryXzjXTg9xxxRdet0s8O2td0gkejn9bPLGsL%2BGyJVimNDPB2iHhL%2FqDyULBtNFRLE6FOZ4A3LHeu6YcJboRjx%2BimMHdIcX33cpUbtiesTy5thRQLGsLVSU0TycgzvNDsxma0Hsgg3s%2FVbTws3kmOlNp5hdVYYAf59xDHDDm4t8dbCb9GqpT3cXVqI42gebq3ErtKO7q1KnXPyTBQ8O7d9Ii4%2BNvnWTF%2BMG131We3V8SkiXVSsN2%2BlI5h52Qvnj9H63LkzRqCPz0LY2VrpzIhqMt%2FsWEv12xVeOBV%2BF0F7EvHuZxFY936nWr9%2BgtAnKlMP8dnZUxefQxPbBpg9qR26d7LRmT09fn0l9YmtNzUwQlDBAwQyx22KIEFmWV2kHOnjkbDVbhaBG1tuyGVwOxeFeZrCa%2Buxi5IMG%2BSFma8PwaRpn4uPS3D4DMn1mw4i%2BOyjLtYjJy5h85a%2FMWtK2Y9LvDlzhHompSGRzTzkvw5fwNhXPsPEgP5ig0Fb7JkIBk4ciO%2B3HTaIPDE2lmLkQAesfLcj3NpZYvuvSeJzhgRBVI3vWOMy%2Fd59LJrpisAxrdHByUrnaZanT6f%2FQwRfy2RwEgTsZsdls4NvPM0z5JFwJQ0xYpGUIXCawmudN6YNx9X4FLwyfR1%2B3rZQ7FrNzMrDtDe%2BEj1FpVIpHrd2eSB69TCcfiY%2Bwehl1gjgjAj4FJv%2BbwbzfFXvueXPafLFzNQELs6O4kxb7k2XurH7TolLSQ7sXKyOoyQzAn2wdecRgzNeOxsT4Go27mXeh0Njei0oQVSFDCaEHNsaGiesiD493DevuwdWPlDg3cc9xWIxzOdK%2BhSR0xSuM%2F79dVm5YZEhXzyxb93KKaW2J4ztK1b%2BybdUE0b4RJmStGnVBNFnN5QZ%2F6JKdCXWBrx7N%2FTwqif2%2F7pjscZzF84bIy7lER1WOm8sLU0REbz%2BieN4YyM5OqjOGq%2BlucoU%2FjhxGy5tLSGTUW8nQVSGW3cKEBah6p2zspDXRJJa6dPjosgsfbpaDJk72eZpkWgK13f4RJrHRZAgSvL6uDY4euYOVvwvWlwq%2BgYagiAe0W%2FCMfENNBw%2BKa2Le0Odp1lZfSopimox1BRRXRZCov7BX%2Bmk7SvZenvb4fzBgYi6kq3ytiv4Bpqc3AeU4QTZ00P4G2hy8xUwN5WpH8DXhsrYU1X1qfh8Od1qwtBoaGlcdDezUG5vo93Yn421MXp5aff6vbjELMpwguzpIZ2r6AnWpj3RVysIg8PS3OheckpejaQVelH1EnmJAO5SKij3CbKnumlPJIaEwWHbyOTYybCa6dn%2F%2B6TqqyCCBKlsRcMJBNlTHbUnEkPC4LiSlL%2Fi0OEbRfcfKHWaTsKNbCTeyCm2JP5ykCTKfYLsqW7aE4khYXAcCckLNzaShu08mKDTdN5bGf5oQwD%2FEOLflPsE2VPdtCcSQ8IgSU7Lm7h5Z2zBpZgMncT%2F2dcRuHotu9hw49nipZRiL%2BU8QfZUN%2B2JxJAwSMKZbd1%2FIPjP%2FvCMoroNmBvurpKtZAlOSoCztflRVYIgeyIxJIgyCbmk%2BC0nv%2Bj1aQtPC19sjUJVxzz4mMa4OUdLG66Abez%2FwYIMCyjHCbKnumtP9JwhYdCci8R33m5K6Q97r27c%2BWuCvEdnO%2Fj0aw7ndlZo5fD0B%2BvzCooQE5%2BF0At38M%2FJm8x4c0ofwA2Xf1NOgslhrOVMuU2QPdVde6qVFzDq87f%2Bqq1bQU8%2F4VQf8q0sPDvAB0rxjfUytlm1b2%2FyMQ0JTrK1D2vBvnLuMv4AQdQjDNGeZLWR6K00LOWLgz0%2BMtTCwn8f5VPt5FuZ8d7BFYem2MUMrh1b7FnrM54ZciEzQt47ounV%2Bjns2GSpgFBBgkushdJKKsEddmYAM9yzVDUS9Q1DtCfqJiXqj9ep6nrx69IBnaRK%2BLO%2FB7HWrYT9M9dwqoUg4B4zXP6uqVDWel0aRpNlCLInsieCIAiCMCT%2BH8FXwwPn47YZAAAAAElFTkSuQmCC)

```
from_stmt
         ::= FROM IDENT '{' in_from_stmt* '}'
```

referenced by:

* statement

**in_from_stmt:**

![in_from_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAOcAAABRCAYAAAApZ7FIAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAEOlJREFUeNrtnQdYVFcWx%2F9T6L0JIlYQATWKoEGjgh02lhghlhjd1RjjGqOrq65ZN6tZv2Q10WRj2WiwxESjoCZGTbFr7IJiQRRFsAEiRTrCMLP3vgEXFBgGZ5jC%2BX3f843c985r53%2FPuffd9x5AEIReIjKGgwjwhYIupXaJTdCuryhi3jHZcfrMzGuJORNuJOW2z84tNXuUXfLcNp0czGRWFiaPnR3Njt26W%2FzJkbNFscZ6zqXGciAxv28gBWmJwD6TtGr%2FwKaAabP%2B8%2BOnicl5VkP7t8Rr77aCWzNLNHMyf27ZjKwSaXpGkfOJmIxRdx7cHTE8xDLmQWbR%2BNirSDK28y4xhoNwd8GidyaNIBVpiXUbdwvnmE9pmVissWipWCT2c8yKWrkpYe6QEA%2FTJXO6IcjfBa4uFrCyrDlu8L%2Fz8u5dnDF6aFuxXAGPKwk57zRzFl1IzVDcMqbzLibXI3RF1Jc7t2%2FYfjN8%2BcLumDDSE6Ym6rkjX56vt%2FqjIHNLU9GeQD9MInEShAZS2chtieGffhCIzh0cXsgWX3%2FV4iCJVCqO9DcigZI4iUaHd%2F7sPXTv0%2FEs6r2oMKsKdNyIdiIpRGtZBA0jcRJEA%2BC9srfu5FuNGdpWo3anju0AU1OxlLVDtwd0gieJkyDU5NrNnImhwS3UbmPWpw3ao4sLv%2BcjRTk%2BI3EShJrcuJ3n2TvQVSu2B%2Fd15zMLNvX274guJE6CUIOs7CfmLdwstWLbz8te%2BUOEDLEco0icBkRqWjbKSmWkEB2SnfdE5GRnphXbHq5PRW%2FNpkEGL86XO6HOHENVuSERNuojJN5O1Zi90jIZwicsQ1Jyulb293J8CuIuJzd4%2FcKiJ9ix%2B5ReXQN5uQJiiXZGA1baVSjgyGatdHF8L6qXyvUFcZaVIzXAF1G1GVVV3pSRiMUYPfIVONpba8X%2Bvt9isGvP6RdIIfMxd%2BGmJnddRMrIqRN%2FbaheevhiZIAf7snKIdTG0ooD4SKNKC9nhb74QSrBjLNX8bDKgdZZbmikpedg%2B84TSL7zEKGDuuHNiGDh77dT0rHxu8N4%2BOgxzEylCOrRAePC%2B0IkUtbGPAIdPnYFUqkYPt4emDiuP6wszZD2MAdi8f8jwb79sTh4JA7l5XIEde%2BA8Nd6wdSk7mHMPPJu2qLctquLvbCOvZ0lzsXeRBm7WitW7Yajgw3%2B%2BGZ%2FbP7%2BCLq%2B1BY%2Fs%2B3EJ9zFoH5dEcEqiPWbD%2BLM%2BRvw9nLH3JkjYWFuiugfT0KukAvrc94Y2RseLZwM5lpFRiXjUkIuQvu64dV%2BbmrXnTqqGNTSCxdluQhfsoTCo%2BojHNXanAqlWLnR%2BzUpX1W5ofCvZVHwcHfCwJAuWLpiF37Ye0b4e05OIVycbRHBhDG4vz%2FWfP0Lvt12VCj7bvtRrNu4XxDNkIHdcDMpFffuPxLKvlizB4%2Fzi4TfK9fuw7Ivdgm2%2B%2FXtjD2%2FnmfLZapMPUeM%2Bxjt2rhi%2FBvBcG%2FuiENHL8HczBQ21hbC1LKFM9xclZ0d3zBxvj1jNaytLARhfrxiBwYM%2BxDZOfkY8YceOHz8Mv4b%2BYuwbDNnO%2BYtImF9PpmZmxjUtToZk4Vte%2B%2Fhyo1cg%2FMzVXqpjJTlwC5wYT6DVIVRQfmqyg0tkq5ZMRUdfZTNkfyCEuz48RRGDg1CgL%2BnMKXczWDRNRsvB3ojNi4JE8b2w1UWoTq0d0e%2FPp2ESPrq4IDn7MpYPrNq3T5EfTMPXTq1Ef7G7crldT%2FR9iA1C0WFTxDGoribqwP6vtLxaZlvBw8UF5cKkbEq%2F140Af2Z%2BDmnWbRs3645Zr%2BnHPyfyyqK4yfjhd%2FBvTuxGlj03PqGQod2NsjJK0UrdwuDTbGf04sIv8iAj56NlPUS59OGOxDHQmuoQkW5TIZktlGDPHuebd1Y5FS26c7GJmLW%2FEghffTybI5bSWlo21pZ2f2RpbCT%2FrwSnXq%2Bj8CuXhgW1h3hI3pVs5XK0lseBTv7ta7eSSGuu%2FOjPdvWiFd7oOfA%2BawCaIFXgnzx7uRQuDjZ1tnWrcTGqvqpt7WxhIx5gjZo7Gdn%2F%2FZuB4PaX1V6Yp7wqkyBcDaXq9oxaS058ym24gM2H8gMRrL5X%2BoqZ82ppZWRM4L5TYo3WpeL4ccW7M%2BWGcuWvSpVYPq560jUN4cpKCiGva2V8Psf%2F9qKaZPDhEjJWbfxN1yOvyP85m3MUweXIuHGPZy%2FcAuL%2Fr0NDvbWGBD80lNb1lbmUCgUyMsrgr29Vf3bKCwSf%2F7JZHw4bzRi4m4JbU9eSWyJnF3Z86hi%2FeeuX7UyhQY7RjXx0LU61ys1owTJ9wpZBSTFSz52OtnfaqmoD7xlIqxmRjuxg%2FieHclhiRzX2iTiTjRQXtPxVdULm69lLYsNJWWYxKrXt9m1ya0ppX1OnJVGFEojZ00k8OWiYxv7S13lVW0IO5iI27x%2FhU17vbywwM4Ec1mD94y%2FHyIuXsMhXddgJcVlyvmTUmzdcRxhrA0p9LKxFMDc3FT4zQXG00UrS%2BUDvweOxKFHt%2FYszWwpCDV69ylkZ%2BdXs%2BvoYA3%2FLu2wZv0v%2BGBO%2BNOUk0dnoe1XCzyNzszKQ6C%2Fl9CGzMsvRuQ3B4QyO1ZxVFYQDcGWtVd5un2XtXtbeTgbXGazfH0iNu%2B6gwXTfBokTk3C%2FHcAS0WjmQ5W5JZh6K1beFJZdr6OIFeLXmazNuhSdmnm1ybSquKMrkt09SivkYoDWNLNR0iBo1nNE6StCFpfZsxdJ4SUnNwChLA22aTxA4W%2F%2F3XGa5jJIhbv2RSz8rZtXJk4levEJ9xj630tdNpkMlHy1HU4S0WfZeWyKZg6879CL6mYpZ48mkZvnlfn%2Fshk5fjznLXCNrnAs3Ly8Z%2BlU4Sy4WE9sHHLIQSGzIFrM3vsi%2FqHWsdqZ2eFseF9MHjkP4WKZtVn76Bn9w4GI87fz2fC2lKKSeFtdLofPGJyYbIsZsKF69hbj1VU6qXib7WKVFQRhouYka%2BYkaU1GVFVrkY6s5DN%2BrJUY7Cm01p1X1PCO2FMTKXPRbR8FrUe5xXC3c0REkn1AVQ80j7KzGPOYg4Hh7rva2Zk5grrO7H2a31JZ21WftuE96pWhd%2BSSU3PFsSp6pZMbWRm5zHxiwXxq0vV15RoKq2N%2BWmYyuXupxfDf9hBTH%2FLE4ve96v%2F%2Fg7fo%2FG0lu3zfjY7zuwtqceyDdIL783lImU7%2FC7bjvJdEFIJ2tZlRFV5fbEpxmf5FpjOByRfjMclXdaELdxrvtdnY2MhTDXBb208K5zaqCp6fjtm98%2Fnau89Xj4VzVzshJ7aGjt%2FmMjru93acHa0NbiU9kRMJn8EDNPebKfbdJYPoJejM%2FPf4fVZvqF6qRpJn6a1qgxp6jbJ0RSUBPhha8WA5EtoIrw1JkSYCCV8iF19hvCFBbshJMgFrjW86KvWDr7CMs3vL%2FdXEbZy%2F1VDZA2mcv3GH%2FiuwGEW8nuSizZd7G1MZVm5T1S3l21M4OZsrpbtmyl5WnBZ5q%2FMbxu9EmvsDbIKM57Vl97kok0XGyuTxw%2FSi7Ri%2B9wl5WgskQK8K10jN3u5v3K%2FNXpxWhQIIduFXLTp4uRgduxEjHYGlB04oXziSCFCBptpaiMuFX5r3OI8fV%2FI283JRZsu%2FE3t%2Bw7fl5WWyTVqN%2Fl%2BPlLuF1R6Nr%2FPfldDps0r%2FNa4xalM4Y3jMxBEw%2BCfUDA1Ecds25usUbt%2FWxpb1csKeSDVkGlRhd8avTgJAvwTCpHbEkuu3MjRiL1l664i6U5%2BpTBvsylALsZOQz5HJE5CJ%2FBvm5SWKUa9988z5S8qUC7MqKpRWIQTLNSd1%2FW9dBInYbCcvVL%2Bc0GxbMrUBacUKzcnQN02KG9jjp5xtLowFdjC%2Fh2ikGCeoZ8fKbkIoUsuXMPGQF%2B5%2BNudSV9t%2BylZGtTVGaHBHvD2tEVr9%2BpDDYtKZPy1mjgX9wgHT6QycRY825uxRXgSSoQ%2FxRjBV8eMRpza%2FkwdoT1iErC%2BW0fFg%2FLS8uhj5x5K2KTes8G8jclSWfBnj8WYGBuPX43hvBhFWssHN2v7466EliMoE5RIgq7s529MbFnsYl5l0z12VQtrWLyAlSWLFWxZ4AcFYCa80EuKXheMRJiU1hL6VckqU9GRfKB5xfjrwZAzeYrw7JPr1goFHitE4C9VOsfal4tj4o1vrLZRiZOip3FQ0cvKpw%2Bb8nmg3lqCIHESBEHiJAgSJ0EQJE6CIHESBEHiJAiCxEkQhoZRDELQp%2B9h6AoagEHi1FvUfam0MUGD%2FimtJfQ8e6AMgsRJEASJkyBInARBkDgF6PWYhKGgk9di6lKcJT096MXShP5T4aclTUmcj4qt4UqXntB3Kvz0UZMRJ8sREiUidKRLT%2Bg73E%2B5vzYZcbIk%2FjR%2FhaE%2BnHz%2B1eh7DzKRlp5DnkjU5Kz9BX9tKuIUXpOvwLiQNo3f7hw7eTkux6cIv%2Fmn4fuEfoDxUz7HlJmrG2wz%2FvpdxF5s%2BGtS%2Befso384SULQMwT%2FZH6qq8866GT4Hn%2BBU4AvruRb4K%2Fsv0sac9ujhveEq4u98Dtq10l07dwWa1ZMfSGbvx28iIcZjxHg79mg9fPyijFrwXqEv9YLIhF1YusLFf55RVefddDZ2FqJAu%2BVi3Cmmw%2FiLlzH3sbablZ2viCApOR07D9yEaZSKVas2o1eQb4ICqz7m74pdzOw8btDSHuYg2Yudnh9aBCb2%2BPUuRsoLCwR7NjaWuLtCYOwJfoYOvq0wv7DcbjCInVIn84YPzoYG749hFNnE9CujRvmzXodVpZmiKqImitW%2FyT0248a0ROtWzYjdegQ5pdD2Ww289MgXe2DzgYhnLuORLkIEUwnm1kUXejlBbPG2O5XG35FekYOLMxNYW1lDgsLM7Rs4Qw7m7pfMv6ktAwjxnwMD3cnvDU6RFjnwNFLMDM3gR0TpBWzxf%2FW3M1RWH5r1HFMfm8VzFn5kAH%2BTHi7EfKHv7MIm4PhYT1w8ux1fPnVHmFZLnQOX59P5mampA4dwf2Q%2ByP3S%2B6f3E91tS86fSrl4jUc6uGDIJkIq%2B1MML2bL75nOf5hiRzX2iTiTrSGPhteE%2B7NHeHt6Q4TEykiRr6icvl0lrY%2BzitA2KAAeLRwQp9efk%2FLOvq0FNLaZ%2B0sWfgmW76b8DsmLoml03ZYMDv8qdj3%2FBqjbNv07iTMIyitbXQiWBKX4o3W5WL4VXT%2BjFUAV6UsYsYm6E6YOhdnZQRls0HCW74VeJ39fl8uQfvbvmgdoEejiFp7uGDM633QJ3QBvL3c0fNlH0ybFArXZva1p%2B6S%2FycmNlbVI7MNi9SyMpnG95OeTFGP28rRP3eYo91k3naaRctQffl0oN48z1nlLd9665BLP5qID%2BaEC1Fw8%2FdHMH3OWuz4dr5QplCxB88GRJGW6h166Np4oIHv9YTfCz0Tkwg7OysMCH4Jb7AUNvux8hN0%2FG9JyWkNts2jqFgswq3b6XSiCf2LnPqOnIXGWfMjhbmLk61wj%2FTzj5VvIBg6JBBfb9qPgOA5cLS3xoHdi9WyzTunJo7rj2Gjl8Da2hzLl0xCcG8aQNXUMYoUiKe1jfWaEt7xU8rairzXtmrnjVyuwIO0LKHn1czUpEG2s3LyhbmTg41a61V9TQmltRQ5jY5tO3%2FHjt21j9L64pPJQi9tbR1APC3lt0FeBHVFSZA4mwRjRvURJoLQF6hDiCBInARBkDgJgsRJEASJkyBInARBkDgJgiBxEgSJkyAIjWA0I4ToM3iEsSExhoNIy8RiPrm7YFFTv6D8PJBbU1pLEARBEE2P%2FwEqtBzigdMgZwAAAABJRU5ErkJggg%3D%3D)

```
in_from_stmt
         ::= basic_stmt ';'
           | if_stmt
```

referenced by:

* from_stmt

**mode_stmt:**

![mode_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAPkAAAAlCAYAAACAs0%2FEAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAACtJJREFUeNrtnQlYjWkbx%2F%2BnokjFUPYRxkd2hSjblKRMjX2fT1KWyFIX4fumocHIWCZrWfoYu5RlqD5Lxq6MbI3dxKBFQzUtaJ3nfnKOSnVO6Sj1%2FK7rvU69y3Oe932f%2F33%2F7%2Bc9pwCBQFChkZTFmxoZILuiX9grt0vv2laG61VZKM1xoShqZXWyv531rbA3snNPe3G9BB9lXCiCirj0ynMrIgMLysO4ECIXCCo4QuQCgRC5QCAQIhcIBELkAoFAiFwgEAiRCwQCIXKBQJAH%2Fok347aoGxqB2MJ2krddmbjM90VS8iv4%2FOQEFZV3nwicNW8LXrxMws8%2BM2Xrfrv6AOs3B%2BHWnSeoWlUNvUzbYKaTDep8ps233%2Fj9ETw89%2BWcuJoKmjTSRbeuLWFj2QVqVVT5%2BoyMLIy0X%2F5ePzq01ce3c4aX%2Bxs6asIKzHMZgvZt9OXu63fgPGysu0BDvWq5O4%2FncYkIv%2F4Q%2FfsaVlpxfqjupMdzkadnIsrIAP5qqnAuqFF525XJ9YhIRMXE40jwZdhad%2BXrwq7cR%2FDJq8jOfvfBobMXbsF%2B6hrMmTkY380dgdTUN1jjEwjb4YsR5O8OHR1NJCam4t79Z%2FDxmoJ0dlK37j7Bau8j2LozBDs2zYJWjWrIzsrCxbA7WLt8Iurp1ZS1X5Md%2FykwxLY76urWlLsfXbuZLFD27tEWGrrlT%2BT3HjyD508BlVrkJdVdVwMMypRgdUYmarNfq3ORS3Js%2B7DMTAxijR7I36i87crGbpQZE%2BxR2Fh1gUQi4dl6%2FBhz%2BO44IdtnoedezJhiA8dxFrJ161ZMhM3Ixdi8%2FQRcp33N11VVV0P3rq34z5TpJ4zti1EOK%2FHDSn8scR8rO9awQzM0aaz3yQ0Mcjd0jYj%2Fs0BIgesuC2whZ26iyee6mO08kAc8v4MX%2BD7evsGooamB%2FhaGaN2ysdz2g46H4%2FipayxIZsC4S0sMG2gC9apVcCH0Dnb5nUFyymv07dMeY4b35v1ITEzBtt2n0M%2BsEzZtO4a4vxLxzcg%2BsPiyI28vKekVNrL11Mea2prsnrTGAMvO8Dt0AS9eJGHl2kN8P0e7fvxciuJNWjp8t5%2FkQVpHuzrsRpvDqFNzPH4aB392vo7jWBtaOW0EnwhHVlY2rPsZ4XBgGHR1dXA5%2FD5CL99Dx%2FZN4TxpAHc4sc8TcOhoKIYONOWvmSwJOPzb4qPcy%2BLqTiruzGw0yv3B2Tw1eXaOfadGn7JG91G6L852ZdHTpDW33ydP32ARPgrPol7AvFf7PNbuNsvKg2265b1IbJANHGCM0%2BcjCm27CmvXeeIABBy%2BmMcZhF%2F%2Fgw8W6ULtfwqQaGOex8tETu4mKuYlbFmAvPn7Y3z%2FY065olsnp4RpUP8zNG5YB5rV1eW2vWFLMJas2A%2BzXu1g3qcDgo5dwaPHz7mLcnLxZuvaY9zoL7En4ByWrvLnxyT8nYJlXgcwf%2BF2dGKBs4thCzjOWM%2FvIeHk6o2o6JcsaJtxcVEQ4f2rrc1LKOobLWpqqnL75zBtHR78EY1p7H726dkOdk5eiHwcy8sycm2u%2F8n5ks%2B1G5GY77FDVtIcDgrDxOnr8OZNOneLx0OuY8EPe%2Fi26Nh43v9h4zzxIDKaB56PjTzdkbiNWuNJJhAAEnhBNXkRjfIIIm%2F7x8jsUx2tsdrnCJrr18PUidaQ5PrC3nOWHYi6eu%2FbVLLccXGJRbatr6%2FH636y89LBvoVl%2F9y1ak5N3hifGpPt%2B%2FN5CYKyGA1Yog%2Bz6YStVVfosSwmD5qr8PL%2BBbs2ucCwY3O%2BjgIoZcNFLHBMZcIa9FVOkG3UoA6shiyEK3MN3D1VUYP%2FDjeZwzh49BJusIDTsEFtRNz%2BEx6DenB3RcvoYb1k%2FaOgPmyQqULnee1mJB5GxmCb9ww%2Bd9PVqAUuXb6LQBaIaOysWjIBVkM94LXhF%2BwNOI81yxzRqGFt2fGu0wbCjgUa4oum9THaYQVzdt%2Fw39U1quDAjnnQZu6gLHlPdxIEZQAe%2BTO3QiKXksWuHUv1%2FbPlbM%2FIQCR702rKPEGqzahGuxz%2BAMsXjcd1dlOlkN0kkplQdfLVzknJr6GpWXTX4uOTedao8bYm51af1eSlYdfL%2BptoKqrvoiFZWJqLKAmxzB2Qtc4%2FoUeCehgZy62wlBbN6yON2flo5iCkjkqSKypra1VHZmZOPygQ0OQqBR%2FDjs1gz8onCqjF5T5zeGStTSzc8qz%2FnGVxaYDbsGoy%2Bg9eyDK9NUy7GeRzfe9%2BbqZfl5cdKWwhKNiXtsA%2FZFyQ7lh3B2RkYyh7zZLXkFohtcAFduAz9tqXNbiZvc4qajsL1J7FyeQlOUEaTDShRhlFVVXlvRtZu5YWzjDbSHV7bshKGjGbWBRk1cn%2B04x7elpWqd7M0vgjAeXhK6sUSEmoCUkpsqcVUrRqaHAnJIUEkpmZxYKrhkwohTGW1e40WUilRODxKxhh9yOunlslmxxUFHqv5k3r4djBBYXu48%2Fq%2FHatm7DaOgxT7K1Qs2bBk6nxiclc2NUVKGGUOS7y3%2FfcumOvPsxg%2BL5Ohz1Tg0O2BIkFWfX3anJqhL34sQYM2PKU2XCD8Ntwkbf9Y03CmTEh9jPrWGAAcHK0gseyvbhz75ls%2FR7%2FszgWchUOubJMnuj%2FMBoLlu7BgSOX4O42olLN3JJgKTtRDasI5JA6d%2FoC6zcFydaFXrnHs6dZ7%2FbYvf8sD8DE9j2%2F8mycPxgUKDwWYMnOk712mmCFlNTXeMNGLvUthrWdkvpGof6ZGrfCn8%2FiWCkQKlv3%2BMlzXI94xH8%2BFBiKX89FIGDnXJ7Fneds5KWGlMSkVP5KwWkdO0dL807vJZMyu1eF6O7CDUTQq6oqWrB46Mf2S2I7Py0qk1MjFCFCmXM1KEC48raXKZPGWyItLQNfj1rMI%2FSr1DQ%2BUKhGI%2FsoJTomHg1b2csmnXp2b43A%2Fe58cic3JhZz8%2Fzeu0cb7NrsWqGEPsnOEnZTvFCrVg3Mdh6EoQNNitzfy3MCJs3YgE49ZkGVuZ5qGurw2zYb0yd%2Fxdavh6mlG3S0NLlQt26YoVAftu0OwbeLd%2BFfzRsg8lEs3OeM4PeP7l2Htk1hbD4bqhIVBAd8h%2Fr1ahUZhP63fjpc5%2FnCw3MvDxw0kbZq6QQ%2Bc%2F%2Ff73eyvrqhejV1LPp2DKzf1uezptry43fuO41tu07h1es0%2FpRho5dTeblNcnX3dp2LcVt4smrMLX9ml7y1BamsEW%2FWSIG2W972kthPZf05o3Qm9Ji4BKix8FbUoFAmuf%2FMT2nZdWVdr4SEFKRlZECvjo7Cx9BEJ2U5KpFyE%2Ffib7xmIskfMOVBcyLJLDDQjH%2F%2BD%2BaQUyBhSh99KUJMbDxUWP8UPScH57U82NMkH5UaxbkWyhwXJdUdzb6T2NkbTGbvk%2FOcnKX%2FpkU1Im97eYIeiRV3kFVmpHXpsZBr2Lj1WKH7ubsNl026FSYCeuxVEshJ0FIQ0icmK9YewsWwu4W2sf%2FnObKf69UtWXCnYEJLeaGkusud2WV2XV5Dn4rABSWH5joKmu8oL0g%2FzKQMaEZfkceIH5sP1Z30eDUxvAWVHRPjVhX6%2FMS30ASCCo4QuUAgRC4QCITIBQKBELlAIBAiFwgEQuQCgUCIXCAQ5KHMPgxTVv%2FG9VNFXC9BSVEtizeN%2FgsLaWmgiwUV%2FQLTeYrrJVDGuBB2XSAQCASCysA%2Fcglj6wu8a3IAAAAASUVORK5CYII%3D)

```
mode_stmt
         ::= MODE int_const_expr
```

referenced by:

* basic_stmt

**message_stmt:**

![message_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAT0AAAAlCAYAAAAwaT7fAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAADoBJREFUeNrtnAdYVEcXhj%2BkCAhiAVTsXSxRwV6wYMMOdo0dxa5gL3801pCIJvYSEBsaO8ZCFKLGKKKCNZbYomJXbAiKlP%2Bcwb0usLCINJN5n2ef3b1zd%2FbeuTPffOfM3QUkEonkP4ROVnyprTXiZNP%2FOwi%2BnH59SPYL2X8yA72sOtnTR73kFf%2FCqdFwgOwXkmzVf1JDDtn0ks91Z9KhSb6k%2FiNFTyKR%2FKeQoieRSKToSSQSiRQ9iUQikaInkUgkUvQkEolEip5EIpFI0ZNIJJJMRvwio3ZlFAi6iEfJ7aStXJJ%2BRL6Nwp79p9DFsb5sjBQIex6OBUt9cezEZURGRqGIVX7UqVUeQwc6YKb7L7hx66HGz7VoUhV29Stj2uyNyrbSJQuia8f6sK1eWrz%2F68odTJ%2B7WSmfP7sfShSzxJjJngi99wyL3J1hVSifKLtw6Ta8N%2F4Ojzn9lf2vXruHlWt%2BQ8i5G4iJiUOxIuaoV7sCena2Q968JlrPrf%2BwRZg4xgkVyhVJsH25px8CjpwXr4sWzo%2BObepg8aq9ydaz2XMsps7agBv%2FJBy6RoYGWL9qDK7deIDJ367%2F2A4lCqBzx3qoaVM2SV187mFhr7Fm2Sjo6n70SguW%2BNL5WYjPZTSfq0OqzwvRex%2BD%2B7bW2K6ni5GaKtVWLkk%2FXr58A9cpXlL0UiAuLg7d%2Bv2AsqWtsPiHwchtaoxzF25hw5Yj6NA6DL262uHNm7fxgrVoF0qRqDm1qyPeF7DMg2c0eC%2BSWK1ZNhJRUTE4cfoqOvV1x55fpqGydTGUKVUIk107oX2POTi0ZzYKF4wXOP6OHDl04EEDXSVyr15F4NzFf5RjO3T0Aoa6rsBIlzYYPqg19PX1cPb8TazbdAimJkbo06OJ1vM7deY6Xr2OTLK9u1MDEvvXQpQn0fHlIPEZO6L9B6G%2BS5PAbnguHq7sr6uXA%2Bf%2Fuo3GDSvDrl7Fj9t1dcVzeHikOKd1K0fjPQ3yoOC%2F0YXa1ddnCqpWLqHsf%2F3mAxw8dBbGRjlxNPASGjeo%2FFHgr9%2BnNsmcgDGtOlTLGo4xOlgUHYP89NZYiJ5OfJjbJSYGjlTpzsSVaivPSFZ4%2BdHMXAlbdh7DTZq9Hanz2tt9hdXrDuI0dQ7baqUxZmh76OnFN%2Fzde0%2FhSWXcCb6qVAJDnVvBPF9uUcaz5B6%2FU3j77r2Y3fv2bAqL%2FLnFzLxu8yE8efoKBWlQdO%2FcEBXLF0XwmRvY6nsMj5%2B8RN48JmjRtBpa2ldXji3k7A1s3v4nHj15gQZ1rPGeWnWYs0P8BYqKhtfGABwPuqJ09lq2ZbWe75Zdx5QZlOnYtjZ%2BJefXo4sdLM3NxLbo6FgsoRm%2Bf6%2BmeEaD4PjJq7Cigbl5%2B1EY0CAbNshBHD8TExOLjSQGPBh5APaketQ77ZdI6P1nuHT1LjZ6uiltwm6qnUNN0TaqvsDky2eKolRWt1YFZRuLHguCalujBpVwLOgyjh6%2FJEQvp4E%2BChXMK8oKk4PUN%2Fj4E%2FVRQ9pi4jfryFG2EuKoTjSNynHTvDFtQld83bWRsp2PrX3rWsKdfg7sEs1y5yKnllOIN8P9V4UBDUz181TBk4Om7fEC%2BLEdeJwFBl3FH8f%2BSiB6230D0bZFDZiZ5aLXx7Os%2F3yqDqnEjsx2EfUfuiWQ6Lj4cJcrDaVKt7Ad%2FJTyjGD5z35wGb0cVgXyomG9Shg31Rvtus8Rg7kDdSQWQ5%2BtR8S%2Bjx6%2FgGOveShVoiDGj3IU2752XiicAXfoSTPWCdHq2KY2wskJnKcZ%2BsWLN3Dq%2FR2sKZTo1aURLC3yIOBwfAjBYlaqeAH07t6YLH8ZuE31EuEUc%2Fb8LfQavBAlilsK8fzn7mMs89yvHPcQtxW4RMLLs30zCqmcRyzB3zQrakM1iIsWNhePXMaGwkms33xY2cfPPxj7DgSLTniTQpepM9cLwePOaGZmjO795uN1eLxTmELhCwuey4BWcGxbB64UppwMvvZFix4PeBaARSv24Da1e4J8jd6nuw4Wq6dPXqFYUYtUXZ%2B%2BPZvg%2Bx93JCk7c%2BGm6E%2FdOmp26flSEdpmBNdu3EfgySvKI7nrzxPGk2fcDuYJXPWOPYFw6lBXuGU%2F%2FzN4E%2FEua52%2BFh1isbOtiLsxwA6w4GnK6aVQqVBUbeUZ7fyWLXBBlYrFxevfAs4IsWMhYm7feaKEF94%2Bv6NtyxpKCMFCVa2%2Bq8jvcEhQ1MpcuESeuVWOjT8bQxe7ZTMbMWvyrK%2BidQtbIa5s7w1z6otjCCZ3V59c3XJyoIP6NFecnRU5A999J8Xry%2BRCONcTeNBdyX9wR9v722mUK9M%2BxXNVzaLq4W0%2FElXOqYwe0k4Mam%2BfQxjQ214pr1i%2BGFb9NEx5z8J8%2BOhFcf67ydme%2FXOhcC%2BqY9u9%2F2SqXGd2hd2s15KRmD53E9ZsCICpqRFsqpYi52uP5k2qpaqOt5HvFTd94vTfsK5QFC2bVk%2FVZ4c7t0bdFhNxlkJDdXjStbTIrThDdvu79gYp5dXpGBO7w8xg%2F8FgnAq5niSnx7x797EdToZcI8NQAG2a11D2PXHqKjksHdSyKQsdHR0UL2aJfdSPs0P6JYkO6WB%2FNDAzsbNLleipiCVDQ0O2VZyW8uho3KIvNcqok%2BM8igpTE8MEZSb0%2Fv7DMGVG4w7Ms5FygY0MxMzELmfXniBUqTcaVauUpMFRlcTEXgiZfaOvUKvxOJE4blivIoaQK%2BJZ2XdfEGbM24ySxQrQxbbAvfthQgQZDrXZMWqC8xxPKVSu32JSgu1d09hR%2BJhMchmS4IeIQXP1WqgIe5ODne7DR8%2BFWEdEvkMjh6kJk%2FlNq6X7Ncrsf8pg0d6%2F%2FRvhrC5evi1yTQPJTfv87IYGdSumuh5Oh%2FBEEPDrrFS7xNy5jTFsoAO%2BW7gdIwe3UeuLRnj%2B8o1wRywQ0bGxOE7OijlCIeNoCo2zQvRG0WSpymkmx70HYWKiDvCdCT19XWX7NgptOT2wbddxZXLftjsw3UXvc%2FoP6xApRJvoOHSm51htFeklEzsfpw%2Feo%2BdmVOHP9OyaUjlNvO6f4vQ%2B5wS5MyX3PhcJA8%2F2Y0d00PhZvx3Tcev2I5Gr81iyS3x2YO9mWOrhInJjvH312gOY8I03Vv44DOOneYvVKnZ2zMRv1qqJrxGeUiigCS7jEOHw3jnpk8ug42T3unbTIZGL7NHZjpynQbL7c%2B6Iwz%2BTXEYwMzFGoL97knZLb9LjzyDT0i%2Fy5MklRI4fIeduIuT8zVSJnqGRPtw%2B9BO3KV7oN%2BQnbN8wSbig1DCA%2Bo3nen8htoqTo8n03dv3IpXC%2BTGua%2BG8gaKsx0CPbOmac%2Bb82A56FJX0pXbYsXEychnnxNt3Udh74DSaNaqqiDfnSHf%2BGogHD58rec%2FM6j%2BJ%2B4e6DtHzSkN9eFHzD6CpyzlOBy81hbZJcnpcCT1tpQqs6RFKYat1yGW4aSvPLiu6rextRNJePc9z%2BM%2BLYkWUOyK7n5LF45flbaqWFithvGzPYUr%2BvKbCAbGDCgsLp9kaYkWLOwVz%2F8NMqKI57evtEyC2naHBtnT1vgQuhHMjW3ceS%2BAoeD9tmJoag%2FUp8S0X3RwbiFVATiT36Z5wBZA7J4dSqtD2CjnBJnZVRFLeyNhA3D6hghdl2A1%2FyfD1mjJzg2hTFZy%2B4MWrmtXLfHJ97jP6iJXJ4WNXIjY2dbrLguY6rD081%2Fkr2zjH6jKgpVh950U29esT%2FmE1OTsz539fi3MY6rpcRDQHAs6KlNCS%2BYOFePPjR3rUtCmHnXtOZNlxJqdDx8%2FjIj%2Fr6qIsjd%2BttN9r2jk0JafHlbBiBpG7tdYgZNrKsxyH5jZCLFo6fYt8ZiZ4%2FSYShQrkw9a144XgDRq1VNxTxPfCcfg6c1pPkYdxHrkEBnp64oK%2FeBmOpfNdRKgzYYwTuvWbDwvz3OQicwonqYLzeVyny6hlwm3YN64K%2FcDLitPzJofoOtkLcxdsE%2FnAiIgoeMztr%2FUceIbtTaLWpsss8X3cyTi85bxVq2Y2IlwtUjh%2Fgs%2FwrNvQYQr5%2Bji8jYwSx88iLvKcdBwjxq8WC0Jc98vwCMyc0vOLFj1eYQ8lweNz5vPkvGkktcsUt07JrlKmBOfgVi8ajrbdZmPm97%2BgfauacKGBzzRtNw3rV7qiXBmrJJ%2Fr0amhuLtAnQmjncQKKy9csbvmSfMFTbp1a5X%2FpDwqL8ipwzls7lcbt%2F6BqHfv0dPZg0L5samqa%2BT4VeKhhOHUr64GL0sa9tHAXv3TMGqHOZg%2BbxPu3H2iMY3C29Zs8Ffy2T8s2ike6umVo35zM%2Brya9WhD9vcaleGO%2FmWiYmdn84H2xhBlaygSjSGqdrK0xLGZOTfgvNq3IPHz5GHRIw7SuLthjRLqy%2F1q4SDZ7fEgsKhYkREUqFJDN9WwuHOLp%2FJSZLb3PktLcw%2B6Rw43OYEsmrFj4%2BtQctJ8JgzQNzoqsL%2F8Dl4LPYV%2BS2%2BcZYFQT0no4KdJ59%2FeoYk6n%2F3nV7h7af0C3a3D5%2B8EK95pTu7wdFBTGysuPaqhSRJ2vtPWnWIV3dZ%2FOgLhtD3xN%2BnR%2FawZEqVaCvPbvCg1zQIktvOJCcGLDqabjW4E%2FoU46atQYWyhYWo8SKJJienup9KBYdQjyjE1ATfHvP9rL7itcqpKflI%2FxAYk1NTF7zEpCTMiUX%2B3wA7tOwodipUv9pQZwY5qIuX7yaTCzYUOWRJ%2BuqQuvNTwlttFclfYSSFb00Q9%2BfdfiRCmJ0%2Bk4St1wYvmqQFcwqxVUlxdfgm5LEjO8gL8oUwY3IP2Qhp5HN1SPV5PdmUaYNXT9u0sM2076ttWy5ZN6HJUUgkEs3If1mRSCRS9CQSiUSKnkQikUjRk0gkEil6EolEIkVPIpFIpOhJJBKJFD2JRCLJOLLs5mT1391JJLJfSDIL3az40gdP8S0%2FrCwwQ16Cfwd8PWW%2FkGRl%2F5HhrUQikUgkEsl%2Fnf8DpCYXBOiq5ukAAAAASUVORK5CYII%3D)

```
message_stmt
         ::= message_type STRING_LITERAL
```

referenced by:

* basic_stmt

**message_type:**

![message_type](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAALUAAAB9CAYAAADk6CJwAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAECxJREFUeNrtnQlcFdUex3%2FsoCIBIigoirigKIKpuGCm5AZqWFiW%2BpRMRAUStzL1VWpuaUpuqfGs5%2FP1NAKLktxaXMBdXFBQEVxIExdABJTlnXPuIrd7WUUuzP1%2FP5%2F7uXfOnDlzZ%2F6%2FOec%2Fc%2BfODyAIiaEnhY3o4oJiqQTkxAVpxESbGEplQ44fiKjz2%2FCiVwApshrQp11Q%2B0YdKY08JGqCIFETBImaIFETBImaIEjUBEGiJggSNaFriF8Uu7vC9sg53C6tUnnz6wpX025j5ryvldMfz3kTHdo1x4cLtiLpUjqWfDQGzk5NxLwrV2%2Fhsy%2BisX7lJDE9e%2F7XuJKqugvatm6KRfNGi88xscewZduvuHEzA%2FXrm2LY4K4IDBgIUxNjUlkFeVadKZYXon5SiPQuLog0NECwpkbLm19XcGhijYVz30b%2FYfMQ87%2B5SgGfTUxDTk4elq36HhvDp4iyh2z6ZMIV5bJnzqehr5cr%2BvRsrywzN68n3jdt2Y01G3%2FGJ3NHwcOtFW7%2F9QALlm1H3LEkbNs8Hfr6dDtHRaiqzrq5wK9QD%2BEFhbBmk%2FWEqPVkaYh%2FYSH8WKNRf2%2B0vPl1BSNjQ9g3tRKfm9hZwsTYSDlv0vhB%2BGjpt0g4lwo31xYal2%2Fdqil6dGunUpb9MBfLw6PEwdC3t6soa2bfCFs3TkPPAbOx59fTGNjfnRRbASqrM4WYC4vhUPLGApUbmopl06U2Wt78uoyFRX0EBQzG4pXf4duIGRrrXLqSjrijF5XT7m5OOHbyEkxMjJSCftqLm8G7rxt%2BO3iORF1JytNZaWLWKOrSGq3sSusq74z1RsTWvTgYl6hMLUqya88JJuLLyunwpRNwJyMLto0tNbZnx8ovpaSTSqtL3HrYVQB8UpqYyxS1giLgNBsPBhWXM7%2BgAFfZSs3q%2Bk40MzXGtMnDsPjzSHw6f4za%2FJBJQzFiqKdKWQN2Upj98JHG9rJzcsVJY1WgO%2FVUdcZSE5%2BCYrzO3ovK2zGGpeQ2h9mCN9m7N2twM3ufVtZ8I0MsVfTU%2FoBBahs4FuqjPavYj9UZxeqeMyzGFDZyJz%2BPja5OAYx6zQsbImJFr1wR3FxbIv3Pe0hJvQWnFnZPe5niYhyKv4CA0d5V%2Bh5S%2B7MAOxVpU6CHtWyjXFmw%2Fssitt%2BgCIktkpG2AyjUFMeSOmPvX5oaISLvCQJYRzqhWA%2BZ4D12eaJWNFIsa%2BSIkQFcuFjZyqaVNb9kG%2BILJiOFfeSvGGdnfGBhhJksB4p3bw%2F%2FU4nYV5t3viHbqJmhfpg5dwusrBqUf0XF3hqv%2BnRH6PtfIWJtMGysG6KAncbz3p5fQfH7W8%2Bui7C492cpww6mn5WZT%2BB7%2BTLyFfOOldGplqKzsO6uWMp28ezSxF1S1DvKEmsF5mtEvgELPdqJVGUHO2I9n1ePXR5Jl25iTOAq8Xnom4vw5edB8OjcSq3e8CHdsG7TLmRm51So3WULxmH%2Bom3o6T0b1lbmeJCVg7bO9uKEs0EV0w8p9dBc0GzgGnvyImIqsEi5OpOXlSpuPXm3%2F4g1soE1slRTI%2BXNr0SaMJe99WFD64DqTj9qw9%2B5ch7l4979bJiZGaORVcNKL1%2Fy71xSST9YbHaztz%2FY9iysQN0q6Yz%2F6MLFzXbYJLYe2XVqQwO0LKuR8uZXFPNcfJZthinuHeB26jwSpNYr1a9nIl6EPO1gcWZneR1Z3IdVKPWros5K9tx8Wr9EYXkLPTO%2FpSKP9T%2Fb9IvwGoVc%2Bog4s3iLuFdcnFVGsXzN39DEznrZENODQi59RJxZvGv8YKrpFbKThvMs92lDIZc%2BPM483pIXtdlDMUTYUMh1Aht5vKUt6rgbIr8ypXjrBKbyeEtb1LJUix6tpTsZSM3%2F3E%2F%2FfCEkB4maIFETBImaIGoYyTzKlx6DS0iqp%2BY3%2F9DDyglKPwhKP%2BpKj00hJainJkjUBEGiJggSNUGQqAmCRE2QqAmCRE0Q2kQSP77Qc%2BeqDyn8gEXe5IQSqdwURukHoTbq1fWRj0RN0IkiQZCoCUKHRE23iUobPZ0TdQ8HeqCNlNFmfLUm6twGsKXQSxdtxldrojbQQwcKvXTRZny1l1ProR%2BFXtIZtdbiq71fFIvxVt8W%2BLCiD%2BSuDn4%2FeB4%2F7DqKFYvGK8sWfbYDDc3rITjQR1k2MXQdwqYMQ7s2Mn8c7rQVMOUL1DMzwdoVgSptcq%2BXxKQb4rNFw3ro6uGMgDHeMDaS7drYvSex%2BZu9GDLAQ8WpK%2FT9zQgKGCTWMWve10hJkz0ctE%2Bv9ggJ9MX%2BP85g3eZYDHjZDRPHD1QuN2PuvzB21Mvo1KGFmH78pAD%2F2roPv%2Bw9hfRb92BjY4G2zk3h79cL3bto54nJLK6m2Sy%2Bunj142y2GWbU5ApbONrgu52HhPUyp6ioGNu%2FP4TtUYeUdbh93J79p1ndxsqy%2BGNJuJh8A3t%2FS2ACvq7S5rnEa0xgjpg%2BdRgTbhfWfhzCPnj6kz33Kb97LwvLVkfh7v1sZfnpM1eRmS3zX5wePFx4OHZk7Ywe2Ve%2BXCbuZGRi5dof8NedTOVyCWdTkZUlWy7%2F8ROM%2FMdy8b1mTRuBHd%2FMwoI5b8HK0hwffvIfrQVWHtezupdTF2MqewvzaAffmlqnY7PGaGpnJayXOReSr8OlnQNy8%2FKF%2BDhxTMBd3J1hamKsXI4L9bXhPTGYizb6sFq7rZzshGf5a8N6YFaoH349qBrPNs72rMftjPD1ms2pbBu%2FgHr1TGDBRgwry6c2d04tbOE76EUm7J0al9u0ZY84QLdtCoPni22EJ3rnTi0xZ%2Frr2L5lplbiKo9nmDy%2BuiVqbjtXpAd%2FPT18w127nJ1RIw5AvXu0x6F4mb943NEk9OjaFj2ZIOOPJ8nLLsKrh4uyfl7%2BY%2Fy0%2B7gQ7AhfT0TFxKOwsKjU9v9kKUBze%2FVnys8I8cO3kQdwM%2F1upb7v9KmvIurHeKRd%2F0ttXuy%2Bkxj1uheMjNWzyJIHR03A48fjyOPJ46otW0Ht5tQMbhTKfRW5E6qFEaZ4uGh2Qq1OvJiouaOtIq14d9wA0VMePpKE4UO6C6G%2FudRLWf%2BXfafQqqUdWjraormDTKwH4hLRt7erss6e%2FQm4ffsBsnPy8CPL2detmKS23uYOjUSe%2B9kX0fh88TsV%2Fr5N7Czx9siXsGxVlFo%2Bz0cX%2BybWymk%2BAqWmycTP7aN5OvS8KMPZ2PPEBe0JWuuiVvTY7O0Vbk%2BmX4wR7HNIkQFap7jAsctz%2BFWqF%2BuFg2dtRGZmDk6fvQr3Tk6ws7VkJ2W7WC97Hxl3s9DZteXT1CM6DnaNLbFDnne3aN4YkTsPq4haARc0z4m7dWmtcd2hQUPhNfADBL0zuFLfOXiiD3oOfF8tnzdvYIb7Dx4qpy%2Bn3MLRE8m4xcSedu3OM4m6vDv1UmQPU09jAbrEohTHeudBtcVGsNbcTy3fIQnPIwAlsWYnUW2dHbBl237hJc6vUjiyHpifdO38%2BQgTZBth5czJYCd43F98uE83HD4qS1ma2Fohdu8pYQSq8Ex8pZ8b3vZ%2FCQO93THi7SVo29oeg1%2FxUFs3t3geP7o%2FO2n8vlLbZ8lSicBxA7F4RaRKeVeP1vh59wm85d9HTPNUhL9%2BPXD2mU8U6%2FKfBXTyhqberLfe%2BPVukU8r4Hn1hq9iVfLp6Jgj8OzWRqQLite6lYFo2sQKu5iY%2Fk6Hds2xeukEhM7eJEYBTUxmvXT88eRK59Y8TTpzLhWp157m1pPfHYzjpy%2BLy5L8oFSQkZEFXUYnRe3Vsz0ePMhhglUV9R2WevQqIerInXHw8%2FFUW%2F5Vn%2B747ofDGtse5O0h0ozxQeG4cVNduObmZpgyYQhy8x4ry8YGrsL%2B38%2Fgyy2%2F4KMl32psl48KIUG%2BeJSb%2F%2FRqDhthvt%2F6vjiA2ncNhmf%2FWXDr%2BR5Wb4gRI4KuopUhhqcL1Tm81RZvcm2SnZ2LB1k5VfZF51S3N3p1x7nO5dTEs8FHAP4i6E8CBImaIEjUBEGiJggSNUGQqAkSNUGQqAmCRE0QJGqCKAvyJieop66NkDc5QekHQelHXeqxKaQE9dQEiZogSNQEQaImCBI1QZCoCRI1QZCoCUKbkDd5HYd%2BcJKoqDm6%2BDAbuomL0g9JIgUvcRI1QZCoCRI1QZCoqwTPAemsXdroyeOsM6LOI29yaSOPb54uifoOeZNLG3l87%2BiMqNmYlEze5NKGx5fHWWdEzZKtOPIml3xG3U%2FEWQto5RfFIn1E6hchtqa9yTlhcyJw7UaGSllDczNErA3GhaTrmLfov8pyZyc7vOHXG%2B5uTsqyiSFrce9BjvjMDThf9uqIN0b0hr7%2B0%2FPelNRbWL0%2BBsdOyJx1u3ZpjdAgX%2BEGxuF2zoGh65X1HeytMXxIN9GWFFB4k7M4D9KZnlpuL1fj3uSchHNX0bNbW%2BElrngFvSPb95nZuTh%2F8Zoo496FlhYNMGL0EhX%2FwuOnr2DAy26izku9OwiL5RVrolUE7TNyIRrbWOCbje%2BJFzcfHeK%2FAFeu3hJ1HucXCGfdyRMGY9rkoWjt1AQTpq4VHuNSQOFNri1fRa3d%2B8G9qwv1EO%2FRDqdPXkRMTa6b%2BxxyL3FNGBkYKOdx0f4Rdx4HDyeifdtmyjodXJqLOvz1KCcf0T8dwcwQPzFveXg0BvTrjA9n%2BCvrc6%2FwvzIy2bwobPg8SFnOTUQb1DdFL08XnL9wXfgfevd1q9OCLuFN7qmt76Bz3uScpEs3RU%2BpeHH7Y00UPCnE3bvZaOZgU2pb6bfvs%2FmNlNO%2FHTyHEb491Opx6zo%2BrzRusXaal7Ge2g55kyvSEC14k3NifjmOw0eTVHJq7h4rLkXlPcbKNTvFZ16nYwdH0fOWZHv0IRw5nix639%2BZUP%2BzOUyWVjwpQFbWI5Fu%2FB072xeELVxJE881G38Sjrs8vSksKhIe5HUF8iYvp8dGDXqTc6ZPHQ6fgS%2BWWefazQwksx59X8wCGBioD2hchFE%2FxmPJx2OVJ4BGhgYwMjZE9sNH6nnmw1wxj4u4JJnsINj%2F%2B1nsipwvUpGqUtN36pE3ecVPHhO0HVAzU2OEMdFz3vvgK4wLWo3If8%2BGqYmxss7IV3uJPNjDrRWCpq1HS0dbdO7YEnps7HVn7wdYDq7o%2BRXwMo%2BOTqKOgqnsZJQL%2BQWL%2BmI9P26fW2VjT%2FqzQC3IqesCyz%2F%2BB0yMjBA8cxOKitSPm%2F4vdRIniOMmrVZaNnOhboiIFSJWcDAuEeu%2F2oWpgUM0rmfalGHiABkXFI68%2FMe046XSU9ckE0PXqUzz681n48LVr4SwdGHzmqnw9V%2BAhcu3Y%2F7sN9TqvDtuAC6n%2FImxk1Zh57Y5Quif%2FnMMQmZtgp782nVRYZEo69enU6nfaeXiALw%2BdhlC2AG0YdVkleveROWQxJ6rjd7kxcXFuJEu670dmlqrpB3VRXV7iVNPTZTdWzARN7NvRDuCcmqCIFETBImaIFETBImaIEjUBEGiJggSNUGiJggSNUHUKsibnJAcBlLYiD8z8DF%2FNbXBR7oaSL79JGdKPwiCIOoG%2Fwcsaz5Y2Aj63AAAAABJRU5ErkJggg%3D%3D)

```
message_type
         ::= INFO
           | WARNING
           | ERROR
```

referenced by:

* message_stmt

**keystore_stmt:**

![keystore_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAfsAAABRCAYAAADVew%2FuAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAH9NJREFUeNrtnQVYlFkXx%2F%2BEAYKAIhgo6ioC6qqALXaLYhd2gI3Cmqhru67rGit2Yseqq35ru3Zii93dqCgYxHfPhRlnCGdIifN7nmFm3vvGnfuee0%2Fcc18AhmEYhmHSNTrp4Uc42iGCbyUTG2eupg8ZZ%2FlPO3LC94NJjeOSfnppPP%2FDS1iCGDWcnLtlmN%2FK8p%2B65ITvB5PaxiVdbnomvXu97GkxLCdMRpc3VvYMwzAMk85hZc8wDMMwrOwZhmEYhmFlzzAMwzAMK3uGYRiGYVjZMwzDMAzDyp5hGIZhGFb2DMMw6ZD374MRGPghzvKHj18hPJwfFcDEjnyCXvkSsDx5Gc%2Fj2klTeVpi6K9%2BaFTXEVUrF1duG%2F%2F7ehgaZoF3P1es%2FfswNv5zPMZx433aYf6y3ahTo7Q8XsGde88weuIazJ3eC9kMs2LJyr3YvO0EXr8JgqlJNpQqWQjuXeri9NmbsZ6XMM9pjHnTe8vPm8SxK9cewJNnb2BsZADXRuXhIY7PlDnyYYcbNh%2FFOvEisoht9rb50b1jbeS2NJPbHj95Dc9hi2Nco17N0ugpzhMXrwOD4OE5N87ykb%2B0QumfC%2BHu%2FeeYMXcbTvvflNudHIrAs3dj%2FFQot1btv3n7CaxafwgtmlREu5bOyu3uA3zhM7gVbt99hi3bT2LW7z3VjouIiECP%2Fr4Y1LcJStgV4J7LKOVi45ZjaNKonOgPmdL1b13ktwfPX7zFlHGdY5R9%2FRKKCrWG4NLxWchhZsSCkY5IrP5VHC81yNcwPHG0w9%2F6eugf20k1laclLgXcQznHosrvE6auxwn%2F61i3dLD8%2FuDRK%2Bjr68Kzl4vacVZ5zdGgtgOGjl4O5wp2yJ7dUG4fNmYFqlS0k4p50rSN2HfwAsYMa4eC1hZ4KM61dccpHDx6WRoJ1vlzyWP2HriIA0cuY8LI9lFKO3KQmjVvO5at3i%2B2u6FkcWup8MdOXgv%2Fc7ewdE5%2F6OjoSOtdvMFLKL33QSHCgDgG1%2FaTcHjnZGTOpI%2BQT19w%2FNQ1bPQbolZ%2FSwvT77YL1d%2B7XxPl91adp2L6pG6wypdTfi9YwEIq%2BoatxsOtVVX4LRgYaXxsOYpGrcdj%2B7qRKFI4j8b2f%2FzkDQLfBom22gCX%2Bk7yuoT%2F%2Bdv4GPxZGkdd%2B%2F6Ffu6NYFMkr%2FK402dv4fSZm7Atko97P6OEPNmBwxejetWSyJUzEzcIk%2B5IqP4tZ4dmYTqYFRoGGsQNpbLXiQzntwoLQzNx0s3RT6qpPK0ye8G%2FQukGYOPyITDKllW5PVfO7KhYzjamd1yrjPT8p8zchImjOkgv%2FNXr9%2BjTrYEs373%2FHHp3bwDnSvbye%2F585qhU3hahoeHSgKDvxN37L3D2wm21a5BnPWPONqxZ6o3yjjbK41cu9EKlOkNx%2BNgVZTTCXKV%2BVSraw8ahN27efoLitt883gpli0njQFvIUIj%2Bm0nxqipcn%2FErUad6KYwc3Fq5bbhXS7x4%2BQ6%2Fz9yMBTP7aHWtMj8XlpGPeUt2YvCAZmplOc2MUb1yCRkdGTqouXL7pm3HZZRDP5Me9%2F5EQG1OcrR%2B81HcufsMzRpXQK2qP2Oh8BrJqHQs%2FRMG9m4i5ZUg43KxKAu49hA%2FFy%2BI3j3qwzxHdmmYzRfnalTPCfOX7kLQhxB071QHVnlyCg90N67feoKGdRzRsW11reoVKka0RSv24OiJazLS1cWtFkqVKCjLjp28hg8fP%2BHFq3fYs%2F%2B8NEAH9mki%2BykZm%2FJ3Ld6JbIZZ0KCOA%2ByK5U8z92PVhoPwF4bsu%2FfByJsnB7p1qIXCBb9FydZsPIyde8%2FCIpeJ7DP0mxXcf%2FgCcxbtFP3vLUqLvqoK3V%2B6X89eBOKsMKRd6peVfXnXvnMyuvbp01c5nimia8Ehn7Fo%2BR5cvvoA2Y0N5PjR0rWSLKPIyf5Dl6RM2NpYiXtTE4YGWTT%2BtjPnbmPF%2BgN4I%2BrtXKm4%2FG16err49PkL5izcgZ6d62L7Ln88FU4NRey%2BN17dvP1Uymc1Ibv%2FE8eQs%2BXaqBym%2FfWPjHZ8Ek4O1c29az3lWD7dd6uUz5XrDsiIIX1uLxwVBXS%2BdZuOyPGrinDgwsLD0atbfVn25WsolqzYK2XPRFyrc%2FuacCpT5IfISHz1r0LJh0XASvWBvGpz9hGRYX066SNx0vXk%2FsenPC2xcv1BeaPXCuVqappNreylUODkHau%2BgoQXTYz3cZPCT8p3%2FJR1mDK2k1IB2Qivkzrn%2BYt3pYJXoBg4v8eJU9dhbp5dqegVUEiuWpUSMhIQG8%2BeB8rr57HMoX6%2B09fV6k%2FTDYnlwNHLUjlEp3njijh0NCBe5xo2qAUWi8706s37GGU0yNCARCFahSKgQaGFa0XW1olkrlAONF2T19JMDsC%2F%2BCxD47YTERYWDteG5aSSWC0UEEGDaDO3yVL5KIyyDj2my%2FvyMfgTps3%2BR06LkVIuUigPOnvMQKdeM2BpYYa6NUpjnOgfNH2lDd6jlso%2B1bNzHZR1KIr2PabhyvWHsuzoyavo4zUPV8V3FzFgP3j4Sk77EKQECVKUZBwbqhjtaYEXL96hnOjzPYShRAZ3c7ffpKIhZs7dJgypnbI%2FkNNAyl51jGrSZpJURB3axDSo1ouxrXPvGcJQ24sgYShRxM9vzX%2F4U9yzti2cxfVqS2W2fPX%2ByPb3WYprNx6ji1Bq1P5kYBAr1h7AgmW70bJpJdSr7SCdCmp%2FTdAY2LnPTFQSDkT3jnWw57%2FzGDFupSz7FPJVyk5TIVukcF%2BJ3xWhIdXg1p2nmDhtAzoKGXv89LV0sug8JLd1a5ZGW2G0%2BJ%2B%2FJSOvCv70%2FQe9veZK%2Ba0tnJQxk9fghP8NpSFC56Lpx87ta%2BDO%2FefSYFTgPmAOrt98LCOMNYQx3LXPLFmHH4km%2FUtK3tEeD8OEbwRS9NHQ13BSaUloKk9rnj5ZhnsPXJDzwuSlROfa9UdCGLeqbaOQu62xlfQqBvRyQQeP6WjbrIrsGMp9RrnBRwg0DZARwhyzF5Zm4wbl0FN0ZE0eKVmXcYXa81iaSuFWcOPWY9lpQ4Wgb9txGj7Cu44%2BTxe9%2FjRnX7hL7gS3GSnct28%2FIncsdaR8AfLsaEAxyJpZq%2FMVK5pPehaz5m7HOJ%2F2amV1a5XG4NHLZOieplz%2BO3IJOUyNYngvTMKY86cHStpby8%2Fk6ZGSV3jg9x%2B8xIXL9%2BRnmlIi5dqpXQ35vaxDEZSuPEh6SYpprI1%2BQ5XGLHlxZPwq%2BgQZqHQu1T4Sl%2Bxv%2Bd9JnD80HWZRckxTRqSopk3sKr%2B3alZZRtMUEbaSlQbIqEO1yiXktibiN6h6vWkF8mgpakGKpFa1n7Fs1X6hTF%2BiYH4LzBXKZ%2F3ywdJDl21y77k0wIjVwlkp51QUI7xbyu9VK9rL6JoqPYSSVeTpkIHWpddM4dz8Ivse8cuApvIa5LVeufZQeMV1pVFBtGleRb4HXHsgPOZ8qOFcQnreqvlK34PyC8hwaC3uG2FXzApla3hjuDDyFSybO0AZ7dQGivr9u3GUWm7G6KFtpMNw684zUcefZRRKFb95A5Evb06l0UhRjgpONpi7ZAd6Cy9e4clb5DLFjt1n5OdLV%2B4LRf8IR3dPga6ujhyDTgoj4d89ZzDAw%2BWHy0wM%2FauDHcI8HBfdk9dK2SsQvul50Y3rR2goDw3FXXFRg7TSwSiJjTwVsjTti%2BVXC1UTFIb%2Fa6p7nMd7dKknOtYmdGpfQ227hbkJFs7qi89fvgqF%2FASnztzE7AX%2Fk4p61JDW360ThZ6CgoJjLaO5%2BWyxeCwnhfdOHk2PzjET7zaIQSI%2BYXxNkLFCnez9h5AYZVRvRXl8%2BKV%2FU9RuMhruoj1VofOQkqHQPXU0mi5RhBQTCv9HM5Vwnu43uTA2UpcrI%2FGdckUiQ6dPpCe0c%2B85ZbmBQWYZwlcoe7VzRZNRyscIDQ3TWJ97D15Io9tMxWAtViSfDHHHBl07hxj4KaqVN3eOJG2blJQT8kpHjF2B3cLrLVWiEMxMs0mlTFHBx8%2FfyOiJwiiL4ZAIr1NhBMSFhYWJ8jMZ6jQNQpEXHZV%2FpW5dwEK%2BU5LtiHEr4Dv%2FXziU%2Fkl6u2SkdRaGXve%2Bs1Gi4gA4lS4inJeyWvVFiiSSUaasSy4TGBsb4v6jl7C2yqUWldEWuu%2BqYwzd%2F16D5smIR3G7%2FAgJ%2BSJD8eqyrqsuj2FhSmOydbMqsV6Hxu7nL97J6VNVVKcAUoO8kf4Vd7JRaARaineN6zD045gjOCYOfCzea4sTLhLvg75XnkkfUxSefStA754NrMN0YS92rCn2aSf2vawfgb6nruFGcnSa%2BDYYzetQNvh7oaQ6Cg996xofjQls0RUfZcnpxqFMSSCpk9Lr8%2Bev2PvfBY3nLFOqsOggz6UhorBEFQMCheG9%2BzVVbqPpAq9%2BrtJqd203SYanonvHyUGZnwvJUGv0qYbDx6%2BgTMnCagO%2FNpBVTx3uj9lbYpS1EANKzwG%2BGOrZXLafj3erRNX9zFXoIBVSzhY2oTrwFZUrIYR4jZDk%2FXrhuFLwBu5vELc%2FuQeM6Aah6ncyMLu61ZKrVGJ440JxaD63dnUgA%2BOj8G5J0Smu%2F%2F5DsDCAY%2FcfSBnStBopfMX%2BERFJo6OTQk60vR8HjwbgvyOXcWTXbzLfgNhzIHKsyCrGEEo%2BJK9fkcSqNsZkySSjadpiYJhZzpdvWTUCeXKbxShv3rgCGtVzxOWABzLq2bbrNPgf%2BEPmPxzbO0VOoVCk7Vcx1piZGskoxPfvqYG8h6r3LPjjZ7XcqMTiu3AH8glnZ8vq4fI7TR309PTVStZJtl6%2Bfhen41WooCX2bR2X7P1fG3mLLk%2Bq%2Ble8z8%2BaCUs%2BfUU3Ydb0iNDBu9hC%2BNLwiX4ScgrFCezE65G%2BHuzOXoWXpnLVED4NUKdv4M7Za9hOZe%2B%2BoqA47mCYDk6UsUet1DTQUgisbJmi6Og%2BQ3aqxNKj%2F2y1OUpaE0tzVbQ8TROUyU4Z%2B55DF%2BFN1FpaWk4zauJqIaS6cGngFOMYGgSWz%2FOUS9VoyV9y09e9EeYv2aU2P08JLHMW7UA%2F94YJOqdnHxfs3HNWeh6qUKiNBsAhvy6Xc8KKVQHpCeoP1C%2Bof1A%2Fof5C%2FYb6j7aKPjmpX8sBq9YflIlgCig0%2F%2B7dxyS9DnnxJiaG2CzkmKAELsqLUVUotMZcwcLlu6VHWlgMyGRgUj%2BgqYW0xpcvX6En6q%2BYBjkijOaPHyLHIXI%2ByANWJCBSAu8plbGlnPC6%2F919Rjlu7YiaY4%2BLrFkyyykPikjSlBxBx%2B47eFF%2BpmkUPTHOOJb5CX16NEBoeJiM4ND4RfeblD5N9RSytpQJd5qoWbUk1m86qsw%2FWL%2F5iIxC0j1LsvYT5yajR2FM7Dt0UetjaQ5%2F6cr9MiGRQvuUMKiA8gyePg%2FE31u%2FLZWmiAQZEz%2BSuPTvsYu4TO96eigqbN4NYr8gsfOj73n2dBKyFE4Kx9Uuljl4TeWxcusWPou3CQ62MuS%2FQbRjheTy8BPi1dDysg4eM%2BAuLEK%2FuZHLyShsTC9VNq8arrZkLzZo7rpLn1lRIU0DobSD0MylArz7u2pVH8ohoLBe%2BZqDkTOHMd6KTkZryilDnzprXN7xYt9%2BaNdtGgqIwaFgVFjOyq672n7UUX8b0ylR7UUd%2BLexnaRBoiMGKWo%2FGjhoqSB1noRA4dtuHWvLZKTo94YS%2F2g54h8TuqY7RU8efZjomKJzdiIFnxrrSJntpETrNR%2BLHCZGCPoYIhNBaYooKSGPc84fveAxaI6cc33y9A2qVimulsl%2F%2FPR1OFbzRlhomEyoXTirn9JT8%2BhaTyYHmgqPc%2BjA5jJqlxagVRCL%2FPaijLOX6N%2BZZLZ35szfhmTqa%2B6ec6QHq3AIFLRyrSRzjxycB0FXtF%2B9mmU0Xu%2FPyd1E312IkpU9YZY9GwLff5Tz6mRUkXE1bIwfbItaydyAQb2bSAObjI3%2BgxdKJU1JgWR40zMNNNG9Q22Zr1Gx9lBY5jKRSXg0xZmUU4uU1Nim61Q4VI30R8s72Wh9LM3XU65IT%2BGgUYSounMJnDwTqZaMjQ2wxLc%2FvEcskUuzKVJL2f5%2FTu7%2BI8VFo%2F6N2uZVvgSmiGF5aHRPXycqTBAsTjJPnGRKbCfRVB6P8NZI8Vb1zFXUTcpWoDCH%2F%2BElqaYT02BFc0e0RE7bhDVVyOIOfPtBPuiHklJSGxQyffTktfycL0%2FOeIfvUwon525JGp5NYpndLd4OiXpNSO3yTwbd0xeB8iFRsYWUkwqasqJ8AXo4lWrC6dRZm2W0a9zwdnL6QHWaSwFFhr6Ehsq8mR8tJ%2FG9HzR1Z2CQJdaH4dCSOJqTzmNhFmuS79NngdK7jc%2BDdMhTp9yb6H1XsZ0cDdWldRRpefnqPYzEfTGL5wN7KCIRHPw52cYJ8u4paTF6neOLfNjXuoPYuEJ9np7yAsiYSohcJZW8JVT%2FUrY%2BKX1xgV7iOpHr7PX1UOh7J9FUri3GIfgjyAB9yxRHqXMBuIB0CoWrEgPNGRklwxKiURNW4%2BqNR7GWmZoYYtFf%2FbSOiMSWRUvLWSZP%2FzvO4%2Fr2bIAaziWR0SH5RzhKiv7QJC3Ul5RMfLKmo0OJdpu3nYyzfPbUnjIqRh7%2B965DT5GMTdFL%2BY22fDYtEddvIkiBGeaLW4nFNv%2BuCRNhtNFL2%2B0UVVS9L2QUdO8f99w4JebREkqCnBVNDgsZNJ08Zn43okhTC7FByxUTIpuUFErLRotFJWfTVOiMKT1i7Kd4MukP7X8J1L%2Bqnr48j8pGTQclmgP38MnRHqt1w0HrL9Ktsk%2BtjB%2BZvEl8NN8X%2Fcl9TEyk%2FOtgNfWHjPB73VpVk6%2BE0qCOI758%2FsqCk0oggyAp%2BzkZNCk9blBORKe21eUDzrJmzYR%2F1o6Q%2BQipkcTqX8Xx%2Bile8wjsjwAGcpdhMipC%2FivqRGAGt4R28P9CYJIaml6lJ%2BplKCcjpS8YFoEAHcCGxY3JqJD8Uz%2FglmAYJt0qe4MPMqSQi5ueycDkiuoHDMMw6VPZH38k5ymzctMzGZisUf2AYRgmfSp7yCnL1Pk0M4ZJIXSi%2BgHDMEy6VfYMwzAMw7CyZxiGYRiGlT3DMAzDMKzsGYZhGIb5EQ%2FVSSZUnzfMMBkNln%2B%2BHwyT7j17%2BmcCqfX%2FlTMMyz%2FfD4ZhZc8wDMMwTPqD%2FgUktwLD8s8wDMOePcMwDMMwrOwZhmEYhmFlzzAMwzCs7BmGYRiGYWXPMAzDMAwre4ZhGIZhWNkzDMMwDMPKnmEYhmGYpCZdPBufH1LCJDf8%2BFOGYVjZpwL8Dy%2Fhu8kkC%2FxPTRiGSetwGJ9htICiRxxBYhiGlT3DMAzDMKzsGYZhGIZhZc8wDMMwTDpR9jT3ydnNTEZEJ0r%2BGYZh0r2y%2F1TRClm5%2BZmMRpTcf%2BKWYBgmIyj7lyFGsOTmZzIaUXL%2FkluCYZh0r%2BwjgBt6OijOzc9kNEjuSf65JRiGSffKXgc4Lv7U5OZnMhxC7qX8MwzDpCA%2F5Al64br4WzccO6sXhM%2BBeyk7fzn0Vz80quuIqpW%2FBRbG%2F74ehoZZ4N3PFWv%2FPoyN%2F8Qci8f7tMP8ZbtRp0ZpebyCO%2FeeYfTENZg7vReyGWbFkpV7sXnbCbx%2BEwRTk2woVbIQ3LvUxemzN2M9L2Ge0xjzpveWnzeJY1euPYAnz97A2MgAro3Kw0Mcnylz5K3asPko1okXkUVss7fNj%2B4dayO3pZnc9vjJa3gOWxzjGvVqlkZPcR5NdPKYgeCQL2rbqom2cu9aF249piu35bE0RcO6TmhQx0Ft37Pnb8N30Q4EXH2AzKJ%2BzpXs4dm7MSzMTWR5wLUH%2BHXSWrRpVhmtxEvBZbH%2FmMlr0dK1Itq2cNZYT8V9at%2BqKpo3rqDc3rnXTEwZ2wnnLt7F%2FkMXMXV8F7XjwsLC0aX3LIwe2gZFf8qTonIv5D1rUATaC%2Fmvz0MPwzDpXtmfC8AFRztcCjLAL%2BLrhJS89qWAeyjnWFT5fcLU9Tjhfx3rlg6W3x88egV9fV149nJRO84qrzka1HbA0NHL4VzBDtmzG8rtw8asQJWKdlIxT5q2EfsOXsCYYe1Q0NoCD8W5tu44hYNHL0sjwTp%2FLnnM3gMXceDIZUwY2T5KaWeS77Pmbcey1fvFdjeULG4tFf5YoQD9z93C0jn9oaOjg4ePX4l3wKtvE7wPChEK7xhc20%2FC4Z2TkTmTPkI%2BfcHxU9ew0W%2BIWv0tLUy1ap9TwigZ4dVSTRHmEoqalCSdl4wSMk4uBdzHoOGL8TH4k1DQleR%2Bx05ek8p28ICmQpm2RogwGnwX%2FosmbSZi59%2B%2FwtQ0G96%2FDxaK%2Fb5o55doKgwZhRFD%2B5EhoHpvvge1Q%2BDbIHn%2FyOAwyJpZWX9qg1IlCsJj4Bz093BBAStz5XFHjl%2FFtZuP8FOh3Cku91Hyfonkn4cehmFSkh%2B2zl4vAv3Em5eDLVx%2BVB1mL%2FhXKN0ArFrgBaNs3xYH5MqZHRXL2aq9jI0NUK9WGZQpVRhTZm5SeuGvXr9Hn24N5Pfd%2B88JL76e9Gbz5zNHpfK2%2BG1MJ3RqW1N%2BV5yLFE12cT7Fd4fSP%2BF1YBBmzNkmIwQN6zrK%2Fcs72mDlQi%2BcOH0dh49dUYkERNaP6jPjtx549Pg1bt5%2BovbbKpQtplb%2FwgW1V24l7AqoHVuk8DfF7yB%2BP21z71oPTV3K46AwWhSMm7IO%2FdwbyjLr%2FBawtbHCrN97SkNj%2FrJdyv3y5s4hr7FBGCrE%2FYcvZCSgRpWS8bp%2FlcrZwaZIXixZsTdGWd48OVDeyQZbtp9Q275p%2B3E0c6kAXd2UXfkZJedeUXLPMAyTMZS9cBJvhOuglfBS%2FYSXP7JIEWRJyeuvXH8Q6zYdwdql3tLjVOWlUODkxaq%2BgoQXTYz3ccPGLcek8h0vlBuFjPUz6ckymyL5sGbjYZy%2FeBehoeHfwif6mpv5xKnrMDfPLhW8KjnMjFCtSgkZCYiNZ88D5fXzWOZQP58wEFTrT9MN2kIhddVj4%2BLZ87fIbxUZrSBj5dKV%2B2jWuKLaPhSNIOV66GiA2vb%2B7o2kN08Rg3lLdsGjWz3o6cVfAQ8b1AJzFu%2BQEYPoUMRh07ZvUyfk8e%2FccxYtmlRMMTkjuSb5JjkneSe552GHYZiU5of%2B17tzV7BPOIkVQnXga5IJfR3ssAYR2K8XjisFb%2BD%2BBiAsOa77v13%2B2HvggvQ6zXNkj1F%2B7fojTJu9VW0bhdxtja1glS8nBvRyQQeP6WjbrArKOqhMCYxyg8%2B4lWjmNhkRQm%2FZC8%2B2cYNy6NmpjtIgiIsXL9%2FFGWqn%2BXGKICi4cesx%2Fpz9D0KFoty24zR8vFpKo0CV6PWnOfvCXbTz7ldvOAQjIwPl9%2FXLiik%2FL%2FTbg%2Byi7M695zI%2FYPqkyP8I91LUn8htGfM30O968eqd2jaKkOQRHv6Slftw8EgAxo5oJw2e%2BFK6ZCFUFkJECp8UvyqN6jnJ%2B0FGSEl7axl5KWRtiWJF8yWbTLcC9O7ZwDpMF%2FZRyXjtIoT9pB%2BBCmeusqJnGCYDKnuFhy%2Fe6pQpjlK6EWguPg8I10PRO3awdkymp%2ByRkho8oBlGCEVgXyy%2FDAWrQmH4v6a6x3m8R5d6%2BH3mJnRqX0NtOyWhLZzVF5%2B%2FfBUK%2BQlOnbmJ2Qv%2BJxX1qCGtv1snmkYICgqOtYzm5rNli%2FkMopPCe6dwdY%2FOMRPvNiwfLL3qhDBpdAc5tRAXwSGfsX23Pzb5DYVZlJGhqF%2FQhxDkNDNW2%2F%2BD2GYUS%2F0p5N%2FRfTpGDW4t8w0SypCBzeHSegK6dagdo01pqoMSJknZb9p6Ai2i8gsSiqb%2FfHcn8ul490XL3xTSe1x48%2FV5jp5hmAyv7JVefuSAmKBBMb7%2FepTmlCmU%2B14o147CQ9%2B6xkfrBDbZaOSlC0WqG4cypYQ7Ui70%2Bvz5K%2Fb%2Bp%2Flnkaer8Jbz5c2p3K5IjPPu11S5jaYLvPq5yux613aTMGbyGozzaZ8i94miFFQ%2F8sq795uNbetGymiHldhGxg6F6ylsr8rh41fgUCqm8VC9Sgn0FIaKW5vqiaoT5RSQFz99ztYYZaTcfxm5FH16NpDJeX9M7JqoawnvnB%2FzzDBMmiND%2FyOcEd4tUbZMUeFdzsCHj4lfAdij%2F2y5xE5BYOAH7PnvPJwcimilsChj33PoIrwRxxFfv4Ri1MTVwq7QhUsDpxjH0AqA5fM8sWX7SbnkLyWh5X716zigc%2B8ZMp%2BBogh9ejbEhKkbcPX6Q%2BV%2BlN%2Fwv11npFKPDVoCl80w8ekatGxy09bjcl5elaqViiNcGEzDx6xApfLFZPIlwzAMe%2FYZCFJQNOfcwWMG3D194Td3oNxOWfb0UmXzquEal4XRWvcufWZFKuJsBkJpB0kv17u%2Fq1b1oRyCEWNXoHzNwciZwxhv332UWetrlnoja5bMsR5DWfuLffuhXbdpKGCVCwULWMjtVnbd1fbr2La6XBmQlFCyIkVG3AfOwYr5g4RCr4NPQtk2c%2FsNJiaG%2BBTyFUZGWeWyQVubfMl6L2k6o33raliwdJe6gOvrylUDC5fvge80D%2B7xDMNkTH2XHn4EhfH9Dy9JNfV58vQNwsLD5RI5xfrv%2BEBRhsC3H%2BSDfqLPf6cFKCLx7OVb6OnqSiWc1nFy7qb8zGF8hmHYs2eUXmZioMSy2BLaEsuoCatx9cajWMtMhSe%2B6K%2BkWQJOD8qhiENCoRyF6KsJVKEHCtEzDBiGYRhW9kw0xo9snybqSQ%2Ft2ejHypxhGCap0OUmYBiGYRhW9gzDMAzDsLJnGIZhGIaVPcMwDMMwrOwZhmEYhmFlzzAMwzAMK3uGYRiGYVjZMwzDMAwre4ZhGIZh0gvp5gl6qs8vZxiGYRjmG3rp4Uc8fYWx9MqbC2P4ljLJLWvcCgzDpDU4jM8wDMMwDMMwDMMwaZn%2FA0nbVqjwLzi6AAAAAElFTkSuQmCC)

```
keystore_stmt
         ::= ( KEYSTORE_TO_NV | KEYSTORE_FROM_NV ) mem_opt address_or_range
```

referenced by:

* basic_stmt

**mem_opt:**

![mem_opt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAQkAAAB9CAYAAACxrJYHAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAF05JREFUeNrtnQdYFEcbx%2F%2FHHb2JgIgNlCJgpaiosQQVsffEGg222BONMRo1MYkmxhjjFzWaYkuMGOwlMRpbNCoKNggIqIAdUOmIwHHfzAAXMCBF4I7j%2FT3P3t622dndef%2F7vrOzOwBBEMQLkGjCQbg7Q1FTLlhQmGZcM6L6INOUAwk8vVHjL5ZHJ18qsUSVo0WnoPp5TTXJcyJIJAiCIJEgCIJEgiAIEgmCIEgkCIIgSCQIgiCRIAiCRIIgiKpCtLhs1xxWASGILW6lkpZXF6JiYjF30Rbl9JIFw9HMqRE%2B%2BORnhEfeF%2FNqmxnB0b4eBvfzRBPbusp1t%2Fmfwp4DAf9Jc9ni0WL9MZO%2BhjxHjg1fT4Wxkb5YdvJMCM4GXIfv6G6YPvf7YvOVnw%2BCqEhe1m7ztxcikSXHfXdn7JJJMaOoREtaXl1oYG2OTxeOQrf%2Bi3Bwx0LYN7EW84NDY9DO3RFenVvg8ZMUHDt1DT0HLcGXS8dhQO92Yp3bd%2BKhqyPD9Em9C6VpXddMjC9eikT9erWxYdMfeHfGQDHv0aNkhIXfRa1ahpgzvb%2BYl52dg%2BG%2BX2LNl5NQt04tMa9hPQsq0USFU167beuMQXIJ%2FpcthzmbNBAiIckNO4bJ5RjEEt3zfKIlLa8uaDMj54acb9y6OtrKZVww2rd1Ev%2F7%2BrRBv15tMWnmWrRxdUA969xtLC1NlesUxdyZg%2FD2%2FB8xbpQXLGqbKOfr6eoot8vKzBZjt1ZNYNOwDpVkotIoq93mi4NcgQYFG%2F4XesFLkTtdbKIlLdckuFfh7NQQh%2F4IxMRx3mJefHwSzl24Xmi95i42yvDCybEBenq54pv1h1gIMYJKKaEWlGS3xYlDkSJRXKJl3ammYNvQEnfvP1ZOh16%2Fg5Vr9v%2BnTsLYXl85PYeFGj0GLMbEsd5UOgn1FgsJfmd%2B7cfFicMLRSKfHOAK81d8FCUsz85GFNupvqad1MSkNNg1tlZOd%2BnUHF9%2FNv6F2zRqYIFhgzoyMdmLju2cKy1v9CYoUV643bJQpE%2B2AkPZOKekgiQrJpY5yza8x8bdWYI%2FsPE7L1quLcPyfE9iGCCNdoSNXAsubEUvts4Itm6ITIFpzFOPqC4Gc%2F%2FBExZahGP%2BnKFl3nbWlH7o5DMfFuYmlXah6eMzNZu2TnDMlmAtKwTNWeHfzizguDQHobYRiPEH5EXZRUG7ZeMNetrYmJEFX3ajn6CQIAncoyhJJPITUeQmEqAthTM3frazd160vGAaIoMRuMX%2B8uGgvT3mm2pjLot5zru6YNjlUBxT55OfkvIU5y6GY8nnfhg9vCtcmjYscxqWTBx8R3fH95uPwLNNUyrRRIXC7KgbCxH8mT1%2BlZSFvjdu4Fn%2BsosvuOkXY7ez2zXH8iw55hUnFgVFwv9Fxl%2BK5UWSdwCfujmJ0MSfKaBnZXkUJREeeQ9jJn8t%2FvcbvhQbVk2BW2u73DO1YKMYDPR10dSxPmZM7oPhQzoVPgF7%2FhZDQQ74faBMoyBTfH2w1e8ElWiiwj0ILhAKBd64dB0HS7FJiXabN69YsZDkuSXpLJH1LJHlRSVS0vIyhAUL2agzc5UrtFaPu1U17fN1FG7UTFhZP8JGf7Hr%2F2kp1i2X3fJGVFwsWAF7i%2B0nt52ETIrGL0qkpOWlxfgpvkzRxzTXZmh1%2BR9cpUtOEGUIM5jdIActmB31L8365bXbgp4Fn9YqMLOkjV6ak9HIYPe%2FX7RyMIQuOUGUDWE3zH6EHZXe2MtN%2FvZV%2F4KXAseZC9SeLjlBlNV0mN0w%2B6lycarqHcoV%2BIfFOo50yQmibHC74faj8SKhnypcGEu65ARRZizz7EezReLcXRFP6dH1Jogyo5dnP5otErmhFT2%2BI4jyRRxV3xyfvkxFEASJBEEQJBIEQZBIEAShCmSaciAF32sgCII8iULwl53ohSeCIJEgCILCjZf3KOiSEgR5EgRBkEgQBEEiQRAEiQRBECQSBEGQSBAEQSJBEARBIkEQRHmQaeqBKQInae88d35WaETCG%2BE3kxyeJGXqxj%2FJKHNjK3Mz3WxDfe1Ei9q6p27cfvrZiYD0oMrOO%2FXzqTloQgM%2FjRSJo5vdp7y9eu%2BKiKhkw75eDTHwrUaoW8cAdczL%2FtW8uMcZsodx6RZnAuOGxNy7PaB%2FV4PAe4%2FSRweF4GZlHkNN6GxI09GUlw41SiQUio%2B0fv3frh1frA8ZOnqwHb6Y3wY62i8XUXFh4UNL59qYMNxR5ncwyvMHv4gQjxaKwYHB8t%2FJFIjSeIXV2aPQqDoJLhAbd0QOXbmwDd4YZPfSAvE8PD2e7tqPPfUMdCQHPFxA76cTGo%2FGiAQPMdgdfuiKBR5o0dSsUvfF01%2BzxFMqk2n94EpCQZBIVIMwI3CS9sFjd1aMZnf5yhaIgkIxckATiQySDcyj6EVFiSCRqHgqLEbjTzFuxKQYDu%2FbuEoPYPKIptDR0ZLlKLDDvTnsqDgR1cFeqo1ItG9QcR30hEYmjPXpUr%2FC6yBKgu%2BvbStLfvVkkONLKsdEdbCXaiMST41gVVFphd9KtnvFw0olx%2BHduR4f6bPhFdE1PEGoub1UG5GQStCsotJ6%2FOSZXv26Bio5Dhf7WvnOYJzoGp4g1Nxeqk%2BdhAReFZXUk%2BRnEnNTXZUcRgMrpTgZsaEHFWdC3e2lrKiuMZUCI7va4oOT0S%2FfAWqOXAEtadnqdY6djcPP%2B27jalgS9HS00M61NqaOtoODjVHZVDZvvwoFaktUcD5HjF%2BJ%2BbOHoGUz2xLX9d%2FzN%2Fr1bgM9XR21s4G4%2BCRcunoTPt3dSBCeg9mJXgqzl5rnSQDBKfp4VxU7nr8iBFMWXYJHczNsWu6Brxa2goWZLnq9eQaH%2F3pYTqEXnkSVx41D%2BreHlWWtkjWZqdjb839EcvJTtTSEiBv3sPzr3aQIRZBnJ8E1zpOQKjBdLsF5NydcuXQdB6tqv9sP3MHuP%2B7hj82dEBKRjI07o9HQWh8P4zOw4v0WTDwu48JuL1ialyt8kVb1eXz8JAUSSa4388exyzA20kd45D0c%2FysYNo0sMXfGQJiaGsJ%2F71mxzvqNh2FkqAefHm5wadqwxPR%2FP3oJR09cQVZWNtq1aYphAztAV0cbZwOu4xf%2Fv5CaloHuXVti1GtdRD6SktKwZfsJeHu54vstRxD%2FKAljhndFj1db5xb4lKf4js3neaxlYojOHV3Qp6cH%2FPedxePHKfhqzT6x3sRx3uJYXsSzzCxs%2FOkYzl24DlMTA4wb2Q3urnaIuRuPXex4J45laRjnpnH4z0vIyVGgt7c79v92AZaWprh4KRIBFyPQumVjzJjcR3hYsXGJ2HcoAEMHdhRjeU4OJryhuiiS2UdfNprN7MWT2Ut4jfIk2HWNyJFgGCtXW92dsdDeHlVSqbB6SyRmjbPH5bBETFgQBEN9KROLJPgdvIOO7hZo5mgCv0N3qs1dhhv9w7gEpUj4TvsG9x8%2BQf9ebRD8Tww%2BWfGrWGZpYSLG9axro2F9CxgalHy6v%2F3xMJat3Amvzi3QrWsr%2FH4kCNExcTh9NhRTZ69n81pi7MhX4bf7DD5ftUtsk5ichi9W78GCJT%2FBtVUTtHFzwMRZ63Dv%2FmOxfOqc9bj%2F4AneHOUljJOLkMifuQlk2lKRNz7IZCXr7YTpa3Hj1gNMn9QHXTu1wLipqxEVEwubBpYIDb%2BDOR%2FkviR35VoUFnz8szIk2%2F%2F7BUyauRbPnmWhf%2B%2B2OHr8Kj76zE8sexCbIPI%2FbOxy3Ih6IIRLFXB74HbB7YPbCbeXmlcnwbgcimNtneCZLcFaU21Mc3PGdihwXJqDUNsIxPgD8gq96yZk4mZMGrq%2FYoX3Pr%2FGRMEcy95tjqN%2Fx%2BLQidwww6OFGa6FJ1Vb1%2FQtXx%2B8PbWf%2BM%2FvorzAi7j2leZi3L9XW9Rhd9GSyM7Ower1B%2FDL97Ph1jq3ndjAPu3E3fhTJjzTmGEO6usp5jeoZ4FeQ5ZgDvNaODraMuz6eZ7Sw9l76DyuMcGqX88cIWG38fGgV9CeXXg%2BjBzWWZm%2FY6euYdigjqU6zivBUbgZ9RBb1s%2BClpYEbd0dcP5iOH5jQjZtYm%2BsWjYevYZ%2BjNXfHsCO3X%2Fjmy8mokF9c%2BX2c6YPxLhRuXWB9o2tMXLCSixbPEZM6%2BppY8%2FP82FiUnVPzIYxLzTaETZyLbjwSkp25kYogBAZ8yCCwlQnECoXiXyPgo168DYGWgoMZv9n5kjhcMsZNu4V3MosPSNXc7j38CQxEy72Jv%2BNF1iBy8rKKfc%2BVP0tiIIVuNwFz8oqn87GMu%2BEhwbPV4hyg7wZFStc%2BXwc7KyRycKRB8yDEfUzTBzyBYJjYmwAuTw3H1xIZi%2FYKMTLrXUT%2BI7ujlbNbcucv8gb90Vo0KHHvELzGzEvIl8gv131FnwGL2GeRm909HQuXIdUoGQ1sbUSYVNaWm4dOg87KlogSioXtyCWx7BsRbJSf455Dz6X%2F8FVdbjxqM2r4nkn5GplGqaVhS4rAFLhTdg1MkIw8xgymSDEP36mXCf8VgqcmhiX%2Bzgq4pVgdfjoDK%2B34IaemJIGi9qFxdTYSA8pqf9WgHIDk8tzYMi2yTe04hj9WhdR2cpDod%2BOBuH1cStw%2BcwqZeVqaeH7smtcF0f2flTsOrv2nUULFxvsO3QBU3x7oVYtwyLXS0hKFcJgYFB5ES%2B9Kl5N4M2ovTtZYdPOaLz9pgMexGfAweswlvwvTCz3HntaPBrt1bWuxh07N3h%2Bd%2BQxfGnglZ0ervZY9%2F2%2Fn8wICIoQd2%2BvLi2xfedpEZJwfvI7KbyB58WkSMPdf06EIzw8mDq%2BF9LSM%2FAsI0vk7SFLOy39Wany17GdE27fi2ehTIByXsydOFwNiRb%2F9%2F0WgJNnQrB72%2FvCi5jx3nciVMonKSVdjLm4rWXH2LObK6RS%2BpqjWnsSVcWiaU7owcSgcUND8RTjzoOncLIzxqOEZ0pjalBXXyOPffK4nhg3ZTXMzIwwd8YgDB3Y4YXrr14%2BHpNnfQvXV96BVKYFfT1d%2BG%2BZi5lv9WXz16Fjz3kwNTYUhr7521mlysOW7cexaOkvcLSrh6joWCx%2B73Vxh%2Bci0ap5Y7TrNhdSiRYO7%2F4Q1nXNXihim9bNxJz5G%2FHx8h1CeHhF5KrPx4snJws%2F2cbyOg8G%2Brr4dNEo9M6rn3hnWn%2Bx%2FbZfT2HLLyfwNCNTPOX5bvVUUoPibjCq2Cl3pyvS%2FeLpBe7vV%2Br1w26mYNYnV0TY0aKpCW8IhbAbyTi30wvmZmVvaOTR%2F0CFhxuV9fm6xMQ0ZGZno46Faam3iXuUJO6y5maFw7D4x8nIYEbGn0aUhYSEVKQyYeFPXJ5v2MU9FW7Y%2BY8uS8PD2ARosfyV9pgmzFiDTu1dRCUpD5XKci7KVC4KfL6uosqFKsKWGudJcJyZ53BkcydERKfiBhu0tSWwttSHmam2xh97flx%2B5PgVfLf5SLHrLZ73mrLSsjgj4o8tywP3ZPhQZL1RndyGYSvX7MO5C8U3C9i59T3l%2F7pW5fuGCBcjPhA1QCR4jX55mmY72hqJ4WVITcuqlufM26u1GNSVOdMHVFra%2FIlKaR4DExokErWMdbIfJz2TWdau%2BlfuI6OTqRRVMzq0c6KTUJabsCYchLGhduK9h%2Bkq2feFq4%2FEWKIAb5onpyJFkEioIeZmuqfOBMaqZN9Hz9wXY4UEcWwUS0WKIJFQQ3jPWoeO383OfImWkuUh6m4Kou%2Bm5p%2FJW%2Bz3NhUpgkRCDeFd7%2BloawX6HYyq0v2%2Bv7xAj38KpHHHgooUQSKhpvCu937wi8gIDk%2Bokv198V0Ibsak5AvELTa452hhFxUpgkRCTeF9c2ZmKYZM%2F%2FC8vLKFggvErwW9FgnOSICL6vJCDkGQSBRDQLD8t9Sn2RMnzz%2Br%2BGZrGCq6joLXQbw%2B42RhgVBgG%2FvtqZDiPSpOhCaicS0uL4Vik4dzjtZPu26u99sfJfNsbQGfLg3gaGcCm3plaziVnpHNP9ePC1fi8eeZ%2B0wkUguvwAWCv%2FsvwZuBldzLOEGQSFQggWH40a2Z4p48U%2B5%2F6kKslA0V%2B8YWr4NgIQb756PQwtigf3C4oo9BU7qtJyjcUF%2BPghmuRAre7vgPZtSPJUAIG%2B4w404rR3KpbNsoLQVLC9ijAHTFh29l6HCpEgSCv8RTnb8%2FQJAnUW0Iyg0BBomvXuV2nOONHGZ8EhiWMSkjhQKJCgn420cXFFIsCaRKSoJEQnMo8NWrxdVK5MibICjcIAiCRIIgCBIJgiBIJAiCIJEgCIIgkSAIgkSCIAgSCYIgqgyNaEylDt3iVTXU0IogkSgjldWZjTpCL38RFG4QpfKeaqIHRZBIEARBIkEQBIkEQRAkEi8Jj6Wpdp4gSo8kz25qjEhktG8APbruBFE68uwloyaJRPxTI1jRpSeI0pFnL%2FE1RiSYzxQhlaAZXXqCKB3cXrjd1BiRYMHVOf4perr0BFFqo%2FESdlNTREJ0h6fAyK62mlsvEXT5Jv65Tv0HEy%2BPsBNmL6rqRlIlIpH3YdrgFH28q6kX1n%2Ff3%2Fj96CUq4cRLk2cnwarqRlJl725IFZgul%2BC8mxOuXLqOg1W138ysbGz86U%2BcDbgOE2MDjB35Ktq4OYhlO3afgaNdPRw%2FHYwr126hc4dmGDvKC5t%2FPobT58Jg08gS894eDGMjfaSlP8OGjYfRs7srftz6JxISUzFmeFd4dW6J8Mh7uBYSDQN9XXy1Zh%2Bs69ZGY1srPIxNwMA%2B7ZR54XlITEpDb293sgSiSJh99GWj2cxePFWVB5U1prpwHRE5EgyTSLDV3RkL7e2hWxX7nTxrHa4zI54%2BqQ%2B6dW0J32nfIPLmA7HMb9dpMS2TasGnhxu%2B2XAIXXotwO17j9C%2FVxsRQqxkRs9JS88Q%2Fxd%2F%2BgtaNbeFWys7TJyxDiFht2FgoAtDQz2YmBigYX0LWNUxRS32%2F71Fm5GS8lSZl8XLttPLF0SRcHvgdsHtg9sJtxdV5UWlb4FeDsWxtk7wzJZgrak2prk5g1vNcWkOQm0jEOMPyCtyf7yOIDT8Ds4d%2FQJaWrxtigMCAiPw25FAzJrST6zz0YLhGNA7925%2FLTga%2BszgP3p%2FuJjmBr1951%2BFw4qt8%2FLSAm5EPcDeg%2BexcO5rsGtcFxbmJhg2qKNy3RYuNiIM8R3dHQFBEUhOSYdPN1eyCALDmHMd7QgbuRZc8iopR7DyFiJjHkRQmOoEQuUike9RsFEP0cuWAoPZ%2F5k5UjjccoaNewW3ygyPvI%2F4%2BGR06DGv0PzhQzr9GwZp%2FetcGbGwQp7zb8%2FkPMzIyi5et5rYWCm9kqIYO9ILq9btFyKxedtxvDH8VUilL%2BfM0ZugmsGt3HtQDCvwkazUn2Peg89lNeklTm2%2BJ1Ggl61KMxRjIz3Y2tTB8QOflCpdieTF08%2FzJCEVtc3%2B7blcoSicrd493PHhZ9ux91AATvwVjKWLRr%2F0eaOPzxAaWyehCjw9muJhXCJ27jurnHf77iNcvnqr3GkmJ6cr09nHjL93Tw8xbWpigJtRDwsrsrYUo1%2Fvinc%2F2CQqKwsKCkGoK7KadLDGxvrYtG4GZs%2FfiKVf%2BkNPVxtPn2Zi5bLyf%2Bmp%2F4ilyMzMFk83Zk8fwITIUcwfOqAjho5ZjrZec9HE1gp%2BG3Of9r42qKN44uE7pjuVPoJEQh1p5%2B6Iv498jljmUUhY%2FFDH0lS5bM%2B2%2BYXW5RWQBfHp7iaGgpw8tBSPniTDyFBPPPLMx8HOGkGnVuJBXAKs65gp55%2B%2FEI627g5o7tyISh9BIqHOWNWpVWFp1bEwLfrksvCCPwItyHebj2DG5D5U8giqk9B0TFjo8vVn45WPP0sDb4A1aZw3ent70AkkyJPQdPR0dQq1gSgNhga6Zd6GIMiTIAiCRIIgCBIJgiBIJAiCIJEgCIIgkSAIgkSCIAgSCYIgqgaNaUzl0cmXriZBVAJSTTiIB4%2BwhA%2F1LPFRTbuA%2FLipGBMUbhAEQRAEoZ78H43xP44Ns%2B1FAAAAAElFTkSuQmCC)

```
mem_opt  ::= IDENT
           | '@' int_const_expr
           | empty
```

referenced by:

* keystore_stmt

**if_stmt:**

![if_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAkMAAABnCAYAAAADm0aSAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAHWJJREFUeNrt3Qd8FFUeB%2FDfZje9QULoVQgp9CSEgPTOgSJNioAHooi0A0TurAeHeCBwJyqHShFUioAioiC9SSgJnQRCGiGhhQAppO%2FuvTcpJBBIApuy2d%2F389nsbmb2zez85%2B38582bGYCIiIjIhKm4CIhMi7cH9FwKJSMwmL%2BpRMZIw0VAZHoCDq3kQjAwnw5juRCIjJQZFwERkWHIVje2vBExGSIiIiJiMkRERETEZIiIiIiIyRARERERkyEiIiIiJkNERERETIaIiIiImAwRERERMRkiIiN2LDAEF0Niijz%2BYf8ghEfeKHffIyziBo4cu8iAEjEZIiIqnh82HMC%2BQ%2BeKPP43q3fB%2F8Slcvc9%2FjwajBXf7WZAiUwc701GRI915nwk1m06iDt3k1C7pjNGDOmI1LQMBF2KRmxcAlJS0lC3jgsG92%2BH79bvx8kzYYhPSEatGs54bXR31K9bFYGnwhAeeRO79p7BzZv30LhRTfTr3Rr3k9OwfPVOBJwKRRVnB4x7tQeauNdVprvq%2Bz1o7e2Krb8fR%2FClq%2Bjdwwsv9fUTicsuHDsRAk%2F3Onh7ykuwtDBXxr95655IuHbiXFAU3ET5b47tjZo1nJCZqcOSZb%2FihT6%2B%2BHbtHlyJihXltMHgl9op32n3%2FjO4cjUWi7%2F4BRpzNaaM78egE5kgtgwRUYFirsVh%2BGuL4N2iIYYN6gBHBxscPHIBtjaWykO%2Br1OrClycHZXxb92ORxufxnhtVHeo1SoMGjUfmRla2NlZwdrKApUr2SrjOzvZQ6fT45VxixF3JxGTRQIiPzd0zEIlqZFWimRo3KQvUMnRFt07t8Ccf29ArwH%2FRGJiCvqLZGbH7lP4etVOZdx79%2B6j%2F%2FB5qOZSCTMm9Vc%2B8%2FJfP1USIa1Oi0Ui0Zk44yuRJNVC5w5NMeujNTh9LgLmGjUqV7ZT5k3Ol0zgiMg0sWWIiAoUGn4DlhYa9OrWCg4i8enasVnusHp1XODhVgdDBjyf%2Bz%2BZiCQmpSBMfE4mMKvW7kXMjTi4udZCjeqV4ePVKHf8A4cvIDU1HXPeG6G89%2FV2xd4DZ7Fr%2FxmMfLmT8r9FH4%2FB834eyutD%2FkFo0bSBSJz6Ku9lEhV4OlR5vf6nQ2jr64bX%2F9ozt6yffj2KMyLhadokq6Vp%2Faq34SQSH2nfwXM4dSYcLZs1UBK9pKTUfN%2BDiJgMEZERaNUELcz0GAg92oq3rjI%2FEQ%2BVIafRto0bmjepj5btp6GJZ110bOepHH6yt7N%2BZFytVodZH63GXpFotGhaX2mdkWTrTEFCwq4pnZf9ur2T7%2F85yY9kZvbg69iJaapUD97b21nllh0Seg1%2F7D39SFmpaekPysr7WXtrZGp1JRqfIty5Xg6%2FIh6XRdT8dSr8dOoCznDNJmIyRESF8HVH40wVvlTp0FRsTdeJTeoStQ5B9UNwZaPISQy0oVZYmGuwetlU5dBV4Okw%2FG%2FlDuX1wrljsrbm%2BgfF7DlwVumMfPiPT2Bjban8b%2Fuuk%2Fm3%2FnmmamdrhZbNG2Dj6neebkHkSW5kWUP6t8Psd4c%2FMlpaekYBH1U9NF96g8cpMPjJiekQQB3ZGPW0ZvAUb7uKxHaHlwfOa%2FSYePwiQrimE5Uu9hkiMhKtPNFNq8JRsZU9EJ%2BB%2BieDMf3kRWw7EYLwoiZCxXEu6Ipy%2Bny1qpXwl57e6NW1ldLpWHJ0sEVo%2BPXccdNF0qFWq6HRqJX38jBYSp6WGdm%2FSLYE5ejSoSlOn43A3oNnc%2F93Oey60lm6uHp398KmrUfynep%2FNCAEt2LjC%2F2sPPwXGXVLadkqTTJeMm4yfjKOMp4yrjK%2BMs5c24lKF1uGiIyAbBHS6rFRr8douQEtjWkmp6Rh%2FJT%2FKAmD7GSsnP31%2BURl2LDB7ZVOym26zYSnWx189dlbWPndHrTqME05w0t2iNaYqXPLGjm0M0a%2F%2BV9s3xmo9OlZsuB18ZkJeOfD1bktNbKFZtl%2FJhR7Ptu1ccfbk17CwFH%2FRiV7G2U%2BnZzssG7FjEI%2F261jcyxZtg0%2BnWZArTFDwP5FZRLf0FCkiae5Xu44LfZQN4p4%2B7GFiKj0qLgIiMo%2Fbw%2FIU6cOBgZjrgHK0gccWlnk8aNj4pT%2BO%2FJU9bwy0jNxI%2FYealZ3glptljuujY1lbmflvOQhK9laI0%2FRz3uo6tr1O7Cw1KCKk8MzfS%2FZunPtxh04ioRIJnDFIedbJlA5h%2Fiehk%2BHsbmvCztMVkh83hdPHUUZPbnmE5UOHiYjKudkZ2nx1Mw%2BBQvLYvq1azk%2FkghJ5hYa5ZT0nEQoZ9yCEiFJthjJ8R%2FusyPLftZESJLzIcsvbiKUM9%2FPkggZUnacm2XHnYiYDBGRmQ6DoMLa%2FZFI5dKo%2BJQ4i3grcSciJkNEpJyD3Vb82cslYVJB36vEnYiYDBGR0rFPdp6%2BwCVhOmS8Zdy5JIiYDBFRFhfrJNzkYjAd2fF24ZIgYjJERFms%2FKPZX8iUZMfbikuCiMkQEWWRp1%2FpuRhMih689AkRkyEiIiIiJkNERERETIaIiIiImAwRERERlQjeqJXIBOW9jxYRkaljyxCRiZE3EX2WG4kSEVU0ZdIyJO%2BaXR42CBXp%2B1TEDXZJlq8PeMN8k%2F%2FRqUEhd0dfCot3vROfbhl7J7XQaTpXtsy0tTa%2FV8XJ8kBoVMon%2B44lBzJaZKxYD4jKMBmSAg6tLLMvXRKHCMry%2B1Q0JX0IZ9e33hP%2B9tmWT0MiEmz7da2Dl96si%2BpVbVDVufBr3N2KS9XcuJVc5XDArUFXYqL6v9jZJiDmdvLIwPMIY8JJxoT1gKgcJENlLac1hxsE04mPXv9Psx%2BXbN6wYNn5wSMHNsSCf7SGhXnxjhTLDYV8NPdwwrhhjTXrt0X4LV8fct6nmX5gwDntdkaOyjvWA6JHsc8QmQy5AVi54fLgRe%2B3xugBDYu9AXiY%2FLws58s5flY2FqpffTzBXsnEesB6QEyGiMoneUhA7LkO%2FvRdHzRzq2zQsmV5X8z2U2s0ZstbcUNArAesB8RkiKi8kZ1Et%2B25%2BulIsfdq6A1A3g3BiP7PqTRQfSX2jPtwqRPrAesBMRkiKjfk2TKhVxJth%2FVrUKLTGT%2FcDRYWZhqdHhu8m6KhIbdjjKLJMfjNeStAPSBiMkT0tIIu3321d6daz9w3ojCyfN8WLnIrpoEWCw1YdFrn%2BrBiJE1H29pKvFNZD4iYDBEZxKXwhIbtfaqVyrR6dqwpn6zFo32rJmhhoGLj7tvBhZE0HSl2kCtsLOsBEZMhIsNkEnfSrGpVtymVaXk2qpT1QoVbZjoMMlCx4Zk6NGYkTYdahSZ6IIT1gIjJUIV07fodZKRnGrzcGzfvIj0jkwu4AHcS0lTOjpZPF69bqbh6PRnJqdoijV%2B7Wu7Gxk48ehhi%2FsVGMUClQ3tG0oSo0FUF%2BJdVPbhxO2u9T0p%2But%2BUkqgHRCVJuehim6aoduw8bj5upMKGl5SIKzcx84PVue9nvzsMTdzr4r1%2FfY9Ll6%2FlG7dhg%2BqYP3t0uV%2FgfQbNwdqV05XvYUiDRs3Honlj4efDBoSH6bR6mKmLd%2B3GkMgkjJpxHOFR95X3y%2BZ6YVCvWoXvXWRPR6%2BHk8pAFzXVq%2FCb2GtZIl7OATtTV3iyf1iiHiN0ZuhdVvVg6JRjCLqcAI0Yf%2ByQBvh4RpPi7WWXQD0gKon8JOfzykqaocU1bw9s1qgxuaBCCxteUmrXcMbc919Btxc%2FwLYN76PRczWU%2F58LuoI23o3RtWOz3HFtbdm%2FlAxn8fIQJREa1q%2BO8nBrYFfMHXtlj9jaEPNyKgj7vD1h5uOJQQFB2MToVGyJ1nhb%2FsyduoAzZTUPn73fAjfj0jD1X6fx9fpwjOxfBx6NHIpdjiHrAVFBnjY%2F8fXAAK0KSzK1cBZvbTTZK6w8XDZEq8UAUejPDxda2PCSYm6hQa2aTsrrGtUrw9LCPHeYTIza%2BrobZfCu37iLDZsPKy1fvXt44ZUhnXKHHfYPwrpNh5CckobuXVpgxOCOUKmy9rKiom%2Fjm293IjTiOlo1fw4TxvaGvX3xf2dS09KxYs1uHD0RAqfKdhjzSje0bN4AkVG38POvRzHu1R6wt8sq9%2FedgTAzU6F3dy9s%2Be0YqlerjGMnLuF44GW0avEcJo%2Fvq8RFfqdtfwRg4It%2B%2BEWMJ40d2d1oK9itO2nK8xvDGqCZm%2BPTFqM21E69WAOmi73sVS3dEXD6IiL5E1gxebmjn3iartbDryzno6VnVp%2Bfjq1d8PPOGCUx8miEsq4HRAUl3MXKT3KSIK0etfO2s%2BfrM6TPas6UhUaLQn%2BUzUfFGV6aQsOvw%2F%2F4xdyHTB6Mxb8W%2FIjaNZ3RvXMLzF%2F8E37edlT5%2F96D5zB55jfo2a0lRg3rgh82HMDCz7cow%2BLuJqL%2F8I%2Fh4uKAKSIBkX2Eho9bBJ2u%2BEdNxk78HFeiYpVEpkM7T4wc%2Fx9ciY5FvTouOHM%2BEu98mHVoMuBUKD74eC2aN6mvvN%2By7RjGT1mKDJFKv9CnNXbsPqV8F0n2hfr0s58wZPQChEfexO24RKOuYDl9JRzszMvF%2FAQEYbteVGCxVTnk5YkO%2FAmsWBo1gqX4TX1f7PesEZnvEPGTFlIe5sveTpOvPhCVV4XlJzIJ8vbEVS3wE2Qi9BBNIYUqmVZhw0v78Jm0c%2B9pnDobkft%2B8byxqFvb0iiCtnTx%2BNw%2BQ4lJqdi05QgG9PPD19%2F%2BgakTXkD%2Fv7RRhtWoVkkkQPMwbcKLyjgyKZkyvp8yrI2PG3y7vo2jJy6hXZuit5AFngpDdEwcfvhmutLi5OvtisNHg7Fj10mMH9MLS%2BaPQ%2B%2BBs%2FH5V79h3caD%2BGLhG6hZwyn38zOnvoSRQzsrrxvUr4Yxb32uHMqUrCwt8Mvad5%2Bqtao80IpdhYjo%2Bzh44jbOXoxHOy9n1K1pU27m72QQ5nm7I1Klx2YvDwSI5w06NU443kf4%2FkjDXpOGStYQQB3ZGPW0ZvDM7iw9XPyuntfo4RcYXD4SIUn2k1u39Sq%2BXBOGKpUt0bi%2BHZwqWTCAZAxJUVZ%2BosJ2kcrPebglqEjJUA4dcNoM6K0vZHhmJiLEREt1C%2FjWuD4YOvDZT7DJuTt6WZEdv3%2FelnXSiGxRcXOtmTuscaNauJ%2Bchpux97KHPejAKw9duTasKf5%2Fo1jJUEjYNcRcu4O23Wfl%2B79bo6yyHRxs8OWi8eg3dK6SmLVt7Za%2FANWDDpjP1a%2BO%2BPj7ua1y1jYWBk%2BESjM%2B8lBA28H7lNcdfavgh8W%2Beb9uuZp%2FMVt9xJ8%2BZjqlj4mcDhmR8AdxzBvT6loVLpWnWModgnWf%2BWLEtON44fU%2FMaRPbSyd08rofmfJ9Mj8RNSpvpl6DBbPhR5D0Tzmh%2FaI%2BGCMeO4uClwunqc9abi5BvOL0zJUniqG2AtTPWsZz%2FJ9kpJSUMnBVnltb2eFhMSU3GGJ4rVsvbGztVIeCYnJ%2BT4r39vZFS%2F5kOXIhOv3TR8%2BdpxNW4%2BgmWc9bPn1KN4c00tJkApy504ibKwtYW1lUSHiU0Xs8a74xBt%2FBsZh5aZIzFpwHp990KLM55%2BorHYs5FmVb7x3EtWcrTBpdEO0aeFUIvXgCS1lE8vLIUMqfb7uaJypwpdifWgq1od1Yg3eq9YhqH4IrmwEtAWt13nzE%2FH8lZU5VqZmYKwZME6vQnxBh8iUBoaHCxFPG0UBHuIRrVHD42Qwphc2vCxOuzdmqSkZWc9p6Vi76SB6dcva0%2BrasbnSeVqr1Snv12zYB6%2BWz8HR0RbdOjXHH7tPITYuQRl2%2BlwELodew%2FN%2BxduNlOPLVqZtO07k%2Fk92nD57IVJ5vXmrv3Lobcu6f6C1jyumzFoOvf7BupaQkJWQZWbqsHTFdvylp3duB29jZ2Fhhhe718T8Wc3g0dAea7dGKdcZIjJVq8ROwZ176Xj3LXeMHVwfTVwdSmQ6csN2IgThJy9im9ymxGegvvhVOaBV4WgrT3RjJEyPjLuMv1wP5Pog1wu5fsj1JCcRKkr%2BcuQszstntRquYlO2UYyXKEaOflLLkCxEZlLHzEUhBSQ4hQ03uEuXYzBq%2FH%2BV1y8M%2Bxhf%2FWeCSA6M%2F75%2Fk2d%2BrRxuuhufhM7tm%2BaedfW3t17E%2BKlL8XzPvytnc6WmZWD1sinKMHkobOSwzujc9z24PlcT4RE3sHDuGLg4F%2B%2FHSZ49tuKLSXj7%2FVX4cN46WJhrkJaegSXzX0fwpauY%2Fcl6bP7%2B70r%2Fn3kfjkKfQbPxxde%2FK52tlQRt3T6s%2BG43UlLT0dSjrhKTiqiKkyUQloh78emoWZWXbSDTdFckQpJzKfcTCg2FPPY%2B18td6Yqx0dcdfmwhMq0WIa1IXETyMlomQEXJpwvLT7L%2FN71NU8zP0GLWwy1FOclQisyknpDkFDa8RMg%2BMsf3fvrI%2F7eue89og3zmSFZyF3MtTrl0QNUqD07btrWxxPffTMOt2%2FFIT8tE7VrO%2BT47Y1J%2FvPFqT9xLuI%2BqLo75LjXw585%2FF6t1yH%2F3AuV0eI0Iat6E6qz%2FZ%2Fnm5%2BD2efk%2BO0kkRbKz9%2F3k1Hzz7t2qIY7t%2BbTCVEZ726yqsePQTbg9Zw%2B1mke7yLRcj01FwPm7ymsHu7K5bqLcEHp7YLFWhS%2FE256MimnIjvfiIiZCxcpPHk6KxC%2F7m7nJkEaNBk8qpLDhVHy1ajo%2FdljeJOORjbS99RM7KS%2F47GflGkAFkZ2uf%2Fx2Zu57ee2mpyGTJPmoyF4f2gD7j8bik%2F9dVB5FvQI1UUXQacQB5QrUkjyZoFX2dYfKZMckBQsTrTFR3vC1LC9ESaVDubGvDs1E3F8syvhPm5%2FkTYpyk6HCCmIiZDzemTqgxMoeN7p7vtPsjYW8NUBxb8nR3qcKTm3rjuDQrOslFfUK1En3M7gSktHXA3kF6vspWthaq3MvwFgchqwH8rIR3p5Ym33DVyZDFX09lXFWYW1RLxfyrPlJzud5zxgqeoLQ1tMo57uSvUVmXHyaxsWpeH1%2FnBwt8Ly3c7E%2BczkygSsKGX09aPmMLUEGrwd67NUDf2MUKz4R57YqPf5b6kkYFz1VdPa25vdibiSXyrSOn7mtPIvKLJuUtFz6xHrw7PVAq8cFFcC7UJsAGWcZbyZDRAbmXNnywOGA0jnSu%2Bvwtay9GxVuiSceXibWAwPUA%2BskpQwXRtEkuGTHm8kQkSGFRqV88tve6Mz0DF2JTiciOhGR0Uk5NUteZDiKS59YD569HvhHK%2F1HeI0L02CVHW8mQ0SGtO9YcqCFuVnA%2Bm0RJTqdv88PfPBGj%2FtyB5lLn1gPDFIP5JVfeX0L06DKjjeTISJDi7mdPHL5%2BpDUc5fulkj5C74%2Bj7AriTk%2F2%2BHi4a0zw2YueWI9YD2g8o%2FJEJmEQPEbnZ6hHzTpo6NaQ28I5Abgx7x72yocFrs2J3hNFGI9YD0gJkNE5cqxc9rfk1IyXx%2F%2FjyP6z9cE41n7Tsi%2BEUMn78%2B%2FAdDjB%2FG3l16Nd7jEifWA9YCMA68zRCblZBBW%2BXjozL7bHLZs%2FdYIjV%2FLKujdqTYaN3RAvZpPvrBicmomLoUn4PjpWOw%2BfE1sBJLyjyA3APKO2yqMCRB74FzaxHrAekBMhp7Ip8PYCrUgK9r3qcgCgrHCq4k%2BRpuu3Xjg%2BE21eFg%2FU4Gyb4QKh8Wr3nozvBp4ATu4lIn1oHzXA2%2BP0u%2BkW1EFBht%2F53ZNWS64irIyVrTvYxJ7xuKH2rspWkKLhSJqHcRe7HXxb0e9Ck7ivW0hH08SAY9V6RGiUyFZBN3XDLDTa9DuJPeEifXAaOpBwKGVXAnYEFB2yRBRuUhis36wB8gbA2bf96gndCKxVRW6EbDT63FPbDDkPQuO69WYHcBOosR6wHpgonIaAoy5hahMk6GK0LRWkb%2BPqcg%2B20U%2BPuTSINYD1gMyPTybjIiIiJgMERERETEZIiIiKr94S46Kr0xuxcFkiIiIjEVq29q8WWtFlh3f1LKYNpMhIiIyBrEpdqjGxVBxZcc3lskQERFRAfRAiFqFJlwSFZeMr4wzkyEiIqICqAB%2FeZuP8jZft27HIzkljQEyTJC7KnFmMkRERPQonRk2Q48RneuXr35Db01bhl37Tpf6dBMSkrHlt2PPVMbeg%2BdwNeZ2uViOSlxFfJU4MxkiIiJ6VPZFIc8lWuNtLg3g%2Bs27eHfO989UxpJl23D2fGS5%2BD7ZcT13qoyuYs7bcRARkVFQ6zFJq8JRL3ecPnkR20pruukZmVj53W4cOXYRDvY2eHVEF7T2cn1kPHm4bPmaXTgfFCXGs4afjxsGv9ROGRZzLQ7LRRnng66gqWc9THitN6pWcSx02qlp6VixZjfOiKTF3s5aTLcRhg3qgI1b%2FkRaagYWf%2FGLMt4rL3dCVHQsbsclKvPx6%2FYTqF3LGTMm9sfJs%2BH48ec%2FodfrMXVCPzRxr6t8l2s37mCrGO%2FS5Rg0a1IPPbq0LJO4inj2E0%2FTRXz9ymrdYssQEREZheMXlZvCDlGpsMbbA%2B83agTL0pju%2BKlLcVEkDJPe6ItunZtj7MTPcTns%2BiPjvfPBagRdvIq%2FjugKX%2B%2FG2L77pPJ%2F2a9owMh%2Fo26tKpg5ZQAszNUYPnaRkpwU5r05P%2BD0uQi8OrwL2rZ2w%2FZdWWXKRMrMTIU6okz5MDfX4MTJUEx6%2B2v4iwXVt6c3Ll6KRo8BH2HV93vQoZ2nkqC9Pnmp8nkHBxsxHxpUcbZXPl%2B5kl2px1PGT8ZRxlPGVca3rNYttgwREZHROBWEPb7u8MtU4UtHc0z08sA66LFXrUNQ%2FRBc2QhoDTm9CxejEHTpKvx3LVCSD8AVxwJC8PvOAEyd8EK%2BceV4Y17phnZt3JX3Lw94Xnn%2Bfv1%2B9OjSAmNGdlPe%2B3q7YtMv%2FrgYEg0PtzpPnn5wlNK69Lyfh%2FI%2Bp6WpU%2Fum%2BO%2BybRiSPY0cfXp4YeHcMcrrypXt8NG8dfj%2Bm2nK%2B349fdDEbzLi4%2B%2BjqUddkQg5oJ1YmH17%2BZRK7IYA6sjGqKc1g2d2Z%2BnhIh08r9HDLzC47BIhJkNERGR0slsQerRqghZmegwUr6fo1HAN90A9bwNfpfrS5WuIjU1Aux6z8v1fHqp6mDwENeujNVi6%2FHd4t2yE0cO7KIlPSNg1HPIXWdz%2Bs7njmmvUSElJL3T6k9%2Fsh5kffItvVu%2BEd4tGGDWsE9r6uj92fLX6wQEfOzvrfMNy3mdotSUSl5y71z9OeNbVpa%2BIAF0WUfLXqdC7rPoIMRkiIqIKIXtD%2BlQb08I23Dns7axQv15V7P31X4WO2%2F8vbdC7uxcuBEVh1%2F4zGDZmIU4cWAg7WyuMHtoFs6YNLPZ8ysNdslUpKPgq9hw8ixGvLcbRPQugUqmKdJitMDqd4e5%2BERhsvLdLYZ8hIiKix5CdoG%2FcuodNvxzJ%2FV9U9G2cOhP%2ByLjyVHe1ygxeLRvirXF9lGQl6X6qkiCt33wI4ZE3csc9dCQId%2B8mFTr9X34%2FBpXIV1o2b6B0ujY3VyMhMQWODja4L8q%2BKebtackywiJuMMhgyxAREdFj2dtbY9XSyZj%2Bj5X4eOFGWFmaK4e3Fs0b%2B8i4P231x9%2F%2FuQburrUREXkTk8b3Rb3aLspj%2FNhe6PvyXFR2sFUSpKpVK%2BHHb2cWOv1tOwIw60NRZuOsMseO6g7XhjWUYS%2F28UXnfu8r87Rq6ZRif7dXR3TFhGn%2FUxI12TH84w9GmmyceQdgIiIyOfIwWcChlcX6jGyFkYenqro8%2FpR42Tk5ISkFzk72sLHOf7JbZqYO12%2FeQSWREMkkq6jkBRbjE5PhVNketjb5y4yNS4C5Wo1KlWyfajmkpKYjLi5ROQ3%2Fafh0eJAUGvNhMrYMERERFUG1qpUKHcfR0VZ5FLjB1Zgpp7HnuHL1Fma89%2B1jyxo2sL1y9pg8DV4%2BCuLi7PBM38nayuKpE6GKhMkQERFRGahXpyo2rXmHC6IcYAdqIiIiYjJERERExGSIiIiIiMkQEREREZMhIiIiIiZDREREREyGiIiIiJgMERERETEZIiIiIqqQeAVqIiIySXnvq0WmTc1FQEREpub6bcyWj5ou%2BCeXhuGWqbHOOw%2BTERERERERERGZqv8DpsSTS4J%2FPPAAAAAASUVORK5CYII%3D)

```
if_stmt  ::= IF bool_expr '{' statement* '}' else_stmt?
```

referenced by:

* else_stmt
* in_from_stmt
* statement

**else_stmt:**

![else_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAYMAAABzCAYAAAB6gW6%2FAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAF8BJREFUeNrtnQdcVFfaxp8pNKmCWAAVY6NYARVb9NPYEhN7jK4xq8Y0TdNsssnm241%2Brtls1GSN7pqN0STuGiOafJZNsbdYQcQCgoBYUETpSJ%2BZPedSxIIUZ5yBef6%2F38ydmXvPuXfOec%2F7nPecWwBCCCFWj4pFQBo6wf4wsBRMQ0QMfUhDQcsiINZA%2BP5VLAQjE9J%2FOguhAaFmERBCHiTqYuRFMSCEEEIxIIQQQjEghBBCMSCEEEIxIIQQQjEghBBCMSCEEEIxIIQQQjEgxOo4EhGHs3HJNd7%2BwKFoJCalWNz%2FSDifgoNHzrJCCcWAkLrw7%2B%2F2Yvf%2BUzXe%2Fouvt%2BPQsViL%2Bx%2B%2FHo7Bl2t2sELJXfDeRIRUIup0Er7dsA%2FpGbnw8fLA5AmPoqCwGNGxl3E9LRv5%2BYVo1dIT40f1wZp1e3A8KgFZ2XnwbuGBGVMfg2%2BrpoiITBBRwTVs3xWFa9cy0aGdF0YO74GbeYVY%2BfU2hEfGo4mHC55%2FbggC%2FVop%2B139r53oEdwem388ipjYSxg%2BJAijnwgVjns7jhyLQ4BfS7z12mjY2doo219LzRSCsw2noi%2Bio8j%2FpenD4dXCHSUleixdsQVPjuiJr9buxIWL10U%2BvTB%2BdB%2FlP%2B3YE4ULl65jybJN0Npo8NqLI1nphJEBIZVJvpKGSTMWI7hrWzwzrj9cXRph38EzcGxkp7zk95beTeDp4apsn3ojC71COmDGs49Bo1Fh3LMfoaRYBycnezjY26Kxm6OyvYe7M%2FR6A37z%2FBKkpefgVeGAZbqJ0xYpTl2ySojB87OXwc3VEY8N7Ir5f%2FkOw8Z8gJycfIwSzvznHZH45%2BptyraZmTcxatJCNPN0w9zZo5Q0T%2F%2F2Y0UIdHodFgtHP2vu50IkvDGwfye886dvcOLUedhoNWjc2Ek5NnlcUsAIYWRAyB3EJ6aInrcWwwZ3h4tw%2FIMe7VyxrrWIBvw7tsSEMX0rfpOOOCc3HwkinXTgq9fuQnJKGjq290aL5o0REtSuYvu9B86goKAI8%2F8wWfneU0QBu%2FaexHbRU5%2Fy9ADlt8V%2Fnoa%2Bof7K5%2F2HotG1UxshHE8o36WIRJyIVz6v%2B34%2FevfsiJm%2FHVqR1%2FdbDiNKOPxOgaWRxrrVb8FdOH7J7n2nEBmViG6d2yhCl5tbcNv%2FIIRiQOoN3QPRVW3AWBjQW3xtL%2F0zjPw8jt69OqJLoC%2B69XsTgQGt8GifAGX4xdnJ4a5tdTq96HF%2FjV3C0Xbt5Kv0ziWyd34v4hKuKJO3oYPfvu33cuevhOnqW3%2FHSexTpbr13VlEG%2BV5x8VfwS%2B7TtyVV0Fh0a28Kqd1dkCJTm%2FS%2BqnBnUvl%2BgvidU7U2iG9Ct9HnkEULZtiQEiN6OmHDiUqLFfp0Ul4k2%2BFS1mq0SPaNw4XwoRPNpKjUrC10eLrFa8rQzcRJxLwj1U%2FK58XLZhW6s0Mt7LZKXr1cjL2wC8fopGDnfLbT9uP3%2B79Ku3VydEe3bq0QdjXb9etICo5d5nXhFF9MO%2B9SXdtVlhUfI%2BkqjuOy%2Fh3nK7uITcTAE1SB7TWqREgvg4Swv5zkD9Oaw2YdfQs4mjp5odzBsRyo4EADNapcFh4mb1ZxfA9HoM5x89i67E4JNZUCGrDqegLyumjzZq64fGhwRg2qLsy6SpxdXFEfOLVim2LhNPVaDTQajUVw0D5lXrmcn5BRgLl%2FE%2F%2FTjhx8ryIJE5W%2FHYu4aoyWVxbhj8WhA2bD952quvh8DikXs%2BqNq0c%2Fkq6mKpENg8TWV%2By3mT9yXqU9SnrVdavrGdaOyMDQqqMCHQGhIlO7FTpQB7GPvPyC%2FHia58oDlNOsipn%2F3w2S1n3zPh%2ByiRtr8G%2FQ0DHlvj8b69g1Zqd6N7%2FTeUMHzkhrFVrKvKaMnEgpr70KX7aFqGM6S%2F960yR5mW8%2FcevK3rqsoe%2B4pOXa32cfXr54a3ZozH22b%2FAzbmRcpzu7k749su51aYd%2FGgXLF2xFSED5kKjVSN8z2Kz1G98PArFYkGQH06IHmmYqO9QRgjmhc8vJRZJsD%2FkqTP7ImKwwAh5GWrz2MvLyWnK%2BL08VbMyxUUlSLmeCa%2Fm7iIqUFds26iRXcVk7Z1DNrK3Lk9RrTxUc%2BVqOmzttGji7vJA%2F0v27q%2BkpMNVCIIUsNogj1sKSPkQV12o%2FNjLB3kWsqif98XiUZHHUFq%2B%2BeAwEbG84aFAdBWLzs75WGSO%2Fft4e9wlBBIbW61ySma5EJRvey8hkMiIQW5%2F55i9zPtBhUAij0PmX1shKD%2FuBxECY1JWz53L6p1QDAgpM0o9xol%2B5to9SShgaTR8lHoW9a3UO6EYEFKOAegt3naxJKyq0ncp9U4oBoSUo4IyeXyGJWE9yPqW9c6SoBgQUhlPh1xcYzFYD2X17cmSoBgQUhn7Q5c5X2BNlNW3PUuCYkBIZeTpNwYWg1VhAE91pxgQQgihGBBCCKEYEEIIoRgQQggxO7xRHbEKKt9HhxDCyIBYIfImag9yIzVCGBmYiJo%2BbKS%2BOJr6dLyG8BdsNhw6%2FHp0XMbU2ISs9ulZRXbX0wuq%2FA8eje1KHB1sMpu42%2B2Nv5j%2F4e4jeRFsNqS%2BQvu3MDGQ1OaWwhx6MA7bvwp%2B%2BY2%2F%2Ff%2FHceezHUcOaonRL7VC86aN0NSj6mt9UtMKtCmpeU0OhKeOu5B8cdRTAxuFJ9%2FImxJxGgkUbkL7bzhozLFTL0988ML0UfW%2B8P65epPyX%2BTr6g3Ms9jekOEDdYB72vrPvor53bCBPrYL5gYhtLsnmnk6wLHR%2FfsDcr3crkfXJpg4so1ab4DPqZiMF5o2UR2%2FkmqIN5V9WHJ5EtP5BVPUe32zf3PBOQMrYP3Sjd%2Bt%2Bu7c%2BMXv98DUMW1ha1O3apfpZPrl80PtG9mqtoQEgLOyhPZPMSD1JTReuS5u%2FMfvhaBzx8ZGyVPms2xeqEarVa%2FsTkEgtH%2BKAbFs5GTZ1p2XPp4iejPGagiVG8TkUY%2BotFB9LnpII1jahPZPMSAWijxrIv5CjuMzI9uYJP8XJ3WEra1aqzfgu%2BBOaGvMdszaszqMfnPCemz%2FFANiXKLPZTw3fIB3ncdIq0Pm27Orp2zFWuiM%2BrziwoG%2BvJ2xNdHbR6nvAto%2FxYCYgNjE7Lb9QpqZdB9DH%2FWSCwfx6mfEB5qn3XTig06siXwnSEO9TvunGBATkJZeaO%2FdvJFJ9xHQzq08yE814gPNE0v0fASiNaFRIdAAxNH%2BKQbEBKRnF6o8XO1qleZGeiEuXc1DZnZxjbb3aVbR2JzEa4gxjls4hXCVHv1Yg1aECoNUwCFz2L9BGJy0efkqKtLXah%2BmsH9zoVxx0asTmh05XfUzZ6tbb0rmvLcKFy%2FfuO03F2cHrFr%2BKmJiL2HRZ5vw5bLZd6XT6fRYtWYHvt9yGBmZuXBzdUS3Lm3w4rRhaNO6GfYfjMbfVmy9K90rzw%2FHoEe7NIj2pdcZoNbU%2FKLbcxdy8diUfbCxUeOHf%2FSGm4tr9b2JsvxFg3JXGemKdoMK%2FxG9lKXi43xwMrnBI%2BeHcgyYrFdjuDnsXyU2%2BWT1Oaz54SKeftwHy%2Bd1r3lv2gT2X1se1D%2BXp1cOvliHK8H%2B2KjV4NV7ZVrdelMSdfo8nhgagt49O95SMG3phdNZOfk4FnHunukWLApTHP4Hv5%2BI1q2a4uKl69j841HlNykG19OycS01E3%2BdP%2FW2dG3btLDaRvn6%2FCjkFejwxf92Q%2BeOrrVKqyrtGTkY4zgio7E7OADqkACMC4%2FGBrrLhk2OA94Si1ORZxBlrmP4%2BJ0uiIrJwvofL2P0UC8M6dvMbPZfW%2Brqn3v6Y4xOhaUlOniIr6XXYqtKh4sm6HQYIzL94c5Mq1tvajq29xZi4FerNNt2RuLNWU%2BhX%2B8A5XtL7yboG%2BqPkpJbYaCTo32t822o7Dt6A8dOpiO0m7vSGOqIsW5vohc2N0f0tlZ380P4ibNIYg01TIL8MFIOAGgMCDXncWhED3%2Fh3E4YOfNXLFl5rtZiYGT7r60Q1co%2Fl4uACJx8Ksfdt4U1htLvVWZa3XpTEXsuGe6NnW6LDHoEtb9vGr8OPli7fh%2FaPdICnfxbizTqsrS3pklybxbg0NGzd0UGTT1dra5R%2FrQ3RVlOfqqVRRyPiAh%2BCgrAUuEk9ovl5OPR2E%2FX2XBo1w52rjb4nRQCofwTImKMO3lcp%2BES0RF6pJUjIs5kIOVGAZo3qV9nN1fnn6sSgXuKQVWZ1nanxmbrL%2BE4eDS24rucM6hODBb%2BcQrem%2F8vjP7Nh8r3wI4t8dTjPTHj2SEVgpB6PROLl22%2BLZ0yZ%2BDZxeoa58nYLGXZo0tjizkmIQALg%2F2QpDJgY5A%2FwsXyO70Gx1xvInFPknHPSSemZYLoNSd1QGudGgFlk8WThB85rRURgSUIQTk9OjdG4sWbOB2bXe%2FEoEr%2FrMJPJcD8qkTgvmJQEasDJ4TbHG6oZn1JCc6LnZpsvGzu7FF4YlhIrdI0a%2BqmTCwXFBYhLv4KjoSfw9%2B%2F%2BBHpGTl4d854ZZtHfJtjwzdvG%2BUY6%2FszGjIyi5SlR2M7iywH4TxGiLcRar0yxiz3Q%2BoRibfqsXKdNhc91VhLqssm7qX2n55VVO%2F9gPTPooyfKDFgvFjqqzswbRUN76BImCyWj4kMV4rlm%2Fdbb6PFR7WJDB5mgdnb2aJLoK%2Fyyi8oVCaQTUF198q%2FT89o1tGzpukZ1aacnZxKTSG%2FQIfGLjYmKwdCHhZ18TN5eTpl6eigtQj77%2BmHDiUqLBeZdhJ%2F5lvxj3Zp9Ij2jcOFMEB3r%2F9Z2T%2BL5ef2NlhVUIzpouP%2BvEGFLMgIoToxKM%2FEUJrJERsN%2FKWTFzt7837rLdEQpr2yFLNnPoHg7qW3DEnPyMWOPVHo28s83RCl4uKUDpJ8bW3XDu%2FKMVPRMzrcPQATIqOx05zl5evtiMgzmTgdlwWvprwTBLFOpP0rowYtG5n9WIRfGKwzIEz43SVZxRgZH4%2FC8nXH7tOJr8I%2Fz%2BnVCR8V6%2FBOVaJQWQzCqnHyYeYSgRde%2F%2Ftt3%2BVk8qlDS5XPaRk58Pa7%2FS6ya1fOVYaJnn3pU%2BUcYmdHB2V4aNyoPsoZRuWcPJN0V9pFC6Zh0vj%2BJv9PZRW7IMhPGWoLEz2AUFNFCDVhUG9P%2FLAtGRt%2FSsbQfs3oFYjVcSE5D%2BGnM5TOkF9bF7Mei4wIpBAYDJh6%2FCy21qS%2FWZ1%2FLvutSlEoF4N8kcnl%2Bzj56tabjJ2b%2F6%2FKdaEhHZB89t6PzxzQLxB%2F%2BWAqkq%2BkQS9K1LOJizJkVM7YJ0OVl7mRFS0iryUiQlgmvg4113GMGeqNPy8%2Fiy27ruKN%2BGz4t3OhdyBWxcdfxCpXI780ua3SiTQnZf5gSQ2FoFb%2B%2BU5REH%2F1Jfm7clqNVoM2x2Mwp6qMqltvyXh7eSjXGFQWAkvDOV%2B542Fnc97oys5WjYVvdUJxiR6v%2FCkSOTdL6B2I1SCjYnnBWUB7F0yf4Gve4aFSP9C5zC9US139s9xeppPpKyKD6jKpjyJQn5CnSQYHYG3Zja6MdhWmvFS%2BNrekeHJwC3yzqAeycopx%2BWpejaKD3JvFrEBikdTU%2FmU0IE%2B1WfrHbugT5KF0jGqKKexf8QMqrK3p6dMP6p%2FL02tpMhaCAbuEPb5hzCzdnG1L0rIKtZ7uNZ8QHjGgea32cS4pm3VHLJKa2r8cEho3zLtO%2BzCF%2FQs%2F0FtlwKcPXTxpMpaB6MCcETZp1Ns2OzvaZCan5Jn0uI9Gld5EUBhvDspOdSPEEqiv9i%2F9gPQHFAMrxSFXCdWM%2BkAXj8Z2ew%2BEm3aEb%2FuBK6W9GRVSxYLDicRiqMf271nmDygG1sihy8r4oFFP8I%2B%2FmP%2Fhf3ZdLikq1pvkmM9fzkHS5dxyS5LXT1xkTRJLoR7bv32ZP6AYWCkGwLhXL%2B4%2Bkhdha6MOX7f1vEkO%2BPcfRVQ%2B%2Bpuyo8RqJJZCPbZ%2FFczwHA%2BKQQMn%2BUbelJXr4gpOxWYYNd%2B%2F%2FvM0Ei7klDeERPEK1quxkSVOaP%2F1E4pBAydC2GxRsWHc7D8d1hmrQciGsL5yb0uFA6Irc8ycDychhPZPMSDVcOSU7sfc%2FJKZL7570PDZNzGo6xiqHCOd%2BOqe2xuCAf8W78MMGrzNkia0%2F%2FoLrzOwEo5HY3WIv169ZmPCinWbz2tDuzXB8AE%2B6NDWBa29nO6ZJq%2BgBLGJ2Th64jp2HLgiGkPu7RvIhiDvwKrCtHDRA2MpE9o%2FxaDWhPSfTgt9yITH4MugQEOyrkgXtvfoNY141e0ZFHKMVITGkM%2B6UOO5iDP4maVLaP%2F1G7MME8l7fvO%2B92bqIQnDVWnQTXz8RRh1mqiE0%2BJ1SdTGzfskyxXbnFcbRBrgBwNgpzwAXIs%2BxykEhPbfIOAwkRUSURrSjpE3xCq7H9JQ6EVzUMGxiiROBgMyDSq4ic9HDRrMC%2BdkMaH9E2Ia6vujMwkh9dcP8GwiQgghFANCCCEUA0IIIRQDQgghFANCCCEUA0IIIRQDQgghFANCCCHl8ArkBgwvYiu99QktgRCKgdUTvn%2BV1f533gyRkJrDYSLS4KMjRkiEUAwIIYRQDAghhFAMCCGEUAzqIXJsm2e%2FEGK9qMr8AMXAyino7QN7FgMh1klZ%2By%2BgGJDr%2BU5oxmIgxDopa%2F%2FXKQZWjogN4zQqBLIkCLFOZPuXfoBiYOWogEPibZAlHItOp8el5Bu4mpLBiiHk4TmBQYofoBhYN3o1NorwYPJA34c%2FbzBpxmKcPJOkfE69kYX%2Bw9%2FDlJmfYObry%2Buc55mzFxERmVDn9AWFRQj74VcaBrEKlHYv2r%2FiB8wAb0dhQUSeQVSwP07lOOAt8XXBw9z3uKd6o5mnm%2FJ5%2Ffe%2FolvnNvj7khcfKM9fdkTiWmomgru3rVP67Ox8vPHulxg%2Fug9UKp5kRRo2Ze3%2BlPQDFAMCjQGzdSocDvLDieNnsfVh7TctPUdxuAnnU7BtdyRstVosWbYJfUL9ERrS4b5pky6mYvW%2FduLqtQw09XTF2JGhYumGg0djcfNmgZKPi0sjPD91CP4dtheBfq2wbdcJnBKRyMD%2BnTFl4gCsWrMTB4%2FE4BHf5nj7jbFwbGSH9WVRwZLlm5Xz7caN6o3WLZvSSEiDQ7T3kWIxR7T%2FUHMdA4eJLIyjZxGnV2GC8MvfiCjh%2FXbtYPcw9rti1c9ISc2Ag70tnBzt4eBgh5beTeDq7HDfdIVFxRj1zEL4eHng2YkDlTTb90TBzt4GrkIAHEVe8rcWzd2V7deu34cZs5fBXqwfNri7cPSbMPDxP4gIIgNPjeiJX4%2BcxdIVW5RtpbBIZHr5srezpYGQBoVs37Kdy%2FYu271s%2F%2BY6FkYGFkhkNHb29ENoiQrLXW0wK8gf38KAXRo9on3jcCEM0Jlq314t3NGhrRdsbLSYMKZvtdunpGYiMzsXI4YEw8fbA%2F37BFSsC%2FRrqQwT3ZnPgvd%2FI7YPUj6Hn0hAM%2BH0350zvkJctvwcrnwe2K%2BTspzAYSLSQJgggv%2BkDmitUyOgbLJ4kgE4rRURQUSM%2BYSAYmDhEYJYDOkeiK5qA8aKz6%2FpNWif6I%2FWwRZ0lXJrH088M7Y%2F%2Bg9%2FFx3aeaF3Lz%2B8PH04mjV1qzKNRnMrIHV2vD3ycBaRSElxidGPk3cuJZZAYunVxRdEAz4nWvEhEQ0MN9ccAcWgvkUJpYZSJ2N5WA7wo%2FnP4b2545Ve%2Fjff7sasuZ9jw5p3lHWGao7gzg6%2FykQ6x4fcEHJ%2FOGdAHgh5LcLh8Di4ujpi8IAueHpMX6Rn5irr5G8J56%2FWOW8ZJajVKsQnprCgCWFkQCwZvej6v%2FHOSmXp6eGiXKPwycLSJ4yNHBaCL77ahuABc%2BHu5oTtm%2BbVKm85mf3c5EF4cuICODnZY%2FGC6RjQjxdoE2IKGDo3YOQw0cN67KWcKC4qLlHOKqo82avXG5B8NU05M8jO1qZOeadl5ChLj8bOtUpX%2BbGXHCYihJEBeQDWbdyPDZuqvjr%2B0w9nKGcRVTVhLId55GmhD0JtRYAQQjEgRuaZcf2VFyGkYcMJZEIIIRQDQgghFANCCCEUA0IIIRQDQgghFANCCCEUA0IIIRQDQgghFANCCCEV8ArkBk7l%2B%2FMQQkhVaFgEDZerNzBPvrw88QHLAvNoEYRUDYeJCCGEEEIIIcB%2FAZrKlCcV2%2FcTAAAAAElFTkSuQmCC)

```
else_stmt
         ::= ELSE ( '(' statement* ')' | if_stmt )
```

referenced by:

* if_stmt

**keywrap_stmt:**

![keywrap_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAl8AAABHCAYAAAA5pSLCAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAHZRJREFUeNrtnQl8jMcbx3975L4vR8SROnI4Igkh7qKOUkdRpIo6W3W00tJbqVJVVUqpthRt3ZS2%2BFP3GRLEFYlEgoRIJOQ%2Bd%2Fc%2FM2tXIsghu9nE8%2FV5vdn3mHd25nne%2Bc0z874LEARBEARBEHpDQkVAEARBGBq%2BHlBRKeiGkDBq%2BysaORUBQRAEYYgEH1lJhVDOtGg%2FigrBAJBSERAEQRDE8wOPKlJkkcQXQRAEQRAEiS%2BCIAiCIAiCxBdBEARBEASJL4IgCIIgCILEF0EQBEEQBIkvgiAIgiAIEl8EQRAEQRAEiS%2BCIAiCIAgSXwRBEARRCQgKicCViLgSH3%2F0xGVci4k3uO8RFR2P40FXqEJJfBEEQRCEYfPHhkM4cORCiY%2F%2FefVenDgdbnDf49jJMPy69j%2Bq0CoE%2FbYjQRAEUakJvRiDdZsPI%2FleOlycHRAwqAOyc%2FJwOTwWiUmpyMrKQZ3aThjYtw3Wrj%2BIM6FRSEnNRK2aDhg9vCvq1amGkLNRuBZzB3v3h%2BLOnfto1MAZvXu0REZmDn5ZvQfBZyPh6GCNMSNeQmP3OuK6q37fh5a%2BDbFj5ymEhd9Ej5d80K9XayaU9iLodAQ83Wvj%2Fcn9YGJsJI6%2Fk3CfCbw9uHD5BtxY%2Bm%2BN6gHnmvbIz1di8fK%2F8UpPP%2Fz25z5cv5HI0mmFgf3aiO%2F038FQXL%2BZiO%2BWbIfcSIbJ43tTpVdyKPJFEARBVFribiVh6OgF8PWqjyED2sPG2hyHj1%2BChbmJWPjn2rUc4eRgI45PuJuCVi0aYfQbXSGTSTDgjXnIz1PA0tIUZqbGsLO1EMc72FtBqVTh9THfISk5DZOY4OHnDX7zWyGiOCuZ%2BBozcQlsbSzQtZMXZn29Ad37f4G0tCz0ZeJp939nsWLVHnHs%2FfsZ6Dt0Dqo72SJwYl9xzmsj5wvhpVAqsIAJq3cCf2KirBY6tW%2BC6TPW4NyFaBjJZbCzsxR54%2FnigpGo%2FFDkiyAIgqi0RF6Lh4mxHN27eMOaCa3OHZpq99Wt7QQPt9oY1L%2BtdhsXPmnpWYhi53HBtOrP%2FYiLT4Jbw1qoWcMOLXwaaI8%2FdPQSsrNzMeuTAPHZz7ch9h86j70HQzHstY5i24Kv3kTb1h7i7yMnLsOriSsTar3EZy7aQs5Fir%2FXbz0Cfz83jB3ZTZvW1r9PIpQJrCaN1ZG09avehz0TWpwDhy%2FgbOg1NG%2FqKoRlenp2oe9BkPgiCIIgiCJ4N4aXVIVXoYI%2F%2B9iQ6yG2SMrzGv6t3NCscT00b%2FceGnvWQYc2nmI4z8rSrMixCoUS02esxn4mbLya1BPRJw6PPj2OiKhbYrJ76y7TCm3XiC2OVPrw61iya0okDz9bWZpq046IvIX%2F7T9XJK3snNyHaRU818oM%2BQqlTuvH14PVzNPh%2B6%2Bz5SqrtRNKCbaevYRQsmwSXwRBEISB4eeORvkSLJUo0YS13utYE75YpsTlehG4volpoHISBgJjIzlWL58ihgJDzkVh2crd4u9vZ7%2BpVg%2Bqh8nsO3ReTF4%2F%2Br%2B5MDczEdt27T1TWG0UuKqlhSmaN3PFptXTylYQBcQUT2tQ3zaY%2BfHQIofl5OY95lTJI%2FlSlXs9hYQ9XQgPAmQxjVBXIYUn%2B9iZCendPh64KFfhnVNXEEGWXnZozhdBEARRbnh7ootCgpOsVT%2BUkod6Z8Iw9cwV%2FHM6AtdKKrxKw4XL18XrJKpXs8XL3XzRvbO3mKTOsbG2QOS129pjc5nIkclkkMtl4jMfVswqEHni88N4pEvDi%2B2b4Nz5aOw%2FfF677WrUbTG5vrT06OqDzTuOF3r1xcngCCQkphR7Lh9OjbmRICJ3%2BoTXF683Xn%2B8Hnl98nrl9cvrmay97FDkiyAIgigXeMRLocImlQrDeYOtj2tmZuVg%2FOSFQqDwSeni6cQf3hH7hgxsJya1t%2BryATzdauOnRROwcu0%2BeLd%2FTzyByCfQy6UybVrDBnfC8Le%2Bx649IWJO1uJvxrJz3sa0z1drI1E8ArV84dulzmebVu54f2I%2FvPrG17C1Mhf5tLe3xLpfA4s9t0uHZli8%2FB%2B06BgImVyK4IMLKqR%2BIyORw1azfdxxTsq0Gavv1hQBKxsSKgKCIAiiPPD1AH%2B073BIGGaXQ1qq4CMrS3x8bFySmH%2FFX91QkLzcfMQn3odzDXvIZFLtsebmJtrJ7QXhQ4A8GsVfWVFw6O%2FW7WQYm8jhaG%2F9TN%2BLR69uxSfDhgkwLhhLA883F2yaIdOy0KL9KO3fxQ07FlM%2Fn7JVB5ZGN7L80kPDjgRBEMQzwyfXs1VTqyx8WxHXd6nlUER4cYyM5eIVDRrhpTn2ccKLwyNi%2FPhH51zxtJ9VeHF4Pnj6pRVemnw%2Fi%2FAqTx7Uc9MH9U6Q%2BCIIgiD03pgoMQAS%2FHkwBtlUGlUfUc%2BsvkW9EyS%2BCIIgCP2jAvzZf%2FupJJ6rSt8v6p0g8UUQBEHoHwnEZPtLVBLPD7y%2Beb1TSZD4IgiCICoGJ7N03KFieH54UN9OVBIkvgiCIIiKwfRELM33ep54UN%2BmVBIkvgiCIIiKgT8eqKJieK5QgV5ZReKLIAiCIAiCxBdBEARBEARB4osgCIIgCILEF0EQBEEQRBWHflibIAiCMEgK%2Fg4hQVQlKPJFEARBGBz8R5%2Bf5YefCcKQqZDIF%2F%2B1eir6Z78x6TJ9VfA4o80nTk65HHFveHhUSsPklFyTxOTsJ17Twc4k38LM6L6jvcmhyBtZcw8EZYaQHRFkz%2FrNt6HlnyDIDwxIfHGCj6wkiyojug7F7%2F3N9%2B13F%2F01PyI61aJ359ro91Yd1KhmjmoOT36XXkJStjw%2BIdPxaHDCgOtxN%2Fr26WQeHHc3c1jIRUSRHRFkz%2FrJtyHlv7IIc8Kwqap%2BIKuIizo74Ytxo%2FqSVZWRFau2izLky%2B27mFluvQvVF1JP%2B6SNP%2FwW9kH3Ti7GswN90NrbCdWdzGBh%2FnSdzvfz41p6OWJwb1epUgWXC2H3xlVzlJy5laCKJDsiyJ51n%2B%2BK9sfyrD%2BicqCreq%2BsflBSaM4XoWXj4i0bVm64OnDBpy0xvH99GBuVzTz4efz8pbNam5obS%2F5u4QmaNUuQPes53%2BSPBPmv4foBiS9CwEO7v6yPGDj%2F4xZo6mZXLmnydJbMbC2Ty6W%2FeNMNnyB7rpB8kz8S5L%2BG5wckvggxmfGffTfnD2O9Al0YekDfFyRySH5iPY2eVNoE2bP%2B803%2BSJD%2FGpYfkPgiwJ8iibyeZjGkt6tO0h8%2F1A3GxlK5UoUNvk1Qn0qcIHvWf7714I%2F09PHzR7n%2FmHoV8AMSX0TJuHz13ogeHWs985j6k%2BDp%2Bnk5cS%2BVQ4FvqcQJsmf951sP%2FpjTqR5MyQKfH%2FxdRH1nVyb%2FNZR2icQXgfBrqfXbtaiu02t06%2BDMV2ZsaefdGF5U6gTZs%2F7zrWN%2FTMqwhBNZ4PNDliW4wSZWNv81hHaJxBeBpOQc01o1zHV6Dc8Gtuo%2FJEiQKjGASp0ge9Z%2FvnXsj9fylWhEFvj8IJOgsQqIqGz%2BawjtEokvAsmpORIHG5NSnXM3OQc3b2fifmpeiY53qa51Jku2vESlTlS0PatYq8FtmC%2B5ucpSXUMX9lwWP9RwKyFbfI%2FMbEWF5Z8VZ7BEiXZkgc8REnSWACcqqj2Kv6u2%2B%2FTM%2FDJdqyLbJfGmslZNUD3oIu486aDi9uuS6TPWoFc3X3Ro21i77ctvNsLc3ASBE%2Fti%2FZYj2Ly9aN1%2F%2BclQ%2FPTbHrz0YnNxvrZrFhOPz79ah3kzh2PKh79ixaIJsLezFPv%2B3ROCrTtO4NclE7XHL1%2B5GzbWFhg6sD3mL96GoOCr6pqyMIV3M1eMGdENFuaFDSX4bCS%2BXrgVg%2Fu3xSC2aEhITMGEwJ%2B0n90aOiNgUAc0dq9Tof6jVKgglZX8JdJXr6ej67DDMDKSYtsyf9ha2xSv8h%2Bkzxo8e0kF%2FLLC0NEL8NHUAWjWuF6xx27adgyvvNwSpibGBnev4zZ0JjQKPbr60I3%2FGe1Zwg5ZuOoq1m67gddedsHSmd4l77XqwJ5L64eciJh0vBF4CtduZKjvV7N9MKB7rQrJv0qCf1lvfjH7cxZo8n2Vh8%2FvS1MhQClFj4pqjwZPDsLlq6mQs%2BNHDXLFV4GNS3WtsvjBs%2Bohzfki8pWnwC1fD2zkGx93cHH7dcmFSzFITErVfp49fyNOBodj%2FJvdxecbsXchl0uZEOtTaHFxdkRP1kB9MnMtUlMzted%2F%2BMVa%2BLVoiFrODriTcB8nTodr9%2B38XzD%2BO3gO128mPGyI%2FzqGak5qcREReQuudauJ9F99pTX2HT6PMZOWFMnzHxsP4X5KBlYw8VeQrJxcnDh1BZPH9xKLuZkJ%2Bgyeg0tXblQqp5syK1T0sL%2F9sBmautmU6lyJuoehdzsa0Mcf1Z1sSxANUeHdj35lNpNlkGUfERmHed9vpTt%2FOTF%2FejM0c7fBxp2x2Hus9PfTirJnDd%2F9EiGE15DetfHX8jbo2NKxwvJ%2F9jIOsASlLTxpWsHzQJoZ3udN9NlLCK2oPCz61Au%2Ff%2BcHG2sjrFh%2FDWGRqWVKpzR%2BUFY95OeB%2Fr6euJmvQLQ28iVRDz8OUijYTg9sk8swqaCyK26%2FvliyYicOHr2EzauniciTBicHa%2Fj7uRc5vnsXbxEZm7doK776bBi2%2Fn0Sd5mQmzBK%2FVqP9m08hRjSRMaCz0Wid%2FeWbFs46tauhqR7aYiKuYNWLR5OY6jt4qi9Vq2aDugbMAcKhRIymXoENys7F7v2nsG2Pz5E36FzcCUiFu6NXArlq7WfG4yN5CKadyUiDjt2nqrw6FdJOXzqLk6fT0br5vbo1825rMno%2FWetkpLTIJGoezn%2F23cWVpZmCL8ah%2F2HL6BuHSd8MKkfbGwsmNg%2Bro4grNwtbKzHSz7wdKtdbPq8zvceOIe8vHy0aumGQf3awMTYCMeDruDPTYeRnpGNrp2a4fXXOop8pDBxvnrdAXTr7I2fV%2B9B4t0UvDGkk4jUihtbWhZWsO08j7bWFsxWPNGrewts2n4cSUlp%2BG7JdnHc2JHdxHd5Gjm5eVi5dp%2BwdRtrc4wM6AJf7%2Fq4HpuILez7jh3B0rBSp7H7vzNQKlV4mfkEt0sn1vE4feYqgk5HoHkzV0xinQYeEeQdl%2B3%2FBmFgv7ZirVAqMWZ45RtNlrGe75zAJug99hgTMlfxUtvqlcKeNSQk54j1uCGupe4I6SD%2FSuZhU1n%2FZVVzd3Y7vYIYkihVEx939GarqTIVWldkPpp7qjvUHVo6YdueONxJyoFHA%2BjUD0qrh7joUkiwWKGCS8F4cKE5Xyq1GOOJxj5O2RW3X5f8vvEQNmw9ivWrAmFra1FoH4%2BM8Yal4MIbL86Xn7yOzayBOXL8Mr6ct0EMN8qN1GXcrrWHaBw5fDiyRjU7dH3RSxsNO8kaHK%2FG9QoJvYLcvpOMWs72WuGlabzcGtaCB2uwufjbvP34U79XVlaOQQ5vPVFkHIoX64A%2BdSrVzYKLqfiEe1rxNeqdH3ArPhl9erbEhUvX8eX8jWoh72gt1s417VG7lmORIeXHsezX3ZizYDM6d2iKLp28sGtPCGKuJwibmzB1OdvWDCMCXsR6Zr9fL9wizrmfmoFvFm3DxzPXwtvrBbT0aYixU35E3K0ksX9C4HLcup2MN1%2FvLEQPF3eajga3X543vsjlxd8vxkxcishrtzFxXC90at8UIycsQvT1O6jr4oTL4TcR%2BIn6x8nPnY%2FGx7N%2B1w7N7th1CuMmL0VOTh76vOyHvftD8cXc9Q9s%2F57I%2F6AR8xAZfVsIwspKK9aReKGOBUIu3RNzSCoTmrku1pZGBpGf4MvYpWINDbPKIz6eaE8ypWrRoAFMWNv%2FKes%2FrmFKexBraiMMIV9WlvJC%2FqAPitNDmkiXAtgKLrweQV5MokLZFbdf15Gwf8VwYCgWfzMWjvbWRfZfCY%2FFgiU7Cm2b%2FWkA3K1c4FLLAZPf6o1h4xdiSP92opHT0LaVO96eeht3k1OF4Grj5y6Wud%2BpG0gu4toygVaQoyfCkJ%2BnEBGuv1iPf%2B6MNwrt53PG%2BJAkp%2F8r%2Fvjgs9%2FwceAgSKUPx7BPngoX0Q8%2BbHk5Ihbffz2m0jjf%2BfAUsW7ZzK5S30TeGtUD7054Re24VmZCSHA6tWsi1n16%2BmmHm59Gfr4Si5b%2FjT9%2Fngqf5ur39PXr1UpEj%2FgQ%2BTtM8PTvrbYHMRQ%2BYCYCJ%2FUTn3n0c8vv07URub%2F%2BPYnzTAjyIfGLYTcwi9krj7Lyhc8N1ORv36HzheYSPo1zF6IRFR2P1cunCBv0823IOhXh2MkE4jtjX8bCOaPRc%2BAsLFr2N%2BvcHMMPzMe4z2gInNgPI5kAFDde15oIGLMAcz5X27yJqRG2%2Ff4RrK3NUdlp2dRODN9dDE9FDUfDflWVgnWho2MzcPj0XZy%2FkoI2Pg6o42w4dXDmMub4uiNGosIWHw8Es%2FUGpQynbTJw7WAMskFUGgYBsphGqKuQwvPB5PqhrP2%2FKFehdUiYYQgvDp%2FnuG7HTSxdEwVHOxM0qmcJe1v9BDWK6CEJdjEJOOvRSFeJxJcGJbt3S4EeqmL25%2Bcjml3UTFdfjkcDPpjcX%2FTK%2BRBQowaFh7v48OEP88c98fzxI7uzxnUrhge8WGg7H2Zq4lFXiKETQeEY1K8tqlezhamJkZhLxocfv%2Fwk4LFp8uhJjy4%2B6Nrp4atBEu6m4PDxS2jn7ykmbecrlELYHT1xudADA7yhk0iZNbu5YNeWzws1dqWFlbteJ7beu58r1g52Js%2BUjr7z%2FSgFJ3Tyobi8PEWZ0rmTcE9EWR%2BdyM%2BFTlT0HTGkp6Fh%2FZrIzcvH7fhk8ZmLLo3wEtELK3PWsKrzwQXa1I9XClHo0%2FwFjBrWFV5N6pU6f1cjb4khwjYvTS%2B0vY6Lk1Z4Llv4Fnq8OhMTx71cpLNRIHt4oV51MXyakaFuP3nEtryFV0XZhaO92p6TU3INPt98aMV%2F4AHxdwc%2FR%2FzxnV%2BhejKk%2FLNs9WT%2F9ZQqxRwhfh2iEnHtYT0WrNMaCgnCDakueQdk3SI%2FBLx3Cq%2BMPYZBPV3w4yxvvfoB10OsbHrlqzCQrZXFJSR%2FgsMcZyfGsXVXluAvbP3e0%2FazDvy80kS%2BSvsFx73ZXUyYTk3LxBvjF2LHuk%2BESCopYpiR3Z2kj7lDtfP3wLGgKzh99irmzRqhrshW7iLaduNmIlr4NChy%2FOTxvTGgrz96vTYbHkxAaaIS2%2F8JEnPF%2BDwvDY2ZWNyy40Qh8bVu1fsi6lEesN6H5FnTKE19WD4I72ZlK2BnbVRp8q0r%2BJA0F1D30zKKRGWtLE2Rlv5w4j4XLnx%2BoAU7RyNgnsSw1zoKm%2BdDojv3hmDwyPk4e3ShuqelKvnX5teq71oDe%2F764onHbNl%2BHE0962L7v6fw9qieRYb1tcI7JV0ILnNzE52VZ0XZRWamWvRamMkNPt%2BOrEf%2F61xfHAtJwsrNMZj%2BzUUs%2BsyrwsudICqqA8af%2Bh33yRlUdzDFxOH10crLXmd%2B8Gj%2BCuohtv7J1Agrs%2FMwSgqMUUmQ8rghR9FBfzQRttrEEvBgS6xcBo8zYZha3H59Tb7%2FOHAgWno3xBvjvhcNWXnQ3t9TzG2p5mSrnd%2FDhx5%2FWrlbTEp%2BkkjiIuvnxe9gxpx1Ym4Ph8%2Fveu%2BdPlg4d7R24RP9d7HGMzMrp0o4Rr1a6ob5YkRKlXR8LqR4NIfPkSoJPHrawrsBfvx5l3ZbUEiEiDZ17tgM6zYfEUOTnLXrD4ro1eOGzosIIibYue3xYcIJo3siIzMbOcyjed7iWdoZmSWzJz60fiMuUQyRa%2BBP84ZejFF3GHYG4eDRi9j6x4ci6jVp2goxZKohJU39pDAXjUvZd%2BTzGAvOcawqaOz5hdqGP4RqbCxFn67OmDe9KTzqW%2BHPHTfEe74I4nllFeuEJN%2FPxccT3DFqYD00bmit82s%2BSQ8dP4%2BLfC2ToSHrJ29ix6Wxg2OfFvniiXDlFmTEEnmMoCpuv14axoVzRmHY%2BO8xbspSrFn2rtjOn2LkS0G2%2FfGRaLiKoyU7JjsrD%2F4t3bTb%2FFmDdTc5De1aez71XH7Ol58GYCzLyzczR%2BBazB3ROBWET6Z2dLARE6YfjaJVRjr7q58q2bIrDt3aVa%2BSjsyHqUe%2BvQh2dpb4YFJ%2FDOzX5qnHL5o3GuOnLIN3u%2Fcgk0thZmqCTas%2FEHMNx0%2F5EW27T4eNlYUQUL8tm1KiPKxetx%2BfffUnGtV3RjSzq8%2BnDRYRKS6%2BvJq4olWXDyCTSLF76wzUrGH3VHG46sfJCPxoJWbN2yAEHZ9Av%2FDr0eJJyk%2B%2F%2FIPldbp47cnsz17Hyw%2Fmf%2FFOBIe%2FNmX1nwfEHEc%2B5M%2Ffi1fVuB6XieCL9%2BBczRTu9a0rVd7FcGlUGu6n5Ir8E8TziHY6jK3eHl4rVg892Da1VRPMy1Ng%2BqORMI34yuLK7Smiqrj9OmPn5s8LfTYylmPDqve1n6dN6S%2BWYm%2BwF35%2B7Hb%2BOoCo0OWFtvEnymLDfi1yLI90PcqQAe3FwuFPhD2O43u%2F1v4dd2VlpTby%2Ft1q4aulV%2FD3%2Ftt4NzIVHg0qR2N19shC7d%2FfMQFfSET7uePI7jnaz3wi%2FsiAzsjNz0c1x%2BIn3fMoKBdBfM4fjwo52Flp96356V3xNG42Ey%2F86cSC5zxqd7zDoIEPrd%2B7l450Jtj4E5iaJ2L5XDJu%2FzyyxgWT5hURxXUSjv83D%2FF37kHK8lfwO104sVj7t5mpMQ78M7vQuTzqxif380hzwfOaN3VFyKEFVeLGPf%2FncPG2%2B7cC6j%2Fz3Cl9Y2WhvoXvPnIHbi9YiVdnEMTzxO3EbNF54lhb6uX93aXSQ4%2BKMOahb2nFl1wG16clUtx%2B4vnBxFiKOe83wagPgzFhxlnsWNFW2wBUJTTznvbsP1fkZbkF%2BXz6a9rJ9k8SalzMlwUeebN78OsLj6KZ87hgyXbxYMiT2LxmmvbvGtXL9oQqF3l8qYrwKC5%2FwapnQ2uMGlSv0uV%2F7GBXHDyZiLnLroilpG%2B4J4iqQMeAQ%2BIN9xz%2B8Im3p63Or1lWPVRQhGnFV3EJkfCq2vAn%2F0rzkw6vdKmJNd%2B2REpaHmJvZ5Yo%2BpWekVcpy6Zb5%2BZiMVT4T2zpCv6EZUlet1FZ7ZlHu%2Fj0tsWfNxdPS%2FGORUnRhT2X1g857Vo44uw%2FXREWqX7PmpurZYXlnyD07Qf8DfcZWQpYmMm0L1wtDWXxg2fVQ5rz5VTVhK2VcX5SSo7cyb7kc0Z6dqxRqmtcjUmlgq5k8Kd%2Bq7I98yHGskaJdGHPZfFDjr2NMdr6OpA%2FEs9de9T8GSNdFekHUqpqwsrC6H5cfKZOr3Eq9K66wVOBd9EVVOoE2bP%2B803%2BSJD%2FGoYfkPgi%2BAtTDx0N1u3I8t6jt8RaJQH%2F1XIaxibInisg3%2BSPBPmvYfgBiS8CkTey5v67PzY%2FN0%2Bpk%2FSjY9MQE5uusTj%2B0uQbVOoE2bN%2B803%2BSJD%2FGo4fkPgicCAoM8TYSBq8%2Fp9onaT%2F4byQhx9UyOAdDip1guxZv%2FkmfyTIfw3HD0h8EYK4u5nDflkfkX0h%2FF65pvvNiouIup6mMfBrbPFVSrGFSpwge9ZfvskfCfJfw%2FIDEl%2BEIITZYm6easDEGScV5WXw3MA3Fuy9SHBUApw%2BewmhVOIE2bN%2B8k3%2BSJD%2FGp4fkPgitARdUOxMz8ofO%2F6j46of1oShrGPufCx98KSDhQ1chT%2FY%2F91VMkyjkibInnWfb%2FJHgvzXcP2A3vNFFOLMZaxq4aGUrt0StXz9jmh56%2BaO6NHRBY3qW6Ou8%2BNf4JiZnY%2Fwa6k4dS4R%2Fx29xYw8vfAB3MAl6CyR4M1g1qOhUibInss%2F3%2BSPBPlv5fGDCvkhMF8P9rWJciEkTDd16NMYPaAUv8guYx%2FNypQIH0uX4Chb92A9ixFnLmE32RFB9qznfFdg%2FgmC%2FODxyCriorfvYiZfnJ3wBZnVs5elTtJNRKRzDWxkBlqfLU6sd3CNGX4OM1oeLX3ST8ens2PipCqcUklwgSmjulIJEtkZQ5iBnyY7Isie9ZJvg8k%2FQZAfPB4adiSeHIVQh2L7ezeGl1SJAezvbqz3IWH%2FLJ5wiqVKhfvMwPlvPpxivYqZwTSZlyB71ne%2ByR8J8l%2FyA4IgCIIgCELD%2FwFHH2ep0wQ%2BywAAAABJRU5ErkJggg%3D%3D)

```
keywrap_stmt
         ::= KEYWRAP '(' int_const_expr ')' '{' statement* '}'
```

referenced by:

* statement

**encrypt_stmt:**

![encrypt_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAlsAAABHCAYAAAAwToK4AAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAHL9JREFUeNrtnQl8jMcbx3975D7I5Yj7lgi53HdRR6mjcf9RpY6qo2jprVSptqq0SrWNou6raFHqvkkQIiRykiCJhMh97O5%2FZlZWQiIHu9nNPl%2Bf15vd933nnZ15np3fPDPvLEAQBEEQBEFoDQkVAUEQBFHWeLtARaWgHfyvU1tf1sipCAiCIAh9wO%2BELxXCS6Z5hzFUCHqAlIqAIAiCIMovPGpIkUMSWwRBEARBECS2CIIgCIIgCBJbBEEQBEEQJLYIgiAIgiBIbBEEQRAEQRAktgiCIAiCIEhsEQRBEARBkNgiCIIgCIIgSGwRBEEQRAGc8w%2FBjZCYYp9%2F8kwQwiPv6d3nCIu4h9PnblCFktgiCIIgCP1i%2FeZjOHLiarHP%2F3XNQZy5EKx3n%2BPU2ev4fd1%2FVKHlCPptRIIgCMKgCAiMxMZtx5H4IAXVnR0wfFBHZGRmIyg4GvEJj5CenomaNZwwsF9brNt0FBcDwpD0KA3Vqjpg7KhuqF2zEvwvhSE8MhYHDwcgNvYhGtZ3Rp%2BeLZCalonf1hyA36VQODrY4u03X0WTxjXFfVf%2FeQgtvBtg997zuB58Gz1f9UL%2F3q2ZMDqIcxdC4Nq4Bt6f2h9mpibi%2FNi4h0zQHcDVoFtoxNKfOKYnnKvaIydHiWUr9%2BD1Xi3xx4ZDiLoVz9JphYH924rP9N%2FRAETdjsf3P%2B2C3ESGqRP6UKUbOBTZIgiCIAyGmDsJGDZ2Mbzd62GoTwdUsLXE8dPXYGVpJjb%2BukY1Rzg5VBDnx91PQqvmDTF2ZDfIZBL4jFyEnGwFrK3NYWFuCruKVuJ8B3sbKJUq%2FO%2Ft75GQmIwpTODw64a89Z0QTRxfJrbenvwTKlawQrfO7pj39Wb0GPAFkpPT0Y%2BJpf3%2FXcKq1QfEuQ8fpqLfsAWo7FQRMyf3E9cMHv2tEFoKpQKLmZB6d%2BYvTIRVQ%2BcObpg9Zy0uX42AiVwGOztrkTeeLy4QCcOHIlsEQRCEwRAafg9mpnL06OoJWyasunRsqjlWq4YTXBrVwKAB7TTvcaGTnJKOMHYdF0irNxxGzL0ENGpQDVWr2KG5V33N%2BcdOXkNGRhbmfTJcvG7p3QCHj13BwaMBGDG4k3hv8VdvoV1rF%2FH3iTNBcHerw4RZb%2FGaizT%2Fy6Hi7007TqBNy0YYN7q7Jq0de84igAkqtybqSNmm1e%2FDngkrzpHjV3EpIBweTesIIZmSkpHvcxAktgiCIAgCnk3gLlXhDajQhr1swPUP2yQv8x5tWjVCsya14dF%2BOpq41kTHtq5ieM7G2uKZcxUKJWbPWYPDTMi4u9UW0SUOjy4VREjYHTE5vXXXWfnezxVXHKn0ycexZveUSJ68trE216QdEnoH%2Fx6%2B%2FExaGZlZT9LKe62NBXIUSq3Wj7cLq5nnw49Hse0mq7UzSgl2XLqGALJsElsEQRBEGdOyMRrmSLBcooQba603siZ7mUyJoNohiNrKNM9LEgICUxM51qycJob2%2FC%2BHYYXvfvH3d%2FPfUqsF1ZNkDh27Iiabn%2Fx3ISwtzMR7%2Bw5ezK8u8tzV2socHs3qYOuaWaUriDziiac1qF9bzP142DOnZWZlF3Cp5Kl8qV56Pflff77wHQTIIhuilkIKV%2FayCxPO%2B71cEChX4d3zNxBCll56aM4WQRAEUWo8XdFVIcFZ1oofS8pG7YvXMePiDfx9IQThxRVaJeFqUJRY3qFypYp4rbs3enTxFJPKORVsrRAafldzbhYTNTKZDHK5TLzmw4TpeSJLfH4Xj2Tl8koHN1y%2BEoHDx69o3rsZdldMhi8pPbt5Ydvu0%2FmWojjrF4K4%2BKQir%2BXDo5G34kRkTpfw%2BuL1xuuP1yOvT16vvH55PZO1lx6KbBEEQRClgke0FCpsVakwijfQurhnWnomJkxdIgQJn0Qunh788V1xbOjA9mISequuH8C1UQ38snQSfNcdgmeH6eIJQT7hXS6VadIaMaQzRk38AfsO%2BIs5Vcu%2BGceueQezPl%2BjiTTxCNPKJe%2BUOJ9tWzXG%2B5P7442RX6OijaXIp729NTb%2BPrPIa7t2bIZlK%2F9G804zIZNL4Xd0cZnUb2goMtluvldjXJYyLcbquzVFuEqHhIqAIAiCKA3eLuCP3h33v475LyEtld8J32KfHx2TIOZP8aUU8pKdlYN78Q%2FhXMUeMplUc66lpZlmMnpe%2BJAejzbxJSTyDuXduZsIUzM5HO1tX%2Bhz8ejUnXuJqMAEFxeIJYHnmwu03CHQ0tC8wxjN30UNIxZRP5%2ByXUeWRney%2FJJDw4gEQRBEieGT4dmuqU06viuL%2B1ev5vCM0OKYmMrFkgm5Qiv33IKEFodHvPj5T8%2BZ4mm%2FqNDi8Hzw9EsqtHLz%2FSJC62XyuJ6bPq53gsQWQRAEofXGQwkfSLDhaCQyqDTKP6KeWX2LeidIbBEEQRDaRwW0Yf8dppIwqko%2FLOqdILFFEARBaB8JxOT4a1QSxgOvb17vVBIktgiCIAjd4GSRglgqBuPhcX07UUmQ2CIIgiB0g%2FmZaJqvZUw8rm9zKgkSWwRBEIRu4I%2FvqagYjAoVaMkoElsEQRAEQRAktgiCIAiCIEhsEQRBEARBECS2CIIgCIIg9Bz6IWqCIAhCL8j7O34EUZ6gyBZBEARR5vAfSX6RH0omCH2mTCJb%2FNfdqehL%2FkWkzfRVfuNNtp05Oy0o5MGo4LCkBolJWWbxiRmF3tPBzizHysLkoaO92bHQW%2BkLj5xL8ye7IciedZtvfcs%2FQZAf6JHY4vid8CWLKibaDq0f%2FMP7nfeW%2FvVtSMQjqz5daqD%2FxJqoUskSlRwKX7suLiFDfi8uzfGkX5xPVMytfn07W%2FrF3E8b4R%2BIMLIbguxZN%2FnWp%2FwbihAn9Jvy6geysripsxO%2BGD%2BmH1lVMVm1epcoM77dvY%2B5L633oPpC6mqfsOXHP65%2F0KNzddP5M73Q2tMJlZ0sYGX5fB3Oj%2FPzWrg7YkifOlKlCtWvXn8wvpKj5OKdOFUo2Q1B9qz9fJe1P77M%2BiMMA23Vu6H6QXGhOVtGzJZl2zf7br45cPGnLTBqQD2YmpTOHPh1%2FPrl81qbW5pK9jR3Bc1yJciedZxv8keC%2FFd%2F%2FYDElpHCQ7W%2FbQoZ%2BO3HzdG0kd1LSZOn89Pc1jK5XPqbJ33BE2TPZZJv8keC%2FFf%2F%2FIDElhHCJx%2F%2Bfej2tyOY6teGYQ%2FvV1cih%2BQX1pPoRaVNkD3rPt%2FkjwT5r375AYktI4Q%2F5REalWw1tE8draQ%2FYVgjmJpK5UoVNnu7oR6VOEH2rPt868Af6elg4%2BOl%2F%2Fh4OfADEltEwQTdfPBmz07VXnhMvDB4ui3dnbhXyqHAd1TiBNmz7vOtA3%2FM7Fwb5mSBxkOb6qK%2BMwzJf%2FWlXSKxZYQEhz%2Bq1755Za3eo3tHZ76zYFt7zyZwp1InyJ51n28t%2B2NCqjWcyAKNh3RrcIONNzT%2F1Yd2icSWEZKQmGlerYqlVu%2FhWr%2Bi%2Bg8J4qRK%2BFCpE2TPus%2B3lv0xPEeJhmSBxoNMgiYqIMTQ%2FFcf2iUSW0ZI4qNMiUMFsxJdcz8xE7fvpuHho%2BxinV%2B9ssZ5rNn2KpU6Udb2rGKtBLdhvmVlKUt0D23Yc2n8MJc7cRnic6RlKMos%2F6w4%2FSRKtCcLNCIk6CIBzpRVe3TvvtruU9JySnWvsmyXxEphrdxQ%2BVwgYgs7qajj2mTGx764FX0%2F33u2NhbwXT4F14Nv47OvNsLNpQa%2B%2BGiY5vj3P%2B1CE5ea6NHVU7zOyVbA98%2F%2F8M8Bf8TGPYRzFXu0atEQo4d3QeVKFTFx%2BgrcT0gW59rbWaNT%2ByYY5tMRUqkEu%2Faew%2FFTQVj81Vv58vD%2Bp6vx6ise7N41Me3D39V2yKywUYNqGDG4E6pUssPbU5cX%2Brk%2Bmu4Db8%2BymTuuVKgglRV%2FkeabUSnoNuI4TEyk2LmiDSraVihaxT9OnzVw9pIy%2BKWCYWMX46MZPmjWpHaR527deQqvv9YC5mamevfdFhefhIsBYejZzYu%2B6F%2FQnrl%2FLll9E%2Bt23sLg16pj%2BVzP4vdKtWDPJfVDTkhkCkbOPI%2FwW6ni9cr5XvDpUa1M8q%2BS4B%2FWW1%2FG%2FpwHmixf7uHz85JVGK6UomdZtUdDpp5D0M1HkLPzxwyqg69mNinRvUrjBy%2Bqf3KvFzdjWuSOtwu2y2WYUlCiRR3XJgGBEejdvTnatGz0RCHK1QvfJyWnIzzyHm7cjEb%2F3q3h0Uz9NENw6B04OtiqK1KpwuhJy%2FDwUSo%2BmTkQ1as5IjrmPv7YcARb%2FzqNyeNfg%2F%2FlMIwd2Q3ubrURERWHH1bsQXR0AmZPf0MIqgWLt2HHnrN44%2FXWIk3%2Bt9%2BlUCz8fCQib8fjzPkb2LZ2FustK3DsVCD6DJ6PvzZ%2BjJmT%2B2ryPJQ1%2Fl%2FPGYXaNdVTHOrWrmwwTjZtXoDoQf%2F6mQeaNqpQomsl6h6Eha7z7NO3DSo7VSxGtEOF9z76nQlsN5g76Z%2FYCgmNwaIfdpDYekl8O7sZAq4nYcte9p3R3RmvtqtsEPas6Uj%2BFiKE1tA%2BNcTWqI51meX%2FUhCOeLtC2twVPn5B2EbWVb5JtsD7bHf10jUElFUeln7qjtiETEz78jJWbQrHiH414FLftsTplMQPSqt%2FWrpggEKCZTkKOLCX6jXwJerhxEEKBQawRHc%2BnWhRx7UNjxa1adm4wGM21hYY8kZ7LPh%2BG7b88cEzx%2F%2FefwGBQVE4sX8hbGzUZVuDCS6eXlJSquY810Y1xHt8S8%2FIEtEOLrYsLcww7%2BPh%2BHDOWrza2V00zl8u2owVP7wDE9Mnwjg3fzwqdu3Gbfx76BITW%2F3y9KolcG9aW9zHkDh%2B%2Fj4uXElEaw970TiVEp3%2FLFRCYrIocw6vC24nwTdjcPj4VdRigveDKf1RoYKVENwiQuC7H9ZW5uj5qlex6mjfwYs4eOQysrNz0KpFIwzq3xZmpiY4fe4GNmw9jpTUDHTr3Az%2FG9xJ5IPb2pqNR9C9iyd%2BXXMA8feTMHJoZyHmxRcZ6zisYu%2FzPFa0tULHdq7o3aM5tu46jYSEZBGt5Ywb3V18lueRmZUN33WHRCeggq0lRg%2FvKqKoUdHx2M4%2B77g3u2t8Yf9%2FF0WH5LXu3ti99zycnCrgwsWbOHchRHRepkzoLSJ%2BPCK8659zGNi%2FndgrlEq8PcrwRodlrGe7YKYb%2Bow7xYTLzRKLrbKy51ziEjPFfvzQOiXu%2BGgh%2F0rmYTPYV%2BJqj8bwu3wDkSRJyidejdGH7WbIVGhdlvnwcFV3oDu2cMLOAzFCeLnUh1b9oKT6J1dkKVSonjfem2%2FOlkodVuOJRrNEt%2FDwV0mOawveAPGGI3fjjUFexozsirCIezhxOuiZa%2F87GoDePZtrGpe88Ma2IO7eS0TN6o6a13w40r1pHSxaukOIuq6sEW3dvPB5oWnpmayBMikXTrbv2D2xH963pkHlm4une3EPNGJrzLs%2F4g6r1769WuDqtSh8%2Be0WcczJUd0rcq5qL0S4lWXRcwdW%2FL5fRDu7dGzKbMEd%2Bw74IzIqTtjfpBkrhX28OfwVbNpxEl8v2S6u4ZHVb5buxMdz18HTvS5aeDXAuGk%2FI%2BZOgjg%2BaeZK3LmbiLf%2B10WIHC7mRP4cbCE3kYm88S03qvs83p68HKHhdzF5fG907tAUoyctRURULGpVd0JQ8G3M%2FET9Y96Xr0Tg43l%2FaoZad%2B87j%2FFTlyMzMxt9X2uJg4cD8MXCTWqfiH0g8j%2FozUUIjbgrBKCh0op1HOrWtIL%2FtQdiDoghkTtXxdZaP75f%2FIKwT8UaFmaVJ7xc0YFkSfmifn2Ysbb%2BU9ZfXMuU9SDW%2FIboQ75srOX5%2FEEXFKV%2FuMjydsVtBbADXGg9hbyIRIWSK%2Bq4tiNdf%2F%2Frh9PngzWv%2BZwt3ljlwnve0ye9Lhq29m1c8l0bG58kImNFsX33GTE0GJ%2FwCEeOX8Wfv07Pd%2FzLT4ejW9%2FPRaTryN%2Fzn7mei8DsbAUOHglgDW%2BsGMYqD1wJThL7Fs3sDPpzTBzTE%2B8xGxGOyuyHCwdO5%2FZuYt%2B3V0tUcio6UpCTo8TSlXuw4dcZ8PJQz7nr37uViA7NZwLuXSZwBvRRd%2F6qOzuil89czJzSX7w2NZFj%2B5%2BzNRG3v%2F45iytM%2BFVzdkDg9VuYN6C9Jro6fFBHTf4OHbuCQQPaFetzXr4aIToea1ZOE3MOW3o3wNkLwdjLBOG7417DkgVj0WvgPCxdsQebd5zCj9%2BMQ%2FVqDprrZ07uj9FM8Ikv2jpVMfztxVjw%2BUjx2szcBDv%2F%2FAi2tpYGb9ctmtqJ4bjA4Eeo4qjfS0UpWBc5IjoVxy%2Fcx5UbSWjr5YCazvpTBxeDsMC7MSIlKmz3coEf229WynChQirCj0YiA4TBMAiQRTZELYUUro8nww9j7X2gXIXW%2Ftf1Q2hx%2BDzFjbtvY%2FnaMDjamaFhbWvYV9TNNJBn9I8E%2B5jkm%2Fd0JKtYYisXJfvulgI9VUUcz8lBBLup1uYx8OE4PqTyPIb6dMRK339Fo5IXPjT0KDmtWPdRqlTYuecs5n%2F2P9SvWzXfMR5V4EMtfAinYsVnI2KLf9ot9m6uNbF32%2BeoUlk74oSVs04noj54mCX2DnZmBpXvp8k7AZMPrXFhXBpi4x6IIb%2BnJ95zYRMWESuG6HJpUK8qsrJzRKSUw0VWrtBSdxosWUOqzgcXZPxhEC4CvTzqYswI9RzCknIz9I4Y8mv76ux879es7qQRmiuWTETPN%2BaK%2BYrtWufvnOTJnphXyIdDU1MzNJ2aly20ysouHO3V9pyYlKX3%2BeZDJW0GHhF%2Fd2zpiPXft8xXT%2FqUf5atXuy%2FXlKlmOPD70MYEOFP6jFvnVZRSBCsT3XJOxwbl7bE8Onn8fq4UxjUqzp%2BnuepUz%2Fg%2BoeVTe8cFQZKuHwo4nx5IQ5zml0Yw%2FbdWIK%2Fsf305x1nHfZFJYlsacPR5XIpZk0bIBor3shp7uVRT0StZr%2FnIxrEQpVy3zbo2K6JOH%2FCtJ9Rt1ZlTeQiF1NTk0LT4BPkdQHrXUheNI2SlL%2F143BteoYCdrYmBpNvbcHFOxdMD5NTWYOdf2KmjbU5klPSNa%2B5UFEolLBi1%2BQKlsLgT7ByG%2BRDnHsP%2BmPI6G9x6eQSdU9KVfyPze9Vr04VHPjri0LP2b7rNJq61sKuf87jnTG9Cuw8CKGdlCIElqWlWbmx51zS0tQi18pCrvf5dmQ99t8XeuOUfwJ8t0Vi9jeBWPqZe5mXO0GUVYeLP5U7%2FpOLqOxgjsmj6qGVu73W%2FODp%2FOXVP2z%2Fi7kJfDOyMUYKvK2SIKmgIUTRIX86EbbbyhJwYVu0XAaXi9cxo6jjZbUsxNO83quFmCt17OQ1zXvDfDog8UEyPp2%2FHhmZ6l4sjzZs2XkKazceeSaNVzo0xezpPnhr0o%2FPLDlhjNSupm6IA0OSyuXn48KJR2v4HKfiwOf5Nfesj59%2F3ad575x%2FiIgmdenUDBu3nRBDjZx1m46K6NTToqxAAcQ6BHyYkQ%2F7TRrbC6lpGchkHszzdo%2BlnZqWWaz8tWvVGLdi4vHXP%2Bc070XdjkNAYKT4my9lcvRkIHas%2F1BEtabMWiWGQHNJehwF5iJxOfuMfL6iTFb%2BluPLtee6NfR%2FSNTUVIq%2B3ZyxaHZTuNSzwYbdt8Q6WwRhrKxmnY7Eh1n4eFJjjBlYG00a2Gr9noXpn9NXEMj3MhkasH7xVnZeMjs5%2BnmRLZ4IV2rnTFgiBQiooo5rjfHTfs73mq%2BFdfXMsgIbzg9n%2BGDEuCWa9%2BzYuVvXzMKHX6yDW6upYkkI%2FqQaX4frsw8GF3g%2FvgwEb3xHTViC3Rs%2FKRdzVEpLlzbqpz6274tB9%2FaVy%2BVnnDC6B0a%2Fs1TYygdTBmBg%2F7bPPX%2FporGYMG0FPNtPh0wuhYW5GbOxDzB1Yh8RFW3XYzYq2FgJwfTHimnFysOajYfx2Vcb0LCeMyIiY%2FH5rCEi4sRtz92tDlp1%2FQAyiRT7d8xB1Sp2zxWDq3%2Beipkf%2BWLeos1CwPEJ70u%2BHiseNPn0y%2FUsr7PF3EM%2BXP7a4%2Flb099VL1OyfssxrNlwRDyRy5%2FKXLV0Urmr76iYNPgFPoBzJXM0rmdrUHkXw59hyXiYlCXyTxDGiGZ6S0WdLddTpP55%2FN6MVm5YlK3A7KcjXbliK50rteeIqKKOa41Du78s9Bh%2FIvDY3q%2BeiUzF3PDN9x6ff8WH%2BR49ShM99wo2lvkE1IUjz%2F4m5cI5I595b9HcUc%2B8x4csn75fQUReWWWQRj2gezV8tfwG9hy%2Bi%2FdCH5VqTZOy4NKJJ4L7%2BwVj8h3jE9BP7F%2Bgec0nzvMFbrNyclDJsehJ8rVqVBKiJ%2B5%2Bkoj6ONjZaI6t%2FeU98ZBFBhMrfJ5f3mvCAlbmS2fn%2Bo80f3NR%2F%2BBBClKYQONPSOYusMqHrTevfl9EzrhAKuip2qdp06IRTv%2B3CPdiH0DK8pf3M%2BXtpFiYmz7zsAePqvHJ%2BHwINO91Hk3rwP%2FY4nLxRf3tr8FiNfmJw%2Bu98NwnXWNjpf7K3n8iFo3q2oilLAjCmLgbnyE6Sxxba52sl10i%2FfO06GIeOlEjtuQy1HleIkUdNxS4wDLmKFVpMDOVYsH7bhjzoR8mzbmE3avaab7wyxO585YOHL6MVX8cKPS8z2cP1kyOL0yYOTmUTpDyyBrfCoL%2F0gFn8U%2B7cCbPk7lPk3fuYGkf0uCijm%2FlER6l5QuaujawxZhBtQ0u%2F%2BOG1MHRs%2FFYuOKG2Iq7gjxBlAc6DT8mVpDn8IdFPF0rav2epdU%2FeUWXRmwVlVB5EFrEE%2FiTeSX5iYTXu1bF2u9aICk5G9F304oV3UpJzTbIsunexUNs%2BkrehXJfNvwJyOIsf2Go9syjWXx62rLPPcTTTLwjUVy0Yc8l9UNO%2B%2BaOuPR3N1wPVa9zVtwV5A3VHwlqj%2FLCV5BPTVfAykKmWeC0JJTGD15U%2F%2BReL6eqNj4q2pjmJCRlyp3siz%2Fno1enKiW6x83IR1TQBkbbVo3LtT3zIcPSRoG0Yc%2Bl8UOOfQVTtPN2IH8kjK498njBSFZZ%2BoGUqtr4sLEyeRhzL02r9zgfoH6SU6IC74IrqNQJsmfd55v8kSD%2F1Q8%2FILFlhDjYmR076afdkeGDJ%2B%2BIvUqCOLajYWiC7LkM8k3%2BSJD%2F6ocfkNgyQkJvpS%2F853B0Tla2UivpR0QnIzI6JdfC%2BKLEt6jUCbJn3eab%2FJEg%2F9UfPyCxZYQcOZfmb2oi9dv0d4RW0v9wUZ6fTFIhlXcoqNQJsmfd5pv8kSD%2F1R8%2FILFlpMTcTxvx26aQjKvBD15qut%2BsCkRYVHKuQYezzVspxXYqcYLsWXf5Jn8kyH%2F1yw9IbBkp%2Fsz2srJVPpPnnFW8LAPnBr0lb%2B9EgpMS4MKlawigEifInnWTb%2FJHgvxX%2F%2FyAxJYRc%2B6qYm9Kes64CR%2BdVv249jpKO2bOx8KHTDma36BVWM%2F%2B76GSYRaVNEH2rP18kz8S5L%2F66we0zpaRczEIq5u7KKXrtoet3LQ7Qt7awxE9O1VHw3q2qOVc8IKJaRk5CA5%2FhPOX4%2FHfyTvMqFPyn8ANWoIuEgne8mM9Fiplguz55eeb%2FJEg%2FzUcPyiTH9bydmEfmygV%2Fte1U2deTdATSvGL5TL20qJUifCxcAlOsn1P1nN48%2BI17Ce7IciedZzvMsw%2FQZAfFIysLG569z7m8s3ZCV%2BQWZW87LSSbjxCnatgCzPIemxzYuo%2FnBl6JjNSHv0s7KfVU9g5MVIVzqskuMqUUC2pBPHsiqHMoC%2BQ3RBkzzrJt97knyDIDwqGhhGJJ1EGdWh1gGcTuEuV8GF%2Fd2e9Cwn7Z1XIJdYqFR4yg%2Ba%2FoXCe9Rrm%2BtHkW4LsWdf5Jn8kyH%2FJDwiCIAiCIIyX%2FwMK5gDBa5fmHQAAAABJRU5ErkJggg%3D%3D)

```
encrypt_stmt
         ::= ENCRYPT '(' int_const_expr ')' '{' statement* '}'
```

referenced by:

* basic_stmt

**enable_stmt:**

![enable_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAZMAAAAlCAYAAACH%2BAS9AAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAADy9JREFUeNrtnQdYFEcbx%2F8IxIoNsXdjFMVesBesSFSwxS6CvUaMon6JikYTTIhdUCOxxd6wt1gSg71r7GJXEEXEDgffvHPseUu7sxxF39%2Fz7LPH7N7s7M47b5vZA2AYhmGYD8QsJS5axRYx%2FOjVHL%2Fw8fqCny%2FLDcsNy0VyX9MipW722D%2F%2B3OOxVK3rxs%2BXYblhUq1cGEM6fvSpA%2FIK2TNkWG6YtCoXbEwYhmEYNiYMwzAMGxOGYRiGjQnDMAzDsDFhGIZh2JgwDMMwbEwYhmEYNiYMwzAMQ8g34O3tkOfwOQQndpKh46bEY4w%2Fbt0JVZVltcoI%2F9mDceHSbfwwaTnsbAth%2FOhOuuO%2FzQpAWdvCaNaokq7s4uU7%2BP7HZXBqWgU9uzbSlT9%2F8Ro9%2Bk3X%2FZ0lcwZUqVgCbt0aI3Om9LLs29EL0LFtXdSo%2BpWqHXfvPcLQUQvitbmZQ0X0dm2apgTBc%2Bwi3L4XioW%2BQ%2FGFpfaHETzHLca1oAcJnt%2B0YQX06dksyTo79%2FLBmzca7ef29dCmZQ0sXr4XG7cdlX1AfaHQ0e1XzPHphxlzN%2BPcf7cSrK9uTVsM7d8yyWtS%2FS9evkY%2Ft%2BaqcqX%2FFby9umPU%2BMWISeS1rr49myIqKhoLluyOd%2By7Ic5SFkgu7tx9JMtyZM%2BM2va26NaxAczN1T7ahi2HsXTlfgwf1Ao1q5fWlZ84dU3WP9unb5pTHJ3cfTDaoy3Kly1q8NzV6%2F9FyxbVkCH9F6nuPkIehuPE6Wto3rjyZ2sEPlS%2FK9%2BXWiNSg3tVbLHWwhyDE6rU0HFTcvpckFA6VcUgLPXWAoqGEOERL3H9xgNcvHIHzk41ULF8MVl%2B6eo95LLOqqpnpRDoJ%2BHP4ffHdrh2cYCZmfanazRRGhw8chHzZwyUCuHxk%2BfSGN268xC%2FTHTVtuFskFCeFeO17eWrN%2FK7axaPVJXnyZ09TQkTKURSeNY5s2L33tNoEavku3Soh%2BfPX8nPv87YgOLF8kqDYOw9TvFylQbFXRjmJg0qyLIbt0IQ9iQCE71Xoqkos%2FxCa7gOHbssDE8kOrjUlsaYmDVvq%2BiTLLIdRC7rbAavSfVHPHsZr5za%2Fv2I9nBqPxG7A7xQuEAueAxqDcWaDPCYKx2ASrEyVKJYPmzZcUze%2F1jPDqq6viqRX%2B5Pnbku5c6%2Baknp8Mzw2yzlccL%2FOqvO%2F33xLrx6FYklK%2FarjMmTp89x8vT1NKmA2raqiTw2hmUgRjxfMrr169ghg03qMyaXr96F97R1n7UxeV%2F9Xt0WLhozzBAq1Fr8mUmOZDNtuqu9RgMXUen6uJUaOm5qSpUsoBqE%2BlhlyYhv2tTB5N%2FWYNXCEQmeo9FEY8PmQ1gwcxB6DpgpFVfNaqVU51St9CVy22iV1bWg%2Bzh09JLR7ash6lKMU1pk3aaDMoorViQP1m48qDMm%2Bl5nzpxWKFQwV6L9kBAFC1jD0tJcGnYrEU0qNKpfAYdFHyxZtQ9uXRurvlOmVCGVA5BH9Mm7XDMxKNrKnzen%2FFwgn7U0YvoykD69JWxLFYx3rWzZMiV5fUU2a1bXKs7Z87epjpNxuXr9vnA4PNG642Rp6Ehm0zqPHkfoZH7HXyflPV26chd7%2Fj6LIoVtMGKws3h2mbF6Q6A8x89%2Fu4z6mzeprOrjxNi26wR27T2FyMgo2It%2Bau9cC%2Bm%2FsETg4YtYtvpvPBNGvnGD8sLRqC%2FbES4cxUUiKm3qUAnzF%2B3Ew9BwGSU2iXUCI4TjOU%2BUUxuzZ82MerXLwKlZVawOCMSjRxHSgSTIoTDUP6%2BF0%2BO%2F5C%2FpSGbLmgmunRuhSqUSuCkc0LXifnv3aKqT9%2B27TyA6OkaOqY1bj8BGyPPRE1dw%2BOhl6fwO7uskI7bgkCcIEA5dO%2Bfacq%2BJjkav7k2SpS%2FfVb8rRkQTg4L6P9iiisdjtGkvqvSOqHQVhS%2FvctxUkABQxykbdYY%2Bbt0ayXTMP4H%2FJfj9vwPPI6tVJlSuWAKtWlTH2oDAeOccO3lV1k2dv2P3SQxwdzS6fWR49NtHCiQtQQakjfA027SqgT37z%2BCJiM5Mzejh7TDDd7NMM6ZmwsNfqPqWtsdhzxI89%2F6DMBQWBjfus6XI2s62MEqWyIetO49%2FEt4sGYcHIWE6Y%2BI2cCbuPXiMVo7VcPb8TUz8ZZU8ZpNLmyHIny8nColoUEkdJ4Xvgu2Y7LMGDvXKoZGIXreJZ3bjZogc3wM8%2FERZefTo3BAr1h3Az1PX6qK8KdPXY4zXElSqUBzVKpdE76FzZCpaRp7D%2FXDv%2FmP07OIglTgZK9k%2B4ehYCIeH2kabkvVIil6DZksHYVAfJzSoWw6uA6Yj6GYwihS0wX%2BXbmP4%2F%2FxjI9cgjJmwVOeUbdx2BH2GzMbr15FSD%2B3acxrjf1qhlZ3gMNn%2B9j28cVU4s2TgkhtD%2Bp2MSJUyuK0R%2FifIkMTBwkCl0lIZOm7qSGXzjmMIPPI2UqA5ExIWBbLswwa0lIJVp6ZtfM%2BblGVseob2nXr5YNLYrtLTUZj7xw7hRVsgWkQxlPbZtfe09Djj5r8TwmfWRtXflKYp7po3TSiFU2eD8PTpC9StWUbeq13ZIlLou3dqaNLr0pxDOXGt34W3aGgeJCUhbzNu%2FypzJoqCoLm7MGGAd%2Bw5iYW%2BQ1QpHpI9n0luOtlbIxwZiqQ%2FNWiO6tsB2n4kr5wUI9Ggjp3ct3Ksrov8k4Lmqab7bcKy%2BR7S%2BSOcneyld%2F%2BjMFADhQJ3%2BVo7lgvmzwXHtl4YLqIgJfpcu9RTFzFt2HIIZ4RhK5DfGucu3MIElzqxUWRpOYentO8v4UC1d6lt9Hghx3WR31CkS2eG6lVKSmeSnISBvVtg6mR3OLabgOm%2Bm7By3b%2BYOaW3jNAVhg9ylml24sti%2BWQaePLYbtroOIMl1i8djawi2klJ4ul3M2yLAibEjUSMMiYK0eLZCVXaPMbA8agoBImLmix2Hz6otQxJk6Jj23rCW9oRz%2FOjcHi7iDT6u%2BeRE4F0LzFCMCn6IO9AgeZMFGGnkLiJ8zghzMXRuoW9wfatXjTio6W5kvuXPtcGHESRwrml0iMorbRmY6DJjQkxyqMt2nWfgu4dG6ZaJVleGLwV%2Ft8ZGnxYLxTXyCEuqhTOERFBB4eE4%2FbdUCl7byI1UvGQt0wK7mOS0r8cnM78rfxT6icyUvNe9QSLaIfGX9yJfVLc14KCZQpJgSK9N5FRIiJ8rE3XiDGoPw4pG6HRaNtBBocW85CRo3FN6dUKdkXfuX1Xrt6TKalaTTxV5YVFVKIYUt%2Bp%2FdC8jZeIXFqgdg21c6uvJooXzSP1kzIvSU7xxzYkHyIXpN9Fc52iYtBO7KMNVWSRSA4tUHzxrtg3FhX%2BLvbDkjouHALvd4lMTCH4FhbpMHKoixQWEjJd7lUYF%2BucVnJA00bYigFPHqK%2BMdGHBILqCLoRkuyD8mP8Uxtjn2%2BUGPCUn61Vo7SI%2FC5q7z1LRuzad1pOZBcVRsaUlC1dGA3rlMPMeVvSrEdOHrdjk8qoZV8aPfpOw5fF88nP0lBvOAjb0gVV829FCgnDvemQzJWnVbkxJTSvQgbhScRz5MqpXkRjlSWDanEFKWKaD80svqMo5MTo2qG%2BXDRAKbitu47jG9dfcPLAVF0EaSx0rRLF8mLnhvFJOGiBKFemiBhbR9DfzRHZs2dO8Lyw8GfSgGQyIvVnSrmI2%2B%2F6%2Bl3s54qAyf9VJNxE4NArxgzhCaW4pMGPWwk52qICW7HdsTCH7YkL8DB0PKWWDcelpSMtP7TE%2FgPndWVrhMfdt2czTP3JXW9zw%2F7A8wh9%2FDReHZFvomQO%2BOCRSzL18ymz98BZaTj9pvZXPZ96NcvKXH9yMPJbFzmhSqvq0jI0mU%2BruHoN0ebTaZJ2046j8PbqoXq2Q%2Fp9LZ5tID4XyDCQt03PxBho0p4Ww8zRW8hw%2BPhlGQ041C%2BP5Wv%2BkakwYsmKfTK6iGt0ElTwQp4pDUZpKZoPff7iFV4LDUlteyDqNnburrZwFG7dfShXP%2BpSobdDcPrcDfk5YOth7DtwDuv%2BHCWjksEj58kUnUJ4xAu5JyNIizVo4YsxqfRk6atE9HvgGZyjvbk5Sgq7u1qcFyFOvpNUZEKVkCU6bCkqScBAGDpuMvoMnaP6O2eOLDh7cEaCgkupk669tR4HTYiSIM726aM6j1Yt2QmvmDyH9q1rybJKdYfp6qBUxbSf3eUKDYXeQknoQ97oqGFttblbW3fVMVpF8vP47ql%2BoK8JOAiX2LkkfajsVxHheQxs9UHpu3qOY8TAC8UYr6UIffQUPTo7xDuHoh%2Fnr%2B2lYvhYkHGiTYHmxmhwK33Y2HkcFvkOkRGqIWjSt0Bp9X%2Buo5RoC713ZN6mWutKpdm9zzT0c28uU4Y08R5PbsYtxpnzWuVDczJx6w9YPkYq1E%2BFvq7N4Np%2FOnKIcTtisAvaOddK8vzp3u7oO9QXleoMg7lFOmTMkF6mkskQ9xW6oHYzT2SzyiwNAr0XZQyLlu%2FBD5OWyWXdQTeCMXbkNzJiIGNSwa4Y7BuNgLlZOmxfNw758uZI0tj9MWcIho%2F2xwTvldJA0YT6VKEvaKHQ9xP%2FFG31RKaM6fHjD13QInb%2BZJgYS8Sfq%2FZj0bK98rUC0jPzpg9ILd1kUL%2FHlnnY28E7UgPPuJGKWWyY80JU4icqSTBdZej4%2B4TT%2FO9B36L%2FbzY%2FVrqCny%2FLTWqSG1oh%2BCYqCrlzZTP6OyGh4dJrt85hpSp%2FKByTV0IZ0%2BqrdyEs7BmeCQNEK8zivkBJkQ8ZAP0l7IZ4EByGdKJ9xt5Tr8GzZLaDJvspRfcuz8KUcvG%2B%2Bp1We5FRERfoJ66jfc9EhDPFkqrE0HHm84OWVib0driC15iOck7kY0LpA3qRMTFGi0hRP5pkUg%2FKvMHOPacwb%2BHORM%2BjF0SVyffElK2Nddb3agNFRrQlhPISrs%2BsAJniTjSa13tBOW%2BeHO%2FVDjJatKUW3le%2F60cqujSXoYrYkDBxoXQNbckJLeNUlpoyaZOmDhXlllqhlaOmglaQGbM8Orn5UP2ufN%2BCxZthGMb0KKv8PlX4V4MZhmEYNiYMwzAMGxOGYRiGjQnDMAzDsDFhGIZh2JgwDMMwbEwYhmEYNiYMwzAMQ6TYS4v6vx%2FD8PNlWG6YtI15Slz0fii8aMtvg%2FHcBfGfDT9fhuWGSS1yYSyc5mIYhmEYhmEYJuX5P5OJYJjsR7ccAAAAAElFTkSuQmCC)

```
enable_stmt
         ::= ENABLE AT_INT_LITERAL int_const_expr
```

referenced by:

* basic_stmt

**reset_stmt:**

![reset_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAHUAAAAlCAYAAAB8iqZLAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAABMtJREFUeNrtW3tMW1UY%2F3UtHd0G2%2BiKSik4Nx5laFQe3cBFjM9JMiFxZNmYS5aaoMhUNp0xc9E9ElEJOEYcc0GjMUZgPlhw0T%2B2ZMQhY7ANWWDrGIg8hcF0asbow%2B%2Fe0tJCy12BtjzOLzk5vfc733d6vt8533ncewGGWQeRNyqNUcM0Vxxc2%2Bh5H0u81dhzlcWzntDYtdu8Uu88FqzcH5U8HZkYqbMQjFRGKgMjlYGRysBIZWCkMlIZZjD4EyVNNO6qbkCPs0JCcnci%2B%2B1itLX38b%2BXLlmIhPhIbNn4GCQSc388Vl6Fr8sqx%2Bjt2ZWGB1bdi54%2FbyC34AdU117B4OAQQkMCyUYEMrXPQuIjRk7et6g5f3WM%2Fo6s53g9Zzicn4FlAf5T2tbJ%2Btmiz5M6ZEBnjBrHJGJkOTIqJHcnLja0IPmpWKwhIjhyC4oq0Nzajf27N%2FPyjs7rMBmN2Lk9xU4vNFiBodt6pG5%2BHwmaCBTlvwSZTIq6i9fw%2BVcnsSntUSjk%2FmjStWPF8ruRkhxvpx%2B%2BMgg7Xlk%2FXEc%2FXn3rKMq%2BeNMq9%2FdbMOVtnaif49VINYhwUG%2BAnC4X8KSKzGF4g8GAVDL63WijQnJ3IyJMSaRGUqL%2FIhLh40%2BO28nlAX68fDQaGtuoI%2FTiVMU%2BzJf6mMlWBRKBGhiNIyd3oSqFQ33LPV1zl921u%2BCqny1kGkwItj2ItDvQN5mvnRoVknsC3T0DCCESbHG9%2FyaqzjbZ3YuKUEEVJIfMV4q8wnKkpyUhWCk3O486hlg88vDk9z96x%2BjHx4RTGe8sOYT87IxMh6Q6M%2BpqpVON8hM1uKzrwMCNf%2FHTyfMoLsyyk3MjKfdQucM59dOCTOz7oIQP24sXL0TcQyuhfeFJrE2Ispat%2FOUSmlu67fS%2FPPIaZGKpVxc8Y%2Fwswgk9sNcZmeOSaoERuEB99RmTgFyvRwtVKnN3I7%2Bv%2BJXmuRREq0Ps7q%2BOC8eRg5kOdZIeieZT%2F8A%2FqL%2FUilOnf8MmbS5%2BLNuD%2B6NC%2BTLpG5PwsnadW%2F%2F7ZJ7UcH6muJKsN%2BF5yo1ChiROYvsZUuyg%2FAkyeJTy18eT%2B0iQ48pIdbWB69fFIfnpWCSuUWPLi3kIW3EPElerXXJMwNJFVoKrzl7GhfoWK6mewJ08LB%2FtF1s%2FU17k64PiW0PYRgNJaxLhL3AjVmifyhmhrJQMqCm1U1hV1zUiW0juqXlVQ%2FPcgXfSod1eiCtXOwXLn6awuv%2FDEn4etqCmTofWth48%2FOB903af6czPZ%2BrRwOViMcJMJpRSuZtUuH28kcoZ4XpENW3f1A6IEpJ7BBtSE6G71oWtGfk4XrKbv1fxcy2UkfZvGXzz2U5%2BQcWtgDWPv4FAxRJ%2BxWuk7U%2FO3q1YFTkSwg98VMonWzSdK4TfIpk3mijo5%2BF72bQvzaFt0K7RI1c0POz%2FIyOHub24IyNC8onML558neXW4G309v2NebTqVQbJPVav7essdxh%2BJ%2BRn7tCBI5cqyKB6zPtUGt7LxzMiJJ%2Fu8J0vhUq5bPof703Qz7Yj1zqnChmayYTOJEzWzxZ9dqA%2FC8FIZaQyMFIZGKkMjFQGRiojlYGRyjCd4LVPGb31md9cgNgblXb14T0uBSnw7lxxNNdeFn4ZGBhG8D8CEQbUUILllQAAAABJRU5ErkJggg%3D%3D)

```
reset_stmt
         ::= RESET
```

referenced by:

* basic_stmt

**ver_check_stmt:**

![ver_check_stmt](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAbcAAAAlCAYAAADBTqcXAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAE1pJREFUeNrtnQd8zPcbxz8ZRkKsiBG7VikxgiBW7dXUpmZqNwSRamoWpTWKWglilBqtWZQoNf6o1YGi9myMWEnElvD%2FPk9yP3eXO3eXJgTP2%2Bted377%2B%2F0%2B32d9n7sAgiAIgvCGYfcqbupZAs%2Bk699O%2FjyefDInciTjK7x9cmEtjq%2BqsX%2Fsmi8j%2FpZRoXpXkSMZXxlfkYuXgr10vfCyo3bxyGV8BZELMW6CIAiCIMZNEARBEOMmCIIgCGLcBEEQBEGMmyAIgiCIcRMEQRAEMW6CIAiCIMZNEARBeJPhXyjxKoWc%2B48iwtxBlvanFGO%2FWYF3CubCR62qG2w%2FevwSpsxch7nT%2ByB4bhi27zqa6Nzgyb2QJXMGtO82WduWO2cWNK5fAY3qlde2PXj4GNNnb8DmbYdw9%2B4DZM%2BeCZUrFENP3wbI4ZYZ%2FoPm4GpEFB%2FboE459OhSjz9fi4jEtyHr8du%2BE3jyJBYe7xVAn55NUKZUQe3arbtMQPp0aRE63Y%2FfiU2%2F%2FoXjJ8MR0MfHqj64e%2B8hQr%2FbjF%2B2HkT0nXsokD8HvL1KoHO7WnBxcUYb34mYPqEHcufKqp2zYs1v%2BPfyTQzs%2B6H2HM%2BMvj5ZsnhejB7anj%2FHqHbr7hET8wAFCuRAtcol0KltLWTK5MznT%2FmqG%2FLmcdX6LHDIAtSrXQbNm1aWWSS8cj7qNgmDB7ZU87CgxWNpfnzQuKI2J1MT129E46%2FDZ9Gwbvm3diz%2Fq73Rnc%2FG7UkcrniWwCpHB%2Fibuqil%2FSkFKfLQhZsTGbflq3fDNasL7OzscObcVeRURqhj25oGx2RWSjku7in2HjiBkMm94aaM1pFjFxEwZB7uKYPRqllVPo6M1x2l0MeN7IScObLg1Jkr%2BFFd%2F%2Bjxi6jt5oGhn7ZG30%2FnwKtiMbT%2BMP6cm7fvoGnbMahR9T2ETuuD9OnTYOPmP9Gq03gsmTsQlTyL8nF7D5xE8aLu%2BG7JNvTu2jDBKEbh1NkrVrX%2F%2FoNHaNFhnHquzPj6i05seE%2Brc2cv2Iz8%2BbKjaYOK3L4HDx8ZnBd%2B5ZbBPfb9fhKTxnZFvgTjRJDRIu7df4Tm6h55cmfD%2BFFd4OrqgpOnL6t7%2FIKCqv%2BbNKjA7aBnIWKVMPTwnwnXbC74sLGXaFUhVdDSp4rSA1ksHvdMeXkDBs9DzWqlkN4t9Rm3U2cuY%2Fy3q99q45ZUe1OpBJrH2WFabBxI0TmzcbOLT0%2B2jotDc3XRNcYXtbQ%2FpfhAKdYRY5bi2IlLeO%2Fd%2FPHKNfYp1m08gNnT%2FLTj8ri7okqldxOdTxEGUb5MYY466JgL%2F95Qkd4RNm4k6Fu2H8LKRUGoUK4IH5svT3bUqenB9yFy5cyqjFdaFQVmRJYsGXhbyNxNKFQgJyZ%2F9fw30%2Fy6N%2BIIaMw3y7Fu2VBte9CAlhg4dD46tK6pIi0nm9q%2FYPFWxD19igUz%2B8ExjYP2fLVreCA6%2Bp5N16KIsnjRPIm2z1u0BfbKSZg3wx%2BOjvYGfUBRnD5Pnz6Df1AonJzSctvt7e1emwlz%2BOgFLFu5E7cj7yKvkpf2rWugyDu5ed8G5Zis3bCfI%2FDG9TzRurm3dt7%2BP09hzfp93BelShbARy2ra3JgKToIU1F62rSOaNO8mhqz0rz9xKlwdrIqVyqOMHXfbMpJaJXgNJnj1x2HVZSRBucuRCh5PYx8ebNjkH8zZM2aMcGJOqGecT%2BiY%2B4rucyBjm1qaVH2cvUcFJGrIeb76CvNbTuPYNOWv5SD85Dlv02LasjgnO61VIi3bsews0tQe10yOrGTRm0skN%2BN%2Bytz5gxY8dMePmbW%2FE3ImCE9GtYrj5LF81m8fpjqJ9IVJCNeFYujtdIf6dKmwZ79J7B0xU7OsNSt5YEObWryc9D8XLhsO%2BrXLscO%2Bo2b0ejUrhbqvV82Plui5GmO2k7PmCVTBtTwLsmO5Iq1e3DrVgwmz1jLx%2FXwrc9teRGPHj%2FB%2FO%2B3shyQU%2B%2Fbvg48yxXGxfAbWKXa26NLfU33UOaI5nHj%2Bp6sR91UYPD7X6ex%2F%2FdTKOtRCP69mnBEG3E9iudEq2be%2FE56qHvnei9lLG21NzqjFvcMefV%2F4Mtgze1ZfJqSLhquLrqcwjtb9ic3JIwkMKvX7dO27dp7jJVrpfJFtW2XVaRCA6v%2FogE3xdVrt5E%2Fr1t8JyohLFo4D6fkTpy6bJivdTS%2FHLlj91G0%2BKBKou207eDhcwZGoVyZd%2BDlWQwhajLZCik1mkQ6w2bcNzoO%2Fn3eoO2UkjSl3PWPIYeB2EL3UMrcuL3UN7roTsfgUd9z24K%2F6QUHh9dnuZbkg9JWnsrJaaeMEymAnXuO8b7QhVsQHLqRU7CkFGiclq3cpSnJXv2CUbZ0ITRtWBHHT%2F6LvSoKtsSMORsxR8kUKbqmSmF9NuI7Vo5s3JQy%2B3LCcnzsNx1XIiJZKVtiy7ZD6NZ3Bi4qx8ynUUWcOBmOkeN%2B0FL0vfqHoHrVkiwrdurfAaWsiK8mrcSqdXuVUqqLtspwjfz6B2z939%2B8jxTy5yMXoWrldzlNv2vvPzh2%2FNJr6%2B2Tsbp2PVIbt659VP%2BquU79Rc7ElxOX8z7K4BDuubOxE2eNMQ%2BZt4n7khyUOrXKsFNy4eJ17NrzD%2FwGzlLbPNCl%2Ffv4YfVujJuyis%2BJunMPE6auwRA1Z0gHVFT6qkf%2FYJZFdoYDZ%2BHK1dv4uENtNio6%2BXBzzcTznZ6NXo6ODhafr3vfmZzB6tuzCWpVLw1fv6k4fzECBZSe%2B0fJbODQ%2BB%2BfPqT0xJDRi7XU7bqwA%2BjZbyYePXoCn8aVlJwdZhlhPalkk56%2FdZfxOHP%2BKhvcl40le0NGzbMk%2Fo0DVoMMmxGOFi7KltPS%2FpSM5Foqb3Pol4s5PUiRAnnRLXyqaF4a8fvBM4i4EW1wHq256TyeuYs2I5OLM3u%2B4ZdvcYpOE9zJvfn69ZqNYI%2BltPLO27TwZiVojps373AK05hcObOwV0RpS%2F0oLWhAC%2Fi0G4uPO9axqe0R16Phniub5QhvyVaD9YNwZdxowuizcOk25RQ8n8i6NbfrN6J4olti4rQ17PVt%2F3kM0qR1fK0U35lz15SX7chrpmSwdVEUjdXUWeuxYfkwFMiXg7cFxPhg8fL%2FcSr82%2BD1GKLkrk1CJEdGgM6xlPaatWATFgb3Z%2B85Pr38WBnNMG2tN4eSnbAVw23qx%2B5d6mFQv%2Bb8mVLHI8Yu0yJBSlfXfb8MnNKnVc5gmfjI4O4Djvz%2F2PGN5ghdCr%2FJ84ei8skz12LCaF%2BtL8h4W2rb6wQtAwzw%2B4A%2F01wkRU3UqlaK330aVeI1dUtQBodkZGnoQJQvGz%2BezZp4cV%2BNUQaT1tl168553bOjUctRCFRRIpE2jSNWLQ7SdNVPG%2Fbhb2VoKdNETsloFdFTNolelEnQPR85IPrZgxdx6Mh5nD1%2FDQtn9Wf9SEsitAxByyR9ejTmtfJGrUZjash6%2FLj6N16fz6u3PBHYtxl8lYElihTKjfbdJ%2BGrEZ34%2F%2BnSp8GaxYMTObmv0MjF2xs7hMUCo40jNauMm5aGUn2n%2FPOGzyzsj43FeXVTp5RoWJ0aHvhUeRYUbZBwkVcWtmqEwTEkbEMCW5lNS8YrmEfY8MsfnILMlpDOIYoWzo3l3w3itAIpCkozjBi7lMNwSiWagry9mLv3E23XRWwZMqQ32F6siDunP6aF%2FIzChXJZ3XZKm9yJuW%2FxuGnju3PhjQ4qtjl5xjASpTSiqbQk3%2BOO5XuQB9m6mTd6KE%2FvpyWDDSLHpPAyfyG8ildx9lbLVgvAeyXzo4aKckj53b%2F%2FCJGRd9HW9xuD44sWdud3Wt%2BkQiF9LKVio6Lu8TWLFXU3GH9yrHRQoZOtDoKD%2FfNImZy2ODXTiQa1y2Hp8p3wqNKfn5U8954f18eFS9c5e9GgxSiD61A6lGT96rVIeJSyrW2pdXxNYe%2FwvC0UqT95Epek60SoaJDmtXGhCvXV2fMRnPLT1yWPn8RydkiX%2FdB3wsnB1o0bGcCBQ%2Baz0S1f9h107VjXoBjNWk6fucIpxKr1ggy267JTZNhDpvRGQyUHfXs2hnflEkYZmuef3ymYk2WDahIIcpiT27D9F7kge6Met0nsM7RS7xZdMUczOc896sTL6r2uuuBc9R7wov3KQRlvS%2BRmSwMpRKeQebXyOG%2FcuoOiSlHoK3KrvN7O9dlbyZPbFd39Z2D9j8MMvBedkqd1B3pdCr%2FB6UVzxo3SDJSSMC6ooNQOpRJyZE%2FsEX6qPKQ6PsM5VWV1PynPn6o4O7atlWJKwLNMEV5LMC7aMSbAz4f73feTqZzyWbbgU%2FZMk0py%2FPFCa%2BWInpM8W1ICfx46y6lH%2BvzF5%2B1Y%2BWxYOZwLlIwhIxJlheHXx8k5LadsSSHqMgf82cjhSS5Iea1e8jmnoqnKbtqsn9mRozSko4MDdoV9lciQUlEQzavo6PvIni1TijzXyxzflIT0AslIVMy9RH3lkjE9R8g6yDBQERs5tzoDYY6OSg9QEQylTDdu%2BVM5WBNxcPcULfq3FroXOcybfxpp9phVa%2FdwRmrthgP4pGsjs2vGkdF32aA5p%2BC6qzVyYTzu%2BvZGvc9WAeX8h0%2FQVbl73Z%2FZIdpUSpIdEOOLqLcV6gIl1CtcOesl%2FjqOgZb2p3RxSSufqtiw%2BQ9eC6HPSYXSgo3qe6Jz729Z4dyKjEHvgBCO2HSQktiz74RWYGKKXl0b8DrgTxv2a9sozfD1pJXsHZmCjCmlOr%2F%2FYYfVz9vTtz6nGKbN%2FlkrcCHFResLuhz9f4W8%2FJ2%2FHcPM0I0G96D%2Fk2E1jN7sMXuqH6fZ%2BgfNtWkSvkqO%2FHOR11QplUwL6RTtUGEJGR%2FyZCdMWa21neSCCo44a1DLg9djYxO8%2FtNnr%2FK624sg5VDV6118%2F%2BMOLfVJac7aNT1SpG1UDHDx3%2BvsVJGzVb1KSdy%2BHYMC%2BdxQqGAOTA5ep40Tyftu5YCRYatZ9T3Mnv%2BLloqk9BYVILzp6NaSaY3KGihDQbogODRM20ZFRuQc0ZiSTtLJDs1tir6scRhoLZScLkoj%2BnVrxEU9j5TGpme7pq5NVczW4K1k7dLlGwa6iOSB1tiJtRv3c40AOUAk6%2F6fzTFIP0cnZIbIKM9UbaTUfWpZTzdnb%2Fb8jaP0rny3okq0V6jjYtTB4S%2BK3OgiZBn3K9kvYcJgWdqfYlCk5OaamYWK1siMIUVML332bZ2A7K6JhezLoe3RsecU9Og%2FE6FT%2B8Dezh5N24xhD42qIiOj7iqF34A9XzasnSdwFHfwyDlEKc%2BG1j0oRTF3Rh8MG70EX4xdxrlpSh9SdPOiKMu%2FdxP8sGqX1e2misyl8wIxdPRinlyUzqIChArli2DMsLI29WHtD4YbpqcqFMOqxZ9zxSDdY9iXS%2Fj7frp70KQjQ2AqJbtozgD4tB3DhREjgtqmeoVGxrpXvymsOGhdihQHfUdSl9L1%2FywUHt79kcXFGZF37qGXbwO8X700hg9qg76D5qBM9QHInNEZD6kqbYa%2FxfvRWhZFuJu3HcSDB0%2BQxz0bJo7ukiJtIyPd5ZNpyJ2Tvuf4jOV5frA%2FK%2FG50%2Fvy8y9WhtYlgxO3bXBAS1RTBnCCep7eAbNQ1nsAR5tUiLJsfiDeBmh8aXyo2nSQf3Pta0HmmDq%2BGxftlKsWAAfl4DmlT4cVCwehX%2B%2BmanswvBsEIbNLBjZQ34X0t%2BoZFi7bhuFjl6JYYXecvxCBEZ%2B15YiKZLRMqULwqjMIDmosN63%2BwuA7rKaM74LgfggcPB%2Bjx%2F%2FIBpMKRKaM68aVmDSvVywMgrNTOowZ3gGNE9bfdN%2BzXaIcr4VLt%2FMSDlWNzpnql1qGyaK9Sdg20KsUxiv%2FM8g4krNLCAPvq4vMUhcxmV60tD8p6YbU9OfjyZO5fDW%2Biil3jqwmqxPNQRVPtD5n63lJUWI0ebJldUmxcm3y7Gkdir7D5uyU%2FPfQ%2F3PzyZW2skWOqJiI1kpMFdDQWlnMvQf8NQH9dRJO16i%2Bp7UUU0VEL4Iq49IoZWNN4UJyyC8pNlPPSOP6UEXbVMhgDBU%2F0fmmUumv2%2FjaAo3349hYm9p9%2FWY0RzXGKWxaLnmojANFz7ZAcnVXzWmq4DT%2BQjlFhjQHbfn6EP2whL16PmvbREs0FOlT8QqlVJNDBpJDLpJqb6iakoycukFvdZ%2F477mpcK%2FQiy5iaf%2FrDik8WwVThzWVhqagFBeV1pujU7uaBmt6VASjXwiTEtCkNbX29KZgvM6qD3nN5tYisur1O6V4qNTfHJ8HtNBS2qaMiTFUwDR55jqz%2BwP7%2Bpj8Dqct8stjasb5T6k1t9SObqwp9U5f2zDHiKA2WjGJOeXv5pq0PiS5ympmTuuclEkz1vKPKJhj5aLPtM%2B5cmZN0nOQEU0JZzapJNXe6EdyWlrS0oXeZMP2qqDKKn3BFF4PqFRbV06eHND6HL2EV0P92mX5lVoJTPgJvZSAKjRTOquQFP6rvdGd7yjiLQiC8PbxpjtV8lcBBEEQBDFugiAIgiDGTRAEQRDEuAmCIAiCGDdBEARBEOMmCIIgiHETBEEQBDFugiAIgvAqeWVf4tb%2FvTFBEDkSZHyF5MThVdz06k2Mope7G0bKELyd0PiLHMn4yviKXKQUkpYUBEEQBEEQBEFI7fwfdbpPk2oXnaIAAAAASUVORK5CYII%3D)

```
ver_check_stmt
         ::= VERSION_CHECK sec_or_nsec int_const_expr
```

**sec_or_nsec:**

![sec_or_nsec](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAJkAAABRCAYAAADB5wRjAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAACcJJREFUeNrtnQtUFNcZx%2F%2FLy0UEREAUUUxFA0I0SMLDE9sEayrGaDVarU1jItqoqEdprdZ4lCbGxEeJEnxVpYkatUHUKNXa1FalBqwPRBEUESSCj4AKqAVhYXvvhV13XZYFhB129%2FudM2d2d2bu7Hz3v993753Z%2BwEE0cbIzOEigvygNLXvfDbbPGzfFGzM5ULOpCSYzHd9acgUi%2FJkVuTMpfO%2BpuiBSWQEiYwgkREEiYwgkREEiYwgkREkMoJoGWLEPyQAHqcycUffToa2mxL37j9E7LpvcDItGxUVVfDydEVo8POYERkBh44dsG7zIfw7JVPnuPWx76Orm7N4fegfZ7FrzwlcvXYLrq6OCPDthXcmvQZ%2FtjYnnrXeVccLkVXX4GaQH5JsrDG7oUINbTcVlEolJry7Cn37eOLzVb%2BBk2NHZFzMx46vj2P0iHvs8%2B7IzbsFD3dnvD3hJ1rHOjt1FOs%2FxX%2BDnYknsHTBBAQO%2FBFKyx5hf%2FIprFl%2FEJvjosxKZC2t92A%2FjKmRIU5RA1f2tqMQmawubI6vqcEYVui%2Bpws1tN1UKLx5F1lXbuCrrdFqr9TLyw1vRrwMhaJWvV8P5t3Cgn11jv%2B%2BsARxm5KR%2FNfFeKG%2Ft%2FisZw838bqMic3caG69q8RVo4SX5g0zrRvkyrr3egs1tL2949G1M1xcOiFuYzKmTR4G755dnxjC5knztIiJMfW%2Fl7WOHfRiHxxLuQi%2Fvl5qgWl5OmcHs21TGap3feJqUGT6Cm3uSdsrdrY2SIifjaXLd%2BEvO47C0dEeg1jIe%2B9XQzHstRfV%2B51Oz8Wd4jKdNtntH0rh2b2LxTbgdepdhsMK4EN94mpUZCpYADnPft%2FDlQa2KxTIZye1NwVDBQf1xeGkJSgtfYTM7AKkpGYhclY8dm6Jxith%2FcU%2BP38jBIt%2BO07n2E4O8lYPi6b4JAavdxZK31AoMY6taw1dgI2eWPwdO7CIrX%2FKCtzC1vMa284cxAqVJxsPWF%2FvB%2B8aK%2FRnO4azfX7J9s20USKKRaCctrjollRU584OQlR8OZeRh3MX8tQi03uewD5YHbcfxXfL4e7q1CrfXaqHF1mTs59ChnXs5AHMeLuYBf9lXYus3jkoSARqGrKrZr2z9Sa5LRIqqzGFOZqpShnKwD2aIZGpClHWFXLK1hp%2BXDzsZPMa265ZhviCOchjL%2FmS7OODPzjbYj6L2WmB%2FTE%2BPQtHpfoFnmc9ya%2F3ncSMyOGiwc65dPl7ttxAdNQow13yoH6ibTZj7gYWPqejq3td5%2BHEyUs49p9MLGE9TlOA1cNQFuISWX3GllVjZG4uHqubCo04HT31Hh0SgBWsJ7pAn9g0RZbYmHiasL1B6i9g2SBfEVoT2S8otK08miG6sYZ%2FYVEJhkQsgquLI6ytrVBR8RiLot%2FS6k3ysTK%2BaJJ2dKUQZkL8LCxe9hVCh%2F5eiOzBowq4OHfC3JlvmoTAuAfjAlMq8c65y0huwiEG673%2BM71iU4msghVS2Ih4DG03CL8g5hFjmUeLZ29fl0RkHi7YtmkuqqsUuF1cqh6C0OSzTyLFog8np46IWzkNKz%2BajOKScsjldq0WOo1Bvf1jmyiwZtX702JjHnC6WmSsd%2FhcY4UY2t5UHCuw%2BoE9ogL9MTD9EjKkMrStnY2OuJqLvIPdM5dh9DDJ7M5a7S%2BwehjVlP1bWu%2BaYuPvrTQ%2BNHTQM3PsOipZgN9pVYu3QBgdYXdmf1EPTRdLi1Edb%2Fwb5KwXw1xwGFW5JONcYdz%2BRhe30dsESlxisbofVbnx4Xbn9jd7kdk%2FFC7UnapcEtzr7W%2FeIkstFO0BOdW3JMjr7W%2FeIqtrGljOX%2FTbX8Q0%2Fm0sejKWIJERJDKCIJER0mM2U0dZ2nRM5MmMDH8my5ImlSOREYS5hkuVR6MqJU9GkMgIgkRGkMgIgkRGkMgIEhlBkMiI9ohZDMaac2YPcxhgptxK7RhzuelP4dIEvLSpe2oSGUEiI0hkBNFuRUZ%2FizM%2BkvwdTkqRVYZ50R98jUm9vSstSWTFFZ3gQVVvPOrtXWwxImM%2BO8daBn%2BqeuPB7c3tbjEiY42DVD5pMVW9UY0eLuwuAZKM%2BNdaIcmqFn9%2FtTc%2BaOqEbK1F9KIEkVlk7aeRIvMIh09OvHXbPxG7vG6EveReOWLjD%2BC7U9morKxGTy83hL78PKKmRYgZFtduOIiU1GydsjevnSmSUXAOHj6N3UkpuJZ%2FG25uTgjw64V3J4XDt5%2BX0e3N7Cx%2FoMQkZvfhFiMyPpVnkB8uPrDH79jbZcY8d0Zmvliv%2Fny%2Fem7Y8vL%2FqT%2BvqanFLyavgr9vTzHDtYODHOcv5GH77uMYNzpMZDHhibt6eHbBxLGvaJXN5%2FnnfPpZEpIOpCJm4UQMCOiN%2B6UPsfdgGuI2%2Fk0knTA29Xa%2BKNUUqpLdu7RWYhafdp3Pit3ESXJbjdnvj8TCpdswc%2BoIkbRLk4IbP%2BDK1SLs3b5QzPXP8fZyx%2BgRIVr5l7z05F%2FKL7iDDVsP48jeGLXX4nPLDvDvLUn%2BJWbfkdyBM3uHSlXXkg3G8mnWa2UYL5NhG%2FNqi3180MFY5%2BbJu3iqmxVrknS2de%2FWRcxwvWbDARQUanfGNPMvFdbnX9Jc%2BKzaR49fYN7ruQbDojHzL3F7crty%2B3I7SzWtvaSeTITNLBzl8%2FrzzBjOtoga5NdwZoy2YObUCIS9voCFwnytz%2B3ldmKu%2FphPdmPzl98KwQUN7IMpvx6K8B8PUO%2BXdvoKim7e02mT3eH5l7oZP%2F9SI5lgQs9mSycwyUWm8mhsNYxP%2F22lxFj2ek6tNfrm%2BcE7qA3vCvDkXVEsXC6P3YN5TyV64GHwyL4YkX%2FpYlYBjp%2FMxOTpa7Fn%2BwKRlYQzbvRgzJ8zRqdckX%2BpvPXDoqEnMfLqRvMLmMGuMqulMu81XMpp7NuVyDQ7A7xd3hYVoI%2F33g7Hlm3fMhE1PFcvb5MNGdxfLGfSryE9I08tMn28FOiD%2BD8fwv37D9U9zdbAlB9etOgb5Hw4Yl7UKDF8oeJMei6WfLxT5Lx80iO9jss5hUJAhhgc4gt%2Fv16YHr1RDIWo4LmXPl6daJF2toGFM3HsEGxKOPKk4e%2FhInqIg3%2B2UKSzkbGWc9VjBZYunKglMp4Omi%2BanDsRKxK3frF%2BDj74aAeCX52vzr%2FEczlFzxptkTY2iycheLhs7cevq6oVohGvGoJoCRWVVSi5Ww57ezu4dWl%2B%2FiXNx69NOVxavCfTB8%2Fy%2B6y5k3hP1dTyL1GbjCCREQSJjCCRESQygiCRESQygkRGECQygkRGEA1DuZWINsfaHC7iVgn%2ByBdPd8SYa0Xx66NwSRAEIRX%2FB%2FX8000nZItoAAAAAElFTkSuQmCC)

```
sec_or_nsec
         ::= SEC
           | NSEC
```

referenced by:

* ver_check_stmt

**const_expr:**

![const_expr](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAN8AAABRCAYAAABSQ3OEAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAD8dJREFUeNrtnQlcjekex3%2BnvbQgWbIlotJoEilriLFmG2OyzaA7IWU0YwzXdYeJuRlm7sS4lgnX1hgiM5nBMC5mlC0iUpIiYZKlRes53ed5qlMpOjXpdI7%2F9%2FN5e5fnfZ93%2B%2F%2Be%2F%2F%2F%2FvG%2FvAQiCUAoSdTgJRxsU0q18vbgQo%2Fq2q6UuN%2BP8qc1kka8J3fpMV4vz0KBbSahqtKPqEQ%2BJjyBIfARB4iMIgsRHECQ%2BgiBIfARB4iMIgsRHEKqHeMOlhx2anYnGgxetVFW5KvHocSa%2B%2BvYA%2FoiIQXZ2HlqZm8LZqRNmzRiKZQG7cfPW%2FUq3G9zfHn172WGx%2F075svbtmuOd0b3g6NBezF%2B9fhv%2FXPG9vHyV%2F%2FuwaNMUHy4MQvLdNAQGeMK8RWNRduVaErbu%2FA2rl0%2BTrx974y42bDmMyKibkEoL0aZVE%2FTsYY2Jb%2FdFo0aGVZ7btNmBWPDhWFh3bFVu%2BX%2BCDuHYictiunVLU4we7ow1Gw%2B%2BsJ7vgz7C3z%2FfgZuJ5W%2B5vp4Otm%2F8EDdu3sPCpdtLr4NFM7w9uie6d7WqUBc%2F90ePMrBlnS80NUvb%2Bq%2FWHmDnZya2UzX%2Bqh5Kthfiy5cixdEGIVqa8Kms0qrKVYXCwkJMeP9LWLU3x5ovP4CxkQGirtzCjh9OYNSwR5j0Tl9kZeUUCScwFJZMXGNHOov5Zk0bIo0ZUTQTzZZ1PsjLkyLifCzGvReAsN2LYWfTBh0sW2DhvHFw91iO42H%2BaNm8SGh8HxoaEqxmBlcitvT0Z4iKTpQf2%2FFTVzBr3nr4eA2H99%2BGQVtbC5cuJ2Bb8HEYGepjqkf%2FKs%2Fv3MV4pGdkV1j%2B7tjerNHJEI3Dp%2Bz4NJgIPprjXtxg3GGN0Y8IWuMtX19TSwOXrybBtY8d%2Bva0LV2uqSnGmZnZ4py2bZiLfGYcZy7EYTy7rgd2LYK9nYV8%2FfiEe%2Fj1%2BCUY6OviVPg1uPa2K21o4lPYNVHNwKumenCywRipBIEFUpiyWQMhPklR%2BDleKsUYVun%2B5yutqlxVSE5Jw7XYO9gZ5IemTUzEMu5dRg7tjoICGbS0So2hcWMjtGZlLk7W8mVcfNwwS5b1690Zf5yJwanT14T4dHW00aJ5I1HWknlUbZ3SV2d9Z47AgiXbmIcdIkRalgJ2Nz9evBWLP3kHk9%2FpJ1%2FOj819mJPw1n8F7jVNjBswz6UrGhGOmamxvFyH3dCy51kCb6QqW14kxNLr0LdXZ4SficXJP66WE1%2FIgXCMGNwNJiYN2PTpcuJTZaqrhxLRsWCmVdkX4so1PYVFYSivNJlV%2BgN3j9Upr%2B9ww%2BOGGLg%2BDEl3%2Fiwff2tVvxXmonmYmo42rc2qXJeL%2Fb2J%2FbHy3%2FsqlF28koAnT7IwgYWwldFYgZDzVXDjZgrCz16XD2cv3Kj8OrCGKzWNX4cm5aKMfWHhGDvKRUQPh45eRNazXLXK2arSAxedoy3uSIF94MKrLOd7SaVC2VWVq4on1GGh3Oa1PiwvC8aWHcdgZKSPrvaWmDZpIAb1f1OhOnKy80W%2Bwok4Hwcb69Z4a4CDQtt6ew6Dy%2BAFuMRCtrI8%2BPMJmpoZyz1lfl4BQg%2BekZc7sGN83lvWBb%2F8egHnIuMr5Hyc3NzS63A28gYsWd43fFA3%2BboR52KZh5DAieWBEokEbVnu%2B%2FPh8xg%2FppfadZxU0IMEvxQAy573dAqJrwQZcIn5gyGFVZQXFOAW26m%2BKlwoJ0cr%2FBKyRHia6JgkkYvMmLMWu77zQ28XW4XruXP3IWJYCHvsp88V9prGxgaYPWMo%2FvV1CHw%2BGC5fbshyusdPs4S34IZaIJPhNPM0nBMslJvLQlZliM935kh5zvsi7t57JDqPjh1YBi1tTfnyvSzk5GH73tDTYt6cheN7fwyvdfHVp%2F9s4HpgIenwgkK8zcayqg5M6wUx7Wm24V02dmMVfsfG815WzhxKQInnG8%2FSgcSOaCvVgC1bcQBbx4OtG61VCG9mT3Gv4qRrcgMaNmwgxMaHyKgERF5OUEh8evra8JszSkz7LdqM92d%2Bg5AdnwqvoAjTp7ghaPtRIXq5Z3ujHXJz8kXuyPMnXtfXX8wQZR4zVtfLRkxXt%2FQ6aLH87z12HfbtXIgGBrrIyc3DwSPn4dbPXt6I8Bx6%2F0%2FhuHf%2FsTwvrg1q%2B59qWRrbsUCCb1mldsyogpll%2FaYpwzWLOCTtAaSV2VtZPbDxBj1tbGa3czprkj0LJXhaWchZIefjlbDRHlaBDRuSWThpExkDv6rKy4ac%2FADPxSEh8jrCeNnTfFiw7U6whDPCwRYDlWkwPNxbtGyH8Fol8B5A3uPX3aFDtesL%2BGyq6Mnz%2FmgDZDLF9M%2BFNW%2B2O4K2HZUv4x0SXtPfwjwm5vMXS8M8bsSZxb2v9Znl%2F5gszmHWvP9AKpXhyLFLaG3eBGtXfSAaET78mw3du3bE%2FrCIense3D65nXJ75XbL7ZfbMbfnEuEpopfTlxHNx5qasGLBzB62XgZbOfllno9XwpV7hkUPNpXkcFWVV0p8PHiW7d%2FVWoSoe1jL4vyqPGBVNG%2FaEMlMeH2GLoJpIyPRY5ednYtFfuNe2Kv3MniOtinQGyMm%2BGPZyt1wH9IdXswAOQNGLsb2DfPQsYN5he08xvXB%2Bs2Hyi37ZO5Y0SPpyUJgHnpyz%2FKEhaIuTp1EqKwoYyZ9UW5%2Byruu4lHFzj0nkcfytImeq1mI%2FZFCdfnM3ygGeXjcQA%2BxF9ZVDJ%2BYQWz6Zja7Dsvxzy%2BCcftOKkaP6FFhPb5sy46jmO05VMx%2FGbhfDCVYWjTHqUMrlJOOMI%2FHcrQ9TCxTueAU2KRKPRQv8%2Bthh4B8KRY87wklxW70GatkPaskoLJKqiqvRni4mPdMs1BhcG2HndX5jATv0Lif%2BkRMt27ZpN61wCksj5KyvK%2BpmYl4fEGUp%2BxnJGor7GQ2dISNTrL6%2FBVYt0Z64L2hXITsgGey%2FRQ952Pust3LKqmqXFGMsrEqQx%2FeDp1hf%2FEqopR187jHqo%2BiK6HkLZiyfMY8SnTMncqvq6GeeIOEqGG4yewRMrzB7NNdkfVrqoeynlAedlZVUW09RvhfInIcbbFLQ4ZxbDaKbrvifLbQgy7CK0LYowS7uH1WQ0Q1pmT7un%2B%2FpxC%2FMZftQrecqC8Ie2R2Weeir%2BsdsqT2Kot5O9ItJ%2BoL3B65Xaq9%2BPQzhcs1o1tO1CPMiu1SvcUXniziaj2630Q9Qq%2FYLtVbfEUhtnp8pp5Qp8iz7l9To%2F9kJwglQeIjCBIfQZD4CIKoA9TmJ8LU5WejCPJ8KgV%2FuVYdfiyRIPERBEFhZ%2FU9IN1SgjwfQRAkPoIg8REEQeIjCBIfQZD4CIIg8REEiY8giFeFWjxkr0%2Ff61cX6IUFEp%2FCVOejucTLoZfUKewklBxNUERB4iMIEh9BECQ%2BgiDx1RD6fCBRX1DKZwOVKb4cl1b04VxC%2BRTbYc7rJL7UbEM0o1tPKJtiO0x9bcTHfHycpgSd6dYTyobbIbfH10Z8LMgOZ38GKGPf%2FFdf%2BS%2FT1jb3HzxGXn4BWbPqZXwDhD2%2BLuKTaSCEub%2BJrhZ1n%2FcNHbcMcQkptV7vuCkBiIxKIGNWIYT9MTsU9vi6iK%2F4J6GvZOjjYzIBQlkU298VZf1EudLe7dQsxBypBBFdrXEp8jrC6nLf9%2B4%2Fxu6Q33Er6QGGDOqKSeP7yct%2BD7%2BG4L2n8Cw7F2797THx7b6QSIqeitxOfohNW48g%2FtY9OHSxxKzpQ2BkpF%2Ft%2Fefk5iFo21FEnItD40aGmDZpIN7s0g6Jt%2F%2FE%2Fp8i4PneIBgZFtX785EL0NCQYIhbV4QePIPmzRrhzLlYnL1wAw72lvDxGg5dHW1xTmGHz2OsuzMOsPU40ye7kcJeALO7EWzkx%2BzQWVnHoLSH7GevI04mwXhm19scbbC4Qwfo1tW%2BP1%2F5A1qZm8LN1R4BX%2B3D%2FrAIsfy3k1fgM38TBg98E1Pe7Y%2Bdu09g1ZpQUZb2OAOjPJbDzMwYvszgeY7n4bkaMln1HxFN916DpNupQjh9etpistfXSEpORdvWZoiKTsQnS%2F4r1jt%2FMR7%2FWL4LXTpbiPnQsDPw8l2H%2FAIpRg7tjkNHL4pzKcllv%2FxmH8ZPXYmExAd4mJZBCqsEbmfc3rjdcfvjdqisY1HqfzVcvIZjTtZwLpDgWxNteHe1QTD%2FbWxNGa5ZxCFpDyB9Fftd95UXOlu3KQo9MnOwN%2FQ0xoxwxsathzF31kiMGtZDlLVo1pAJbgXmzXIX63AR%2BHqNEGU9unWC04CPmfeKRc8e1grv%2B8LFm0i%2Bm4adm%2FyER3VytMLvETE49GskvKa9hcAATwwZuxRrNhxE8J6TWLvqA5i3aCzffv7c0Zg8wVVMt7Nohmmz18B%2F8SQxr6ergwO7FtXIG6sr41mQldgRbaUasC3uXPFgzWW0FvN4F2KUJzyli6%2FEA7LRIIfOsNcoxFg27SvThFWCDdo61sFbMO3bNWeer6izi3uMTlbm8rKOHVoi61kuHqQ%2BKS5rWRoysFDQqr05W36%2FWuKLu5mCuymP4OK2oNzyTh2K6jY2NsC3q70wYoK%2FaAhcuncqX4Gk9JJYWjTH06dZIkTm6Bvo1LrwVP0%2FGxKK3l5JYlftBrOmcObthigrx6t34nuuEyaqrg0kMzMbDY0biGkjQz2kZ2SXJuRsmnsnwwZ6YkjPeFZuWz5vaFg9Y%2Bf1cIH%2FvHfJC9fZ%2B%2BNpvGHbFqEs%2F5vJvCEXZGU8epQBA31d6OvpvLL7Qv9Uq4Y5nzLJyc6Xd3zs2nsSbw10EPMD%2BnYRnS1SqUzMb9t9HF3ftISJSQMM7NcFh1mOlZqWLsouXbmFG%2FEp6OVsU6198%2FW5Fw07dE6%2BjHe0XL6aKKZDfgwXoWxo8EJ072YF3wXfobCwtG1JTy9qAAoKZFgX9AuGDXaUdwgRqoXW63jSPvM3ivDt8dNMuPa2k%2FcKfjjbHV5z16HX4E9Fb2NObj7%2Bu95XlPHQcvK7rnAd%2FndYWbJw89Z9rPKfBjNT42rtm%2FduBq2dg48Xb8GSFcHQ0dZCbl4%2By%2FX%2BhpjYO1j6xfcI2fGpyN9WLJmCoeOWYu3Gn0XnjGgQgo8jaPtRZOfkwc6mDTZ8PYusWEVRiyaTh53V%2FYzE3ZQ0aOtooWkTkwplfz58irzcArRqaVqhjIeiT9Kz0NTMRHTx%2FxX44wEtbU2FBfz%2BrEDx%2BIN3DmU9y6n02GuDsp%2BRoLCTPF%2Bt09Lc9IVlLzNq3qHxsk6Nld%2FsF8%2FgKo3xNST4Yet8%2BXyL5o1qdOwNDHTFQJD4iDJ8MnfMK6vbc6pbuccOBImPqCN6u9jSRVAj6DMSBEHiIwgSH0EQJD6CIPERBEHiIwgSH0EQJD6CUD3U5iE7%2FawVoWpoqsNJ3HuIpXwwN8NndEtr%2F9rSVaCwkyAIgiD%2BOv8HL63kC7zL%2BWcAAAAASUVORK5CYII%3D)

```
const_expr
         ::= STRING_LITERAL
           | bool_expr
```

referenced by:

* option_def
* option_list

**int_const_expr:**

![int_const_expr](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAGsAAAAlCAYAAABF7RcQAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAABIlJREFUeNrtWwtMU1cY%2FgotLY8OnQGSSQS3IFYIWQa6acT5xEXmMkUSJW5Mpoz5IhINPmJU8AFGHJuGRbMwnTMxoiAqbuJjRl1ZY51IcIL4ihaYgkaQWGx76c692Kat0Aul7V3N%2BZKbc8%2F9z%2F%2Bfnv87%2F3%2FOPTcFKDwGIiE6jVXA6OmOu3rT%2Fb4TCzVY9aVijyUqLj5NkH69aHJxPDu4O0NQsjwIlCxKFgUli5JFQcmioGRRsig8h6wPoxFirxGfnMI%2BBuo%2Fkz5Hlp5BE3kbP9ybUT45hX046r8xCsyKHYWHBgb32Dp3NijqJi2ZYYhQgTKxN5apavHIpMQndyV0egOKD5yFUlWHt%2BR%2BSE2ZhNEfREDT%2BASHyy7j6y%2BmIjDQn2tbeb4aetI%2BcXocKk6r8fbgAKiv3cFfV%2BoREx2O5Rmfwlfmg8etbSg9XoW5s%2BNxrEIFnU6P9AXTXTaG%2FvqPJYkR4QfGiFDLAy2rNcvYTR5rVNPTTOCTuwLfZBahrqERS9MTMWViDNKW7ELDnWaEDh2C%2BttNWLG2%2B0C45sZ9ZG%2FYj%2BioMK5%2B4vcrWER0X2hf4rMZY3DhUi3Wbz7IyVoIWdsLy5D0ZR6x0YjWp8%2FdEmF8%2FjNFEgOUgiXKBmIeo9xM4JO7KtJu1D3AP%2FUPUXVmO7y82C8SEVCpb%2BFUpRqZ385EwZYFSEzOxc7d5Sg7qULhtoUICw0y62dmzMSi1Gnc%2FcgRoUian4f8Talc3UcqRumB1eaodCde858IvxmAHNtI6hNZJnQB1ST0PjHyyA0G3COd%2Bjp7UPUNTWhpace4adlWz%2BcmxXNlgL8MP36XgYTPNyL9qwR8PD7KOv1YfHF6NzwE2k4d2tpfcHWpROIUogZy8s76j%2FzERIMRc0jZxWdI3EuOVRLFRlJOJQZ%2FIuUKe3KJGPn9iay%2BDlAeIEN4WDDOn8jttc3R8ipEK4ZxaY9Nlew61ROePuuAxEcMOSG42YkTqi8fIW3Ha%2Bk%2FUu6RSVDcqUcamfgLjSK09ZQCX1uzWCOkKCEGFOTSkPSm%2BPsmsvjkrtpsfBQXiX8fP8ORcqX52QNNK65dv8vdV1RexZk%2FqnH019WYPCEGS1buQZfF%2FGx%2FFUUM04WivaeQMOl9jjCh0Jv%2FlDWoZUtvb0QYjSgh7Z6Txhp7kcUaYZlWSYiRHgjgkzsdcrkvfi5ahqw1xdiyowQyqQRarQ4FW9Nw%2B24z1mz4BYf2rYS%2FnxQ56%2BZhxpxcFOw%2BhlXLZ3H6h0ov42DJRXS%2B1CHyvaHYu2uxkDt4Xv%2B9epZFNh75ZLufbRtpJrK0LNN2SOCTu%2B6FMnYE%2FqzMwyMSYSKyCAUHBZplNVXfm%2B%2BlPhKcO55jpcuuYynJE9DR0WmlFzVyGK4rC905jH75z5Y0EmkZZrJIOA63Z4RP7g6EBA9ySM%2FPV8pdQsJR%2F1mSZiaLz5DQRDmC1JTJGDJY%2Fr%2F4LQP1n0lfjDcUY0dHvpkHuRSULApKFiWLgpJFQcmiZFFQsiicBsFeioX624wnw1uITptbsYm93gnCRk93IDsOmgYpKDwZ%2FwGTVeBry0x1AQAAAABJRU5ErkJggg%3D%3D)

```
int_const_expr
         ::= expr
```

referenced by:

* address_or_range
* bool_expr
* call_arg
* call_target
* enable_stmt
* encrypt_stmt
* jump_sp_stmt
* keyblob_block
* keywrap_stmt
* load_data
* load_ifr_stmt
* load_opt
* mem_opt
* mode_stmt
* section_block
* source_value
* ver_check_stmt

**bool_expr:**

![bool_expr](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAasAAAI1CAYAAABoldXDAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAIABJREFUeNrs3Ql8FOXBP%2FDf7G42J0cOSATkCgQSDiEJGJQCRYHwloIQ%2BAuUQrUoWPGoVSu%2BvCq%2BVgtBW0FatKiItYZLeTWiFkFpU464ATEhkIMckGAIJCEHOXd3%2Fs8zCRg0kIO9Qn7fz2cys9ndZ2afOX77zMzOAERERC5OYRX8WEQoVNaCbSUdb1%2FLmmq63237gYOPpKaXLEw7WTqwuLTW%2FVxxdYs%2Fg7%2Bvu9nb0%2B1CgJ%2F7vsxTVS99eagyiUsB1z%2Buf21n4Gxsmunfb7ESbCTyJ%2Fe2q%2BndvSnigUdf3Rmbnl3mPW3izbhraW8EdfdCd3%2BPFpdRWFRtKCisDEgwFcbk5p%2BaMX2Clyn%2FfOWCpBSc5BLB9Y%2FrH8OKXPzbsit%2Fw1PV53Rb1%2B7YsnpDyuwFs4KxevkoGN10bSpLBpvshof6YfHcEENcfHbUxrj0lMhh6ixTsuVTLhHE9a91dJyNRPVkUL21JWP2yytGYeHM4DYH1Q%2FJcmR565%2BP8vAyKh9HhuFe1jYRw4qo1eSuP9HymR37dCSGDfK1yzhkua%2BtjNIbDLqNIxlYRAwrotaQJ1PE7zkdu0C0fuwVVI0Da%2F6M%2FooByuuihTWVtU%2FEsCJqEXnWX2Zuuffcaf0cMr4l8wbBaNQZrCq2RAxFMOcAEcOKqFmpGSWLosf3tNkxqubI8Yy%2BpZs80m2ABWs4B4gYVkTNSssqCx4bGejQcU4e10P2PEU3duQQ3MK5QMSwIrqmouIaj55BXg4dZ9iArvUDCgp1VsRwLhAxrOzqzHfFqKs127zcgrMlqK0zs4IdoLisRvHv4u7QcfYKvByOPqKbxLnA9Y9aEFa3DsU194E093xHNjXmeaRnnbF5uTG%2FXIXDR7NYwQ5gtajQ6R37W8lL41NV%2BIleb84Frn83quvNj0vv18KqzoIzEaHYerVCm3ueqKM7kVWOp1Ynw2xp3WXtlPqWFdcrumG1NT9Gh2JmRBhOmy3Ilo8NDSuMDK05Fot4MhQfGvR46FAKzjZaoa75fEf3XUEJtuxIQHbuWURPCscv5oy%2F%2FFzCgVS8v%2F3fqKyqwZ0%2FvQXzZ4%2BDotR%2Fqz6Vdx5%2F2%2FRPZGZ%2Fh5HD%2B%2BOBe6PRqZNnq8dfXVOLNzd%2FgYNfp8PP1wf3%2FOIOjBjeDzmnCvHhxwexeNEkdPKpL3fXP5Og0ymIvjMcOz85hKBAXxz6Og2JSRkYeUt%2FPLTkZ3A3ummfKf5zE2ZNj8L%2FiddJ9y64kzO78UpotuLTrwrw5rYc7D9cBINoLf3vY0PQhutD61mbXP9u1PWvtfkhQ8qiYK343ter8SWNrzhmpdaHlyw0r6kkbO75jup%2FV29Frx7%2BuHPCLVj1ygf4MP6g9v%2B9%2F0rGQ0%2F8DZPvGIFfzv0p3tuyD2vW7dSeKyopx4x5f0C3bp3xsFhA5T7yeYtfhtXa%2BgtO3%2FvgOuSeOqct6D%2B5LQwLlvwJuXnn0OfmbjiakoMnn3lHe53pSCb%2B5w%2F%2FwPAhfbXHO%2BMPYcnDfxEbXQt%2BPnUUPvviiPZZJHksIPbVDzBn4Wpk5ZzF%2BaJyzugGBeerser1NIyctge%2FXp6ErFMX8fjiEBz%2B%2BE64GXgYmOsf17%2BmNJcfl1pSFuADyKD6AUMzhWpJ2NzzHb2l9ZdXlmDI4PrDDuUV1di%2Bcz9mTovCG5s%2BxyMP%2FBwz%2FutW7bmbAruKFeRF%2FPaB6dpr5EL78JJp2nO3Rg7C6ImPi29nabjt1sEtHnfSkZPIyy%2FCe397TPvGODpiIBIOHsdnuw9jyT1TsHbVYkTPWol1r3%2BC97f9C6%2BtuR89bvK7%2FP4nHrkLC%2B6eoA336xuIe36zDi%2Bs%2BIX22MPdiP%2F7x9Nt%2BrZ5o1oem4J3PsjVWlUTbu2GP%2F5%2BKKLHBWmtKuL6x%2FWvVaFVnx8KPjUDz%2F%2BwJdWisLrECnwjvidGq808bzYjW4yUWzQhuF%2BQ%2BGZ3QBuW34gGDexx%2BbmQAT1xsbIGZ89daHiu5%2FdNXJ2CgcE9xP8LWrWypJ88g%2FwzxRhz5%2B%2Bv%2BP%2BgAfVld%2B7shfUvL8G0u1%2FQVtwxowb9oI3%2B%2FUa2f98glJZe1HaZSJ5eRpuvKO39XkWpmWVaUPl1MeK2cH%2BMHu5nk6DiPZy4%2FnW09U%2Fmh%2Fj0PzOrmC36zbZpDVfZx7hfvDFf9O8UBW4U%2Fd9e63k3A1ZdalnNAfQ5Iehj0SFMvHCieM088doUg4oHE08gvbUfyNbl2XuGVlRUoWtnb224k48HysqrLj9XLoblty8fbw%2BtKyuvvOK98rGPT%2BsWTlmOXCF3bX%2Fmqq%2FZ%2FtF%2BDAvrg50fH8RS8W1PrkBNKS4uh5enOzw9jHZbQJu7RYGrz%2B8dfxmjHad6a3sOXvzrCcT%2BLR3R4wPxq1l9MW50gN3qxV5GD0aIWcF6MfKhohLeFzWxV29Fat905G4DLM4oj%2Buf89Y%2Fe8zvH87Pxvkh%2Bq97uOGt6jrcKxo%2Bi1UFpU3tAtS%2BUPywENHbJgoIFV2eQY%2FQw8fxWHPPN94FKCfw63RkHT6BePlcaR36ivftsyg4ODIMd7S2Mmxdnj1UV9XV92tq8Y%2Ft%2F8KUO0ZqjyeOG64d3LVYrNrjzVu%2BRPiI%2FujSxRt3jB%2BOz784gnNFZdpz3yRnIyPzDG6PCm3VuOXr5bfE%2BM%2B%2Bvvw%2FeWD322M59RvXjw5ouzZ2vr8coyIH4uHfb4Sqfr%2FslJXVr7Bm0Vr4y5uf4r8mR1w%2BAO0Mrj6%2FZSvq53fchA%2F%2FOgYJWydg0aw%2B%2BOrgOcQ8eABRs%2FeKed1%2BGkiyPmW9yvqV9SzrW9a7rP%2B2BJWty%2BP6d2MtP1fLj%2F3fIkX29XoMFFWzTbyuXLw471otK1mITLpDbqKQJo5BNfd8kzIzIdu0L4QP1nYZbhNJHHU935BtXZ4tPPTEG1pzvqS0AhPGDr181s6jv5mOJY%2F8BbdPfko7G6i6pg7vbHhYe07ualgwdwIm%2FOy%2FMbB%2FD2RlF2DNC%2Fegm3%2FnVo1bnn305mvL8PiKt%2FHMi%2B%2FDKJq5NbV1WLvqPhxPO42VL8Vhx9%2Bf0vZ%2Fv%2FjMLzE1ZiVee2OXdjBYW4Hf%2FxJvvvsFqqprMTS0N17%2F0wMutUK44vy%2BvKunXye89MRQrFg2GFt35eHt7bmwWFXo28HxK%2FmNWOTqNrFxWCg3MK5WHte%2FG275aTY%2FGv732K1DsarOgt%2F%2FsKWlNDTTKkUhG0Qhq5oqpLnnW7G7ZYXojRNN0ck22n1j0%2FIa74Zo7W21888Uwc1oQPeALj96rvB8KWprzOjV0%2F9Hz8ldExfKLqJ7ty7aKavXQ57uahAzqaUr3K8eWKudzisPRl%2BsrG5y2m2h8W21r2c3hF3n90c%2Fd%2FgKHzn9Y6ftBhSf%2BZ%2Bi9y8x3hdcrTyuf665%2FrV1frc1P%2BTZgjK0xAQvFePxMtTv2kC%2FaxXS3PMt1akKa8o98aC8cOeRYzjqauVdj549%2FK%2F63LUWQnkA9VoHUVe%2F%2BqH2G4wm9%2BHqFGzd9MTlxzcFte1eTN5e7lrn6lxpfrdn2oVzrRgm6nO6K5bH9e%2FGWn7amh%2BNW1qXdwM2V5CtTkv%2FKgfVEWH4R8OFO4%2B6Wnmu6MlHZtqt7MUL77ziNFpXZ6%2F5LS995OhLLlVcrHNaPWr1p%2BAfsj5dsTyuf66ttfP7evPj0vsd%2FwtGFXtFk3CMy5bXgYwdE6adLtuu2GF%2Bd%2B1kNBeV1jj0Y2TklDmxCkX9iXp01fK4%2Frn6Kuic%2Be3wsBJfYI%2BJ768hrloeuTZ7zO9O3m4X8gsqHfo5Eo%2Be1%2FqKCnlpAosjxy3rT9ajq5ZHrs1Z89vhYeVZoTXpurlqeeTa7DG%2F%2FX3d9yWYHHsBlt0J9VcKVxUUip6jr%2F7SraEeXbU8cm1Omd8OD6sDedp%2BTg9XLY9cmz3md%2Bapqpc%2B2Ztnrq2zOuQzZOeVIyev4tIaKO9DccrB1ejRUI%2BuWh65NqfMb2dcdVMFbHqarq3LI9dm8%2Fn95aHKJKObzhQXn%2B2QD%2FDUqqTGn%2BaibGg5uA6Vhnp01fLItTllfvMS0URC%2FvnKBRvj0quT00rsOp7Vb6TgZG75paDKEl2EVYcdnANEDCuiZiWJDKmtU2OWPXvQYq%2FAkkG1tXHrTUGC%2BIr6NX8zRsSwImqxQ8mWXRVV5vuWLN%2Bvrtt8HLY6hiWPUd390FdXBpWK98TfKaoeT7LmiZpnYBUQfe9wKt6ODLXq3t1xckPcR9mGqBEBiB7fCyHBndGnh0%2BLyqisNiMtqwyJ35zDFwlnRFhVXPkCGVTyivIK7jGJFh1rnYhh1WaNr6dFHYvpON4MH6LmW2ot2%2FYlntWLzjY3FZLHqBQkQN4jTodFScfwGWub6x%2B1DHcDNkFe7NFZ9xciF2lhiSBR9BghBj8XIVMkFoYU0Z0WS8XFVhRTId6TrVNFGcCHKuAuHvuIr4i3HWZQcf0jtqyIbLLRrN9FN1NeuLPheoSTYRUbUQXeLSzCR1VxQVXQVQwnqnqsNPFkCiKGlT2%2B4bEWqOFsPdk9w9rg%2BkfOwd2ARETEsCIiImJYERERw4qIiIhhRURExLAiIiKGFREREcOKiIg6Ov4omKgJqul%2Bt%2B0HDj6Sml6yMO1k6cDi0lr3c8XVNv%2BRqr%2Bvu9nb0%2B1CgJ%2F7PnnHYnkjSNY%2BEcOKqFm7N0U88OirO2PTs8u8p028GXct7Y2g7l7o7u9h83EVFlUbCgorAxJMhTG5%2BadmTJ%2FgZZI3gkzi1diJGFZETbam1Od0W9fu2LJ6Q8rsBbOCsXr5KBjd7LunXAag7IaH%2BmHx3BBDXHx21Ma49JTIYeosU7LlU84Vono8ZkXUQAbVW1syZr%2B8YhQWzgy2e1D9kByfHO%2F656M8vIzKx5Fh4H0yiBhWRN%2BTu%2F5Ei2Z27NORGDbI16nTIsf%2F2soovcGg2ziSgUXEsCKS5MkU8XtOxy4QrRpnB1XjwJo%2Fo79igPK6aGFN5VwihhVR%2B2SzM%2FPkWX%2BZueXec6f1c6kPuGTeIBiNOoNVxZaIoQh2tXojYlgRNWNML9js1LzUjJJF0eN7OvwYVXPk9Iy%2BpZtMFwMsWONq9UbEsCJqRpUPAm1VVlpWWfDYyECX%2FJyTx%2FWQPU%2FRjZV3LHaleiNiWBE1Q69giK3KKiqu8egZ5OWSnzNsQNf6AQWFOitiXKneiBhWRM1RMNFWRRWX1Sj%2BXdxd8mP2Crwcoj6im%2BRK9UbEsCJqjor5E%2Fra5viL1aJCp3fN8w4uTZeqwk%2F0el9PWVp9iXrjwkMMKyLHSS73xOOuMjEnssrx1OpkmEXw2achqbWsrut4U0N9JXPRofaIl1uidkmvYplFwcHwwfjm8AnEO2Ma6sxWfPpVAd7cloP9h4tgEK2g%2F31siBYtNbVWmJJLrvreQf18EODX6l2P%2BrZOq6inaaL3mKi3KFFvaVyCiGFF5ACJJ5A%2BMgxzdMC2iFC8UlqH2MxM1Dhi3AXnq%2FHOjly8%2B%2BEpnC2qRlCABx5fHIKFs%2FrAzVC%2Fs6LgXDXuWrr%2FqmVseCEcMVN62n1aBwyAexc3PCGDyqpgTtJxpIv6ImJYETnKkVTsGT0YUWYF68UG%2BcHwULwPFXv1VqT2TUfuNsBi63Euj03BOx%2Fkaq2qCbd2wx9%2FPxTR44K0VlVjAX5GrHt2xFXLiRxqnytlzBGtr5wQ9LHoECZPphBTNU8FUgyiRSWDiksNMayInNTCEr1J8jdIOhWzxPDDVj0GZoWiT4QdrtaQmlmmBZVfFyNuC%2FfH6OF%2BPwoqyd2ox%2B0R%2Flctx9%2B3bWcfilbRNQ%2BKZUF7PldMUYb49AdEayr6yDEc5ZJCDCsiV2hl1W%2BQ27RRbi4AGtvxlzHacaq3tufgxb%2BeQOzf0hE9PhC%2FmtUX40YHXH5dfkEVIu%2Fac9Vy2robULSOeLkkYlgRUTMrjGhF%2FfyOm7QuLbscm7bnYssnp%2FHxnu8Q3Mcb%2F9nyU%2BjFa7p0csOT9w%2B6ajlhwZ1YmUQMKyL7G9SvE156YihWLBuMrbvy8LYILotV1cKqa2c3PHFfCCuJiGFF5Bq8PQ24J6av1hGRffBHwURExLAicvmVQK9ol1xyRRUX6ziDiBhWREDXTkZzUWmNS05bRk4ZZxARw4oI6OTtdiG%2FoNIlpy3x6Hmtr6gohx1%2B5EzEsCJqJ%2Fx93fclmM665LTtTjij9VUFhaJ3lnOLGFZEHVTmqaqXPtmbZ66ts7rUdGXnlSMnr%2BLSmpol%2Fp7i3CKGFVEH9eWhyiSjm84UF5%2FtUtP11Kqk7x%2BouCgbWpxbxLAi6sDyz1cu2BiXXp2cVuIS07P6jRSczC2%2FFFRZoouw6rCDc4oYVkQdWJLIhto6NWbZswctzg4sGVRbG7fyFCQowNe8IC0xrIgIh5ItuyqqzPctWb5fXbf5OBx9DEseo7r7oa%2BuDCoV74m%2FU1Q9nuQcoo6Ml1siauRwKt6ODLXq3t1xckPcR9mGqBEBiB7fCyHBndGnh49Nx1VZbUZaVhkSvzmHLxLOiLCquPIFMqjkPakU3GMSLT%2FOHWJYEdFlpuN4M3yImm%2BptWzbl3hWLzpPh06APEalIEEMRas6LEo6hs84V6ij425AoqZaWCIgFD3krX4%2FF%2BFRpAApojstQuSiHUZXIcrO1qliXMCHKuAuHvuIr5K3HWZQEbFlRXQtSfW73mZqdyG2IkYMT4ZVxJUCbxuPykdVcUFV0FUMJ6p6rDTxZAoihhVRazS6C%2FEzrA0i5%2BBuQCIiYlgRERExrIiIiGFFRETEsCIiImJYERERw4qIiIhhRUREHR1%2FFEzUBNV0v9v2AwcfSU0vWZh2snRgcWmt%2B7niaqWl7%2Ff3dTd7e7pdCPBz3yfvRCxv8MhaJWJYEdnM7k0RDzz66s7Y9Owy72kTb8ZdS3sjqLsXuvt7tLiMwqJqQ0FhZUCCqTAmN%2F%2FUjOkTvEzyBo9JvHo6EcOK6LpaU%2Bpzuq1rd2xZvSFl9oJZwVi9fBSMbm3bUy6DTXbDQ%2F2weG6IIS4%2BO2pjXHpK5DB1linZ8ilrm6h1eMyKqIEMqre2ZMx%2BecUoLJwZ3Oag%2BiFZjixv%2FfNRHl5G5ePIMNzL2iZiWBG1mtz1J1o%2Bs2OfjsSwQb52GYcs97WVUXqDQbdxJAOLiGFF1BryZIr4PadjF4jWj72CqnFgzZ%2FRXzFAeV20sKay9okYVnRjU2xVkDzrLzO33HvutH4OmfAl8wbBaNQZrCq2RAxFcHutNyKGFVEzxvSCh63KSs0oWRQ9vqfNjlE1R45n9C3dZGoYYMGa9lpvRAwromZU%2BSDQVmWlZZUFj40MdOj0Tx7XQ%2FY8RTdW3om4PdYbEcOKqBl6BUNsVVZRcY1HzyAvh05%2F2ICu9QMKCnVWxLTHeiNiWBE1R8FEWxVVXFaj%2BHdxd%2Bjk9wq8HI4%2BopvUHuuNiGFF1BwV8yf0tc3xF6tFhU7v2PMOLo1PVeEner0dMU6tvkS9ceEhhhWR4ySXe%2BJxR4%2F07R05%2BOiLM6gzW23U0NFaVg45jtRQX8lcdIhhReQgehXLRO%2Bx8MGY5sjxpqSX4dfLkzBy2h6sej0NBeerbfJx7D3dDfX0WEO9EbU7vDYgtUuJJ5A%2BMgxzxLetbRGheKW0DrGZmaix93j%2F%2BMRQjIsMwKYPcrFmYzr%2B%2FHYGoscH4d7ZffGTUQEuV08DBsC9ixuekEFlVTAn6TjSRX0RMayIHOVIKvaMHowos4L1YoP8YHgo3oeKvXorUvumI3cbYLH1ON0MOsyY1EPrMnIrsGl7LrbuOo34vd8hpK8P4tbeiptv8nJancwRrbScEPSx6BAmT6ZQgHmqaBAaVETJoOJSQwwrIie1sERvkvytkk7FLDH8sFWPgVmh6BNh56s19OvljTHhfvj2xAUc%2FKYY2XmVqLhoblNZorWj2mKasqCVkys%2BeIb49AdEayr6yDEc5ZJCDCsiV2hl1W%2BQ27RRbm1QfHeuGps%2FyMXfd57SjlkFBXjgyfsH4Zcze2vDbSFaPbwMEhHDisg2Xn0nE3%2F86wmYLSrGRgbgxceHYuqEIBj0zBoihhWRiyg8X4NfxfTFr2b3waB%2BnVghRAwrItfzh9%2FxakVEzsDfWREREcOKyOVXAr2iXXLJkSou1rHiiRhWRC3XtZPRXFRa49BxZuSUseKJGFZELdfJ2%2B1CfkGlQ8eZePS81ldUlMMOP14mYlgR3WD8fd33JZjOOnScuxPOaH1VQaHoneVcIGJYEV1T5qmqlz7Zm2eurbM6ZHzZeeXIyau4tAZmib%2BnOBeIGFZE1%2FTlocoko5vOFBef7ZDxPbUq6fsHKi7KhhbnAhHDiqhZ%2BecrF2yMS69OTiux63hWv5GCk7nll4IqS3QRVh12cA4QMayImpUkMqS2To1Z9uxBi70CSwbV1satNwUJCvA1LzRLxLAiarFDyZZdFVXm%2B5Ys36%2Bu23wctjqGJY9R3f3QV1cGlYr3xN8pqh5PsuaJmsfLLRE1cjgVb0eGWnXv7ji5Ie6jbEPUiABEj%2B%2BFkODO6NPDp0VlVFabkZZVhsRvzuGLhDMirCqufIEMKnmvKQX3mESLjrVOxLAiajXTcbwZPkTNt9Ratu1LPKsXnadNCpbHqBQkiKFoVYdFScfwGWubqGW4G5CoqRaWCBJFjxFi8HMRMkUKkCK60yJsLraimArxnmydKsoAPlQBd%2FHYR3xFvO0wg4qILSsiW0iq30U3U7sLsRUxYngyrCKuFHi3sAgfVcUFVUFXMZyo6rHSxJMpiBhWRPbQ6C7Ez7A2iJyDuwGJiIhhRURExLAiIiKGFREREcOKiIiIYUVERAwrIiIihhUREXV0%2FFEwURNU0%2F1u2w8cfCQ1vWRh2snSgcWlte7niqsVW4%2FH39fd7O3pdiHAz32fvGOxvBEka5%2BIYUXUrN2bIh549NWdsenZZd7TJt6Mu5b2RlB3L3T397D5uAqLqg0FhZUBCabCmNz8UzOmT%2FAyyRtBJvFq7EQMK6ImW1Pqc7qta3dsWb0hZfaCWcFYvXwUjG723VMuA1B2w0P9sHhuiCEuPjtqY1x6SuQwdZYp2fIp5wpRPR6zImogg%2BqtLRmzX14xCgtnBts9qH5Ijk%2BOd%2F3zUR5eRuXjyDDcy7lCxLAiukzu%2BhMtmtmxT0di2CBfp06LHP9rK6P0BoNu40gGFhHDikiSJ1PE7zkdu0C0apwdVI0Da%2F6M%2FooByuuihTWVc4kYVkTtk83OzJNn%2FWXmlnvPndbPpT7gknmDYDTqDFYVWyKGItjV6o2IYUXUjDG9YLNT81IzShZFj%2B%2Fp8GNUzZHTM%2FqWbjJdDLBgjavVGxHDiqgZVT4ItFVZaVllwWMjA13yc04e10P2PEU3Vt6x2JXqjYhhRdQMvYIhtiqrqLjGo2eQl0t%2BzrABXesHFBTqrIhxpXojYlgRNUfBRFsVVVxWo%2Fh3cXfJj9kr8HKI%2BohukivVGxHDiqg5KuZP6Gub4y9Wiwqd3jXPO7g0XaoKP9HrfT1lafUl6o0LDzGsiBwnudwTjzt6pG%2FvyMFHX5xBndnq4Iak1rK6ruNNDfWVzEWH2iNebonaJb2KZRYFB8MH45vDJxDvqPGmpJdh8we5CPT3wC9n9saimD4ICvhxA6%2Bm1gpTcslVyxnUzwcBfq3e9ahv63SLepomeo%2BJeosS9ZbGJYgYVkQOkHgC6SPDMEcHbIsIxSuldYjNzESNvcf7xyeGYlxkADaJwFqzMR1%2FfjsD0eODcO%2FsvvjJqIDLrys4V427lu6%2FajkbXghHzJSedq%2BnAQPg3sUNT8igsiqYk3Qc6aK%2BiBhWRI5yJBV7Rg9GlFnBerFBfjA8FO9DxV69Fal905G7DbDYepxuBh1mTOqhdRm5Fdi0PRdbd51G%2FN7vENLXB3Frb8XNN3mJVpMR654dcdVyIofa50oZc0TrKycEfSw6hMmTKRRgnioahAbRopJBxaWGGFZETmphid4k%2BRsknYpZYvhhqx4Ds0LRJ8LOV2vo18sbY8L98O2JCzj4TTGy8ypRcdGsPedu1OP2CP%2Brvtfft21nH4pWkXqt57OgPZ8rPniG%2BPQHRGsq%2BsgxHOWSQgwrIldoZdVvkNu0UW4uAH7ou3PV2nGrv%2B88hYLz1doxqyfvH6Qdw7p0%2FCq%2FoAqRd%2B25ahlt3Q0oWke8XBIxrIjo2l59JxN%2F%2FOsJmC0qxkYG4MXHh2LqhCAYfnDqe5dOblqAXU1YcCdWJhHDisg%2BCs%2FX4FcxffGr2X0wqN%2FVA6drZzc8cV8IK4yIYUXkeH%2F4Ha9WROQM%2FFEwERExrIhcfiXQK9oll1xRxcU6ziAihhUR0LWT0VxUWuOS05aRU8YZRMSwIgI6ebtdyC%2BodMlpSzx6XusrKsphhx85EzGsiNoJf1%2F3fQmmsy45bbsTzmh9VUGh6J3l3CKGFVEHlXmq6qVP9uaZa%2BusLjVd2XnlyMmruLSmZom%2Fpzi3iGFF1EF9eagyyeimM8XFZ7vUdD21Kun7ByouyoYW5xYxrIg6sPzzlQs2xqVXJ6eVuMT0rH4jBSdzyy8FVZboIqw67OCcIoYVUQeWJLKhtk6NWfbsQYuzA0sG1dbGrTwFCQrwNS9ISwwrIsKhZMuuiirzfUuW71fXbT4ORx%2FDkseo7n7oqyuDSsV74u8UVY8nOYeoI%2BPllogaOZyKtyNDrbp3d5zcEPdRtiFqRACix%2FdCSHBn9OnhY9NxVVabkZZVhsRvzuGLhDMirCqufIEMKnlPKgX3mETLj3OHGFZEdJnpON4MH6LmW2ot2%2FYlntWLztOhEyCPUSlIEEPRqg6Lko7hM84V6ui4G5CoqRaWCAhFD3mr389FeBQpQIroTosQuWiH0VWIsrN1qhgX8KEKuIvHPuKr5G2HGVREbFkRXUtS%2Fa63mdpdiK2IEcOTYRVxpcDbxqPyUVVcUBV0FcOJqh4rTTyZgohhRdQaje5C%2FAxrg8g5uBuQiIgYVkRERAwrIiJiWBERETGsiIiIGFZERMSwIiIiYlgREVFHxx8FEzVBNd3vtv3AwUdS00sWpp0sHVhcWut%2BrrhasfV4%2FH3XAZqkAAAgAElEQVTdzd6ebhcC%2FNz3yTsWyxtBsvaJGFZEzdq9KeKBR1%2FdGZueXeY9beLNuGtpbwR190J3fw%2Bbj6uwqNpQUFgZkGAqjMnNPzVj%2BgQvk7wRZBKvsk7EsCJqsjWlPqfbunbHltUbUmYvmBWM1ctHwehm3z3lMgBlNzzUD4vnhhji4rOjNsalp0QOU2eZki2fcq4Q1eMxK6IGMqje2pIx%2B%2BUVo7BwZrDdg%2BqH5PjkeNc%2FH%2BXhZVQ%2BjgzDvZwrRAwrosvkrj%2FRopkd%2B3Qkhg3ydeq0yPG%2FtjJKbzDoNo5kYBExrIgkeTJF%2FJ7TsQtEq8bZQdU4sObP6K8YoLwuWlhTOZeIYUXUPtnszDx51l9mbrn33Gn9XOoDLpk3CEajzmBVsSViKIJdrd6IGFZEzRjTCzY7NS81o2RR9PieDj9G1Rw5PaNv6SbTxQAL1rhavRExrIiaUeWDQFuVlZZVFjw2MtAlP%2BfkcT1kz1N0Y%2BUdi12p3ogYVkTN0CsYYquyioprPHoGebnk5wwb0LV%2BQEGhzooYV6o3IoYVUXMUTLRVUcVlNYp%2FF3eX%2FJi9Ai%2BHqI%2FoJrlSvRExrIiao2L%2BhL62Of5itajQ6V3zvINL06Wq8BO93tdTllZfot648BDDishxkss98XjHaUhqLavrOt7UUF%2FJXHSoPeLllqhd0qtYZlFwMHwwvjl8AvGOGm9ufiXyCqqaXplEK%2BjWEX7acE2tFabkkquWM6ifDwL8Wr3rUd%2FW6Rb1NE30HhP1FiXqLY1LEDGsiBwg8QTSR4Zhjg7YFhGKV0rrEJuZiRp7j%2FedD3KxbnNmk8%2F5eBmQva%2F%2B97sF56px19L9Vy1nwwvhiJnS0%2B71NGAA3Lu44QkZVFYFc5KOI13UFxHDishRjqRiz%2BjBiDIrWC82yA%2BGh%2BJ9qNirtyK1bzpytwEWW49zxp09ENLPp%2BmVyfD9XvUAPyPWPTviquVEDrXPlTLmiNZXTgj6WHQIkydTKMA8FUgxiBaVDCouNcSwInJSC0v0JsnfIOlUzBLDD1v1GJgVij4RdrhaQ5%2BeXvDr6tbkc4ry%2FejcjXrcHuF%2F1XL8fdt29qFoFanXej4L2vO5YkoyxKc%2FIFpT0UeO4SiXFGJYEblCK6t%2Bg9ymjXJzAdDY2ncyW7QbML%2BgCpF37blqOW3dDShaR7xcEjGsiOjaxt8aAE%2BPps9zcHP7Pke6dHLDk%2FcPumo5YcGdWJlEDCsiO4XV6G5a15yund3wxH0hrDAiG%2BHvrIiIiGFFRETEsCK63pVAr2iXXHJFFRfrOIOIGFZEQNdORnNRaY1LTltGThlnEBHDigjo5O12Ib%2Bg0iWnLfHoea2vqCiHHX7kTMSwImon%2FH3d9yWYzrrktO1OOKP1VQWFoneWc4sYVkQdVOapqpc%2B2Ztnrq2zutR0ZeeVIyev4tKamiX%2BnuLcIoYVUQf15aHKJKObzhQXn%2B1S0%2FXUqqTvH6i4KBtanFvEsCLqwPLPVy7YGJdenZxW4hLTs%2FqNFJzMLb8UVFmii7DqsINzihhWRB1YksiG2jo1ZtmzBy3ODiwZVFsbt%2FIUJCjA17wgLTGsiAiHki27KqrM9y1Zvl9dt%2Fk4HH0MSx6juvuhr64MKhXvib9TVD2e5ByijozXBiRq5HAq3o4Mtere3XFyQ9xH2YaoEQGIHt8LIcGd0aeHj03HVVltRlpWGRK%2FOYcvEs6IsKq48gUyqOQ9qRTcYxItP84dYlgR0WWm43gzfIiab6m1bNuXeFYvOk%2BHToA8RqUgQQxFqzosSjqGzzhXqKPjbkCiplpYIiAUPeStfj8X4VGkACmiOy1C5KIdRlchys7WqWJcwIcq4C4e%2B4ivkrcdZlARsWVFdC1J9bveZmp3IbYiRgxPhlXElQJvG4%2FKR1VxQVXQVQwnqnqsNPFkCiKGFVFrNLoL8TOsDSLn4G5AIiJiWBERETGsiIiIYUVERMSwIiIiYlgRERHDioiIiGFFREQdHX8UTNQE1XS%2F2%2FYDBx9JTS9ZmHaydGBxaa37ueJqpa3l%2Bfu6m7093S4E%2BLnvk3cmljd8ZC0TMayI2mz3pogHHn11Z2x6dpn3tIk3466lvRHU3Qvd%2FT3aXGZhUbWhoLAyIMFUGJObf2rG9AleJnnDxyReTZ2IYUXUqtaU%2Bpxu69odW1ZvSJm9YFYwVi8fBaObbfaUy6CT3fBQPyyeG2KIi8%2BO2hiXnhI5TJ1lSrZ8ytonujYesyJqIIPqrS0Zs19eMQoLZwbbLKh%2BSJYry1%2F%2FfJSHl1H5ODIM97L2iRhWRM2Su%2F5ES2d27NORGDbI1yHjlON5bWWU3mDQbRzJwCJiWBFdizyZIn7P6dgForXjqKBqHFjzZ%2FRXDFBeFy2sqZwbRAwrurEotipInvWXmVvuPXdaP6d8kCXzBsFo1BmsKrZEDEVwe6k3IoYVUTPG9IKHrcpKzShZFD2%2Bp92OUTVHjnf0Ld1kihhgwZr2Um9EDCuiZlT5INBWZaVllQWPjQx06ueZPK6H7HmKbqy8M3F7qDcihhVRM%2FQKhtiqrKLiGo%2BeQV5O%2FTxhA7rWDygo1FkR0x7qjYhhRdQcBRNtVVRxWY3i38XdqR%2BnV%2BDlsPQR3aT2UG9EDCui5qiYP6GvbY6%2FWC0qdPqWnXfw%2BEvf4q6l%2B7H2nUzbrogN41dV%2BIleb3tUmVZfot648BDDishxkss98bijR5qRU4H%2FJBUh77sqOzV8tJaVXY4rNdRXMhcdao94uSVql%2FQqllkUHAwfjG8On0C8o8br5anX%2Bt5e%2Bsv%2FO55ZhuLSuiZf39nHgGGDurT649l6ukU9TRO9x0S9RYl6S%2BMSRAwrIgdIPIH0kWGYowO2RYTiFZEVsZmZqLF%2FWBmu6EvPv3YcX%2FynsMnXjxrmi11vjXVaPQ0YAPcubnhCBpVVwZyk40gX9UXEsCJylCOp2DN6MKLMCtaLDfKD4aF4Hyr26q1I7ZuO3G2AxeZh5aG%2Foi8tnd8fM%2B7s0eTrA3wde%2BLGHNEqywlBH4sOYfJkCgWYpwIpBtGikkHFpYYYVkROamGJ3iT52ySdilli%2BGGrHgOzQtEnwg5Xa%2FBu2A3o1Wg34JABndH%2FZu8mX280tu2wsGj9qG15Xxa09%2BWKD54hPv0B0ZqKPnIMR7mkEMOKyBVaWfUb5DZtlFsTDFPGBckbKWLUML%2FL%2F3vo%2BW9svhtQtIJ4WSQihhVR23xXWH8W4BnRHxrSWRuePbUXwoc0fQHcHt15dSMihhWRg7330WkkHi3Goll9MHls%2FRnmMVN6smKIGFZEruOTjbezEoicgD8KJiIihhWRy68EekW75JIzVVys44wgYlgRXV3XTkZzUWmNU6chI6eMM4KIYUV0dZ283S7kF1Q6dRoSj57X%2BoqKctjhx8xEDCuids7f131fgumsU6dhd8IZra8qkD%2FYOsu5QsSwIrpC5qmqlz7Zm2eurbM6ZfzZeeXIyau4tEZmib%2BnOFeIGFZEV%2FjyUGWS0U1niovPdsr4n1qV9P0DFRdlQ4tzhYhhRfQj%2BecrF2yMS69OTitx6HhXv5GCk7nll4IqS3QRVh12cI4QMayIfiRJZEZtnRqz7NmDFkcFlgyqrY1bcwoSFOBrXniWiGFFdFWHki27KqrM9y1Zvl9dt%2Fk47HUMSx6juvuhr64MKhXvib9TVD2e5Jwg%2BjFebomokcOpeDsy1Kp7d8fJDXEfZRuiRgQgenwvhAR3Rp8ePm0qs7LajLSsMiR%2Bcw5fJJwRYVVx5QtkUMl7Tym4xyRaeJwLRAwromaZjuPN8CFqvqXWsm1f4lm96DztMiJ5jEpBghiKVnVYlHQMn7H2iZrG3YBETbWwRHAoeowQg5%2BLUClSgBTRnRbhcvE6iq0QZWTrVFEm8KEKuIvHPuIr422HGVREbFkRtUVS%2FS65mdpdiK2IEcOTYRVxpcC7jUX6qCouqAq6iuFEVY%2BVJp5MQcSwIrKFRnchfoa1QeQc3A1IREQMKyIiIoYVERExrIiIiBhWREREDCsiImJYERERMayIiKij44%2BCiZqgmu53237g4COp6SUL006WDiwurXU%2FV1yt2Ho8%2Fr7uZm9PtwsBfu775B2L5Y0gWftEDCuiZu3eFPHAo6%2FujE3PLvOeNvFm3LW0N4K6e6G7v4fNx1VYVG0oKKwMSDAVxuTmn5oxfYKXSd4IMolXXydiWBE12ZpSn9NtXbtjy%2BoNKbMXzArG6uWjYHSz755yGYCyGx7qh8VzQwxx8dlRG%2BPSUyKHqbNMyZZPOVeI6vGYFVEDGVRvbcmY%2FfKKUVg4M9juQfVDcnxyvOufj%2FLwMiofR4bhXs4VIoYV0WVy159o0cyOfToSwwb5OnVa5PhfWxmlNxh0G0cysIgYVkSSPJkifs%2Fp2AWiVePsoGocWPNn9FcMUF4XLaypnEvEsCJqn2x2Zp486y8zt9x77rR%2BLvUBl8wbBKNRZ7Cq2BIxFMGuVm9EDCuiZozpBZudmpeaUbIoenxPhx%2Bjao6cntG3dJPpYoAFa1yt3ogYVkTNqPJBoK3KSssqCx4bGeiSn3PyuB6y5ym6sfKOxa5Ub0QMK6Jm6BUMsVVZRcU1Hj2DvFzyc4YN6Fo%2FoKBQZ0WMK9UbEcOKqDkKJtqqqOKyGsW%2Fi7tLfsxegZdD1Ed0k1yp3ogciT8KpvZJxfwJffHfX%2BWg%2BnqLslpU6PQtO%2B%2FgQlkdXvrrCSSYzqOqxopeQZ5YMq8%2FfvbToB%2B99p0PcvGPj07hXHEtfLz0mPKTIDxxX4g8aaLl3yYbpktV4adc5%2Foq6sujXNQbFx5iy4rIcZLLPfG4o0f6%2BB%2B%2FxVvbc9DrJi8siumDA0eK8OvlJpz%2BruqK1%2B36qgCPv%2FQtcs9U4rf3DERFpQV%2F3pSBN7Zkt7FBpLWsrut4U0N9JXPRIYYVkYPoVSwTvcfCB2OaI8d7SoSPFDG0Kxb%2Fv77Q6RRYrarW1GssN7%2F%2BdQFd3TF%2F%2Bs0YMrCz9thiVa%2FrY7f1jQ319FhDvRExrIgcIfEE0q0K5igKNkeEYsWAAXDIQaeHFw2AQa%2FglbcyMPs3ByHGjyfvH6S1fU5%2FV4naOqv2ujlTe6J3Dy%2BkZZdj2uL%2FYPd%2FzmL0LX6YPvEm7XVyd6IjyHqR9SPrSdaXrDcuPdQe8ZgVtVtHUrFn9GBEmRWs7%2BKGB8ND8b5o4OzVW5HaNx2520RDxtbj9DDq4eNt0MLGlFKCudNuxu9%2BHYKet32COrMVe94dh%2BGDu0A2oLr5uWstMfm6noGeeHtVJJ5fl4otn%2BThwV8G47mHw2xeJ3NE6ysnBH0sOoTJkylEls4Tk5JiUBGVdJxBRQwrIqe1sERvkvwNkk7FLNn4seoxMCsUfSJsfLWGc0U1%2BPVTJlRWW%2FDacyPxh%2FXHERd%2FGjW1Vqiqqu0SlCdcSL994SiSREgt%2Fn%2F9cKawSjuGFX1PAm7qXv%2BbXNnqagvRSrrmfsSs%2Bv2RueKDZ4hPf0C0pqKPHMNRLinEsCJyhVZW%2FQa5TRvl5gLgktSTZVpQSZNu746fjArA3IcP4sN%2F5mv%2Fu%2FtnveDX1agNJx0r0frBvb3xwmND8PSaFO3EDLkLsJu%2FO2ZO7tmmzylaR7xcEnVIPGZF1EJhwZ3h4V5%2FjsOCxxKx79A5jBnp%2F32QpFy4fGLFyLD6H%2FOufiMNf9uSjZD%2BneDjVf%2FdsLS8DnsPFLJCiRhWRLYnW0Rv%2FjECPbp74OvkEjz8%2FDd4P%2F40lv0yGONHd0NmbgWm%2FjoBR4%2BX4k8rbtFaXiVldfifPx3DU6uTETHUVzu%2BZTareOB%2FDmPd5kxWKlELcTcgUStMHhuIyZ9MQl5BlXacKjDA46oXwP3gL2NQXFqLi5VmdPJ2Q9fObtr%2Fn1o6iBVJxLAisr9LJ1I0x6%2BLUeuI6PpwNyBxJdAr2iWXXFHFxTrOICKGFRHQtZPRXFRa45LTlpFTxhlExLAigjyedCG%2FoNIlpy3x6Hmtr6gohx1%2B5EzEsCJqJ%2Fx93fclmM665LTtTjij9VUF8lz3s5xbxLAi6qAyT1W99MnePPOl6%2Fq5iuy8cuTkVVxaU7PE31OcW8SwIuqgvjxUmWR005ni4rNdarqeWpX0%2FQMVF2VDi3OLGFZEHVj%2B%2BcoFG%2BPSq5PTSlxiela%2FkYKTueWXgipLdBFWHXZwThHDiqgDSxLZUFunxix79qDF2YElg2pr41aeggQF%2BJoXpCWGFRHhULJlV0WV%2Bb4ly%2Fer6zYfh6OPYcljVHc%2F9NWVQaXiPfF3iqrHk5xD1JHxChZEjRxOxduRoVbduztOboj7KNsQNSIA0eN7ISS4M%2Fr08LHpuCqrzUjLKkPiN%2BfwRcIZEVYVV75ABpW8J5WCe0yi5ce5QwwrIrrMdBxvhg9R8y21lm37Es%2FqRefp0AmQx6gUJIihaFWHRUnH8BnnCnV03A1I1FQLSwSEoscIMfi5CI8iBUgR3WkRIhftMLoKUXa2ThXjAj5UAXfx2Ed8lbztMIOKiC0romtJqt%2F1NlO7C7EVMWJ4MqwirhR423hUPqqKC6oCeROsRFWPlSaeTEHEsCJqjUZ3IX6GtUHkHNwNSEREDCsiIiKGFRERMayIiIgYVkRERAwrIiJiWBERETGsiIioo%2BOPgomaoJrud9t%2B4OAjqeklC9NOlg4sLq11P1dcrbS2HH9fd7O3p9uFAD%2F3ffKOxPJGj6xdIoYV0XXbvSnigUdf3Rmbnl3mPW3izbhraW8EdfdCd3%2BPVpdVWFRtKCisDEgwFcbk5p%2BaMX2Cl0ne6DGJV1EnYlgRtak1pT6n27p2x5bVG1JmL5gVjNXLR8Hodn17ymXAyW54qB8Wzw0xxMVnR22MS0%2BJHKbOMiVbPmWtE7UMj1kRNZBB9daWjNkvrxiFhTODrzuofkiWJ8td%2F3yUh5dR%2BTgyDPey1okYVkQtJnf9iRbP7NinIzFskK9dxyXLf21llN5g0G0cycAiYlgRtYQ8mSJ%2Bz%2BnYBaLVY%2B%2BgahxY82f0VwxQXhctrKmcC0QMK7oB80V0iq0Kk2f9ZeaWe8%2Bd1s%2BhH2LJvEEwGnUGq4otEUMR7KDRKg31R8SwIrKz6jG94GGrwlIzShZFj%2B9p82NUzZHjG31LN5keBliwxhHjbKi3ai5CxLAisr9zVT4ItFVhaVllwWMjA53yQSaP6yF7nqIbK%2B9IbO%2FxNdTbOS5CxLAisjMVSNcrGGKr8oqKazx6Bnk55bOEDehaP6CgUGdFjL3HJ%2BtN1h%2BXImJYEdmZAhwQfybaqrzishrFv4t7y19fWovT31XCYrny0I%2FVqmr%2FL75Q2%2BKyegVeDkkf0U1yQOVN1OqPiGFFZF9WHXaI5tX8CX1tc9zKKkJHp2%2F5%2BRp%2F%2FGsawqfvQcH5Kw%2F9lFaYtf8%2F8%2BdjLV8BG8arqvATvd72rDetvkS9afVHxLAisq8jx3BU9JLLPfH4DdRalC0rux44a6iv5Ib6I2JYEdmbXsUy0XssfDCm3Ugfy14FN9TTYw31RsSwInKExBNItyqYoyjYHBGKFQMGwJ218mOyXmT9yHqS9SXrjbVC7REvZEvt1pFU7Bk9GFFmBeu7uOHB8FC8DxV79Vak9k1H7jbA0tHqZI5oneWEoI9Fh7CGkynmqUCKQUVU0nEGFTGsiJzWwhK9SfI3SjoVs8Tww1Y9BmaFok%2BEDa9y4SiiFXRdV5fIqr86Ra744Bni0x8QraloHqMihhWRq7Sy6jfIbdooX29A2JJo%2FSicm0Q%2FxmNWRETEsCIiImJYERERw4qIiMjZeIIF8RubXmnVJZeWzu%2BPGZN6oJvvlT%2Ft6uRtwM4Nt6F7QMt%2F8lVxsY4zgIhhRdS8rp2M5qLSGkM3v5ZdarB%2Fb2%2Bt%2B9HKJMLu9gj%2FVo07I6eMM4CoJV8qWQXU0XXydruQX1DplHEnHj2v9RUV5eiAP2ImYlgRtZC%2Fr%2Fu%2BBNNZp4x7d8IZra8qKBS9s5wbRAwroiZlnqp66ZO9eebaOqtDx5udV46cvIpLa2KW%2BHuKc4OIYUXUpC8PVSYZ3XSmuPhsh473qVVJ3z9QcVE2tDg3iBhWRFeVf75ywca49OrktBKHjG%2F1Gyk4mVt%2BKaiyRBfBmyISMayIrilJZEdtnRqz7NmDFnsHlgyqrY1bcQoSFOBrXnCWiGFF1KxDyZZdFVXm%2B5Ys36%2Bu23wctj6GJY9R3f3QV1cGlYr3xN8pqh5Pcg4QXR1%2FZ0XUyOFUvB0ZatW9u%2BPkhriPsg1RIwIQPb4XQoI7o08Pn1aVVVltRlpWGRK%2FOYcvEs6IsKq48gUyqOQ9pxTcYxItO9Y%2BEcOKqMVMx%2FFm%2BBA131Jr2bYv8axedJ42HYE8RqUgQQxFqzosSjqGz1jrRNfG3YBETbWwRIAoeowQg5%2BLcClSgBTRnRYhc7ENxVWI92brVFEW8KEKuIvHPuKr4m2HGVREbFkRXY%2Bk%2Bl1zM7W7EFsRI4YnwyriSoF3K4vyUVVcUBV0FcOJqh4rTTyZgohhRWRLje5C%2FAxrg8g5uBuQiIgYVkRERAwrIiJiWBERETGsiIiIGFZERMSwIiIiYlgREVFHxx8Ft5Bqut9t%2B4GDj6SmlyxMO1k6sLi01v1ccbXyw9f5%2B7qbvT3dLgT4ue%2BTd6CVN%2FZj7RERMazsbvemiAcefXVnbHp2mfe0iTfjrqW9EdTdC939PX702sKiakNBYWVAgqkwJjf%2F1IzpE7xM8sZ%2BSbyqNhERw8ourSn1Od3WtTu2rN6QMnvBrGCsXj4KRrdr7zmVASa74aF%2BWDw3xBAXnx21MS49JXKYOsuUbPmUtUpE1Ho8ZnUNMqje2pIx%2B%2BUVo7BwZnCzQfVD8vXyfeufj%2FLwMiofR4bhXtYqERHDymbkrj%2FRIpod%2B3Qkhg3yva6y5PtfWxmlNxh0G0cysIiIGFa2IE%2BmiN9zOnaBaBVdb1A1Dqz5M%2ForBiivixbWVNYyEVHHCytVdIqtCpNn%2FWXmlnvPndbPphO5ZN4gGI06g1XFloihCObiRzcApWH9I2JYtUD1mF7wsFVhqRkli6LH92z1MarmyPJG39JNrt0GWLCGix%2B1dw3rXTVrghhWLXOuygeBtiosLasseGxkoF0mdPK4HrLnKbqx8g60XASpPWtY786xJohh1QIqkK5XMMRW5RUV13j0DPKyy7SGDehaP6CgsOFW6UTtllzv5PrHmiCGVQsowAHxZ6Ktyisuq1H8u7jbZVp7BV4OQR%2FRTeIiSO185ZuorX9EDKvmWXXYIZpX8yf0tc1xK6tFhU7fsvM1Hn%2FpW9y1dD%2FWvpPZsgpvKFdV4Sd6vbkIUnulrW9ivdPWPyKGVfOOHMNR0Usu98Tjjh53Rk4F%2FpNUhLzvqlrbGpQtq0AugtReNaxvyQ3rHxHDqiX0KpaJ3mPhgzHNkeP18tRrfW8vfZsmm4sgtUcN69ljDesdEcOqpRJPIN2qYI6iYHNEKFYMGAB3R4zXy9NwRZ%2FoRibXK7l%2ByfVMrm9yvWOtkCPcUFvYI6nYM3owoswK1ndxw4PhoXgfKvbqrUjtm47cbYDF5mHlob%2BiT3QjmSNa%2Fzkh6GPRIazhZIp5KpBiUBGVdJxBRQyr62phid4k%2BRsmnYpZYvhhqx4Ds0LRJ8KGV7m4xLthN6BX23YDQnxL5a%2F%2FyWVl1V%2BdIlesOBli7TkgWlPRPEZFDCtbtrLqV6g2rVStCZAp44LkDRcxaphfm6ZTfDtVuBgSEV0bL2R7nb4rrD8L8ExhFSuDiIhh5Zre%2B%2Bg0Vr%2BRhn%2F%2B%2Bywrg4jITngK23X6ZOPtrAQiIrasiIiIYUU%2FrhS9ol1yyR4qLtaxgomIGFbXr2sno7motMYuZWfklLGCiYgYVtevk7fbhfyCSruUnXj0vNZXVJTDDj9SJiJiWHUQ%2Fr7u%2BxJM9jm7b3fCGa2vKigUPZ5CSETEsGqbzFNVL32yN89cW2e1abnZeeXIyau4VPNZ4u8p1jYREcOqTb48VJlkdNOZ4uKzbVruU6uSvn%2Bg4qJsaLG2iYgYVm2Wf75ywca49OrktBKblLf6jRSczC2%2FFFRZoovgTeuIiBhW1yVJZEttnRqz7NmDlusNLBlUWxu30hQkKMDXvCAoERHD6rodSrbsqqgy37dk%2BX513ebjaO0xLHmM6u6HvroyqFS8J%2F5OUfV4kjVMRNQyvNxSMw6n4u3IUKvu3R0nN8R9lG2IGhGA6PG9EBLcGX16%2BFzx2spqM9KyypD4zTl8kXBGhFXFlYXJoJL3BFJwj0m03Fi7REQMK5sxHceb4UPUfEutZdu%2BxLN60Xm2qgB5jEpBghiKVnVYlHQMn7FWiYhajrsBW9rCEgGj6DFCDH4uwqdIAVJEd1qE0MUmXl4hnsvWqeK1wIcq4C4e%2B4ivBrcdZlAREbFlZU9J9bvuZmp3IbYiRgxPhlXElQLvH7zUR1VxQVXQVQwnqnqsNPFkCiIihpUjNboL8TOsDSIi%2B%2BNuQCIiYlgRERExrIiIiGFFRETEsCIiImJYERERw4qIiIhhRUREHR1%2FFNxCqul%2Bt%2B0HDj6Sml6yMO1k6cDi0lr3c8XVytVe7%2B%2Frbvb2dLsQ4Oe%2BT955WN7Q0d7TGBEKlXPKtpKOQ2Et0I283WBY3UB2b4p44NFXd8amZ5d5T5t4M%2B5a2htB3b3Q3d%2Fjqu8pLKo2FBRWBiSYCmNy80%2FNmD7ByyRv6Jhk56utm%2F79FmeYjUT%2B5F5WAnWI7UZ7oHfGSHt0w3PfncdKl%2F9WpD6nC%2FMr2rpu0%2FEnpkzoZXzhd%2BGIGtkNgd084e117ZyXz8vXjbolAHdP66ezquiVfLzk%2Fu4ByuEzhWqmver1%2FntncCthI2%2B8%2FX9anbaX5ZW43biRt988ZnUNW9fu2PLWlozZL68YhYUzg2F0a1t1yffJ969%2FPsrDy6h8HBkGfmUn4naD2w2GlW2a8Bvj0mfHPh2JYYN8bVKmLOe1lVF6g0G3cSQDi4jbDW43GFbX1Yw33e8Wv%2Bd07ALxrcZWC1zjBW%2F%2BjP6KAcrr4pvSVNY2Ebcb3G64dli57FlW8qANVOcAACAASURBVOydzNxy77nT%2Btml%2FCXzBsFo1BmsKrZEDEUwV3Oi9q%2BDbDectt12WliN6QUPV13oUjNKFkWP79nmfc3NkeWOvqWbnOsGWLCGqzlR%2B9cRthvO3G47LayqfBDoqgtdWlZZ8NhI%2B07e5HE9ZM9TdGPlnYe5qhO1bx1hu%2BHM7bbTwkqvYIirLnRFxTUePYO87DqOsAFdLzWqC3VWxHBVJ2rfOsJ2w5nbbecds1Iw0VUXuuKyGsW%2Fi3ur3nO%2BuAanv6vEhbK6Fr2%2BV%2BDlhdpHdJMc%2FRnPfFeMulqzzcstOFuC2joziDqalm43VBXatkJ2tbXWVo3D2dsNZ263nRdWKuZP6Ouax62sFhU6fcuPI2bkViBixh789Bf%2F0hbAFlV8Q%2FliwfUTvd6O%2FoxTY55HetYZm5cb88tVOHw0i1su6nBaut1QxEv%2B9HYGwqfvwW%2F%2FcLR1G2wnbje07bXYbne8sAKSyz3x%2BI2wkD7y%2FFFUVluw5qnhGDaoSyu%2FqGjfkAK5qhN1HLG%2FH47hg7tg66487P7P2TY0cBy%2F3WjYXic7q86cdm1AvYplFgUHwwfjm8MnEN9eF7p%2FJZ7H198WI2qEH%2B6a3KPN1eGMaf%2BuoARbdiQgO%2FcsoieF4xdzxl9%2BLuFAKt7f%2Fm9UVtXgzp%2Fegvmzx4lvhPXf6k7lncffNv0TmdnfYeTw%2Fnjg3mh06uTZ6vFX19Tizc1f4ODX6fDz9cE9v7gDI4b3Q86pQnz48UEsXjQJnXzqy931zyTodAqi7wzHzk8OISjQF4e%2BTkNiUgZG3tIfDy35GdyNbtpniv%2FchFnTo%2FB%2F4nXSvQvu5NaRXIpetJBe%2FN1QTLvvP3hlYwYm3R7o0tsNsZ2eJnqPie12lNhup3WollXiCaRbFcwR27%2FNEaFYMWAA3NvjQvfpvgKtP39673Y37f%2B7eit69fDHnRNuwapXPsCH8Qe1%2F%2B%2F9VzIeeuJvmHzHCPxy7k%2Fx3pZ9WLNup%2FZcUUk5Zsz7A7p164yHRUDIY1TzFr8Mq7X1F3y%2F98F1yD11Tguan9wWhgVL%2FoTcvHPoc3M3HE3JwZPPvKO9znQkE%2F%2Fzh39g%2BJC%2B2uOd8Yew5OG%2FoM5swc%2BnjsJnXxzRPoskj8XFvvoB5ixcjaycszhfVM4tI7mkW8UX3P69vZF0rAQF56tdchrldllun%2BV2Wm6v5Xa7w7WspCOp2DN6MKLMCtZ3ccOD4aF4Hyr26q1I7ZuO3G2AxdUXuG%2FTSrX%2BqOG%2B7W5l%2BcsrSzBkcH3IlldUY%2FvO%2FZg5LQpvbPocjzzwc8z4r1u1524K7CoC6kX89oHp2mtkaDy8ZFr9Chc5CKMnPi5aR2m47dbBLR530pGTyMsvwnt%2Fe0xrsY2OGIiEg8fx2e7DWHLPFKxdtRjRs1Zi3euf4P1t%2F8Jra%2B5Hj5v8Lr%2F%2FiUfuwoK7J2jD%2FfoG4p7frMMLK36hPfZwN%2BL%2F%2FvF0m1p7RI40apgvsk5dREpaGYICnH8If45oreWEoI9FhzB5MoUCzBNfQ1MMokWVdNx5QeX0sLrUwhK9SfI3AzoVs8Tww1Y9BmaFok8EXP9eQiUXarW%2Bv%2B%2F1NQydfS%2Bq4H5BomV1QBuWLZJBA7%2FfpRkyoCcuVtbg7LkLDc%2F1%2FL5prlMwMLiH%2BH9Bq8Iq%2FeQZ5J8pxpg7f3%2FF%2FwcNqC%2B7c2cvrH95Cabd%2FYIWnGNGDbqyAOX7RaN%2F3yCUll7UdllKnl5GmwcV7xVG9hDgV7%2FdKC6tdYnlMgtaebli7coQW98DojUVfeQYjrpCXbnM%2FawaKuRoK5L%2BQXs1SVuzAPj41FdhVbUFvp3d2jxOW9zk73oW3IqKKnTt7K0Nd%2FLxQFl51eXnysWwbP34eHtoXVn5lWc8ysc%2BPq0LB1mODMRd25%2B56mu2f7Qfw8L6YOfHB7FUtLZkgDWluLgcXp7u8PQw2m355E0Yb2yjByNE7uERM3moWInatIenLetfZWV90d6eBi6XzXD5C9nKBeXrdGTJkzAOH8djpXXoK%2BbOPnlyxsgw3OHs6evbs34Dn5Je2u5mfnVV%2FW%2FC5IkO%2F9j%2BL0y5Y6T2eOK44drJFRZL%2FW9ANm%2F5EuEj%2BqNLF2%2FcMX44Pv%2FiCM4VlWnPfZOcjYzMM7g9KrRV45avl620%2BM%2B%2Bvvw%2FeWLFt8dytOEdHx3Qdi3ufH85RkUOxMO%2F3whV%2FX5bUFZWH5hmsxV%2FefNT%2FNfkiMsngBC1htyOyO2J3K7I7Yvczsjtjdzu2PtQxKXtRv%2BbvTgj2kvLqqUyMyH39bwgzyIUSbtNHvNy5kG%2FiWO64cN%2F5mPHp%2FmYPLZ9nYH%2B0BNvaLvTSkorMGHs0MtnzT36m%2BlY8shfcPvkp7Sz8apr6vDOhoe15%2BSuvgVzJ2DCz%2F4bA%2Fv3QFZ2Ada8cA%2B6%2BXdu1bjl2X9vvrYMj694G8%2B8%2BD6MbgbU1NZh7ar7cDztNFa%2BFIcdf39KO%2F704jO%2FxNSYlXjtjV3ayRhagL7%2FJd589wvRoq3F0NDeeP1PD3Btpja1qCwqtonvQQsdfVZybn4lTCkl6NHdA4ODO3Nm3GhhdYlcsESz%2BxXxjeg18XCys6Zj5uSe%2BMP6E%2Fh473d4NLMMoQPax0J3dP%2BftX7%2BmSK4GQ3oHvD978O8vdzx97%2F9FoXnS1FbY0avnv5XvPd3y2bg%2FkWTcaHsIrp366KdMn7Jf%2F75x1a1rg58sVo73dzgpr8i8L498OoV0%2FOvT1%2B84r3LRGjJk0EuVlZfMe0RI4NxaE8s12xqkYbtxyvO%2BPlM7N%2FStKtZLJ0fDO4UuIHDSupUhTXlnnhQnpzhrIOA7kYdXnxctEqeMuE3zx7BR2%2Fcjk7e7adae%2Fbwv%2BpzjUPgR3XfyfOaJzGsfvVD7TdQTZEnZWzd9MTlxzcFte1MShlisiNqC%2B1CsFYME9uR6Y4et9wbI38QHDawM%2B6d05cz40YPq69yUB0Rhn80XNDRZmElL2nSmksu%2FfyOm7B5zSiUltch77vKFrWuKi7W3dAL1pOPzLRb2YsX3nnFaexEbVrP5XZDwT%2FkdsSR2w3ZmpI%2FS1z7zAjcFu6vfeFtqRt9u3HDhlX9nMdeMd8ftWWRXTsZzUWlNYZufi3%2F3cPU8UGtGkdGThm3Fm00dkwYK4FssOnAGEXFnx293ZC7%2FGKm9GzTODrydqPd39ZefJE5JuZ9iC3L7OTtdiG%2FoNKu05149Hz9gqtCXmLBwk0HkWPJ7YbcfnC7wbByCM8KyKtAdrNlmf6%2B7vsSTGftOt27E%2BqveK4qKBS9s9x0EDlct4btB7cbDCv7O5Cn7W%2B26XVKMk9VvfTJ3jxzbZ3VLtOcnVeOnLyKS3NA3k%2FjFLcbRA7n0bD94HaDYeUQKmx8WaYvD1UmGd10prj4bLtM8FOrkhpP%2FUX5hYnbDSKHUxq2H9xuMKzar%2FzzlQs2xqVXJ6eV2LTc1W%2Bk4GRu%2BaUFLkt0EVYddrDGibjd4HaDYdVqSWLZqK1TY5Y9e9BiqwVPLnBbG3%2FrUpAgvtp97SoXiiQibjcYVu3QoWTLrooq831Llu9X120%2Bjrbui5b7mu9%2B6KsrFzgV74m%2FU1Q9nmRNE3G7we3GtRm4aF3b4VS8HRlq1b274%2BSGuI%2ByDVEjAhA9vhdCgjujTw%2BfJt9TWW1GWlYZEr85hy8SzoiFruLKF8gFTl5BXsE9JvFNjLVMxO0GtxsMq%2BtmOo43w4eo%2BZZay7Z9iWf1omvbzZLkvmbRhBdD0aoOi5KO4TNbT2vkT%2B7lDCPiduOGw92ALf2mJBYQRY8RYvBzsfAUKUCK6E6LhejiNd5WIV6TrVPFe4APVcBdPPYRXxFuO2yHBU7e24b3XSLidoMtqw4uqb7pPVO7q3H99QgnwyoWOwXeV3mLj6rigqqgqxhOVPVYaeLJFETcbnC7wbByhEZ3NX7GJVcOtq6IuN24wXA3IBERMayIiIgYVkRExLAiIiJiWBERETGsiIiIYUVERMSwIiKijo4%2FCm5CRKjtbsh2o7P3D5BV0%2F1u2w8cfCQ1vWRh2snSgcWlte7niquvOk5%2FX3ezt6fbhQA%2F933yzq3yhnhcXtrP%2FCZiWLWS6d9vsRKaYe%2BL5u7eFPHAo6%2FujE3PLvOeNvFm3LW0N4K6e6G7v8dV31NYVG0oKKwMSDAVxuTmn5oxfYKXSd4QL8nOV6nuCMsLL5JMDCtq961QW37jVtXndFvX7tiyekPK7AWzgrF6%2BSgY3Vq2x1oGmeyGh%2Fph8dwQQ1x8dtTGuPSUyGHqLFOy5VPOMdeb30QtwWNW5HJkUL21JWP2yytGYeHM4BYH1Q%2FJ98n3r38%2BysPLqHwcGQY2DYgYVkTXT%2B76Ey2h2bFPR2LYIF%2BblCnLeW1llN5g0G0cycAiYlgRXQ95MkX8ntOxC0RryFZB1Tiw5s%2ForxigvC5aWFNZ20QMK2fhPvR2Tp71l5lb7j13Wj%2B7lL9k3iAYjTqDVcWWiKEIZo13aNxeMKycY0wveHB2tm%2BpGSWLosf3bPMxqubIckff0k1upQywYA1rvOPi9oJh5TRVPgjk7Gzf0rLKgsdG2nc2Th7XQ%2FY8RTdW3rmVtd4xcXvBsHIavYIhnJ3tW1FxjUfPIC%2B7jiNsQNf6AQWFDbcYpw6I2wuGlfMomMjZ2b79%2F%2FbOAyyKo43j%2F7uj92oBVFREsSJYsEWDitixJcaQaLArltgS002M%2BWL0Uz81GluixohRo7HEFo0aY0GwgShgQFRURKR37u6bmYMTjCgQODh4f8%2Bzt3u7s7Ozs7Pvf9%2BZ2dknKdkSa3P9Uu3z%2BEk27j7IQFJKbonCO9RWi6EJm3pTrtdQyF5oHdXnpWAlRvVwxIcnbyNLk4ed9cEm3Ln3WCzbWJuiWRMHDB3UCfUdbNRhNmw5hsO%2FX%2F7Hvsu%2B8kM9exuMGL0YymcG7Onb2w3WVqb4cccp1YXSkSJg0xxkZefAd%2FxymJsZ4bvlU8R6zp4D5xH3KAmT%2FLyRlp6FMZP%2F94%2FjdWzXBHOnD8HufeewfdefYp2RoR4a1KsFL09XdOvcvFIvoUKuhFRW8nbvyJg09PI9DV1dKfas6QQLM%2FOXP53lx8%2Fy20qi4fIfHROHuR9vVv9f8MFItGhWHx9%2B8SPCI%2B%2BLdVaWJnB2ssPQgR5o5FhHHXbbzlPYs%2F%2FCP%2BJc9ImvCP%2FWhOWQK%2BSiTJiaGIptJ8%2BE4uyFm%2FDz7Qn%2FueuLTVdBOmoKzE4YpDJ7QeafxKqyCEk1xBw2X6jJg14NjUZ%2Fr3bo1KEpHj1Oxu9%2FXEXvwZ9g5TcThAAUGCkLcyOMfatXkX1trM3E%2FFxgOJYt8oODvbV6W53alrCxMkNqaia%2B%2B%2F6IECqOnBn0c4E30czZHgG7T8P39R5ifez9J4i5%2B0gs5%2BXKRZgNK%2F3FcQuwsjTND5sApUKBOdN9kJ6RjUtXozBt7jr0erUNlix8R2su%2BIzPryIjS471H7uiVVPzUu0rUXlWhppMr0Ndayz86E30HPQxDuz4CE6N6qoKblgMOro7w%2FOVVkh4korjp66hz5AFWPLlGAzu11GEuXM3Hvp6OvCf0K9InHXrqLr4X7wUCXs7K1FW5kzzUXmdj1NwI%2FweLCyMMdt%2FkKps5Ckw0m8JVi2ZgDq1VFWi9exsapTRy7cTIfw2IwkgsdI4MiX85RKcd2uGK5du4oAmj920iT0Tq2ZimRuXA4cvYvq89fjr2H9gnS8QXHwKwjyPNq0aiifkZ%2BHela6urIiQcd6bOQzzF2zFcJ%2FOMNDXe26c7dycYJsviM%2BLtyA9vXq0wTvs6dt76ALs3PMXRgzpUuWv9%2BnAx7h47Qk8XK3g42VX5mKjyTTrMrHhglIgMvp6uuptXLgKrscA7%2FYY2LcDJkxfjfZtm8CurmofW1vzF5Yh7jXPnL8RY970FA86BfDyUbBfbk6emLu1aSQ86poGsw8DeIUIsxcezF6EkwRoD9WmzYo5EhEKCUZIJNji7oKPnJygX1lp4caGG5gjhar%2BHsYlCm%2Bn8JSZlfPUQwuJVq%2B%2FEBzx0mPwKrvGDetg09bjxYYJunSryPHCI2OLDctF7e2RPbBr3zmtuN6HTj0U81GDqmf1FfeyXJrVw8EjQep18fHJ%2FyhDqWmZ6u3NnB3Qx7MtVq49SJbtGbg94HaB2wduJ7i9oFwhz6rSuByG4%2BwB0iNPgtXmupjq5oLtUOKETIEwxwjE7ATkmkpLg3q2uHc%2F4WnarkVj6ap9RcIUtFlxfth%2BAoYG%2BvlPwrrouN75pcf4YNZw%2BE5cBt%2FXuj93%2B9pNh5lX9vQSizarJkOKjc%2BxQS38zDwrbeBaeLKYt29tWW1vTsdnylDYzbv%2FKEO8zcrU6Wlt5uxpPqIaevxorxpt2EYwr%2Fm2MxrIpWjOO1NIgDeUQKgO86iCb5BQkVhVEQ%2BLzXrzd2ikSgxly9MVMjSJckEDdw2%2BtZ6UnA5LCxP1f95hgrdXFMeyRWOfWw34IlxbN0Sn9k2xZuNhGBv%2F8x3HDav8i60GfB6JiSzNliZlOl9Nf9MpMUnllVpb%2FjsHuip%2Fi4qXocYN66r%2Fd%2B%2FWEsu%2FGvvCfXjHHl6Nu3TVXnTp6FJhaavq3%2FCKgkhfDLvhI9ldf455U96Xr%2BMqmXwSq6rnZakK5tXKuBF5h4orzJNa9hLDUh7MmzEUA19fiNf%2BZTuTUqkUPQoLOoWUlvL4ZERp8t3ERFV0M7PksDTTLfMxNZ3uknL%2FwRPR8Wb%2B7OGl3nfG5IHo5j1f3YGnIqBPhBCahgayLUdSUjJw8GgwXn9nCaZO6AfH%2BhXfgN2kcV3083JXd0UvLbzn4JWQaLwzZSUyM3MwYYx2VB852huLeWhEcrUqQ7z359ETV8TrDL4je6B503qljoN7036%2BvfDDthN0UxLkWRFPmTDjW9XTvrGBaOSeP2sYhgzwKBLm%2Bx%2BPi6kwJ%2FZ%2FIXoSFsePO07imxV7kZSaji5e7%2BOvo%2F95brjZ%2FoOx98A%2F38Fx7TKzyH8uauv%2FN1Usc1G1b%2BYHqVQiOmr0ftVVdGcurmdhVcOzky32HI3F7kOx8OqqHSPn8A4ub01cLpYHjvwS3y2bDDdX1Xi6%2FH09PhkZ6qOpsz2mTeyPkcO6Fdmf99Tc%2BUyb4v6AD9VxFGaynze2BPxBNydRbagUV55Xm5RnNUJFxEeftX85hT9zXl7VaUH7BpYobHaOAu0GH0dCUg6Ob%2B0GF6eSV3m1G7S%2F%2FNNdwz5rXx2qAcvbbtQUKivfqBqQ0Er09aRYNKclcvMUmPLpZaSm51GmEEQ1hqoBiSoDHwqpNEMuDexZF1uWtEdyai7uPcgokXeVlp5LGU0QJFYEUXYsTPXyEpKzdWytSv6pob7dSzdiTuTtFMpogtDGh1nKAqKqYGqsmxT7MKNCjxF4VTXosESJVGjwJXGCIEisiGqCtaX%2BqTNBcRV6jGNnVKObKyXgo%2F7GUa4TBIkVQZSKW3cyvzp44l5eTq6iQuKPvpeK2%2FfSCkp%2BFPu9Q7lOECRWBFEq%2FriQEaynKw0KOBBdIfG%2F%2F3Xw0z9KpHNHi3KdIEisCKLUxD7O8N0QEJEVEp5YrvEuXheKv2NSC4Qqik3uCil2U44TBIkVQZSaYKYpObnKYf6fnpeXl2Bxofq5sLcmwRkJcJEGNiUIEiuCKDMXQuS%2FpWXmjZ84%2F6xy5ZYbKGsbFm%2Bjen3ayaJCpcQ29ttHKcM8ymmC0B7oPSuiSnIpDN%2B3c1FIt%2B7%2Be23AvmgdD1cbeHd3gHNjMzSwe%2F5nTDKy8hAelYLAK%2FH4%2Fcx9JlZpRQNwoeLfNpLgnSDmwVEuEwSJldZTeBw0onIIuoGNbi2UsfIc%2Bc5TgXEyNhmWKSLeRiXBGbbkrZRidPB1HKbyQhDaBVUDPgc%2BSCMNcFlFPCwmLBIZ%2BEe2jjDRSWAXJZRNd9nVSX%2FBbmksTLRUyfYB9igBffbfhD2adb5UAUJF5YUgyLMiCNHpgs2GiK8%2FKzCMLXtBwcRBAuNidjFRKpGklMCCLQcqZVgQRJ0pCILEqjp7WJQLVYdCX3%2F%2BhMoLQdQsqBqQIAiCILEiCIIgCBIrgiAIgsSKIAiCIEisCIIgCILEiiAIgiCxIgiCIAgSK4IgCKKmQy8FPwd3FyhryrlW9IusyqAJurvOnZ8RFpH4dvjfyU2eJOfoxz%2FJKvaY1pb6ecaGukk2Vvqn%2BJeD%2BQcZ6XoTmiqvBImV1hH056Zqf44VPfjqsR%2FcJ89csfebiOgU4wGe9eAzqT7q1DJCLWuDYvd5lJCl8%2FBRhs2ZoEfDYmLvDB7UwyiIf5AxuIJHSa8J15vKK0FiRWi9F1meT6xK5WfSn%2F%2B3e8fitaHDfYc2xuL57aGnW7IaZy5kfGrtYoVxI511Ag5Ee2wIiAht10o5NChEfoiuGJVX8rBqJtRmRZQ7XKg27YgcvvSj9nh7SOMSC9Wz8P34%2Fqs%2F9zAw0pPsb9cc9GhNECRWBPHv4VV%2FzBMa%2Fs0H7dCqqWW5xMnjWbXAQ6ajI93QlgSLIEisCOLfwDtTHDh%2B9xtf5g2Vl1AVFqxRgxtJdCD5jnlYfSm3CYLESivtJJuoDruS4b3%2BbsWkGo8c0LBC4p%2F4RlPo6Ul1FErscG%2BJxpTjxL9Akm83CBIrjZLVyQEGdDkrl7DIxNHe3e3L3Eb1Mni8HdrYciujAzmWUI4TZSXfXmRRTpBYaZr4TBPUpstZuYRHpTTu2q5iL4PXK3Z8ZsimrvzLwZTrRFnItxfxlBMkVhqF%2BfIRMgla0OWsXBKeZBvY1zGq0GM0d7JQLUjwKP8T9wRRari94HaDcoLESqNIgHPsx5MuZ%2BXyJCVbYm2uX6p9Hj%2FJxt0HGUhKyS1ReIfaajE0YVNvynWijEbDU9gNQmuoFi8FK6TYzZ6yD%2FdwxIcnb2uuHjo6Jg5zP96s%2Fr%2Fgg5Fo0aw%2BPvziR4RH3hfrrCxN4Oxkh6EDPdDIsY467Ladp7Bn%2F4V%2FxLnoE18R%2Fq0JyyFXyPHd8ikwNTEU206eCcXZCzfh59sT%2FnPXF5uugnRo%2FDrIlZDKSt7PJTImDb18T0NXV4o9azrBwsz85U9X%2BfErlbCS0EvtRBlgdsIgVYlRzG54U26QWGmUy9dx1d0FIamGmMP%2BLtTUcR3qWmPhR2%2Bi56CPcWDHR3BqVFesDwmLQUd3Z3i%2B0goJT1Jx%2FNQ19BmyAEu%2BHIPB%2FTqKMHfuxkNfTwf%2BE%2FoVibNuHVWX74uXImFvZ4Xvvj%2BCOdN8VF7I4xTcCL8HCwtjzPYfJNbl5Skw0m8JVi2ZgDq1VFVk9exstOK6zfj8KjKy5Fj%2FsStaNTUv1b4SlWdlSLcwUVry7UQItxuUGyRWGkemhL9cgvNuzXDl0k0c0MQxdZnYcEEpEBl9PV31Ni5cnTo0E8sDvNtjYN8OmDB9Ndq3bQK7uqp9bG3N1WGex9zpQzBz%2FkaMedMTNlZm6vUG%2Bnrq%2FXJz8sTcrU0jNKhXS2uu1%2BnAx7h47Qk8XK3g42VX5suu6XRfDb2N7btO40liGhzsrDFqxCvqh5Ttu%2F7E0ROXYWigj5HDuuKVLqpm1CvXonE39jErA%2B3F%2F5zcPKz67iCmTegvytBPO0%2Bjg3sT3LkXL8L6DOgovPDDv19i8V1BLgvfsX1TjPDpLMrYteu3sTXgJGIfJKCDmzMmje0jysTLOHTsEizMjRDGHnhO%2FhkCx%2Fq1WRnzgZmZqmp1JUtT1O2HSE7JQMMGtTFhjBdq5z8Abf7pBNxcG%2BPgkSBcv3EHfXq2xdBBnbBxy%2B84fzEczZwdMHeGjzodj%2BKTsX7zUZbWGDg3tsMkvz7sXrGu9HLH7MMANpvF7IUHmX%2Ftotq8FBx4ExEKCUZIJNjCvKyPnJygX5XSx70sl2b1xM1eQDy7oc%2BxhBeeUtMy1du5Aejj2RYr1x6sdgXv0KmHYj5qUH2tSXPs%2FQS8MXYp3Ns0ZmLUDebMyJ8%2Be11s%2B%2B%2BqX4VBf2vkq%2FDu1RYz3t8gPGrh%2BV%2BLwv5Dgep4srNzsZSFz8mTi%2F8%2FMfHzHb%2BM7f8HUtOzkMW2c4964Tc7Rbnp9WobHGZCE307DpevRmGs%2Fyp07eSCmZMHIezmHbz3yZYSpZ%2BL3ztTVzIhScIg9vB0JTQaXy7Zqd6ekJiKbp1bYMwoT7H89sTl6m0%2FsHMbN22VqJLu%2FaqrSFvvwZ8iKTkdg%2Ft3xO8nr2LtxiMibAoTO583FsHayhSz%2FQfDxtoUI95ejLxceaVdO24PuF3g9oHbCW4vyPyTZ1VpXA7DceZweORJsNpcF1PdXLAdSpyQKRDmGIEYdlvKKzN9jvVscY8ZvALCbt5lRmtfkTC8zcrU6Wnt1uxpPswofILxo72qVcG7Fp4s5u1bW2pNmm9FPRRVt9yr4N4IFxKOXK7Auh%2BOYtfW99DSRSW%2B3DtZs%2FEwenZvXaK4p4zri7ffeFUd37C3vsbW72aiXVsnsY5XHysUSoxn3vmsqYPV1ckNHWujQ485WPqlH3R0Xv7sOXVcP0yb2F8sGxkbYNnqp%2BXvs%2FdHIpmJDz9PLyZIO%2Ff8heycXHWNweIFY9C9q8pb%2FOvCTbiwh6mZUwaqzpftx9dxdrD92rk5MW9K1STEvcY9B84j%2BNrfonpcE4xgXvdtZzSQS9E8vzPFG0ogVId5VME3SKhIrKqIh8Vmvfk7OFIlhrLl6QoZmkS5oIF7JY9ywZ9CGzesq%2F7fvVtLLP9q7Av3qe9ggxFDujBR24suHV0qLG2a%2FqZTYlKOmFtb6mtNujt1bIrWLRzh2vVdtGheH690bi4McjrzhrhHzDvGFNC0ib3ogFNSatk%2BbbPjVWjcO2nd0rFoNYhUgvDIWFy68jdWrNmvXs%2Br6rKyc2Ci8%2FL34mWyp4JmxrwkuVz1%2FJaZlYPp89bjSkg02rDjGhroqYXz6b5Pbx8TJnSSQneTSaG4Im%2FdxzHmaXn0nFfk2NlZuRorr1Gq0SliWBIj2V1%2FjnlT3tRGRWJVNb0sVcG8WhE3Qlm4%2F%2BAJzgWGY%2F7s4aXed8bkgejmPR821mYVll%2Fl8cmF0uSbiYlOvpGUw9JMVyvSraerg81rBXRIFgAADTNJREFUZyDuURKCmWCs2XRYLH%2FKPBIJs9xcsKwtTUVYvswNegG5eSV36o2N9EV8%2FOGmlk3Rjie8Gu79d4eKdtB%2FS2Gx%2BfmXM7j%2FkJXRo19DR1cm0v%2FL%2FvMl2vfZ%2F8YmBqL365cf%2B1bp8kpoFzSQbQWTmpopGslHjF4M35E90LxpvVLHYctEys%2B3F37YdqLa5IujvbGYh0Yka02aeS%2FPmxGxwpPp5%2BUu2hN5RwsuIO3dnPBjwEm1N7Lt51PwzK8C5F5TWPhdZGRmi6q8vQcuvPA4vIqRx8erEdU1BsGReBiXKKogv91wCElJ6WI97w168Oi%2F%2F5hyTq5ciLFEqtIAXmbLCm%2Bz28PO8QY752fTTxDkWVUCvErmrfxG6IEjv8R3yyaLHlOcWR9sEpORoT6aOtuLdgLeKF8Y3ibAp8LsD%2FhQHUdhJvt5Y0vAH9Um7zw72WLP0VjsPhQLr67aMVIWF5uJ05cJMeHVZOkZ2diwcqrY9t9Ffhg9aQX2Hw5CenqmaEvinQs4PXu0xur1v8G9%2B2zoymToy4TuZSz%2FehwmzViDtl3fFZ4O72X38w9z4T%2B%2BHx4%2BSoRHr3mwsjBBYko62rk6oX8J4nwRIwZ3RsDu0%2BrjdfUoe5Uzb5d6f%2BZQDGcPaOYmRiLf%2BOsWP22YTUaDKHtNQGUclFe7VGU3nqevpn3Wvryq04L2DSxR2OwcBdoNPo6EpBwc39oNLk4lr%2BJsN2h%2F%2Bae7FNf7XmyCaD8qeAXh2W16%2Bjr%2FqL5TKpWicw1vJzI3Ny7xseITUkQVW%2BFXFzi8jekx22ZrY1aibuslgXt9vDu8uamRujt7ecRX2nPWVHkltMt%2Bk2dFVAr6elIsmtMSfu8HYcqnl7FvXReYGmtHcXSwty71Nt4GVc%2B%2B9C9r2xbTTsk9u8Lx8dFNVq37rdh45r87DO5tX%2FxVFS7AZUmjpuIjajYkVkT5GSeZpFRDLg3sWRdblrRHcmou7j3IKJF3lZaeSxn9HHp0bSkmgiCxIoiXYGGql5eQnK1ja1XyT4v17V6nVMeIvJ1CGU0QNfFhmLKAKC9MjXWTYh9mVOgxAq8%2BFnOJEqmo5Je8CYIgsSK0EGtL%2FVNnguIq9BjHzqhGs1dK8IjN4ijXCYLEiiBKxa07mV8dPHEvLydXUSHxR99Lxe17aQUlN4r93qFcJwgSK4IoFX9cyAjW05UGBRyIrpD43%2F%2B60MuvSvC3Yo9RrhMEiRVBlJrYxxm%2BGwIiskLCy3e0gsXrQvF3TGqBUEWxyZ1%2FdJNynCBIrAii1AQzTcnJVQ7z%2F%2FS8vLwEiwvVz4W9NQnOSICLNDApQZBYEUSZuRAi%2Fy0tM2%2F8xPlnlSu33EBZ27B4G9Xr004WFSoltrHfPkoZ5lFOE0TNgd6zIiqES2H4vp2LQrp1999rA%2FZF63i42sC7uwOcG5uhgZ3Jc%2FfJyMpDeFQKAq%2FE4%2Fcz95lYpRUNwIWKf5tIgneCmAdHuUwQJFY1nsLjkBFlI%2BgGNrq1UMbKc%2BQ7TwXGydhkWKaIeBuVBGfYkrdSitHB13GYrjdB1CyoGvA58EEaaaDMcvKwmLBIZHBli0eY6CSwTA1l012Wu%2Bkv2C2NhYmWKsG%2Fk75HCeiz%2Fybs0arzpQoQKrreBEGeFUGIThdsNkR8vVmBYWzZCwomDhIUNxS3iVKJJKUEFmw5UCnDgiDqTEEQhKbR9CfUCYIgCO2231QNSBAEQVR5SKwIgiAIEiuCIAiCILEiCIIgSKwIgiAIgsSKIAiCIEisCIIgCBIrgiAIgqhgqsUIFvSScfWBhj0iCKLaihUn6M9NdDW1HBpMliCI4qBqQKLKecnkKRMEQWJFEARBkFgRBEEQBIkVQRAEQWKlIXibBPX6IgiC0C4k%2Bfa7xohVVicHGNB1JwiC0B7y7XZWTRKr%2BEwT1KZLTxAEoT3k2%2B34GiNWzIeMkEnQgi49QRCE9sDtNrffNUasJMA59uNJl54gCEKLYHZb2O%2BaIlYKKXYz92pUD0fNt1u9MXYprl2%2FXaKwO%2Ff8hazsnCpZZh7FJ%2BPw75fo5iEIQiMIe83strDfNUWsLl%2FHVTYLSTXEHE0fe9igTqhta%2FHScEqlEjPnb0RKSmaVLDgRt2Lx9fJf6A4iCEIj5NvrkHz7rXEqbWxAmRL%2BcgnOuzXDlUs3cUBTx014kgqJRNVr%2FsjxyzA1MUR4ZCxOnA5Bg%2Fq2mDvNB%2Bbmxti596wIs3bTYZgYG8C7txuaN6330vgPHbuEY39cQW5uHjq2b4oRPp2hr6eLsxdu4qedp5GWnoVePVrjzde6i3QkJ6dj8%2FY%2F4OXZFus3H0X842S8NbIHer%2FqqiogqZlYx9bzNFqYGeOVLs3Rv0877Pz1LBISUvHfVb%2BKcOPHeIlzeRHZObnYtPU4zgXehLmZEcaM6gn3to0Rcy8eu9n5jh%2FN4jBVxcG9NoVCiX5e7tj3WyBsbc1x8VIkLlyMgGvrhpg2sT8M9PUQ9ygJvx68gOE%2BXcRcrlBg3Nu96c4miGoEs9MD2GwWs9selZWGSnspmNnLCIUEI5i93uLugo%2BcnKCvieNy8Xn4KFEtVn5TV%2BL%2BwycY1Lc9Qq7H4ItvfhbbbG3MxNyurhXq2dvA2OjlyVuz8TAWLd0Fz1daoWePNjh0NBi3Yx7hz7NhmDJrLVvXGqNHvYqAX87gP8tUnnRSSjoWr9iDDxZsRds2jdDerQnGz%2FgWsfcTxPYps9fi%2FoMneOdNTyESXAxF%2BqzNoKMrE2njk46O7KXpG%2Be%2FGreiHsB%2FQn%2F06NYKY6asQHRMHBo42CIs%2FC5mf6gaDPjKtWh88PmPaN3CUfzfdygQE6avRnZ2Lgb164BjJ67is68CxLYHcYki%2FSNGf41b0Q%2BEgBIEUT3gdpnbZ26nub3mdruy0lKpo65fDsPxDs3gkSfBanNdTHVzwXYocUKmQJhjBGJ2AvKKTsMkP2%2FMnDJQLHOvghteTo%2BuLcV8UN8OqMW8ipeRl6fAirX78dP6WXBzbSzW%2BfTvKLyThUwApzKBGDJA9VDiYGeDvsMWYDbz4jh6ujrY%2FeN7ao9v78HzuMaE097OGqE37uDzIV3RiWUUn0aNeEWdvuOnrmHEkC4lOs8rIdH4O%2FohNq%2BdAalUgg7uTXD%2BYjh%2BY4I6dXw%2FLFs0Fn2Hf44Va%2FZjxy9%2FYeXi8XCwt1bvP9vfB2PeVPWJcWpYF6PGLcWiT94S%2F%2FUNdLHnx%2FkwY94aQRDaywhAdtsZDeRSNM%2FvTPGGEgjVYR5V8I3KE6pKF6sCD4vNerdtgTZSJYay5ekKGZpEuaCBuwZGuZDKnh6CV43l5pZNH%2BOYt8ar7Aq8EXX8TBj%2Bjo4TVWwFNGlcFzm5eXjAPDoOF6kCoeKYmRpBLlelgwvarA82CRF1c20EP99eaNPSsdTpi7x1X1TZde79XpH19ZlXVSDUa5ZNgvfQBczz6ocuHi5FwhVKHho51hbVmenpqncDeXVgeQsVjbxOEJonSjU6RQy73SOZ9T3HvCnvymqjqnJipfayVBlSpkypCoaNt2txwUlKTYeNlVmRbaYmBkhNe9pRgxt6uVwBY7ZPgcEvDt%2FXuotOIbyK8rdjwXh9zDe4fGaZ2MY7gZQUfqzGDevg6N7Pig2z%2B9ezaNW8AX49GIjJfn1hYWH83HCJyWlCoIyMKq7mlj7CSBBEkQd%2FyoLnw4WHewu8jack8E4Z7do64dv1h9TrLgRHCG%2FGs3trbN%2F1p6gq5GwNOCm8o2dF7bkCsu%2BcqCbk1XZTxvZFekYWsrNyRdoesrjTM7JLlL4uHZvhTmw89h68oF4Xc%2FcRrobeFsu%2F%2FnYBJ8%2BE4pdt7wuvatq8daIKs4Dk1Awx5yK7mp1jn55tIZNR8SEIooZ5VlWRiWP6YMzkFbC0NMHcaUMw3KfzC8Ov%2BHosJs5Yg7Zd34VMRwpDA33s3DwX0ycNYOu%2FRZc%2B78Hc1FgIzg9rZpQoDZu3n8DHX%2F4E58Z2iL4dh0%2FmvS48Hi5WbVo2RMeecyGTSHH4l09Rt47lC8X0%2B2%2BnY%2Fb8Tfj86x1CAHmHiWX%2FGSt6Gn70xTaW1vdgZKiPhR%2B%2FiX757VfvTh0k9t%2F28yls%2FukPZGbliF6R61ZMoQJCEITmHIjqcBK8GrCiPmuflJSOnLw81LIxL%2FE%2Bjx4nC6%2FD2tK0yPr4hBRkMWPPe%2B%2BVhsTENKQxgeM9FHn1W2G458YFpqDLeUl4GJcIKUtfSc9p3LRV6NapuejMwaswS5MXpaHwZ%2B2pGpAgCPKsSkFBu83RE1ew7oejxYb75L3X1J0rijPmvLt5WeCeHZ%2BeR%2B1aqhecl676FecCw4uNY9eWeerlOrUty5QOLop8IgiCILGqonh5uoqpqjLbf3CFxc17IJak%2Bz5BEASJFVFpdO7YjDKBIIhKhbpzEQRBECRWBEEQBEFiRRAEQZBYEQRBEASJFUEQBEGQWBEEQRAkVgRBEARBYkUQBEHUdKrNS8GFx5UjCIIgqhey6nASDx5jAZ%2FsbPEZXdLqAb%2BelAsEQRRA1YAEQRAEQRAEQRD%2Flv8D7QG%2FgPsYKIcAAAAASUVORK5CYII%3D)

```
bool_expr
         ::= ( bool_expr ( '<' | '<=' | '>' | '>=' | '==' | '!=' | '&&' | '||' ) | '!' ) bool_expr
           | ( '(' bool_expr | DEFINED '(' IDENT | IDENT '(' source_name ) ')'
           | int_const_expr
```

referenced by:

* bool_expr
* const_expr
* constant_def
* if_stmt

**expr:**

![expr](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAckAAAMRCAYAAACHzU0aAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAIABJREFUeNrs3Ql8FPXdP%2FDP7JkLCEkgFCJBAoEkIIQEnuiDQmnB%2BJSKEKjAQ6Ge4COoD3%2B1YqmKPVBQWxVatIiKtSYc6qPBowhKm3LEDUcTEnIfJEgCue9kd%2Bf%2F%2B20CggckYXezu3zer9dkZsnub2a%2FM%2BSzv5nZGYCIiIi%2Bk%2BIJbyImAqq7v4e0LM9YFz2lmu7V7zhw8MHMnOrF2fm1I6tq24xnqlq6XJPA%2Fkazr7e%2BJijAuC%2BvpHnt54ea0jy1VtzeiZxH5ylvxPTPLW677LE33nlVb4S734i576EX31%2BfU1jnO3PaNbht2VAMGuiDgYFeXW6jorJFd7qiKSjFVJFQXFYy69apPqays02L0jKQ74k14%2FZOxJC8qpzrHVxNn7BV9SnNtpd2Jq3blDF30ZwwrFs1EQa9pkdtyUCVw3URAbh7frguMbkwbnNiTkbsWHWOKd3yMbcwbu9EPaFhCai3yIDckpQ79%2FnVE7F4dliPA%2FKbZDuyvY1Px3n5GJQPYyPBrgsRMSTJfchdrKKnN3f947EYO6q%2FQ%2BYh292wJk6r02k2RzMoiYghSe5AnqSTvOfk%2BkWit%2BeogLwwKBfOGq7ooLwiepS3sPpExJAklybPYs0rrvedP%2FNap8xv6YJRMBg0OquKpJgxCOMaICKGJLmszNzqJfFThtjtGOTlyPlMGjdAniGigwXPcQ0QEUOSXFZ2QV3Y5Nhgp85zxk2D5chbDJOjozCOa4GIGJLkkiqrWr2GDPJx6jwjR%2Fh3TCio0FiRwLVARAxJcklVda1KYD%2BjU%2BcZEnw%2BlP3EMJ1rgYi6HJL%2FMQaX3Pd1ud8TdYfVokKjde53yM%2FNT1URIEZDuRaIPNuV5ta519tCst2CUzER2PZ9jV7u90TO8Oe3C3Dbsv0y6HpM6ehJcjsm8nA9za1JEZgdE4mTZgsK5WNd5x8OGZbzLBbxywi8p9NixaEMlF%2Fwh%2BWSv3cnbe1mbHnrM%2Bw%2FdAJ9%2B%2FhgycIfYuKEkSgtq8S291Jw189%2FjH79fG3P%2Ffveo2gXz%2F%2FJzbHY9akJAf39YDqSj4NfZuO6McPwwLKZ8PYyoOJsLd794ADmz7kR7%2B86hLa2dtx7x83cSu0sv6QB%2F0qrFCGpQlGuqCeqvVpqxu2drlbdzS0ZjhYFL1lUhFx4C4GLjkmqHaEpGy39rgS%2B3O%2FdwdIH%2F4QTuWVYfu9P8KOp1%2BHO%2B19Gbv5XCBkSiOy8U%2FjfxzsuHP3v40X45ZNvYkxUqO3xh598iXvEa5uaW3Hrf03CF%2F%2FMwK9%2F%2B7btd2fEH411f3wPCYufEW2U4WxVPbdQ4vZO5AIul1vneo4W4F3IgPwG3WUatSXw5X7vLj3L4ydKkJl9Egd2r4NGI3siI3HIlIOP%2Fm7Cg%2Ff9FM%2F%2F7g78ZN5v8MKG%2F8N7yYfwx7V3IzRkwPnXP7jsp7hnScc5H6PDQ5Cw6Bk8u2aJ7bHBqMO7bz12%2FlM52cef%2FpqPrPyOP8Km9OqO9fCbY%2Bd%2Fv%2BbBSAT4G1gobu9EXQ3LjtxS8LEZePqbPccuheQ5VuCo6GrGq5f5vdmMQjFTb1cvUnbuKZw5U4cbpv%2Fyon%2Bfn3Cjbezn64U%2F%2F2EZZtz2FO79xQxMmRx1cff9gj18w4cFo7mlDbV1TbbHRr3eLn8wPOFegfaUmVeH%2FYerbNPVtW22sdzlek5zq4V15vZO1GUyt8Sm%2FROzirlibL3cBvidISleuF%2B8sEyMfywa3CzG%2F3up3%2Bt1ePZcT3IeoC0KR6hFg0jxxGniOQvEczN0Ku5PPYEcR7zprv5H6%2BPnhWGhA7H3w99873N2%2Ft8BjIkYatvdJHdRyeMy36WqpgF6gw59xB%2Bar%2Bz4Xi536yB719eV15e04ano89MPr%2F033ny3GKb3p3X2jBxXZ0eZNBrhZgUbxczHiCK8IyqxV2tF5rAcFG8HLNzee7%2B%2B5Pq6sp6%2F%2Bf%2FkwtwS41e89NjS0o47RUfvblVB7Xftav1WSJ5rRO1o5JBeiwgZfmJm%2F3up31%2FYhm0Bc1AgJuWQPGIEVvXT4xGLgoPRkZh3JBN7equwcbGjcLqiBjv%2Bbz%2FmzrrB9m8lpWdRWVmH6HHDsevvadj9%2BVF8vPNJPP1sEu5%2F%2BBW8%2FZeV5%2F8g13V%2BirZYrPjTqx9hxg%2FH2%2F5wOJO96%2BvK68vTiHr%2ByKJiu9iaXqhtx8y8PLSe%2B92X3N7drr7kHuv5Mrm18j%2FG4Nl2C375fWF54Ra%2F%2FVLh14Xff6fON%2FDbCaNtu2a3i08AcY7qoVz2k3Ufb7z%2BpxVYuWoLfvfcdngZ9WhubsPzv78TeQVfYdWTW5H4xsPw9THi6V8twH%2FN%2FQ2e3%2FA%2BHnlgtu31ie%2Bm4O3t%2F0BLaxtGhQ3Bqy%2F%2FT69vMPauryutL0%2F75Cv%2FY6sqFh8%2BgWRu7%2B5fX3KL9XzZ3Or8t%2B8Ny3Mh2SwaKb1E%2BF3u95cl35Dokb4geigbxMMZvVXk%2F4gJx7%2F%2B%2FgzKxSds%2BTWCgQP6nf%2Fdvw%2B8eH7aaNBjzwdPX%2FRaedxm4byb0NDQctHrokYPxbH9f%2BzVjcfe9XWV9XWh51ZdZxvcUWcdX3D2H3BP3d5dpb7k0uu5W7n1zbAUPdBl50NSp8W1l2rkcr%2Fv8ifbZjxX74375QWmjxzHsd4sdvBA%2Fx69zsfbaBtckb3r60rry613D8kLqlsxVtTzVm7vnllfcr313NPcujAs5WPNBf94uRddsS%2BK0AIFf3PHC0wvWTgNN90Q5dLLaO%2F6Omp9yUvEyUvTOVNDY3uvrRdb%2FUQdbfXk9s76klPW85Xm1rnXO%2F8C5yr2ij%2BP17vbCrp%2B4iiEjxjs%2Bgtq7%2Fo6YH359zGYK2tbnVqW3KK6Xlwlon6ijtzeWV9yv%2FXs9JAUHYjjChDOVe4e9XXE%2Burjq68pO93k1LqkHjtrGysq5JUJnPpVAFk%2FWUdunawvud96dnpIejfYurADuMrdo76OWF%2BB%2FY37UkzOvUDT7pRTHZ9GFVSIkbOvDjWgs47E%2BpKbrWenh%2BSBUtv%2BZC%2Bub%2FeoryPWV15J89pde0vNbe1Wp9SksLQeRaUN57Z4%2BX3QEievFq%2FOOhLrS262nnvjpstqR8%2BZ3KS%2Bdl9fnx9qSjPoNabE5EKnFOSxZ9MufDeNsmPp5HWidNaRWF9ys%2FWsYd2pN5SdbVq0OTGnJT272qHzWfdqBvKL688FZIEYYqwa7OQaICKGJLmsNJFdbe1qwvInD1ocFZQyILdd2FtVkCI%2Bin7J73wSEUOSXN6hdMtHDc3me5au2q%2B%2BvDUL9jpGKY9B3r7ii4sDUoW8GeLNqhaPsvJE1FU6loB60%2BFMvB4bYdW8tTN%2FU%2BIHhbq48UGInxKC8LC%2BCB3s16U2mlrMyC6oQ%2BrRM%2Fgs5ZQIyYaLnyADUt7hRMEdJtGDZdWJ6KoLydgb7%2BTadFOmLLw2IUots7RZtu9LLdeKwT73JpXHIBWkQN4TVYMlacfxCbd3IuoOj9jdKu9J11v3ByQ79ShFgClajBeTn4pwqxQrM0MMJ8VabexGMw3iNYUaVbQBvKcCRvHYT3wUvOGwBwUkt3ci9iTpKpTWsSt0tryQcef1YmfAKsJAgW8Xm%2FBTVdSoCuTVvFNVLdaYeJIOETEkv%2F6EzVXq%2FjrPPpXDE6wGt3ei3sSzW4mIiBiSREREDEkiIiKGJBEREUOSiIiIIUlERMSQJCIiYkgSERG5K15xh1yCarpXv%2BPAwQczc6oXZ%2BfXjqyqbTOeqWr53i%2FLB%2FY3mn299TVBAcZ9eSXNa%2BWNnFlFImJIksfZ%2FUbMfQ%2B9%2BP76nMI635nTrsFty4Zi0EAfDAz0%2Bt7XVFS26E5XNAWlmCoSistKZt061cckb%2BScxrt8EBFDkjyi96g%2Bpdn20s6kdZsy5i6aE4Z1qybCoO%2FaEQAZoHK4LiIAd88P1yUmF8ZtTszJiB2rzjGlWz5mdYnIHnhMknqNDMgtSblzn189EYtnh3U5IL9Jvk6%2BfuPTcV4%2BBuXD2EjwPlJExJAk9yV3sYqe39z1j8di7Kj%2BdmlTtrNhTZxWp9NsjmZQEhFDktyRPEknec%2FJ9YtE789eAXlhUC6cNVzRQXlF9ChvYbWJiCFJzmC32zLJs1jziut958%2B81iELunTBKBgMGp1VRVLMGIR5St2IiCFJLur6EHjZq63M3Ool8VOG9PgY5OXIdieNGyDTSQcLnvOUuhERQ5JcVLMfgu3VVnZBXdjk2GCHLu%2BMmwbLkbcYJkdHYZwn1I2IGJLkorQKouzVVmVVq9eQQT4OXd7IEf4dEwoqNFYkeELdiIghSa5KwTR7NVVV16oE9jM6dHFDgs%2BHsJ8YpntC3YiIIUmuSsXCqcPsc3zNalGh0Tr2fJZz7asqAsRoaG%2BUzFYvUTduPEQMSfJ86fXeeNj9OsC2nmSvHBfsrFc6Nx0ihiR5OK2K5WK0csJozHTHxXf2DDvrtLKzbkTEkCRPlnoCOVYF8xQFW2MisHrECBhZlW%2BTdZH1kXWS9ZJ1Y1WI3BcvcE5ddiQTeyaNRpxZwcZ%2Betw%2FIQLvQMVerRWZw3JQvB2w2HN%2B%2B1LP4A9bci%2F6t82%2Fj0FQgOvk8zzRSy0KR6hFg0h5ko4CLFCBDJ2KuLQsBiQRQ5Kuuh6lGE2X3z3UqJgjph%2BwajGyIAKhMXa%2BuszZ6jb8K63yon9rabP2qC3Ru1MdUY8C2NotFm88V7z7A6L3GH%2FkOI5xSyFiSNLV3KvsCIIehUFXAyvh5iG2wR5Er46XhyOibuMxSSIiIoYkERERQ5KIiIghSURExJAkz9rotIrt0nSO1NDYzkITEUOS3I9%2FH4O5srbVofPILapjoYmIIUnup4%2BvvqbsdJND55F67KxtrKioh50vckBEDEkihwnsb9yXYip36Dx2p5yyjVUFFWJUzqoTEUOS3EJeSfPaXXtLzW3tVoe0X1haj6LShnNbeIH4WcKqExFDktzC54ea0gx6jSkxudAh7T%2F2bNrXD1Q0yo4lq05EDElyG2VnmxZtTsxpSc%2Butmu7617NQH5x%2FbmALBBDjFWDnaw4ETEkyW2kiSxra1cTlj950GKvoJQBue3C3qmCFAX4khccJyKGJLmdQ%2BmWjxqazfcsXbVffXlrFnp6jFIeg7x9xRcXB6SKt8XPm1UtHmWliaineBcQ6lWHM%2FF6bIRV89bO%2FE2JHxTq4sYHIX5KCMLD%2BiJ0sN93vqapxYzsgjqkHj2Dz1JOiZBsuPgJMiDlvR0V3GESPVZWmYgYkuS2TFl4bUKUWmZps2zfl1quFYN3jxqSxyAVpIipeFWDJWnH8QmrS0RXgrtbyTV6lCLQFC3Gi8lPRdhVKkCGGE6K0Gu8xMsaxHMKNap4DfCeChjFYz%2Fx0e%2BGwwxIImJPkjxJWseu0dnRURinsSJBTM%2BAVcSkAt%2FveYmfqqJGVeAvplNVLdaYeJIOETEkyZN1no0qhydYDSLqTdzdSkRExJAkIiJiSBIRETEkiYiIGJJEREQMSSIiIoYkERERQ5KIiMhd8WIC5BJU0736HQcOPpiZU704O792ZFVtm%2FFMVYtyudcF9jeafb31NUEBxn15Jc1r5Q2dWU0iYkiSx9j9Rsx9D734%2FvqcwjrfmdOuwW3LhmLQQB8MDPS67GsrKlt0pyuaglJMFQnFZSWzbp3qY5I3dE7j3T%2BIiCFJbt17VJ%2FSbHtpZ9K6TRlzF80Jw7pVE2HQd%2B8IgAxSOVwXEYC754frEpML4zYn5mTEjlXnmNItH7PKRHQleEySeo0MyC1JuXOfXz0Ri2eHdTsgv0m%2BXraz8ek4Lx%2BD8mFsJO5klYmIIUluR%2B5iFT2%2Buesfj8XYUf3t2rZsb8OaOK1Op9kczaAkIoYkuRN5kk7ynpPrF4len70D8sKgXDhruKKD8oroUd7CqhMRQ5IcSbFXQ%2FIs1rziet%2F5M6916AIvXTAKBoNGZ1WRFDMGYe5eNyJiSJKLuj4EXvZqKzO3ekn8lCFXfAzycmT7k8YNkCmlgwXPuXvdiIghSS6q2Q%2FB9moru6AubHJssFOWe8ZNg%2BXIWwyTo6Mwzp3rRkQMSXJRWgVR9mqrsqrVa8ggH6csd%2BQI%2F44JBRUaKxLcuW5ExJAkV6Vgmr2aqqprVQL7Gbv1msZmM05VtHR7XiHB58PYTwzT3bluRMSQJFelYuHUYfY5vma1qNBou3Y%2BS2V1G1paLfh4Xzlm37ff9m9fnel6WJ6bj6oiQIyGOrNktnqJunHjIWJIkudLr%2FfGw86e6Ytv5mLqf%2B9DenatDDo8%2FXIW4ubsRVl5czc7dLaepFOPD3bWK52bDhFDkjycVsVyMVo5YTRmOnO%2BT66IxNIFw%2FHGjiIUnmzEkcwa7PnrTRgS7N2jt%2BGs5e6s08rOuhERQ5I8WeoJ5FgVzFMUbI2JwOoRI2B0xnzlrtV%2FpVWi3azK7zwiu7AeqceqbL1KVyTrIusj6yTrJevGrYfIffEC59RlRzKxZ9JoxJkVbOynx%2F0TIvAOVOzVWpE5LAfF2wGLvecpe5BeIhyfeWQM%2FpJUiN8%2FPAa%2Fej4DU%2BMGYvDA3v8K4jzROy0KR6hFg0h5ko4CLBD5naFTEZeWxYAkYkjSVdejFKPp8juHGhVzxPQDVi1GFkQgNMYBV5dZvTzCNv7oi9MI8DfgxolB%2BEfi1B63J3p5du2DFsDWXrF447ni3R8Qvcf4I8dxjFsKEUOSruZeZUcQ9CgMehJU%2FzV1kG24UqJ3x8vEEVGX8ZgkERERQ5KIiIghSURExJAkIiJiSJJnbXRaxXZpOmdoaGxnwYmIIUnuw7%2BPwVxZ2%2BqUeeUW1bHgRMSQJPfRx1dfU3a6ySnzSj121jZWVNTDARc7ICKGJJFdBfY37ksxlTtlXrtTTtnGqoIKMSpn9YmIIUkuLa%2Bkee2uvaXmtnarQ%2BdTWFqPotKGc1t6gfhZwuoTEUOSXNrnh5rSDHqNKTG50KHzeezZtK8fqGiUHUtWn4gYkuTyys42LdqcmNOSnl3tkPbXvZqB%2FOL6cwFZIIYYqwY7WXkiYkiSy0sTGdbWriYsf%2FKgxd5BKQNy24W9VAUpCvAlLzxORAxJchuH0i0fNTSb71m6ar%2F68tYsXOkxSnkM8vYVX1wckCreFj9vVrV4lBUnou7iXUCoVx3OxOuxEVbNWzvzNyV%2BUKiLGx%2BE%2BCkhCA%2Fri9DBfpd8bVOLGdkFdUg9egafpZwSIdlw8RNkQMp7PCq4wyR6rqw2ETEkye2YsvDahCi1zNJm2b4vtVwrBu8ralAeg1SQIqbiVQ2WpB3HJ6wyEfUEd7eSa%2FQoRZApWowXk5%2BKkKtUgAwxnBRh19iFlzeI5xZqVPFa4D0VMIrHfuIj4A2HGZBExJ4keYK0jl2is6OjME5jRYKYngGriEkFvpd5qZ%2BqokZV4C%2BmU1Ut1ph4kg4RMSTJE3WehSqHJ1gNIupN3N1KRETEkCQiImJIEhERMSSJiIgYkkRERAxJIiIihiQRERFDkoiIyF3xYgLkElTTvfodBw4%2BmJlTvTg7v3ZkVW2b8UxVi3K51wX2N5p9vfU1QQHGfXklzWvlDZ1ZTSJiSJLH2P1GzH0Pvfj%2B%2BpzCOt%2BZ067BbcuGYtBAHwwM9LrsaysqW3SnK5qCUkwVCcVlJbNunepjkjd0TuNdP4iIIUlu3XtUn9Jse2ln0rpNGXMXzQnDulUTYdB37wiADFI5XBcRgLvnh%2BsSkwvjNifmZMSOVeeY0i0fs8pEdCV4TJJ6jQzILUm5c59fPRGLZ4d1OyC%2FSb5etrPx6TgvH4PyYWwk7mSViYghSW5H7mIVPb656x%2BPxdhR%2Fe3atmxvw5o4rU6n2RzNoCQihiS5E3mSTvKek%2BsXiV6fvQPywqBcOGu4ooPyiuhR3sKqExFDkhxJsVdD8izWvOJ63%2Fkzr3XoAi9dMAoGg0ZnVZEUMwZh7l43ImJIkou6PgRe9morM7d6SfyUIVd8DPJyZPuTxg2QKaWDBc%2B5e92IiCFJLqrZD8H2aiu7oC5scmywU5Z7xk2D5chbDJOjozDOnetGRAxJclFaBVH2aquyqtVryCAfpyx35Aj%2FjgkFFRorEty5bkTEkCRXpWCavZqqqmtVAvsZexaw1W04%2BVUTzBa1S88PCT4fxn5imO7OdSMihiS5KhULpw6zz%2FE1qwg4jbb757PIYJy2aB9m3v2vrm%2FgnfNRVQSI0VBnlsxWL1E3bjxEDEnyfOn13ni4Nxfgk32ncaqiBUsShkHXzZBVOnqSTj0%2B2FmvdG46RAxJ8nBaFcvFaOWE0ZjZW8uweVuh%2FEoHfj6rxx1CrbOWtbNOKzvrRkQMSfJkqSeQY1UwT1GwNSYCq0eMgNGZ8z9RUI%2F9hysx60eDMSDQ6LJ1knWR9ZF1kvWSdePWQ%2BS%2BeIFz6rIjmdgzaTTizAo29tPj%2FgkReAcq9mqtyByWg%2BLtgMVR896yrUgeV8SdPxvmUjWZJ3qnReEItWgQKU%2FSUYAFYjEzdCri0rIYkEQMSbrqepRiNF1%2B51CjYo6YfsCqxciCCITGOOjqMvWNZmz7qBTjI%2F0RO%2BbKLmMnenmqPZetALb2isUbzxXv%2FoDoPcYfOY5j3FKIGJJ0NfcqO4KgR2HQ3aBKSj6JxmYz7pp35b1I0bvjZeKIqMt4TJJcmtzFumV7EQL8DZg9YwgLQkQMSaJz%2FvHlGeQWN9jOaDUauLkSEUOS6LzXthVBq1Vs340kImJIEnWSl6DLyq%2FHvFtCcM0PvFkQInI6nrhDzv9kJnqGXbk0XWB%2FA75878oufdrQ2M6CExF7kuQ%2B%2FPsYzJW1rU6ZV25RHQtORAxJch99fPU1ZaebnDKv1GNnbWNFRT0ceLEDImJIEtlFYH%2FjvhRTuVPmtTvllG2sKqgQo3JWn4gYkuTS8kqa1%2B7aW2pua7c6dD6FpfUoKm04t6UXiJ8lrD4RMSTJpX1%2BqCnNoNeYEpMLHTqfx55N%2B%2FqBikbZsWT1iYghSS6v7GzTos2JOS3p2dUOaX%2FdqxnIL64%2FF5AFYoixarCTlScihiS5vDSRYW3tasLyJw9a7B2UMiC3XdhLVZCiAF%2FywuNExJAkt3Eo3fJRQ7P5nqWr9qsvb83ClR6jlMcgb1%2FxxcUBqeJt8fNmVYtHWXEi6i5eTIB61eFMvB4bYdW8tTN%2FU%2BIHhbq48UGInxKC8LC%2BCB3sd8nXNrWYkV1Qh9SjZ%2FBZyikRkg0XP0EGpLzHo4I7TKLnymoTEUOS3I4pC69NiFLLLG2W7ftSy7ViuLJr0MljkApSxFS8qsGStOP4hFUmop7g7lZyjR6lCDJFi%2FFi8lMRcpUKkCGGkyLsGrvw8gbx3EKNKl4LvKcCRvHYT3wEvOEwA5KI2JMkT5DWsUt0dnQUxmmsSBDTM2AVManA9zIv9VNV1KgK%2FMV0qqrFGhNP0iEihiR5os6zUOXwBKtBRL2Ju1uJiIgYkkRERAxJIiIihiQRERFDkoiIiCFJRETEkCQiImJIEhERuSteTIBcgmq6V7%2FjwMEHM3OqF2fn146sqm0znqlqUXraXmB%2Fo9nXW18TFGDcl1fSvFbe6JlVJiKGJLmd3W%2FE3PfQi%2B%2Bvzyms85057RrctmwoBg30wcBArx63WVHZojtd0RSUYqpIKC4rmXXrVB%2BTvNFzGu8GQkQMSXKL3qP6lGbbSzuT1m3KmLtoThjWrZoIg94%2BRwBkwMrhuogA3D0%2FXJeYXBi3OTEnI3asOseUbvmY1SeiruAxSeo1MiC3JOXOfX71RCyeHWa3gPwm2a5sf%2BPTcV4%2BBuXD2EjcyeoTEUOSXJbcxSp6dnPXPx6LsaP6O2Wecj4b1sRpdTrN5mgGJRExJMkVyZN0kvecXL9I9O6cFZAXBuXCWcMVHZRXRI%2FyFq4NImJIkj0o9mpInsWaV1zvO3%2Fmtb3yRpYuGAWDQaOzqkiKGYMwd6kbETEkyUVdHwIve7WVmVu9JH7KEIcdg7wcOd9J4wbI9NLBgufcpW5ExJAkF9Xsh2B7tZVdUBc2OTa4V9%2FPjJsGy5G3GCZHR2GcO9SNiBiS5KK0CqLs1VZlVavXkEE%2Bvfp%2BIkf4d0woqNBYkeAOdSMihiS5KgXT7NVUVV2rEtjP2KtvJyT4fEj7iWG6O9SNiJyPFxOgrlGxcOow%2FOqLIrRcaVNWiwqNtmvns%2Fz7RC2eeikTRaVNGDrYG2sejMK4iH6239U3mnHXYybM%2FOEPsHhOaPc%2BHXbOX1URoDjo%2F4Gol1e9qBs3HiL2JMnzpdd742FnztBqVbHkkS%2BRX9yAlXeOFONG%2FOLRL2Ww2fz57XwcOFKFH0%2Fu%2BWE%2FpaMn6ZDjhp31SuemQ8SQJA%2BnVbFcjFZOGI2ZzppnWXkzSk8320Jw0W1DMe2GgbbHpyqaUVXThk1%2FK8Adc0MxeOAVn0Cqtfeyd9ZpZWfdiIghSZ4s9QRyrArmKQq2xkRg9YgRcPhBRY2mY5eoxaKe71naEk2r4MU382w9yod%2BMVL0Jivx%2FGs5eDWxAGerWnu1TrIusj6yTrJesm7ceojcF49JUpcdycSeSaMRZ1awsZ8e90%2BIwDtQsVdrReawHBRvF3lmz%2FkNCfZG%2BDA%2FfLzvNAYFeeHTf5zG6OF9bOG4ZXsRViwOw67PT2Pl748hYkRfnBI9zw1b85GybSr6%2BumdUpN5IrOLwhFq0SBSnqQjYn2BWLwMnYq4tCwGJBFDkq66HqUYTZffLdSomCOmH7BqMbIgAqExDri6zNt%2FmIR1r%2Bbg4NFK%2FPg%2Fg%2FHLpaPw%2FOYc%2BHhpcd9%2FhyHh%2FgPw76vH53%2B9CX%2F74KQtMPfuP4PbZgzu1nxE70%2FtyfIVwPa6YvHGc8W7PyB6j%2FFHjuMYtxQihiRdzb3KjiDoURh0J5CGhfjiT09Hn39cVNpoC8PH%2F2c0%2BvjqUF3bjn599LZdsAH%2BBttzahrau71MotfHy8cR0bfwmCS5lWdfyUZQfwPu%2Ftkw2%2BOwob746kwLMnLqbL1NaYT4NyIihiRdVbLy6vDu309h5d3h8DJ2nJC6atlo9O9jwA%2F%2Fe5%2FtbNe58UPwnzF%2FpVEDAAAgAElEQVRBLBYR2QV3t5LbkCfnlB%2B6%2BBso8sICR3f9GF9VNMNbBGdQgJGFIiKGJNH5jVir4Jof%2BLAQRGR33N1Kzt%2FoRKhZLWqvLkNDYztXBBExJMn1%2BPcxmCtre%2FdL%2F7lFdVwRRMSQJNfTx1dfU3a6qVeXIfXYWdtYUVEPO18EgYgYkkQ9FtjfuC%2FFVN6ry7A75ZRtrCqoEKNyrhUiYkiSS8graV67a2%2Bpua3d2ivzLyytR1Fpw7n%2FAQXiZwnXChExJMklfH6oKc2g15gSkwt7Zf6PPZv29QMVjbJjybVCRAxJchllZ5sWbU7MaUnPrnbqfNe9moH84vpzAVkghhirBju5RoiIIUkuI01kVVu7mrD8yYMWZwWlDMhtF%2FZeFaQowJe8IDkRMSTJ5RxKt3zU0Gy%2BZ%2Bmq%2FerLW7PgqGOU8hjk7Su%2BuDggVbwtft6savEo1wQRfR9ecYd61eFMvB4bYdW8tTN%2FU%2BIHhbq48UGInxKC8LC%2BCB3s16M2m1rMyC6oQ%2BrRM%2Fgs5ZQIyYaLnyADUt77UcEdJtGj5VogIoYkuSxTFl6bEKWWWdos2%2FellmvF4O2QGcljkApSxFS8qsGStOP4hNUnokvh7lZyjR6lCCxFi%2FFi8lMRZpUKkCGGkyLUGq%2Bg2QbRRqFGFW0C76mAUTz2Ex8NbzjMgCQi9iTJnaR17PqcHR2FcRorEsT0DFhFTCro6Q0i%2FVQVNaoCfzGdqmqxxsSTdIiIIUnurPNsUzk8wWoQUW%2Fi7lYiIiKGJBEREUOSiIiIIUlERMSQJCIiYkgSERExJImIiBiSRERE7ooXEyCXoJru1e84cPDBzJzqxdn5tSOratuMZ6paFHvPJ7C%2F0ezrra8JCjDuyytpXitvAM3qExFDklzW7jdi7nvoxffX5xTW%2Bc6cdg1uWzYUgwb6YGCgl93nVVHZojtd0RSUYqpIKC4rmXXrVB%2BTvAF0Gu8GQkQMSXKp3qP6lGbbSzuT1m3KmLtoThjWrZoIg96xRwBk8MrhuogA3D0%2FXJeYXBi3OTEnI3asOseUbvmYa4WILsRjktRrZEBuScqd%2B%2FzqiVg8O8zhAflNcn5yvhufjvPyMSgfxkbiTq4VImJIUq%2BTu1hFD27u%2BsdjMXZU%2F15dFjn%2FDWvitDqdZnM0g5KIGJLUm%2BRJOsl7Tq5fJHpxvR2QFwblwlnDFR2UV0SP8hauJSJiSFJ32O1MU3kWa15xve%2F8mde61BtcumAUDAaNzqoiKWYMwlytbkTEkCQXdX0I7HaqaWZu9ZL4KUOcfgzycuTyTBo3QKaaDhY852p1IyKGJLmoZj8E26ut7IK6sMmxwS75PmfcNFiOvMUwOToK41ypbkTEkCQXpVUQZa%2B2KqtavYYM8nHJ9xk5wr9jQkGFxooEV6obETEkyVUpmGavpqrqWpXAfkaXfJshwefD208M012pbkTEkCRXpWLh1GH2Ob5mtajQaF3zfJZzy6WqCBCjoVfSlq1eom7ceIgYkuT50uu98bCrLMyJgno8ti4dZhG4l9LYbMaWHUX49J%2Fl3ewA2nqSV3Q8sbNe6dx0iNwXL0tHXaJVsdyi4OCE0Th6%2BASSe2MZ2s1WfPzFaby2vQj7D1dCJ3p9v1kZhe%2F6loUM0TdEOCbtKkVDkxnrHhvbo7fd02UVdZopRitF3eJE3bK5BRExJMmDpZ5ATnQk5mmA7TEReKG2Hevz8tDqjHmfPtuCN3cW4633SlBe2YJBQV54%2BO5wLJ4TCr1O870hKn93803B%2BEVCKKZMGuCUOo0YAWM%2FPR6RAWlVMC8tCzmiXkTEkCRPdyQTeyaNRpxZwUYRBPdPiMA7ULFXa0XmsBwUbwcs9p7nqvUZePPdYlsATv2PAXjml2MQf9MgWy%2FyQv9Kq8TSXx22hejggV54bNkoLLptKIIDHfs1xXmit1kUjlCLBpHyJB2xVAtUIEMnepAyILnVEDEk6SrrUYrRdPkdQo2KOWL6AasWIwsiEBrjgKvLZObV2QIyoJ8BN0wIxKTrAr4VkFKFCEcZkFKseI58rj0CUvQCL3nQswC23xeLJcoV7%2F6A6D3GHzmOY9xSiBiSdDX3KjuCoEdhcLngudDOP11v24UqT775%2FZ9PYP1fchA%2FJRi%2FmDMMN00KOv%2B82TOGIHJkX7yxoxhJu07ig89OYfTwPlgyJxQ%2F%2B0kI%2Bvrpe%2FQ%2BRW%2BQl5UjYkgSuegGKnqNP%2F3RD2xDdmH9%2BRD8cM9XCAv1xb%2BSfghtZ89y1LV9sPaRMVi9fDS2fVSK18VzVz2Xgac3ZOGV307ALVMGsaBExJAkz%2FRdIWixqudD8hxfbx3uSBhmGw4ercJr2wtRXtnKAhIRQ5I834UheDlx4wNsAxFRT%2FBiAkRERAxJcpmNTqvYLk3nihoa27mCiIghSb3Hv4%2FBXFnrmscIc4vquIKIiCFJvaePr76m7HSTSy5b6rGztrGioh4OuDgCETEkiS4psL9xX4qp3CWXbXfKKdtYVVAhRuVcW0QMSSKnyitpXrtrb6m5rd3qUstVWFqPotKGc%2F8zCsTPEq4tIoYkkVN9fqgpzaDXmBKTC11quR57Nu3rByoaZceSa4uIIUnkdGVnmxZtTsxpSc%2BudonlWfdqBvKL688FZIEYYqwa7OSaImJIEjldmsiktnY1YfmTBy29HZQyILdd2KtVkKIAX%2FJC5UTEkKRecyjd8lFDs%2Fmepav2qy9vzYKzj1HKY5C3r%2Fji4oBU8bb4ebOqxaNcQ0TEy9JRrzqciddjI6yat3bmb0r8oFAXNz4I8VNCEB7WF6GD%2Few6r6YWM7IL6pB69Aw%2BSzklQrLh4ifIgJT3hFRwh0n0dLl2iIghSb3OlIXXJkSpZZY2y%2FZ9qeVaMXg7dQHkMUgFKWIqXtVgSdpxfMK1QkQSd7eSa%2FQoRTApWowXk5%2BK0KpUgAwxnBTh1eiA2TWItgs1qpgX8J4KGMVjP%2FGR8YbDDEgiYk%2BSXFFaxy7O2dFRGKexIkFMz4BVxKQCXzvPyk9VUaMq8BfTqaoWa0w8SYeIGJLkDjrPKpXDE6wGEfUm7m4lIiJiSBIRETEkiYiIGJJEREQMSSIiIoYkERERQ5KIiIghSURE5K54MQFyCarpXv2OAwcfzMypXpydXzuyqrbNeKaqRbH3fAL7G82%2B3vqaoADjvryS5rXyBtCsPhExJMll7X4j5r6HXnx%2FfU5hne%2FMadfgtmVDMWigDwYGetl9XhWVLbrTFU1BKaaKhOKyklm3TvUxyRtAp%2FGuH0TEkCSX6j2qT2m2vbQzad2mjLmL5oRh3aqJMOgdewRABq8crosIwN3zw3WJyYVxmxNzMmLHqnNM6ZaPuVaI6EI8Jkm9RgbklqTcuc%2BvnojFs8McHpDfJOcn57vx6TgvH4PyYWwk7uRaISKGJPU6uYtV9ODmrn88FmNH9e%2FVZZHz37AmTqvTaTZHMyiJiCFJvUmepJO85%2BT6RaIX19sBeWFQLpw1XNFBeUX0KG%2FhWiIihiR1h93ONJVnseYV1%2FvOn3mtS73BpQtGwWDQ6KwqkmLGIMzV6kZEDElyUdeHwG6nmmbmVi%2BJnzLE6ccgL0cuz6RxA2Sq6WDBc65WNyJiSJKLavZDsL3ayi6oC5scG%2ByS73PGTYPlyFsMk6OjMM6V6kZEDElyUVoFUfZqq7Kq1WvIIB%2BXfJ%2BRI%2Fw7JhRUaKxIcKW6ERFDklyVgmn2aqqqrlUJ7Gd0ybcZEnw%2BvP3EMN2V6kZEDElyVSoWTh1mn%2BNrVosKjdY1z2c5t1yqigAxGnolbdnqJerGjYeIIUmeL73eGw87e6av7yzCB5%2BdQrvZesnn5RY34NlXsnH6bIudOs62nuQVHU%2FsrFc6Nx0i98XL0lGXaFUstyg4OGE0jh4%2BgWRnzTcjpw5b3y1GcKAXfj57KJYkhGJQ0Lc7tC0tFjy3OQd%2FfD0X8VMG4c65w3DjxKArfts9faGo00wxWinqFifqls0tiIghSR4s9QRyoiMxTwNsj4nAC7XtWJ%2BXh1ZHz%2FeZR8bgptggvCGC8lIhOHZUP%2FwjcSreFD3PbR%2BVInnvVwgf5oc7xPNun3kN%2Bvg6Z1MfMQLGfno8IgPSqmBeWhZyRL2IiCFJnu5IJvZMGo04s4KNIgjunxCBd6Bir9aKzGE5KN4OWOw9T71Og1nTB9sGuUv1jR3FIgRPng%2FBxJf%2BA9f8oONkm4iwPnjm0bF44oFI7BBBKYN11XMZ%2BM2GLDz5YKQtWO1tnuhtFoUj1KJBpDxJRwEWqKIDrBM9SBmQ3GqIGJJ0lfUoxWi6%2FA6hRsUcMf2AVYuRBREIjXHw1WWuDfHF9RMC8O8TNTh4tAqFpU1oaDR%2F63k%2BXlpcHxOI7MIG5BTWo6nFgvzixh7NU%2FQC1Uv9vgC23xeLN54r3v0B0XuMP3Icx7ilEDEk6WruVXYEQY%2FC4HLB801fnWmxHZf86%2FslthNz5DHJR%2B8dZTtGeeHxSXlyz0efn7b1IFNMZ2290PgpwbYe5OTYnh2fFL1BXlaOiCFJ5JpefDMPz%2Fz5BMwW1RZ0v394DG6ZOgi6b3yFpPBkI35yz79wprL1e0OUiIghSR6l4mwrfpEwDL%2BYG4pR1%2Fb53udV17Xbfv%2FsI2O%2FM0SJiBiS5HF%2B9%2F%2B6dlW3CVH%2BeO%2FP17NgRGRXvJgAERERQ5JcZqPTKrZL07mihsZ2riAiYkhS7%2FHvYzBX1ra65LLlFtVxBRERQ5J6Tx9ffU3Z6SaXXLbUY2dtY0VFPRxwcQQiYkgSXVJgf%2BO%2BFFO5Sy7b7pRTtrGqoEKMyrm2iBiSRE6VV9K8dtfeUnNbu9WllquwtB5FpQ3n%2FmcUiJ8lXFtEDEkip%2Fr8UFOaQa8xJSYXutRyPfZs2tcPVMjr2O3m2iJiSBI5XdnZpkWbE3Na0rOrXWJ51r2agfzi%2BnMBWSCGGKsGO7mmiBiSRE6XJjKprV1NWP7kQUtvB6UMyG0X9moVpCjAl7xQORExJKnXHEq3fNTQbL5n6ar96stbs%2BDsY5TyGOTtK764OCBVvC1%2B3qxq8SjXEBHxsnTUqw5n4vXYCKvmrZ35mxI%2FKNTFjQ9C%2FJQQhIf1RehgP7vOq6nFjOyCOqQePYPPUk6JkGy4%2BAkyIOU9IRXcYRI9Xa4dImJIUq8zZeG1CVFqmaXNsn1farlWDN5OXQB5DFJBipiKVzVYknYcn3CtEJHE3a3kGj1KEUyKFuPF5KcitCoVIEMMJ0V4NTpgdg2i7UKNKuYFvKcCRvHYT3xkvOEwA5KI2JMkV5TWsYtzdnQUxmmsSBDTM2AVManA186z8lNV1KgK%2FMV0qqrFGhNP0iEihiS5g86zSuXwBKtBRL2Ju1uJiIgYkkRERAxJIiIihiQRERFDkoiIiCFJRETEkCQiImJIEhERuSteTIBcgmq6V7%2FjwMEHM3OqF2fn146sqm0znqlqUbr6%2BsD%2BRrOvt74mKMC4L6%2Bkea28sTOrSkQMSXJ7u9%2BIue%2BhF99fn1NY5ztz2jW4bdlQDBrog4GBXl1uo6KyRXe6oikoxVSRUFxWMuvWqT4meWPnNN7Ng4gYkuSWvUf1Kc22l3YmrduUMXfRnDCsWzURBn3PjgDIQJXDdREBuHt%2BuC4xuTBuc2JORuxYdY4p3fIxq01EPcFjktRrZEBuScqd%2B%2FzqiVg8O6zHAflNsh3Z3san47x8DMqHsZG4k9UmIoYkuQ25i1X09OaufzwWY0f1d8g8ZLsb1sRpdTrN5mgGJRExJMkdyJN0kvecXL9I9PYcFZAXBuXCWcMVHZRXRI%2FyFlafiBiS5AiKvRqSZ7HmFdf7zp95rVMWfOmCUTAYNDqriqSYMQhz17oREUOSXNT1IfCyV1uZudVL4qcMsdsxyMuR85k0boBMKx0seM5d60ZEDElyUc1%2BCLZXW9kFdWGTY4OduvwzbhosR95imBwdhXHuWDciYkiSi9IqiLJXW5VVrV5DBvk4dfkjR%2Fh3TCio0FiR4I51IyKGJLkqBdPs1VRVXasS2M%2Fo1MUPCT4fyn5imO6OdSMi5%2BPFBKhrVCycOgy%2F%2BqIILVfalNWiQqPt2vksNXXtWPvnE0gxnUVzqxUhg7yxdMFw%2FOSHg7r3abBzfqqKAMVJ272ol1e9qBs3HiL2JMnzpdd742Fnz%2FThZ%2F6NLTuKEPIDHyxJCMWBI5W4a5UJJ79q7mHHztaTdMpxws56pXPTIWJIkofTqlguRisnjMZMZ8635FSTbRwzxh93%2F2wYNBoFVqtq69peydtx9HJ31mllZ92IiCFJniz1BHKsCuYpCrbGRGD1iBFwykHFB5aMgE6r4IUtuZj7Pwch5o9H7x1l6xOe%2FKoJbe1Wl6qTrIusj6yTrJesG7ceIvfFY5LUZUcysWfSaMSZFWzsp8f9EyLwjujQ7dVakTksB8XbAYu95%2Bll0MLPV2c7NmnKqMb8mdfg%2F90VjiE37EK72Yo9b92E60b367WazBO90qJwhFo0iJQn6YgMXyD6uBk6FXFpWQxIIoYkXXU9SjGaLr9rqFExR3b2rFqMLIhAaIydry5zprIVdz1mQlOLBRueisbvNmYhMfkkWtusUFXVtutVnsjTE6K3p9pjGQs69vsWizeeK979AdF7jD9yHMe4pRAxJOlq7lV2BEGPwqCrAZWZX2cLSGn6fw7EjRODMP%2BBg3jv72W2f7v9JyEI8Df0aPlFL4%2BXiyOiy%2BIxSXJZkWF94WXsOMdm0cpU7Dt0BtdHB34ddBk1KC5rYqGIiCFJV58BgUa89kwMBg%2F0wpfp1Xjg6aN4J%2Fkklv88DFMmDUBecQNuuSsFx7JqWSwicgjubiWXNmNyMGbsmo7S082245DBQV5OuzA6ERFDktxCT0%2FQISK6EvxITs7f6LSK7dJ0ztTQ2M7CExFDklyffx%2BDubK21anzzC2qY%2BGJiCFJrq%2BPr76m7LRzz0pNPXbWNlZU1MMBFz0gIoYkkV0E9jfuSzGVO3Weu1NO2caqggoxKudaICKGJLmkvJLmtbv2lpqddd3VwtJ6FJU2nNviC8TPEq4FImJIkkv6%2FFBTmkGvMSUmFzplfo89m%2Fb1AxWNsmPJtUBEDElyWWVnmxZtTsxpSc%2Buduh81r2agfzi%2BnMBWSCGGKsGO7kGiIghSS4rTWRXW7uasPzJgxZHBaUMyG0X9lYVpCjAl7wAORExJMnlHUq3fNTQbL5n6ar96stbs%2Bx2b0h5DPL2FV9cHJAq3hY%2Fb1a1eJSVJ6Ku4hV3qFcdzsTrsRFWzVs78zclflCoixsfhPgpIQgP64vQwX5daqOpxYzsgjqkHj2Dz1JOiZBsuPgJMiDlvR4V3GESPVhWnYgYkuQ2TFl4bUKUWmZps2zfl1quFYN9rkEnj0EqSBFT8aoGS9KO4xNWm4i6g7tbyTV6lCLAFC3Gi8lPRbhVKkCGGE6KkGvsRjMN4jWFGlW0AbynAkbx2E98FLzhMAOSiNiTJHeW1rErdHZ0FMZprEgQ0zNgFTGpwLeLTfipKmpUBf5iOlXVYo2JJ%2BkQEUOSPEnn2adyeILVIKLexN2tREREDEkiIiKGJBEREUOSiIiIIUlERMSQJCIiYkgSERExJImIiNwVLyZALkE13avfceDgg5k51Yuz82tHVtW2Gc9UtSjf9%2FzA%2Fkazr7e%2BJijAuC%2BvpHmtvJEzq0hEDEnyOLvfiLnvoRffX59TWOc7c9o1uG3ZUAwa6IOBgV7f%2B5qKyhbd6YqmoBRTRUJxWcmsW6f6mOSNnNN4lw8iYkiSR%2FQe1ac0217ambRuU8bcRXPCsG7VRBj0XTsCIANUDtdFBODu%2BeG6xOTCuM2JORmxY9U5pnTLx6wuEdkDj0lSr5EBuSUpd%2B7zqydi8eywLgfkN8nXyddvfDrOy8egfBgbiTtZXSJiSJLbkrtYRc9v7vrHYzF2VH%2B7tCnb2bAmTqvTaTZHMyiJiCFJ7kiepJO85%2BT6RaL3Z6%2BAvDAoF84aruigvCJ6lLew2kTEkCRnUOzVkDyLNa%2B43nf%2BzGsdsqBLF4yCwaDRWVUkxYxBmKfUjYgYkuSirg%2BBl73aysytXhI%2FZUiPj0Fejmx30rgBMp10sOA5T6kbETEkyUU1%2ByHYXm1lF9SFTY4NdujyzrhpsBx5i2FydBTGeULdiIghSS5KqyDKXm1VVrV6DRnk49DljRzh3zGhoEJjRYIn1I2IGJLkqhRMs1dTVXWtSmA%2FY9efX9uGk181wWJRu%2FyakODzIewnhumeUDciYkiSq1KxcOow%2Bxxfs4qw02i7fj7LM3%2FOxoRb9%2BD02Zaub9id7asqAsRoaG%2BUzFYvUTduPEQMSfJ86fXeeNj9OsC2nmSvHBfsrFc6Nx0ihiR5OK2K5WK0csJozHTHxXf2DDvrtLKzbkTEkCRPlnoCOVYF8xQFW2MisHrECBhZlW%2BTdZH1kXWS9ZJ1Y1WI3BcvcE5ddiQTeyaNRpxZwcZ%2Betw%2FIQLvQMVerRWZw3JQvB2wXG01mSd6qUXhCLVoEClP0lGABSqQoVMRl5bFgCRiSNJV16MUo%2Bnyu4caFXPE9ANWLUYWRCA0xoWvLiN6d6oj2i2Ard1i8cZzxbs%2FIHqP8UeO4xi3FCKGJF3NvcqOIOhRGDgqsC5F9Op4eTgi6jYekyQiImJIEhERMSSJiIgYkkRERI7EE3fI%2BZ%2FMtEq3Lk23bOFwzJo%2BGAP6d%2F2rmQ2N7Sw0ETEkyf349zGYK2tbdQMCunYp2OFDfW1Dd%2BQW1bHQRHTlH%2BpZAnK2Pr76mrLTTQ6dR%2Bqxs7axoqIeV%2BFFDoiIIUluKrC%2FcV%2BKqdyh89idcso2VhVUiFE5q05EDElyC3klzWt37S01t7VbHdJ%2BYWk9ikobzm3hBeJnCatORAxJcgufH2pKM%2Bg1psTkQoe0%2F9izaV8%2FUNEoO5asOhExJMltlJ1tWrQ5MaclPbvaru2uezUD%2BcX15wKyQAwxVg12suJExJAkt5EmsqytXU1Y%2FuRBi72CUgbktgt7pwpSFOBLXnCciBiS5HYOpVs%2Bamg237N01X715a1Z6OkxSnkM8vYVX1wckCreFj9vVrV4lJUmop7i9ySpVx3OxOuxEVbNWzvzNyV%2BUKiLGx%2BE%2BCkhCA%2Fri9DBft%2F5mqYWM7IL6pB69Aw%2BSzklQrLh4ifIgJT3dlRwh0n0WFllImJIktsyZeG1CVFqmaXNsn1farlWDN49akgeg1SQIqbiVQ2WpB3HJ6wuEV0J7m4l1%2BhRikBTtBgvJj8VYVepABliOClCr%2FESL2sQzynUqOI1wHsqYBSP%2FcRHvxsOMyCJiD1J8iRpHbtGZ0dHYZzGigQxPQNWEZMKvu%2BadH6qihpVgb%2BYTlW1WGPiSTpExJAkT9Z5NqocnmA1iKg3cXcrERERQ5KIiIghSURExJAkIiJiSBIRETEkiYiIGJJEREQMSSIiInfFiwmQS1BN9%2Bp3HDj4YGZO9eLs%2FNqRVbVtxjNVLUpXXx%2FY32j29dbXBAUY9%2BWVNK%2BVN3ZmVYmIIUlub%2FcbMfc99OL763MK63xnTrsGty0bikEDfTAw0KvLbVRUtuhOVzQFpZgqEorLSmbdOtXHJG%2FsnMa7gBARQ5LcsveoPqXZ9tLOpHWbMuYumhOGdasmwqDv2REAGahyuC4iAHfPD9clJhfGbU7MyYgdq84xpVs%2BZrWJqCd4TJJ6jQzILUm5c59fPRGLZ4f1OCC%2FSbYj29v4dJyXj0H5MDYSd7LaRMSQJLchd7GKnt7c9Y%2FHYuyo%2Fg6Zh2x3w5o4rU6n2RzNoCQihiS5A3mSTvKek%2BsXid6eowLywqBcOGu4ooPyiuhR3sLqExFDkuyea2JQ7NWYPIs1r7jed%2F7Ma52y8EsXjILBoNFZVSTFjEGYk2undNaPiBiS5KFarg%2BBl70ay8ytXhI%2FZYjdjkFejpzPpHEDZFrpYMFzzixcZ91auAkRMSTJc51p9kOwvRrLLqgLmxwb7NQ3MOOmwXLkLYbJ0VEY56z5dtbtDDchIoYkeSgVyNEqiLJXe5VVrV5DBvk49T1EjvDvmFBQobEiwVnzlXWT9eNWRMSQJA%2BlAAfEj2n2aq%2BqrlUJ7Gd06nsICT4fyn5imO7E4k2z1Y%2BIGJLkmawa7BTdyYVTh9nnuKTVokKj7d55QKrojq1YcxQ%2FW3EQldVt3d%2FQO%2Bcn2gkQo6HOqJutXqJutvoREUOSPNOR4zgmRun13ni4t5bh9Z1FSEw%2BiS8OncHDa%2F99Jb1i2ZN0ygHRznqld9aPiBiS5Km0KpaL0coJozHT2fMuK2%2FGbzdk4caJQfjl0lFI%2FvwrJO0qvaK34%2Bhl7qzTys66ERFDkjxZ6gnkWBXMUxRsjYnA6hEj4LSDirLn2NZuxXOPXYcHfzESE6L88fhzGSg93exydZJ1kfWRdZL1knXj1kPEkKSrwJFM7BE9ozgVmNJPj6IJEXhB9pgmhmP4PAf1znZ8UobP%2FlWBlXeJmQz1hU6rYMOaaFtoPvD0Uduxyt4k37d8%2F7IOsh6yLrI%2Bsk6yXtxqiNwb7wJC3e5RitF0%2BV1DjYo5YvoBqxYjCyIQGmPHq%2FKcM3p4H7y%2F6QZMvO7ry9eNDPXD39%2B8EVU1bWhutcDHq%2Fv5LHp7donXgo6r6RSLN54r3v0B0XuM5zFIIoYkXe29yo4g6FEYdCegxoT3%2Fc5%2Fjwjrc0XLn5Zl%2F0AnIs%2FD3a1EREQMSSIiIoYkERERQ5KIiIghSZ610WkV26XpnKmhsZ2FJyKGJLk%2B%2Fz4Gc2Vtq1PnmVtUx8ITEUOSXF8fX31N2ekmp84z9dhZ21hRUS9GFq4FImJIkksK7G%2Fcl2Iqd%2Bo8d6ecso1VBRViVM61QEQMSXJJeSXNa3ftLTXLS8s5Q2FpPYpKG85t8QXiZwnXAhExJMklfX6oKc2g15gSkwudMr%2FHnk37%2BoGKRtmx5FogIoYkuayys02LNifmtKRnVzt0PutezUB%2Bcf25gCwQQwxvgkxEDElyaWkiu9ra1YTlTx60OCooZUBuu7C3qiBFAb7kBciJiCFJLu9Qugf0J4QAACAASURBVOWjhmbzPUtX7Vdf3poFex2jlMcgb1%2FxxcUBqeJt8fNmVYtHWXki6ireBYR61eFMvB4bYdW8tTN%2FU%2BIHhbq48UGInxKC8LC%2BCB3s16U2mlrMyC6oQ%2BrRM%2Fgs5ZQIyYaLnyADUsE0RcEdJtGDZdWJiCFJbsOUhdcmRKllljbL9n2p5VoxeNulYXkMUkGKmIpXNViSdhyfsNpE1B3c3Uqu0aMUAaZoMV5MfirCrVIBMsRwUoRcYzeaaRCvKdSoog3gPRUwisd%2B4qPgDYcZkETEniS5s7SOXaGzo6MwTmNFgpieAauISQW%2BXWzCT1VRoyrwF9OpqhZrTDxJh4gYkuRJOs8%2BlcMTrAYR9SbubiUiImJIEhERMSSJiIgYkkRERAxJIiIihiQRERFDkoiIiCFJRETkrngxAeoR1XSvfseBgw9m5lQvzs6vHVlV22Y8U9WifPN5gf2NZl9vfU1QgHFfXknzWnnDZUcvW0wEVK6hnknLgsIqEDEk6QrsfiPmvodefH99TmGd78xp1%2BC2ZUMxaKAPBgZ6feu5FZUtutMVTUEppoqE4rKSWbdO9THJGy6nOfhuHKZ%2FbuGK6qbYG%2B9kEYgYktTj3qP6lGbbSzuT1m3KmLtoThjWrZoIg%2F7Se%2BxlcMrhuogA3D0%2FXJeYXBi3OTEnI3asOseUbvmYVXUt53rh7FESdeAxSeoyGZBbknLnPr96IhbPDrtsQH6TfL583can47x8DMqHsZFg14WIGJLk%2FuQuVtEDnLv%2B8ViMHdX%2FitqSr9%2BwJk6r02k2RzMoiYghSe5MnqSTvOfk%2BkWiF3ilAXlhUC6cNVzRQXlF9ChvYZWJiCFJTss1MdjtmJI8izWvuN53%2Fsxr7bqQSxeMgsGg0VlVJMWMQRhXG%2FWA0rm9EzEkqctarg%2BBl70ay8ytXhI%2FZUi3j0Fejmxv0rgB8q%2BcDhY8x9VG3dW5nbewEsSQpO440%2ByHYHs1ll1QFzY5NtghCzrjpsFy5C2GydFRGMdVR93RuZ2fYSWIIUldpgI5WgVR9mqvsqrVa8ggH4csa%2BQI%2F44JBRUaKxK49qg75HYut3dWghiS1GUKcED8mGav9qrqWpXAfkaHLGtI8Pnw9RPDdK496ubGPs22vRM5CC8m4IGsGuwUvbJPpg7Dr74ouvLjNVaLCo3WMd8tP9euqiJAcfL2WFhcjkd%2B%2Feb5x2sen4%2Bo0UPxq9%2F8Fdm5p%2FDMUz%2FHiOE%2FsP0uv%2FA0nnv5ffz5hWVYcNfzaG%2B3fGebdy%2F%2BMeJ%2FPOGS862vb8YLf%2FoA%2F%2FhXBhobW%2FGDQf0RN3EUlt1xM%2Fr188XipX9EU3Ob7bk%2Fm%2F2ftuGJ3%2F0Nmdml32pr%2FNhhWP3Iz2A6kodn%2FvDut37%2Fi4U%2FxMz4iR65nYvt26texUKxvcfzfz0xJKnLjhzHsZgIpNd742Hx8Ldu0vuVPUlvZ84z5AeB%2BO3q%2F8aPbv01kpNWnw%2FE9MxiEV4tWPfHd%2FHqS%2Ffb%2Fq1BPD58rONKeg%2Fe91OoVqttesWjf8HiBT%2FExOgRtsfXhl7%2B2O3PRQgG9PfDC7%2B%2Fyzb%2B9%2FFiJO74hwjtCoy%2F7lqsffLnWLzsRcxPuBHxP4q2veb2hMmoq2s634bZbMXDv34d0dd1nHFcXdOAopJyvLzunovmNWxosMdu553bd7rc3vm%2FnhiS1C1aFcstCg5OGI2jh08g2V0W25kz0xt0GDI4wDYte3NGg%2F7875bdEY%2Bnnk3EsYwijBsz7KLXxcWGn5%2F2MhoQER6C6yeN7tI8q6sb8OXhXKR8uvZ8oF4zJAg%2FmRFjCz5pyOBAGPQ6BAb0Qd%2B%2BHbujZQ%2F3Qr%2F%2B7d%2FE6wbglw8lXLQsXV0Odye265litFJs53H8306OxGOSHir1BHKsCuYpCraKXuXqESNgZFW6Tu72vO%2FOW7D2hR12bdff3xfBA%2F2x4dWPUFB0%2BuJPrLqu%2FXdMejcFuz8%2Fildf%2FJ%2BLXtPS2oYDYsVfOHx1utqj1ovcjuX2LLdruX3L7ZxbK7EnST1yJBN7RMcizqxgYz897p8QgXegYq%2FWisxhOSjeDlhYpe931%2BIfY8tfP0PKgUz06WOfs3sV8df99T89gF%2F%2F7m3cGP84%2FHy9MG7stVg8f2qXjh0eOVaAp9clYcebj9p21V7cS23E8xs%2BuOjf3P2Y5DxAWxSOUIsGkZ0n6SxQgQyd6EGmZTEgiSFJduhRitF0%2BR1EjYo5YvoBqxYjCyIQGgPXu9ODK90L0tvLgP%2F9n1ux9g878fsnfm63duXu2w%2Fe%2BZXtGOPx7JP45%2F5MrHjkL6JXqL3kST8VZ2px9wMbsW7NEkSMuuZbv5e7jHdsfdSj1kNBx9V0isWGmiu21gOi9xjPY5DEkCT79yo7%2FrD06I9Ld%2F5gph6rQrtZRdTIvvDvq%2B%2F2vOxxiyZ7%2FoFfkHAjNm35BB%2Fvtv%2B9ouXxxusnjrINWSIsj%2Fy74HtDsq3djLtWbMDtcybjJzfHOnx74a2yiDrwmCTZ1c%2F%2F35e4bdl%2B%2FPtErWd8itRr8ciDs%2FHa1s%2Fs0l5u%2Fld45NdvoKik4vy%2F5eSdsu1GnThh5Pe%2B7vE1byEooA8eXnEbNzIi9iSJHC87t8z2dQzpp%2FN%2Fh1f%2BcB8mjP%2F2ddZn%2Fdck%2FOkvH6O2vvGK5xkQ4Ieq6gZMm%2Flr9OvnA4NBh%2FqGFvzvfT%2FFj6d2XJXvR7c%2BgYLC03jq9%2B%2Bgsqoe9yyZjv%2FblYqm5lZcE3nXRe0NHzYI%2F%2Fzk97Zp%2Bb3PIaMvvvPYU4%2FNxz2%2FmMGVTdRDvbJLRe4O4%2B4c9yHXl%2BmDnzqs%2FdhbPzw%2Fba%2FdraZ%2FbnHpmprbLfiqouPM0yE%2FCIRG0%2Fv%2FHWJvvNOu64HIE3KDPUkiO3rl9U%2Bx%2B%2FPvP%2FT7%2Bp9WoI%2Bft203rvx%2BJBG5NoYkXZa8dJyjLk3X0NjuUbVaesfNtoGIPOTvH0tAl%2BPfx2CurG11SNu5RXUsMBExJMl99fHV15SdbnJI26nHztrGiop68OIGRMSQJHcT2N%2B4L8VU7pC2d6ecso1VBfI7EeWsNhExJMmt5JU0r921t9Tc1m61a7uFpfUoKm04tyUWiJ8lrDYRMSTJrXx%2BqCnNoNeYEpML7druY89ecBUbFfJLiLtZbSJiSJLbKTvbtGhzYk5LerZ97iqx7tUM5BfXnwvIAjHEyJtFs9JExJAkt5MmMq2tXU1Y%2FuRBy5UGpQzIbRf2ShWkKMCXvHA1ETEkyW0dSrd81NBsvmfpqv3qy1uz0N1jlPIY5O0rvrg4IFW8LX7erGrxKCtMRK6GFxOgbjmciddjI6yat3bmb0r8oFAXNz4I8VNCEB7WF6GDL76%2FYVOLGdkFdUg9egafpZwSIdlwcWMyIOU9AhXcYRI9VVaXiBiS5PZMWXhtQpRaZmmzbN%2BXWq4Vg3e3GpDHIBWkiKl4VYMlacfxib2X8cLrkBIR9RR3t1LPepQi2BQtxovJT0XoVSpAhhhOivD7rltlNIjfFWpU8VzgPRUwisd%2B4iPaDYcdEJDyIsi8QDcRsSdJvSqtYxfp7OgojNNYkSCmZ8AqwkmB7zee6qeqqFEV%2BIvpVFWLNSaepENEDEm6GnSelSqHJ1wqxNmbJKIrxN2tREREDEkiIiKGJBEREUOSiIiIIUlERMSQJCIiYkgSERExJImIiNwVLybQRarpXv2OAwcfzMypXpydXzuyqrbNeKaq5Xu%2FrB7Y32j29dbXBAUY9%2BWVNK%2BVNy529DLGREB19zrzAgBE%2FPvGkHQzu9%2BIue%2BhF99fn1NY5ztz2jW4bdlQDBrog4GBXt%2F7morKFt3piqagFFNFQnFZyaxbp%2FqY5I2L0xx8twvTP7e4bZ15UXIi%2Fn1zNdremOngAfj%2F7d0JXBTVAwfw3y63gNyeqKSI4C144K14m7dRXnmWpqLmVWpqZdrhUZpaaYplpqZp5ZFpavrXIhWvVBAwBO8TQUCQa%2F%2FvDbBBagLCHvD7fj7LXrMzszNv32%2FezPDmnet38K7Bb11p3lHXdLy7aelXoVM7tXE1nzvZG74NXFDWxQrWpf57%2B0K%2BL4drVM8ZL3V7Tp2hgeuZ0HsjyzirTly7pblQVMt15PCeRlsYV675SfkOxlI%2BiIy69WiE9Zs%2B6gUek%2FwPmz7d8l3gdxEvLJrZCIN7V4O5WcEWl%2Fyc%2FPzyOb6WpcxV2xvWBJtMRMT6zQgwJP9jF8SqjeEvLJjREHVqOBTKOOV4lr3ra2Jqql7VgEFJRKzfGJJGuRsieKTZjn2XFwwSW0eFVYByFqQBPauqTKFaIba4unBpExHrN4bk4xjsWYzyLK8L0fHW%2Fbo9VyTjH9W%2FBszN1aYZGnznUxvV%2BLMlItZvhpkXegvJpq6wNNRCFBJxb0jn1hULvI%2F%2BaeR4G9dzkWvdFOlYyJ8tEbF%2BM8y80FtIJtmgrKEWorDI%2B9VaNCza2evYqoK8sxK3Fg1qoR5%2FukTE%2Bs3w8kJvIWmiQi1DLUR3Yx5aVixXqkinUdPdPnsnwi11Bvryp0tErN8MLy%2F0d0xSBT9DLUQx9x%2BqnOws8vWZOzEPcfn6A8TeT83T8K5ltYXURtw68KdLRIZUv2k0UOo0eUtJycjXNAq9ftNjXugvJDUY0MbNMI9LZqRroDbJ%2B3HiiOgE%2BPTch7YD%2F6cUqDwt%2BKzxi4LoKO4q86dLRIZUv6nEIJ%2BsiYB3j32YOO90%2FoKlEOs3JSdEXpS8kATOxFthSnEodBPmnMaD5HQsnFYXdWrY5XMDSdnSKsufLhEZmgVv1kVdTzts%2BvkKfv39ZgEagM9ev2XlxJkSF5ImGgSIu0nenuhmzIXof0fv4NhfMfCt74heHSsUeHHoer5TUtPwReAvGDxqMQKmrMSxExHK61eu3sXHy35CXFyidtg9%2B09h5%2B5g5bG8Dzp6HktX7MTAVz7GR4u3Iik5RXnv1p04ZZyxsYn46tv9WLlmN2sZIiNmIlqE70%2BurTz%2BeFWEzuu3rHyYlJUXJSskRT0bnqGCv2jSr%2FXxwkx3d1gYYyHadfCGcj%2Bgh3HtMR014TOcj7iKgJHPo12buhg%2Bdiki%2Fr4O14pOCLtwDRNnZHaU%2Fte5KLz59teoXauK8nz7L8fwqvjsg6SH6NG1MQ4cOotZc79V3rstQnL%2B4h%2FQd%2FCHYhxXcScmnrUMkZFrIhoAVStb4%2Fi5e7hxJ1kn05R5IHNB5oPMCZkX%2Bvr%2Ber0KyMkQ7GvsCd80FZbbmWGstxc2QIP9JhkIcQtH9GYg3dAL0F9hccp9o7oORlPoz52%2FhJCwywj6dT7UannsoDqOBIfj5z3BmDC6OxbNG4bn%2Fd9TWpQ%2F7DiCxR%2B8giquLtrPT3itO14dknks3tPDFX0HfYiP3h2iPDe3MMXWb6bBzs6atQtRMdGojgMiLyXibNh9lHMu%2FFNJ%2FEVrM8oDVdLVqClP0hG1Un8NcNZUA9%2FjofoLSL2HZHaLUtx1kP9Lo9agj3g8PsME1SO9UMUHhn9twXuxmbsanRyerSGsy2tBhkVcw%2B3b99Gsw5u5Xu%2FXt6Vyb2Ntic8%2FeQ0de72DkUM7onWL3Gdfq3KslapuZZXdrXH3M09YsjAzK5SALA7XxiQqLpwdM%2Bu3mLiUIvk9R0J5P1pULRGi1g8SrcfOJ8%2FhtCF8d4O5nmTWAjmdjy2MsUXVBM9PBW1jk7kIk5LT4VDarMDTLIyLDed1vm1tLOFWpQz2b3%2FvicNs%2BSkItb0qK7tX5S5ZRwebxw4XE5sAM3NT2IpgvV6I64AXXyZ6VGNPeMg9b%2BLHUVv82Au0560gG6APHmSO2trKtMT9ng2%2Bg3O54o%2BFI%2FLEeew4EYpJcalwE0v7YLoKfzaoiXb6nj%2B3ipmtprPhcUaz0n0b1sCNW7H4%2Fqc%2FtK9dunIHJ09HKo937jmOX387hS3rpsGvVV2MnbICGRn%2F%2FK7uZ7Ua09Mz8NnKn9GxbX0lKImo6Mj6TtZ7sv6T9aCsD2W9KOvHoj40lV2%2FVa1UqsQtd6Or2S5cwENxN9fbE6dEwm%2BWxzT1eVDXr6kLfthzFVt2XUXHFsbxnxy2tlZY89k4TJoeiHkLN8PSwgxJSSlY9P5wXIi8julvr8XGr6bAupQF5rzVH11feA%2BLlv2IqeN7K5%2FfuPUwvt38PyQ%2FTEGNahWxcukY1mBERdyCTNdgs0aDwTIYdTnt6KsPEHz2HiqUsYRntdIMSWMhC4qPFz4WW1bLxNOO%2BpqP3h0rYt7y89i%2B%2Fzpev3AfXu7GUYia%2BHjg9z0f4qZoUapUKpRx%2Bef%2FO%2F8KWqJ9bGFuhn3b5uT6rDxOOcC%2FFRISknN9rpZnZZz%2BYzFrNKJCllXPfazrgJQWfBmm9L7z2oBquc5HKCmM%2BnqStklKD%2FN19NlBuIW5Gu9PqY3UtAyMefsk4hPTjGoZli1jnyvo8qqUlUWBPkdE%2BZNVv9XJqu90Su4lkx0J1KxeGsP93Urk8jfqA0kHopDsUxPrszrQLbQzoWSXSvnpmq57u%2FJYu7AR4uJTceX6gzy1JhMSU41ymQ8Z4AcnB1vWXES6asnI%2Bk2F9bK%2B02X9JluP8lSET2fXRzNvJ6VBkFfGWr8Vu5DMXJPYL9bj64U5Sntb87S7cQ9NXRzz%2Fv9AXVqXy9c0IqLuG%2BXibtqoBmstIp1WcWiq0qDQjmPktX6Tu1b7dqpYoGkYa%2F322I0KY%2F8CYoPonFiXHoU5Tltrs9irNx4U6XwfPX0nsyBqILulSWdVQESPDSsoJ%2B2cY%2F3GkCwQqwTIXnddCnOcTg4WBw8H3yzS%2Bf718LXMrUQVbom7m6wKiOgJXLLqOdZvDMn8C7qi7Kcv1H6SLlxK%2BmDn%2FitpKakZRTLPF6%2FEI%2BpKQvYakP%2BceIn1ABE9gWVWPcf6jSFZIBoUcvd1vx15cNzcTB28ccfFIpnhaR8dzzn38nIbv7IeIKInUGXVc6zfGJKG4%2BqdB4NWbQxPPhN2r1DHO3%2FlWfwdHZ9dgCLFzSdDjS1c4kTE%2Bo0haTSOi3WdkqrpG%2FD2n%2BmFVZBkAdqUc%2BtNhcNiE%2FGYoXTkS0Ss31i%2FMSTz7MiZ9J8TktJeHTX9D83StaEo6D58uY%2F%2BpXEHchcgDeRFGDtpTPAGlzQRsX4zTOyV%2BilOhGBNQ68M9Tdb%2Fv5i47aLpr71ndG5tSs8qpVGlQqPvzLGg%2BQ0hEXex9FTt7H38DVRiBJyDyALkLyiiQrDgsUWHZcyEbF%2BY0gareBQrPaupbmanpK%2B%2BeDRmybiZlWgEcl99CocFo86a9QYcvwcfinseW3YcjhXGBEVy%2FpNH7i7Na9bXGKFq0xQXzzcLQrDXRVwVtwui0KR%2BB8fSxDDXFRrxGeAHzSAhXhuIzZNmp0oggIkr9nG6zASUXGs39iSNALHM3cd9JYdDmf1F9sRGaIYqWD9hI%2FYaDSI1ahgLx4f1Zjg3WCepENErN8YksVZ1tla8jbbIAs7W5NEVEzrN13j7lYiIiKGJBEREUOSiIiIIUlERMSQJCIiYkgSERExJImIiBiSRERExoqdCTyGj1fhXeDU2BV1xwSa4JFm3wf9OSEk%2FN7gsL%2FjqsfEpVjcjkl%2B4jSdHCzSrK3MYp0dLQ7KK6zLC8iyfJGhl3NiSBY7wYcCS%2FwyKOrO0n%2F9ymf060t%2BXBB%2B8b51N79K6PVaZZQrUwplnCyf%2BJlbd5NNb9x64Hw4%2BFbf6KuXevZoUypYXkD2uJFdbYDlq%2BSUc2JIUgloVRfmlrZG845606dbvpv%2FxdkXBvWphvnTG8HcLG97%2FmWAyltdL0e80s%2FDdOOOi76rNoafbVhH0yf4TPourjEylHJOxQOPSZLOyYAM%2FC7ihUUzG2Fw72p5Dsh%2Fk5%2BTn18%2Bx9eylLlqe8OaYJOAiBiSZLzkLlbR8nthwYyGqFPDoVDGKcez7F1fE1NT9aoGDEoiYkiSMZIn6ezYd3nBINH6K6yAzBmUA3pWVZlCtUK0KLtwaRMRQzJH%2FStuPJZg4ORZrBei4637dXuuSMY%2Fqn8NmJurTTM0%2BM6nNqpxiVMxoMqq34gh%2BUySm7rCkqvTsIVE3BvSuXXFAh%2BDfBo53sb1XGStYop0LOQSJ2OXVa8lc0kwJJ%2FV7SQblOXqNGxhkfertWhYtKupY6sK8s5K3FrIK6xzqZMxy6rXbnNJMCSfiQYIN1GhFlenYbsb89CyYrlSRTqNmu72mQ9UuKXOQF8udTJmsl6T9RuXBEPymaiAIPHHj6vTsMXcf6hysrPI12fuxDzE5esPEHs%2FNU%2FDu5bVhrCNuHXgUicjr9z8lPqN9KZYdCaQocYW0Wr4pY0b3joQpdv99zH3EvDx8p%2Fw%2B5%2BhSEpKgWsFJ%2Fg2roHRI7rAupQF%2FIfMhybrsPuQ%2Fm3RvUsjvDHra0RG33xkXE3F5yYH9MShP0Kw5Isdj7w%2FekRntGtdV3kcdPQ8Plv1CyL%2BvgZLSzO0aVkHE0d3h52dtfL%2BkePhWLDkx0fG8e6MfqjlWVk%2F6yldA7VJ3s%2BviohOQPtB%2F4OZmRo%2FfN4U9qXtnr7VlzV%2BscwdVcWgfP9X%2Bdq6LUgpR2%2B%2F%2BZJ2%2BPT0DARMXYnBoqzZly6FWfM2wL9XM7zUp4V2mJCwy5gtXu%2FdvQkG%2BrfGrTtxGDNphfb90rZWaNLQA0MH%2BsHC3Ez7%2Bo5fjuGr9b%2FhytU7sLa2RPfOjfDaiE6wtDBX3t%2F281Fl3NMm5q8Bf%2F3GPYx740vt8yqVXNC7WxO0aFpT%2B9rjfjNWlub4ZuXrCL9wDTPmrHtkvBNe64aWzWoa7boX9ZllvAYDRP3WmVHFkHwmJ8%2FhtI8XzsRbYYp4OldX09WImviloQtQvVoFLF0wUlQupXD6zEWs23QQPbvGiNfL45P3R4ig%2FAjjRnUTQVZb%2Bdygfq2RmPhPlj9MScPEaavRsqlXVuvpPm7eisX8OYNzTa%2Fac%2BWV%2B1%2F2nsB4UanMnPoi5s0ehPvxD%2FDJ8m3oNfAD7Ng0SwnnmJgEXL56G4s%2FGJFrHJUqOBvNep0w5zQeJKfjy1n1UaeGXb4%2Bq8psSVoZc7l%2BWvl6vlNDtOo6A21b1Ear5plHGwLX7cO16zHwFSF35HgEzoZGI%2BrSTRGIvjA3y%2Fy5f%2FblLpw7fwkNG2SeAJycnKpsdG1YPVlskJjg9p37%2BGjxVnEfp5Qx6cuvf8VSseH23qwB8K5XTSmf783fhKBjYcrn1GoVrt2IQWjYlXx%2Fz6Tkh8r0N301VfnOJ05HYvCoJVi7YoI2KP86FwU%2FsYGY%2FRuRTExMlPuEhCRlucjhc6ruXsGo67Ws%2BuyMrN8YVQzJZ2aiQUC6Cn96e%2BLUifPYoYtpXrl2V9ly%2Fnb1JJRxzqzEK7s6K63FtLQM5blrRSeYmprC2ak0bG0y6%2By6tdxyjWfi9NWoU6uKEqTZZNA1bez52IpzzoffYcZkf6W1kG3F4jHo1OdtrPvuAEYN66Td0n7cOIzB%2F47ewbG%2FRGVf3xG9Oha4sjMx5jL9tPJlaqrG9El9lVbU%2Fh3v4e7deCz%2BfBu2rH0TKlVmi7qsiz08RFhs2noYg15qIzac7uD02Si0a1X3kek1aeShbTnKYa5dv5dZWYsQWrBkK1YsGYO2LetkbmxVdMa6lRPRrOOb2LP%2FJDq3937m7%2BvbqIYIPrUSjDIoD%2F5%2BLldrUm50Pqk8m4hlYaxl%2FXFEPSYrg0miXvNlTOlXselMQGyIhmeo4C%2FqhrWiVTnT3R0WRT3NsmXs4eBgg0%2FFFnb05Vu5tz5M87ZoV3%2BzV6kQli8cpWyNZ0t8kLl1nfN263YcLkbfxCVR0cndUf%2BeXo8ujUXFcjbHFnpKrs9fiLxuNOtz18Ebyv2AHpVL7I8zL%2BVrwAut4Ohog%2BUrf8bb76%2FHyyIIPT1ccw0bMPJ5pfUog3XFmt0YObSjEir%2FduRYuFJO5G5VuctfDicdO3EB5hZmaNOidq7hbW2t0L5NPRw4fLbQW9C3bseKDQKXXK9H%2FH09V3k%2BKlrK2dLFd8v5nty4MEay3pL1l6zHZH0m6zXGFFuSheZkCPaJjUnfNBWW25lhrLcXNkCD%2FSYZCHELR%2FRm8VsqzOnJ3VeBy8aJymkD1qzbp1Qa3vWqYtjAdujQtv5TP%2F%2FHkfNY%2FNk2%2FLRhhvLZnGQlsWjZtlyvyWOS8liQpaiwso89%2FrtSvXX7vva5bFnkHEfr5rVEa%2FV5o1iXf4XFKfeN6jqU2B9nXsqXbDF%2B%2BM5gdH9xnmg12uHTBa8%2BMp56td1QqZKLGMde7D94BrPeeBHBpy48MtySz7dDpVaLME1Xyt9u0UKsX%2Fc5ZberbJFmt05zKlfWQTkuXhg%2BEb8FtZiGbMWWKmUJ%2F97Ncr3%2F857gXMGYfUxSSklNzVXW69aqgtk5jtUaKn%2FRCI7yQJV0NWpmnaTTXwOcNRUtyOOhDEiGZBG1KMVdB%2Fk%2FcmoN%2BojH4zNMUD3SC1V8iqBXnsY%2B1bFry2zExiYqx38OBYVgRMAyrF81Kdeuon%2BTu71GT%2FwCSz56FVXdyj3y%2FnNVyuL7tW888vrZ0EuiQkhTbtnHmLLFJyTDxvqfPhXkrt7HjaMgdH0NxHuxKcq9k4OFUc23PspXzRqV0NzXUzlWmH0Szb8FvNoVA15ZpOymz3kyTk7rAydr37t7Lx5tu85UTuCRZSohMemxn5G7Yq2tC68fjzsx8cpJSnu3zXnku0wY3R29uz1%2B76OVlUWhlHVdl5fIzN50okXFFCFqpyDReuzMY5AMSd20KjML2mld%2FVDs7a2VSiv7eMqJvyKfGJJyN%2BjwMUsxangn%2BLWqk6%2FpyONLcgv6cFDoI5899Mc5paVRFArjEkL5Wa42NqZZyyodDqXNimy%2B%2F2NLfmxR7eoqivJlYWH2n2cOy7M8Rw7thJf7tcnT9JwcbFG5sguiom%2BJVms95WSgyKgbuTbo5G5RGWiyZVsYJo7poRyTlMfjB49ajG0b3lK%2Bty4V9qWyGnvCQ%2B7ZEiOtLVZ6ke7ZoqLBDs6fwakzF5WTJmSrMJs8a%2FDc%2Bcto1MD9yZXB9NVK2I15Jf%2F9cMvW46tDO2Lme98qxyezBa7biyPB4Rg2Gzky0wAAIABJREFUqF2xWLZuFTMrx7PhcUU6HVlRHQtHpDzZ60QoJsWlwk1UaAflSWANaqKdMZavJ5G7WW3y0Op7mJKKH3ceQUjoZTRr4omKFZzQ6%2FkmmDBttfLvIlJaajrmLtgsWpjJ6NOjaaF%2B7%2BmTXlDO6H1l3DKkpqQZbRmW5UeWI1meZLmS5UuWM1neGJBsSZYI5crYK%2F8z1rLLDGXLW24FJyU9xIxJfbVn2jVr%2Fyau3ozB1Jlf4fbE3ujftxW27zqmvCcropzkWa9y15p0JiQaFT1zX%2FVpwXtDMcC%2FFSaN7YmMDA069noHTo62SHyQrJw9%2B%2B2qScpZh8WBX1MX%2FLDnKrbsuoqOLXTX4%2BCFC3go7ubKs6TFFuRmeYxbXydP5KV8FaaqdUcp93I6tb0qY9WyscrGnFL25g7FrLnr0bzDNKXMxd5PRA33itgYOCVX8O49cPqRcht6dBlKl857T0vyBLalC15F7wEfYPLMNfh0fuZx1oApK5VbNnm2%2BPng5QZZfmULMl2DzaKxPVhXZ9tT0dDLlTPk7iZDvgK4nL%2FgQ4F5Hl5u7d64Has81mVIyS1%2BecarbF3Kk3YKW8OWwwt1N5SyXLd1z%2BN3y0DDnvtwNzYF%2B75pCS%2F30nmf7x7bC2W%2B5VmG4q6VGEfHkli%2BHkeedR1zLx5WVuZwdiyN4qCwy3nWOt4j7v4nxjcXZNS5wZZkITAzN9VL5SVPsiguLcdHv5sa70%2BpjeHTgjHm7ZPYtrI5bK11W1xtk7Aw3gpj5Ulg%2BjyZQl%2Fl63Hk8UJ5y4%2F%2BIxYhNfXxexdlhwb57aHH0Ckd62egjig%2FPVg7Gj%2BGJOmMPLEkP13TdW9XHmsXNkJcfCquXH%2BQp9ZkQmJqoc2v7OLQpybWZ3WUzjMOC0j2yFOiyrksLyqs13UXmcSQJCNnb2uedjfuoamLY97%2FZaBL63L5mkZE1P3CnWkN9muA17n2KO9FBk1VGizmkigmGz1cBKQrttZmsVdvPCjSaRw9nXkmqKik4lEIZxCKhu850e714NqjvJLlRZYbLgmGJFG%2BODlYHDwcfLNIp%2FHr4czeXzQqyH7cnnliVgnKOFy49igfXLLKDTEkifLuwqWkD3buv5KWkppRJOO%2FeCUeUVcSskt2pPh76VnHGXRFOa5kybVH%2BWCZVW6IIUmUd78deXDc3EwdvHHHxSIZ%2F7SPjv%2FzRINE2bAshNHK3nFUXHuUD6qsckMMSaL8uXrnwaBVG8OTz4TdK9Txzl95Fn9Hx2fHWqS4%2BciLcXOJExFDkozGcZFlKamavgFv%2F5leWEEpA3JTztapCofFpvwxdhRNRAxJMjpHzqT%2FnJCU9uqo6X9olq4NRUGPUcpjkC%2BNO5A7IDX4VvztpDHBG1zSRPSs%2BH%2BSpBcnQrCmoVeG%2Bpstf3%2BxcdtFU9%2F6zujc2hUe1UqjSgWbx37mQXIawiLv4%2Bip29h7%2BJoIyYTcA8iAlFfyUGFYsGixcikTEUOyiOTsz5GKRnAoVnvX0lxNT0nffPDoTRNxsyrQiOQxSBUOi0edNWoMOX4Ov7B8EVFh4O7Wx5Cd6BpyB%2BzFqkUpAk1lgvri4W4RdnfFQj8rbpfF0k%2F8j48liGEuqjXiM8APGsBCPLcRm3zNThhBQLJ8EbElSZT30MjcNdpbdgyd1U9qR2SIEFHhSVfctdFoEKtRQV765KjGBO8G8yQdImJI6n6Ln0tBd7LORpW32SxfRGQIuLuViIiIIUlERMSQJCIiYkgSERExJImIiBiSREREDEkiIiKGJBERkbFiZwJEOubjVXIuyMsOE4ghSUT5FnwosNh%2FR3biTsUBd7cSUZG2mktSy5kYkkRERAxJIiIihiQRERExJIkKSB5T41malBeqrPJCDEmiEiO5qSssuRjoabLKSTKXBEOSqCS5nWSDslwM9DRZ5eQ2lwRDkqjE0ADhJirU4pKgp5HlRJYXLgmGJFGJoQKCxB8%2FLgnKQ2HxU8oLFRvscYfoKTLU2KLOwC9t3PDWgSjdHW%2B6GH0TU2d9rX3%2B7ox%2BqOVZGW%2B9tw5hEdeU1xwdbODhXgF9uvuiqls57bDfbj6IH7YfeWSc788epAz%2F8sjFSM9Ix4rFY2BrY6W8d%2BDwWfxx5DyGD2qHgKlfPnG%2BsueDchPlwzJegwGivHTm0mBIEpUYJ8%2FhtI8XzsRbYYp4OldX03Ut74S5MweiXY9Z2PHdTLhXLa%2B8fiYkGk18PODXqg7uxsRj38G%2F0Kn3u1g4byh6dm2iDHPp8m1YmJsiYGTXXOMsX85BuT92IgIVKzhixZrdmDKul%2FLanTv3ERp2Bfb21pgc0EN5LS0tA%2F2GL8SyhSNRroy98lqlCs4sFI%2BRVT7OyPLCpcGQJCpRTDQISFfhT29PnDpxHjt0MU0zEXIyyLLDzcLcTPueDMymjT2Vx906N0L3Lo0xcvxyNGpQHRXKZ37GxcVOO8zjTB3fG69PX42hA%2F3g7Fha%2B7qlhbn2c6kpacq9d72qqFKpDAvCE4hy0U3cTRLlxJdLo3jhMUmiPDh6HuEZKvirVFgrWpUz3d1hYUjzJ1uVXp6VsHN3sPa127fjECRmPOctPiFJ%2B76nhys6%2BTXA0i92cgUXkCwHsjzIciHLhywnXCpsSRKVSCdDsE80sHzTVFhuZ4ax3l7YAA32m2QgxC0c0ZuBdH3On1slF1y5dlf7POT8ZSxati3XMPKYpK27lfb55HG90KHnbLw6pCNXcB74AyZRHqiSrkbNrJN0%2BmuAs6aiBXk8lAHJkCRii1JWhB0a1EI9tQZ9xOPxGSaoHumFKj567pUnNi4R1Z4rr33eumVtLP5gxH9%2BprKrM%2Fx7Nxdh%2BiOaN%2FEqsnkrLlcCiczsTSdarOgIsbaDROuxM49BMiSJ6N%2BtysyKsUCVY1EExrXrMQg6Gobpk1%2FI92cnjO6Olp2nw9mpdJEtL158mYwVj0kSGbH4%2BCTs2X8K%2FkPmY1C%2FNqhZo1K%2Bx%2BEiwnH4oPb46tv9XKBEbEkSGYewiKt4edRi5XH3fvOw4pPR8K5fTXk%2BaUagcitlZYEaHhUxbtTz6Ne3Za7Pb%2F7hd%2BWW0%2FaNb2nHkdPo4Z2xduNvXOhE%2F6KXXSBydxN3v1BJJct%2F8KHAYv89G7Ycrn3M3zsZa25wdysRERFDkoiIiCFJRETEkCQiImJIEhERMSSJiIgYkkRERAxJIiIihiQRERFDkoiIiCFJRERUorGDcyI9yNmvKRGxJUlEWWQnzezwm4ghSUREZNS4u5VIjy1KLgUitiSJiIgYkkRERAxJIiIihiQRERFDkoiIiBiSREREDEkiIiKGJBERUVEoFp0J%2BHhBw1VpWPiP8kTEkDQgwYcCuTYNBDvvJqLigrtbqcha92zhExFDkoiIiCFJRETEkCQiIiI9hyTPfiQiIoPOC72FZFNXWHK9ExGRIeeF3kIyyQZlueqJiMiQ80JvIWmiQi2ueiIiMuS80N8xSRX8uOqJiMiQ80J%2FPe5oMKCNG946EIVkXU3yYvRNTJ31tfb5uzP6oZZnZbz13jqERVzDh%2B%2B8DPeq5ZX3%2Fr54AwuX%2FojPP34N%2FUcsQmpq%2BmPH%2Bcrg9ujc3vs%2FpyvH3651Pfi1qpPr9R93HsG67w5mrghTNebMGIAZc9Y9cTwfvz8cW7cF4fCfoY%2B8t%2BrTsTAzN8WQ15ZoX6tY3hHPd2qIjn71Hxn%2Bo8VbcezEBaxYMhpODrba1zd8fwi378Zh%2FKhu%2FGESkd6JnLCMF3lR8kISOBNvhSnifq6uJuha3glzZw5Eux6zsOO7mdpAPBMSjcTEZMwXwbFShI2UIJ6fOP238njC6O7QZGQoj8e98SUG92%2BLRg3clefPVXn6rnI5%2Frq13B55vV2ruoiPT8KKNbuxMXAK7OxKYXJAD%2BW9mNhEjBy%2FHGtXvI5SVubKa85Otoj4%2BxoqVnBEvz4tco3LupQFHiQ9RNDR81i1NAB2pUvhr3NRCJiyAgvnDkOPro21w8rvtnrtr6jk6oyfRFAPH9Re%2B96lK7dx9dpd%2FjKJyCBk5cQZcStXokLSRIOAdBX%2B9PbEqRPnsUMX05QtLRkwUvlyDrAwN9O%2B99qwznjno404fTYK9WrnDjTfhh7ax5YW5vDycEXTxp7PPD%2B2tlZwcrSFmZkJXCs6Ka9lj%2FfmrVjlvrF3dWW4nCpVdH789EVISj4NqqGMsx2aNfHEhcjr%2BO3QmVwhuWvPcdSt%2FRxe6NkU32w8kCskiYgMhcgHuUtrksgLX5EXYfqYB70dkxQNnvAMFfxVKqz18cJMd3dY6HNl2NlZY%2FTwLvjg4%2B8NvuBcvnpHaTHmvKWmpD122Os37qGyq0uu177fFoS%2BPZri%2BY4NERp2RQlSIiJDIfNA5oLMB5kTMi%2F0NS96vQrIyRDsEw0i3zQVltuZYay3FzZAg%2F0mGQhxC0f0ZiBdl%2FMzYnB7BK7bi8NBIaL1VspgC9CRY%2BG4ei0m12vymKQq699tVwTuVna%2FRojwi7mXIFqK7XKF5vGTF5ThZQu1fdt62CJC883X%2B%2FCXSUR64Q%2BYRHmgSroaNeVJOqIq668BzpqKFuTxUP0FpN5DMrtFKe46NKiFemoNZE09PsME1SO9UMVHx70sWFmaY%2BKYHvjgky14f%2FbLBlugXujVDFPG9Xrk9bi4RO1jedzxl19P4McNM5RWcrat24OUY5G%2F7D2hPC8tglK%2B9saE3iJkC39x80ogRPQ0kVDqiWhRA0WIWj9ItB47nzyH04YwbwZzPcmsBVKghVKYFXH%2Fvi3xReAv2PXrcaMtcKOGd1KOSZYtY4%2FhY5cqJynJY7DZISl3v%2F4htk604Xr%2FAf4MDkfTRjUKfV548WUiMmamXAT%2FWiBmJpgqWlVTZ34FR0cbo%2F4uo4Z1Us6GHTxqMX5YPx1Rl27h2o172LXlbZib%2FbPqzUxNseWnP4okJImIGJJGIiziKl4WgSF17zcPKz4ZDe%2F61R4ZrmfXxvjsy12Ii08stGlPmhGo3LI19%2FVCjy6NsGDJj4gV02necRp%2B3%2FNhnsb1yfJtyi1XS%2FzQJ7Awf3R1fvj2YPQbsQijJ36B56qUQdcOPrkCUurdvQmGiRbnvNmDlOfyGKW85XT1fCB%2FLURU4uhlV5jcPVqYu%2BHk%2BIIPsRI3FA1bDtc%2B5u5WIjLE3GBLUkdkRwC%2F%2FvbkQ6lrPhsHWxsrLigiIiPEkHxG8rifvBERUfGj5iIgIiJiSBIRETEkiYiIGJJEREQMSSIiIoYkERERQ5KIiIghSURExJAkIiIqXopNjzs5%2BwslIiJiSzKL7PSWHWkTERFDkoiISEeKVQfnbE0SERFbkkRERAxJIiIihiQRERFDkoiIiCFJRETEkCQiImJIEhERMSSJiIiomHQm4OMFTUlZYewwgYiIIZlvwYcCi%2F3KYifuRES6xd2tRthqLkktZyIihiQRERFDkoiIiCFJRETEkHwGPEuTiIgMOi%2F0FpJNXWHJ9U5ERIacF3oLySQblOWqJyIiQ84LvYWkiQq1uOqJiMiQ80J%2FxyRV8OOqJyIiQ84L%2FfW4o8GANm5460AUknU1yYvRNzF11tfa5%2B%2FO6IdanpXx1nvrEBZxTXnN0cEGHu4V0Ke7L6q6ldMO%2B%2B3mg%2Fhh%2B5FHxvn%2B7EHK8C%2BPXIz0jHSsWDwGtjZWynsHDp%2FFH0fOY%2FigdgiY%2BuUT5yt7PoiIKDeRE5bxIi9KXkgCZ%2BKtMEXcz9XVBF3LO2HuzIFo12MWdnw3E%2B5Vy2fOSEg0mvh4wK9VHdyNice%2Bg3%2BhU%2B93sXDeUPTs2kQZ5tLl27AwN0XAyK65xlm%2BnINyf%2BxEBCpWcMSKNbsxZVwv5bU7d%2B4jNOwK7O2tMTmgh%2FJaWloG%2Bg1fiGULR6JcGXvltUoVnPlLICJ6jKycOCNu5UpUSJpoEJCuwp%2Fenjh14jx26GKaZiLkZJBlh5uFuZn2PRmYTRt7Ko%2B7dW6E7l0aY%2BT45WjUoDoqlM%2F8jIuLnXaYx5k6vjden74aQwf6wdmxtPZ1Swtz7edSU9KUe%2B96VVGlUhn%2BAoiInkDkQzdxN0nkha%2FIizB9zIPejkkePY%2FwDBX8VSqs9fHCTHd3WBjSypGtSi%2FPSti5O1j72u3bcQgSM57zFp%2BQpH3f08MVnfwaYOkXO1m6iYgKSOaBzAWZDzInZF7oa170ehWQkyHYJxpYvmkqLLczw1hvL2yABvtNMhDiFo7ozUC6PufPrZILrly7q30ecv4yFi3blmsYeUzS1t1K%2B3zyuF7o0HM2Xh3SkSWdiCgP%2FAGTKA9USVejpjxJRwX01wBnTUUL8nio%2FgJS7yGZ3aIUdx0a1EI9tQZ9xOPxGSaoHumFKj567pUnNi4R1Z4rr33eumVtLP5gxH9%2BprKrM%2Fx7Nxdh%2BiOaN%2FEqsnnjlUCIqLiIhFKfRYsKP0LU%2BkGi9dj55DmcNoR5M5jrSWYtkAItlKIIjGvXYxB0NAzTJ7%2BQ789OGN0dLTtPh7NT6SJbXrz4MhFR0WMH5%2F8SH5%2BEPftPwX%2FIfAzq1wY1a1TK9zhcRDgOH9QeX327nwuUiMiImZakLxsWcRUvj1qsPO7ebx5WfDIa3vWrKc8nzQhUbqWsLFDDoyLGjXoe%2Ffq2zPX5zT%2F8rtxy2r7xLe04cho9vDPWbvyNJYyIyIjpZZed3D1amLsL5fiCDwUW%2B5XVsOVw7WPubiWikqSwcyOvuLuViIiIIUlERMSQJCIiYkgSERExJImIiBiSREREDEkiIiKGJBEREUOSiIiIIUlERMSQJCIiKtGKTQfnOfs1JSIiYksyi%2Bz0lh1%2BExERQ5KIiEhHitX1JNmaJCIitiSJiIgYkkRERAxJIiIihiQRERFDkoiIiCFJRETEkCQiImJIEhERUTHpTMDHCxquSsPCjh2IiCFpQIIPBXJtGgh2Nk9ExQV3t1KRte7ZwicihiQRERFDkoiIiCFJREREeg5Jnv1IREQGnRd6C8mmrrDkeiciIkPOC72FZJINynLVExGRIeeF3kLSRIVaXPVERGTIeaG%2FY5Iq%2BHHVExGRIeeF%2Fnrc0WBAGze8dSAKybqcbMy9BHy8%2FCf8%2FmcokpJS4FrBCb6Na2D0iC7Yui0IkdE38fabL2mHT0%2FPQMDUlRjcvy3sS5fCrHkb4N%2BrGV7q00I7TEjYZcwWr%2Ffu3gQD%2FVvj1p04jJm0Qvt%2BaVsrNGnogaED%2FWBhbqZ9fccvx%2FDV%2Bt9w5eodWFtbonvnRnhtRCdYWpgr72%2F7%2Bagy7mkT%2B%2BbrO16%2FcQ%2Fj3vhS%2B7xKJRf07tYELZrW1L72xqyvle%2Bak5WlOb5Z%2BTrCL1zDjDnrHhnvhNe6oWWzmvzBEpHOiJywjBd5UfJCEjgTb4Up4n6uznJZo8FLQxegerUKWLpgpAivUjh95iLWbTqInl1j8HynhmjVdQbatqiNVs0zW%2FeB6%2Fbh2vUY%2BIqQO3I8AmdDoxF16aYIRF%2BYm2Uuvs%2B%2B3IVz5y%2BhYYNqyvPk5FQEHT2PDasnw8zMBLfv3MdHi7eK%2BzjMnPqiMsyXX%2F%2BKpV%2FswHuzBsC7XjXcvBWL9%2BZvQtCxMOVzarUK127EIDTsSr6%2FZ1LyQ2X6m76aqnznE6cjMXjUEqxdMUEblH%2Bdi4Jf67po2dTrn10aJibKfUJCkrJc5PA5VXevwF8sEelUVk6cEbdyJSokTTQISFfhT29PnDpxHjt0Mc0r1%2B4qLbNvV09CGWc75bXKrs7o3qUR0tIyYGqqxvRJfZVW1P4d7%2BHu3Xgs%2Fnwbtqx9EypV5hnIZV3s4SHCYtPWwxj0UhtcFq3A02ej0K5V3Uem16SRh7blKIe5dv1e5koXIbRgyVasWDIGbVvWUV6rVNEZ61ZORLOOb2LP%2FpPo3N77mb%2Bvb6MaIvjUSjDKoDz4%2B7lcrcnq1cqjaWPPx68fsSye9B4RkS6IfOgm7iaJvPAVeRGmj3nQ2zFJ0dAJz1DBX2TPWh8vzHR3h0VRT7NsGXs4ONjgU9GCi758K%2FfWgmnmohjwQis4Otpg%2Bcqf8fb76%2FGyCEJPD9dcwwaMfF5pPcpgXbFmN0YO7aiEyr8dORautOjkbtVDf4Qow0nHTlyAuYUZ2ogWa062tlZo36YeDhw%2BW%2Bgt6Fu3Y8UGgUuu1yP%2Bvq7MX%2FbtqGgpZ0sX3y3ne3LjgohIF2QeyFyQ%2BSBzQuaFvuZFr1cBORmCfaKx4pumwnI7M4z19sIGaLDfJAMhbuGI3izq6sKcntw9GrhsnAi%2FDVizbp8SSt71qmLYwHbo0La%2BMoxsMX74zmB0f3GeaDXa4dMFrz4ynnq13VCpkosYx17sP3gGs954EcGnLjwy3JLPt0OlVoswTVdCardoIdav%2B5yy21W2SLNbpzmVK%2BsgwutaoXzfTz7bBrWYhmzFliplCf%2FezXK9%2F%2FOe4FzBmH1MUkpJTcWiZdu079WtVQWzcxyrJSIqLP6ASZQHqqSrUVOepCNqxv4a4KypaEEeD9VfQOo9JLNblOKuQ4NaqKfWoI94PD7DBNUjvVDFpwh6WWjsUx27tsxGbGyicnzxUFAIRgQsw%2FpVk7S7ImvWqITmvp7KscLsk2j%2BLeDVrhjwyiLMmOyf62ScnNYHTta%2Bd%2FdePNp2namcwGNjbYmExKTHfkbuipUn8RSWOzHxyklKe7fNeeS7TBjdHb27%2BT72c1ZWFvh%2B7RvPPH1eCYSIniYSSj0RLSr8CFHrB4nWY%2BeT53DaEObNYK4nmbVACrRQClIR29tbK6GYfbzuxF%2BRuY7XWViYQW3y5IyWZ3mOHNoJL%2Fdrk6fpOTnYonJlF0RF3xKt1nrKyUCRUTdQ1e2fY9Fyt6gMNNmyLQwTx%2FRQjklal7LA4FGLsW3DW8r31iVefJmIjFmJ6uD81JmLykk58mSbbPKs1HPnL6NRA%2Fd8j0%2FuZrXJQ6vvYUoqftx5BCGhl9GsiScqVnBCr%2BebYMK01cq%2Fi0hpqemYu2CzaGEmo0%2BPpoX6vadPekE5o%2FeVccuQmpLGUk9EZGwtSV0oV8Ze%2BZ%2FEll1mKC072cpKSnqIGZP6FsmZnFXrjlLu5XRqe1XGqmVjlTNjpQVzh2LW3PVo3mEanBxtEXs%2FETXcK2Jj4JRcwbv3wGlU9Byea7yhR5ehdOlSed8SUquwdMGr6D3gA0yeuQafzs88zhowZaVyy2ZrY4Xzwcv5qyAiyqKXXWFy92hh7oaT4ws%2BFJjn4WVr6sbtWOWx%2FNcLfUp88BAx9%2BJhZWUOZ8fSxaJQNWz5T6hzdysRGWJusCX5H8zMTfUejtnk8UJ5y4%2F%2BIxYhNfXxJ%2F7KDg3y20MPERExJIsN2SMPEREVPTUXAREREUOSiIiIIUlERMSQJCIiYkgSERExJImIiBiSREREDEkiIiKGJBERUfFSbHrcydlfKBEREVuSWWSnt%2BxIm4iIGJJEREQ6Uqw6OGdrkoiI2JIkIiJiSBIRETEkiYiIGJJEREQMSSIiIoYkERERQ5KIiIghSURERMWkMwEfL2i4KnWLHTcQEUPSiAQfCuTa1BF2Jk9EJQV3t1KBW%2B9swRMRQ5KIiIghSURERAxJIiIiAw5JeSyLZ0cSEVFeqLJyo8SEZHJTV1hyvRMR0dNk5UVySQrJ20k2KMtVT0RET5OVF7dLTEiKNnO4iQq1uOqJiOhpZF7I3CgxIakCgsQfP656IiLKQ2j4KblRUkIyQ40tojk5oI0bj0sSEdGTKTkh8kLJjZISkifP4bS4OxNvhSksAkRE9CRZOXEmKzd0Tm99t5poEJCuwp%2Fenjh14jx26Gq6n67YgcEvtYW9vbXyfN%2FBv2BlaY5mTTwR8fd1BJ%2B8gEoVnbBu00FkZGgwbtTzqFOzinbYX%2FaewN2YeLg4lUbvHk3h29BDee%2F3P0PxMCUVZVzscfDwWXh6uOJsSDT6%2B7dCGWc7ZZi0tAwsW7kTwwb6wc7O%2BqnzunN3MH7aeQSpael4vmNDvNCrGVJT0vDFmt3wa10HtTwrK8OFhF3G4T9C8MqQjvjrXBQuXb6N9IwMbN91DA72Nnh9THfxnZyVYZet%2FBkv9m6OP46eR%2BTFGxg%2BqL12WRARGRKRD93E3SSRF776mge9dSYg6ujwDBX8VSqs9fHCTHd3WOgkJD%2Ffgdj7idrnew%2Bcxu9HQpXHFyKvY%2FqcbxC4bh%2F8WtWFswjCIa8tQXp6hvL%2B9Zv3lGAaNrAd3KuWx%2BCRnyDq0i3lvcMiJN98e624fY07IkTjE5JEYEXjm40HtNPave%2BEEnx5CciVIgg%2FW70LL%2Fdri6ED2imPv9t6GGbmprCxtsSIsctw%2F%2F4DxMcn4ZWA5ahcyQVqtQqnz1zEhDdX4X%2B%2Fn0Pn9t5ISkrBwFc%2B1n6HZV%2FuRJ9BH2Lvb6cRG5eItIx0%2FhKJyKDIPJC5IPNB5oTMC33Ni16vAnIyBPsae8I3TYXldmYY6%2B2FDdBgv0kGQtzCEb0Z0HkNXqtGJQQuH6c87tPNV4Tcb7h6PQaVXZ0x6MXWSElNU8K0ds3KqFDeEafPXoRb5TLK8A3qPIcVS8ZApcrsJ8HJwRYTpq3ChNe6w9RUjTXf7sfwl9s%2FdR5koC3%2BYgd2bZmNKq4uymsT7nfDhu8P4aU%2BLTBsUDulxTvprUCoxbR6d2%2BiBGK2dm3q4pMPRmi%2FQ53mE5Tw9K5fTXlt%2FpwhSsuZiMgQ%2BAMmUR6okq5GzayTdPprgLOmogV5PFR%2FAan3kMxuUYq7Dg1qoZ5agz7i8fgME1SP9EIVHz30yqM2%2BadxbWpmglJWFkgVwZjdupO7K2uJgCxXxh5xoiWXnv5PJxAuLnbagJRaNPVSWn2yBSlbnucjriiB9jS3bschTrTyXhqyINfrHu4VtI8XzB2KVl1moFxZB3yxeMyTV7D4DpUqOOPGrdh%2F5jNr929h4JVAiOhZRWb2phMtas8IUesHidZjZ30dgzS4kNS2KjMXSIEWSn4qahliaWn5b6DeuHkP8z7%2BHv%2Fb9b62dffSsIVPndaQAX74av1%2BVK9WAf37toSlhflTpyWDVX521%2Fez4eBg89hh5DFQK0sLZXfv8VOogaAKAAACNklEQVQX0Mi7%2BhPHdy8u4YnjeVa8%2BDIRFWclroNzecLNsRMXlMcXo2%2FixKm%2F8%2FQ5efIMNBpYmpspz8MiroqAuvnUz73Yq7myq%2FP7H3%2FHkP55%2B9dQW1srNG1cAx8t2aqc7CPJY4%2B%2FHTqjPJbB%2BMasr%2FHlp2Mwd%2BZAvDbxC9yJua%2F9fEJisnLSkfT9T3%2BI2dagYb1qLO1ERMbaktSV8aO7Ydq732DJ59thLVpsDnZ5O7NTnh068MU2aNFpOhwdbVC2jH2eWoUy8Lp08EHig2S4VnTK83wuWzASAVNXom7zCbC3LYV79xPx2rBO8G1UA6%2BMW47J43spZ9DK2%2BGgEIwWQbkxMPM%2FakLPX0FjvylKUJqbmWLl4jHKCT9ERJQ%2FxWJXmdzdGnwoMM%2FDx8YmIj4xSftvEflx604cNCJ8ZEjmhTwJp0WnaVg0b3iBTpa5dy8BCSJg8zqvX6%2Ffj0MiNFeIYLx2IwauFZxyHSctDA1bDtc%2B5u5WImJLspiR%2FxdY0P8NLJPPk17k%2F1WWKmWRKyB%2F%2Fe0UVqzZ88TPzH7zRdSt5aY8lscSC3I80cREXaCNACIiKuEhqUvOzqW1%2F46RrUPb%2BsqtKDT39VJOEiIiIoakwWvi46HT6cl%2FNZE3IiJ6dmouAiIiIoYkERERQ5KIiIghSURExJAkIiJiSBIRETEkiYiIGJJERERGqth0JpCzP1EiIqLCYFIcvsT1O3hX3iq44B2uUt0vey4FIiquuLuViIiIiIiI8uf%2FC8mYNyvnK0oAAAAASUVORK5CYII%3D)

```
expr     ::= expr ( ( '+' | '-' | '*' | '/' | '%' | '<<' | '>>' | '&' | '|' | '^' ) expr | '.' INT_SIZE )
           | ( '(' expr | SIZEOF '(' ( SYMBOL_REF | IDENT ) ) ')'
           | INT_LITERAL
           | IDENT
           | SYMBOL_REF
           | unary_expr
```

referenced by:

* expr
* int_const_expr
* unary_expr

**unary_expr:**

![unary_expr](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMUAAABRCAYAAABiz2KlAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAADnhJREFUeNrtXQl0FEUa%2FnrOXAjkZCFLgEAgAYQcYOQhIEpAiRwGnsBjyYoKcVFRhFXUXU4PTpVLYVlEXdaQyCUgCoKyRkLCJIAJCbkJJAEmFwkh58z0VnVm8pIISQg9kznqe69f9Ux1%2FTX19%2F%2F1X%2F90HQADA0MTcNbaMF41T%2F5t7NmFKemlc9KyyvqVlNUqC0uq29xel65KjaO9%2FJars%2FJ05tWqD3%2BOq0ywNB0E%2BoK39PuYkGp6G5VZIyFO7A58%2BfVPD65Lzyl3DB37Z0yJ6Ilu7g5wd7Frswx1cbXshrrSNUalDsvNvzp50hgHVX5R5eyEZGRZki5Uv%2B6y2PsY9NjcDqlXalXegV8u8XMujtq8O3XJ%2BDGeitVvBiDY3w0ebvZwdLg%2F%2FtPrablhQ1zxXGhviY6HZ1Jq6Tx3Vy6xQM1nWoI%2Burth%2Bby5ky32fu744pDQBnpcL8IKU9UrsSZSRG3at3fX3oxpG94bhjlTvaGQi9M8KofK27oy2M5BwR0O8sNcMFgtrIYUtMu0MzJ92rp3gjC4f1ej1EHlblkRLJXJJDv9GTEYKcw9qD5y8tq62eRpbixCNCbGrMl9OBm47cRjPMVMiJHCLEH%2FZcrMve04I7S3SeqbP7M%2FFAqJjMQZewMHwZuZESOF2SElozR8wugeosUQbYkxhg9xo%2F8VyqDFemZGjBRmh7Tscu%2BRQR4mrTNkVHea2JNjpP9ADGGmxEhhViguqbHr0c3BpHX69e1Sf8JBLdEhjJkSI4VZoaS8hnPprDRpnZ4eDSR0Isc4ZkpWRopHBqHFvkdr%2BR0NnZaHRGra0QCG%2BngeziTpyUyp4%2FGgdmooL5CiTouCQF9E3Utoa%2FmWis%2F2ZGNKxBlq2O0GV%2B8pPJhJdjzaa6fDfTE10A%2FXNFrk0M8y%2FY2l5Jiu1ZJMXxyQSfFqXDJuNrrxLeZbKrKuVuC3hGJCCh4c90CexuKHy9TWabDr659wJu4yHurkgPBZj2NYQD%2Fk5Rcj6kAMXvjLk%2Bjc2VG49vipC6gj108cH4SjP6rg3NUJqvNZOHsuDQ8P6oXXIkJhb6eAuqgM%2B7%2BLxYxnH8PBo3Gora3DvOfHG60N92unlAxaDptIR8Oz8dDJJjEFX08SKjTvboxrLZ%2FBcjF%2F4TZczsjHK%2FMm4okxD2Pugs3IyLoOzx4uSMsswBvv1A8s%2FP3SFby17EsMGuglfD78wzm8RMpWVtVg0tPD8cuvyfjH6j1CXiEhxdpPDiBszkdERj6KSm6bpC2t2anBM2iB%2FaCEaAZZK0IFxrWWb0meY9t%2FspCaVX9zVEmlQrpw1cWG%2FBUL%2FeDcRWFThLh0%2BSpS0q4h9sRaSCTUY%2FZDnCod3x9XYeHLz2DD%2B89j4vRV2LjlEA4cicMnH74IL0%2B3hvILI57BS%2BH1%2FzUM8PFE2OyPsGZFuPBZoZRh%2F9dvN3gZU%2BIPdsrhmAZY2dwztIkUDQEscIG4kgl8K%2FkaDXJIpfaWYAApmeU4k1ginJeW1Qop7UIZUFWjbZdcS567kJZRgMLCcowY91aT72eEPSakTo52%2BOzjCIRMWY55fw3B6JEDm3ZbGvU8%2B%2FTyQFV1LcrKK4XPSrlcFEI8iH6pnZKfOFHDYxpJda0Jkt2jb3aGFMwn6ZNE4E6SvtFSvlyGNQZPMZ30r6%2F4wEsrgR%2B5cCy5Zia5NlnGY0H8ZaQb46bej8K2LPdvOF%2F84e%2F4cn8uVAfH6p%2BQ7YfYk2GGD4CPhsNWInQQadw3pIWnpDqk9EpHbjSgFVMvnZzs0MvLHacOr7rnNfsOxWKQb0%2Bhu0S7WDSOuBtKblVArpChEyHSdRH10Rb9Nm9vYzsl6XY7OXZV12EueZC%2FyHMou1vX6Q%2BkMAjh64XEyaXwpcZOKnujpfzGMoQblo5sckqPI337YmlnOZaQgOasvx%2Bmn0%2FBSdaDbxlET08QFx9N9L2xrA6hmZmoMeSdM0J9wUH9cUN9C98eOoNpk0cI313NK0JxcTn8h%2FTB0eMJOPHzBRzbtwwr1%2BzFgsXbsedfixoeJOV6r6DV6rBtx%2FcIeXyoQIyOQit2uojEGGvqtHjrXuRo%2FMujWzL2NuTfFfobujpggNDViiZPwGBjeQxrAPUQlBA8jzmJl3HEFHV26mSPL7a9ikVLd%2BH99dGwU8pRVVWLDR%2FMRWb2dSxd9hUidy%2BGo4MSK9%2BdiaenrcKGLQex5LWpQvnI%2FTHYE%2F0%2FVNfUor93D%2BzY%2FLeOVGGrdqr%2F7p7kMJCiigjJa8HYW8tvFfQGE4%2BzkXiMLeRjiDkY4PqlDwuHOUGvn42mIoQBjwT64LfjH%2BEm8Rj072l3t84Neb%2FHftpwrlTIcfK7lU3K0jhj1vRRqKioblJu4ICeuHjmE1M2477stDk5iIeJaCCFTIreLQlpLb%2FNT6QqrL9tjwV0AN35S7jI%2FEKzbhMdWKjDYKKnSR31Gzzcu7SrnIO9Ujg6Eu2108bkoJ8ljb5srdAD45crqCYdvv%2BKPYCODrmgQz1MiYo7daLLFPRC9CPoyUIQPmssRo0YaBa%2F5UHt1FDe9AMCeZwi5vuomCK7dFJoistqTNqMjCvlRlAN0QvRjyV5t0eH9YdP3%2B5W5bFNTgryQL9E%2Bm4%2BogaKjvJb%2BTcqTdqO%2BItF9f908KBvArViyKR6ofphHUkbI4V9heCi3MSU6dJVeTpGZdoX6idiCuqf7hzUJBGrcje9fhhsiRSxeUJ%2F2U5MmXQFv6On8jS1dTqTtCEn7zau5FUYNEjfx1wVSbSdXj8MtkSK%2Bq6zuG9%2F6ZKWCrlEFXkkxyQNeHtNQuPW3KGOQyTRnF4%2FDDZGCqOALmm5MzK9Oimt1Kj1rN2RjKzc2wZCZJMjUCfBPmZKjBRmB7rGa20dH%2FbKsrNaYxGDEiKqsTfiEEMe7efYOxdGCrNFXJL2%2B4oqzUvzl57hN3%2BVCrFiDBpDPPfqL00JwYNOGhjPS%2FF3ZkbWBatbdTwxBV8E%2BeokX%2B%2FL%2BjzyuxxZ8FBXTBjtCR%2Fvh%2BDV3alNMiqrNXTZHMRfKMRPMQWEFBXNo6I9wghgDs%2BrLGwVcgYbJAWFKhX%2FDhjI52trtdGn429KySHOXA8aQ5AuE%2BgcEwnCEy7hB3PXRUctZ8%2B6T%2BboMYjBclIMJac%2FEmMuJn3%2FZHJcI0Z95z7EVJAyORKeyAAO8IBSWKhAhhGJFkAIOgehIzY9YZ7CzINvkkylA%2B30461CoCNGwqGtU8GceB63eA50lFw8iR9WqFhQzUhhDdD%2FO0SPf9riTWbegnWfGBgYKRgYGCkYGBgpGBgYKRgYGCkYGBgpGBgYKRgYLANW%2B%2FKObiNMd01NSS%2Bdk5ZV1q%2BkrFZZWFJ9z5dYLl2VGkd7%2BS1XZ%2BVpOpOPTlxi5sFIYTWgG82%2F%2FunBdek55Y6hY%2F%2BMKRE90c3dAe4u954Fqy6ult1QV7rGqNRhuflXJ08a46CiE5cS2ChYm0OHbDbS3Q3LrxdhhejegV8u8XMujtq8O3XJ%2BDGeitVvBiDY3w0ebvZwdGiZ%2FzSfXjdsiCueC%2B0t0fHwTEotnefuyiUWqPlMS9YLgw3HFFGb9u3dtTdj2ob3hmHOVO9276tNy9HyW1cG2zkouMNBfmDjrxkpLLPLtDMyfdq6d4IwuH9XUWRSOVtWBEtlMslOf0YMRgpLC6qPnLy2bjZ5uotFiMbEmDW5DycDt514jKeYyTBSGM2OIeIyN%2FRfpszc244zQnsb5cfOn9kfCoVERuKMvYGD4G0knbDlbWycFNWPeoq3IFpKRmn4hNE92h1DtCXGGD7EjVqtDFqsN0Yden2whdBsmBSFVU7i7ayall3uPTLIuBu1howSFhGmc71HCkvmiwy9PgqZSdooKUgfIV3KQbT124tLaux6dHMw6m%2F269vF0MlRi72VAAXVB9ULM0kbJQXphsTSJWLEkldSXsO5dDbuhiGeHg2ko%2BvkjDOCUsYKemGwTVIIy0zymDWmlzhxBd2whW7cYlRF6eXzPJxJ0lNM2YIeiD7Y8ps2TAr9QgJJt%2B2x2NIUxtV7ClEDGL0ektjym7YdaEPK4xWSLAoYgFAL1Jtow2P07V%2Bk1weDLZOCbhus4zCd4%2FBVoC%2Fe69sXSltSPG0vbTdtP9UD20bZfNCho2TpRvN0X20Nh62d5VgQ4Itv6J5vUh1SeqUjN1qkbbMMOB1fiI93ZTT5bucHgXB1Nj4fpxPvcsUHXloJ%2FPRB9UweSJbxCE5IZYRgpGjmMUgyTljFj8ez5Pw1nRT9sn3hFSjy5i5FpbX4LaG4yXfVte1bmZw85e%2Fr7XN2%2FdvqXNKgDNKqWOIdJrAYgpGiLcH3RWMaaNj4HsIhBtiqeyymYGBgpGBgYKRgYGBgpGBgsFpS0CEYdKiHMVFxp45ZCyOF5aBLJ4WmuKzGqHVkXCln1sJIYTno5Ci%2FlX%2Bj0qh1xF8sElKOB91EW8tMh5HCrOHSVXk6RnXTqHWciCkQUp6DmiQ3mekwUpg16Ip%2BR0%2FlacTaN7s56D7aVwzbBkvoy2lcZabDSGHWoEtcKuQSVWTjzd9FxNtrGq2gyQu7q55gpsNIYfagS1zujEyvTkorFVXu2h3JyMq9bSBENjkC2WQg64bUWhpyXY3SP7ly54%2F%2Fmj8jaLCrxMPVXhRCRDX2PhwOc0BRYgo2MdNhpLAMb6HmM1y66q4dO5U3qbJGy%2Fn7uUDajmmqNIaIeDcWMeduNu427SGkCCEam0kJyEzHemGVIz2DfPECx3Gfy%2BUSWfBQV0wY7Qkf74fg1d3prtdXVmvoMjmIv1CIn2IKCCkqml5QT4ixHIcXVCk4xsyGkcIiETAQE6BDNFfvDdvXl6IxBIcYkk7gpQhPvIQfmMmw7pPlxhiFyOzeDVHEoL3J4Uae8tmEIDXEyOkcEsU9ilWQa%2FIlPOJ5Dkk84CXhUEhKzCCEOMfMhXkKq4Ewq69%2BAbMQQpAepNWeLXiHPJKfT86O03%2BZ2Ow4BgYGm8f%2FAY9whRXOA8A8AAAAAElFTkSuQmCC)

```
unary_expr
         ::= ( '+' | '-' ) expr
```

referenced by:

* expr

##
![rr-2.0](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8%2F9hAAAAIGNIUk0AAHomAACAhAAA%2BgAAAIDoAAB1MAAA6mAAADqYAAAXcJy6UTwAAAAEZ0FNQQAAsY58%2B1GTAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A%2FwD%2FoL2nkwAAAAlwSFlzAAAOxAAADsQBlSsOGwAAAltJREFUeNp1k21IU2EUx393u0aslxlDrDTLZJUaUmREYBIIlpqQ5YciikAoKiIJihgk6JcWRBlpnwr6EOWHiOiN3j6ZMOd068WXZW8SpEY22LI1N7fb8%2BzmcroO3Av33P%2FvnPOccx6FGaa5KfD%2F5LjjNbVaDDMKRCIEghN0bi6iYUU17ul6JQF2kyaEV5%2B7qFMNKCXrwDT3n9A%2FDu1uNKPKk8oydiqFhBMBJGy%2FwaeBIbJbTsGCeaS0WAxONsehH5cayVKsTBjkj8gkLRLu%2BwgXb%2BnCVHDTNejwwGQUS08XbdJvlGd%2B6uD6kV0ovgA8aIdRH5SuF5mUZPjhS6guhXPHwNXH6jY794wn9tA0OsbGgpU6JOHpQTQtGT5bBwZRdziC8s3HItXZy26DyGRrBfN8qN%2BrZ5VBJCyfRx06XFsGZ1p03YFK8LynXBXlpY%2BHYG0eDH6BkTE9iwRlVmk7tui%2B7gFYmgFpKrwT2jQjCw1TcxQl4fNDXvbfsWr%2Fn4R3CIrz9W81HCWwfAmWjHTIz4W3H%2BB%2Bu162zCxNViIbum87bN0gjiP8bq%2BYhlgwNRTCuSqHSnmunMWzGxZfFkXvibSpJuZmwc3HeIwX6vE6%2BzlkXYaSqtsSTjUdwWixKEeNzbcZOVjFptY7WF84k%2BHEvs8IMiwaHQzSub8BW1y2rYIauZ7issyCp0z65L%2BqEvj6Hb9BoyK%2BifLVeIWo4y6XM00UuvpZI5ck05IcICq639ULv37jyLZQfPg8%2FqTbmLiVPRS9GcT2eZjyOSrm%2BNZN4hcjfmU2Ya85zbPp%2Bj%2Fv7PhdECerqgAAAABJRU5ErkJggg%3D%3D) <sup>generated by [RR - Railroad Diagram Generator][RR]</sup>

[RR]: http://bottlecaps.de/rr/ui
